/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").
 * You may not use this file except in compliance with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */
/*
 * Copyright 2008 Sun Microsystems, Inc.  All rights reserved.
 * Use is subject to license terms.
 */
/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2006 Unicode, Inc. All rights reserved. Distributed under
 * the Terms of Use in http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation (the
 * "Data Files") or Unicode software and any associated documentation (the
 * "Software") to deal in the Data Files or Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, and/or sell copies of the Data Files or Software, and
 * to permit persons to whom the Data Files or Software are furnished to do so,
 * provided that (a) the above copyright notice(s) and this permission notice
 * appear with all copies of the Data Files or Software, (b) both the above
 * copyright notice(s) and this permission notice appear in associated
 * documentation, and (c) there is clear notice in each modified Data File or
 * in the Software as well as in the documentation associated with the Data
 * File(s) or Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
 * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
 * THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS
 * INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR
 * CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE
 * OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder shall not
 * be used in advertising or otherwise to promote the sale, use or other
 * dealings in these Data Files or Software without prior written authorization
 * of the copyright holder.
 *
 * Unicode and the Unicode logo are trademarks of Unicode, Inc., and may be
 * registered in some jurisdictions. All other trademarks and registered
 * trademarks mentioned herein are the property of their respective owners.
 */
/*
 * This file has been modified by Sun Microsystems, Inc.
 */

#ifndef _SYS_KICONV_UTF8_EUCTW_H
#define	_SYS_KICONV_UTF8_EUCTW_H

#ifdef __cplusplus
extern "C" {
#endif

#ifdef	_KERNEL

/* Maximum mapping number from UTF-8 to EUC-TW. */
#define	KICONV_UTF8_EUCTW_MAX		(55442)

/*
 * Unicode (UTF-8) to CNS 11643 mapping table
 * (some characters are missing;
 * includes plane 1/2/14, i.e. cnscode begins with 21/22/2e;
 * supports CNS11643-86 only, CNS11643-92 not yet supported)
 *
 * support Unicode 3.2 and mapping source is Unihan-3.2.0.txt
 */
static kiconv_table_t kiconv_utf8_euctw[] = {
	{ 0x0000, 0x0003F },	/* Special entry for non-identical conv. */
	{ 0xC2A7, 0x1A1F0 },
	{ 0xC2B0, 0x1A2F8 },
	{ 0xC2B1, 0x1A2B4 },
	{ 0xC2B7, 0x1A1B1 },
	{ 0xC397, 0x1A2B2 },
	{ 0xC3B7, 0x1A2B3 },
	{ 0xCB87, 0x1A5EF },
	{ 0xCB89, 0x1A5ED },
	{ 0xCB8A, 0x1A5EE },
	{ 0xCB8B, 0x1A5F0 },
	{ 0xCB99, 0x1A5EC },
	{ 0xCE91, 0x1A4F5 },
	{ 0xCE92, 0x1A4F6 },
	{ 0xCE93, 0x1A4F7 },
	{ 0xCE94, 0x1A4F8 },
	{ 0xCE95, 0x1A4F9 },
	{ 0xCE96, 0x1A4FA },
	{ 0xCE97, 0x1A4FB },
	{ 0xCE98, 0x1A4FC },
	{ 0xCE99, 0x1A4FD },
	{ 0xCE9A, 0x1A4FE },
	{ 0xCE9B, 0x1A5A1 },
	{ 0xCE9C, 0x1A5A2 },
	{ 0xCE9D, 0x1A5A3 },
	{ 0xCE9E, 0x1A5A4 },
	{ 0xCE9F, 0x1A5A5 },
	{ 0xCEA0, 0x1A5A6 },
	{ 0xCEA1, 0x1A5A7 },
	{ 0xCEA3, 0x1A5A8 },
	{ 0xCEA4, 0x1A5A9 },
	{ 0xCEA5, 0x1A5AA },
	{ 0xCEA6, 0x1A5AB },
	{ 0xCEA7, 0x1A5AC },
	{ 0xCEA8, 0x1A5AD },
	{ 0xCEA9, 0x1A5AE },
	{ 0xCEB1, 0x1A5AF },
	{ 0xCEB2, 0x1A5B0 },
	{ 0xCEB3, 0x1A5B1 },
	{ 0xCEB4, 0x1A5B2 },
	{ 0xCEB5, 0x1A5B3 },
	{ 0xCEB6, 0x1A5B4 },
	{ 0xCEB7, 0x1A5B5 },
	{ 0xCEB8, 0x1A5B6 },
	{ 0xCEB9, 0x1A5B7 },
	{ 0xCEBA, 0x1A5B8 },
	{ 0xCEBB, 0x1A5B9 },
	{ 0xCEBC, 0x1A5BA },
	{ 0xCEBD, 0x1A5BB },
	{ 0xCEBE, 0x1A5BC },
	{ 0xCEBF, 0x1A5BD },
	{ 0xCF80, 0x1A5BE },
	{ 0xCF81, 0x1A5BF },
	{ 0xCF83, 0x1A5C0 },
	{ 0xCF84, 0x1A5C1 },
	{ 0xCF85, 0x1A5C2 },
	{ 0xCF86, 0x1A5C3 },
	{ 0xCF87, 0x1A5C4 },
	{ 0xCF88, 0x1A5C5 },
	{ 0xCF89, 0x1A5C6 },
	{ 0xE28093, 0x1A1B9 },
	{ 0xE28094, 0x1A1B7 },
	{ 0xE28096, 0x1A2DD },
	{ 0xE28098, 0x1A1E4 },
	{ 0xE28099, 0x1A1E5 },
	{ 0xE2809C, 0x1A1E6 },
	{ 0xE2809D, 0x1A1E7 },
	{ 0xE280A5, 0x1A1AD },
	{ 0xE280A6, 0x1A1AC },
	{ 0xE280B2, 0x1A1EA },
	{ 0xE280B5, 0x1A1EB },
	{ 0xE280BB, 0x1A1EF },
	{ 0xE280BE, 0x1A2A3 },
	{ 0xE28483, 0x1A2EA },
	{ 0xE28485, 0x1A2A2 },
	{ 0xE28489, 0x1A2EB },
	{ 0xE285A0, 0x1A4AB },
	{ 0xE285A1, 0x1A4AC },
	{ 0xE285A2, 0x1A4AD },
	{ 0xE285A3, 0x1A4AE },
	{ 0xE285A4, 0x1A4AF },
	{ 0xE285A5, 0x1A4B0 },
	{ 0xE285A6, 0x1A4B1 },
	{ 0xE285A7, 0x1A4B2 },
	{ 0xE285A8, 0x1A4B3 },
	{ 0xE285A9, 0x1A4B4 },
	{ 0xE285B0, 0x1A6B5 },
	{ 0xE285B1, 0x1A6B6 },
	{ 0xE285B2, 0x1A6B7 },
	{ 0xE285B3, 0x1A6B8 },
	{ 0xE285B4, 0x1A6B9 },
	{ 0xE285B5, 0x1A6BA },
	{ 0xE285B6, 0x1A6BB },
	{ 0xE285B7, 0x1A6BC },
	{ 0xE285B8, 0x1A6BD },
	{ 0xE285B9, 0x1A6BE },
	{ 0xE28690, 0x1A2D8 },
	{ 0xE28691, 0x1A2D5 },
	{ 0xE28692, 0x1A2D7 },
	{ 0xE28693, 0x1A2D6 },
	{ 0xE28696, 0x1A2D9 },
	{ 0xE28697, 0x1A2DA },
	{ 0xE28698, 0x1A2DC },
	{ 0xE28699, 0x1A2DB },
	{ 0xE28895, 0x1A2E1 },
	{ 0xE2889A, 0x1A2B5 },
	{ 0xE2889E, 0x1A2BC },
	{ 0xE2889F, 0x1A2C9 },
	{ 0xE288A0, 0x1A2C8 },
	{ 0xE288A9, 0x1A2C5 },
	{ 0xE288AA, 0x1A2C6 },
	{ 0xE288AB, 0x1A2CD },
	{ 0xE288AE, 0x1A2CE },
	{ 0xE288B4, 0x1A2D0 },
	{ 0xE288B5, 0x1A2CF },
	{ 0xE288BC, 0x1A2C4 },
	{ 0xE28992, 0x1A2BD },
	{ 0xE289A0, 0x1A2BB },
	{ 0xE289A1, 0x1A2BE },
	{ 0xE289A6, 0x1A2B9 },
	{ 0xE289A7, 0x1A2BA },
	{ 0xE28AA5, 0x1A2C7 },
	{ 0xE28ABF, 0x1A2CA },
	{ 0xE29080, 0x1C2A1 },
	{ 0xE29081, 0x1C2A2 },
	{ 0xE29082, 0x1C2A3 },
	{ 0xE29083, 0x1C2A4 },
	{ 0xE29084, 0x1C2A5 },
	{ 0xE29085, 0x1C2A6 },
	{ 0xE29086, 0x1C2A7 },
	{ 0xE29087, 0x1C2A8 },
	{ 0xE29088, 0x1C2A9 },
	{ 0xE29089, 0x1C2AA },
	{ 0xE2908A, 0x1C2AB },
	{ 0xE2908B, 0x1C2AC },
	{ 0xE2908C, 0x1C2AD },
	{ 0xE2908D, 0x1C2AE },
	{ 0xE2908E, 0x1C2AF },
	{ 0xE2908F, 0x1C2B0 },
	{ 0xE29090, 0x1C2B1 },
	{ 0xE29091, 0x1C2B2 },
	{ 0xE29092, 0x1C2B3 },
	{ 0xE29093, 0x1C2B4 },
	{ 0xE29094, 0x1C2B5 },
	{ 0xE29095, 0x1C2B6 },
	{ 0xE29096, 0x1C2B7 },
	{ 0xE29097, 0x1C2B8 },
	{ 0xE29098, 0x1C2B9 },
	{ 0xE29099, 0x1C2BA },
	{ 0xE2909A, 0x1C2BB },
	{ 0xE2909B, 0x1C2BC },
	{ 0xE2909C, 0x1C2BD },
	{ 0xE2909D, 0x1C2BE },
	{ 0xE2909E, 0x1C2BF },
	{ 0xE2909F, 0x1C2C0 },
	{ 0xE290A1, 0x1C2C1 },
	{ 0xE291A0, 0x1A6A1 },
	{ 0xE291A1, 0x1A6A2 },
	{ 0xE291A2, 0x1A6A3 },
	{ 0xE291A3, 0x1A6A4 },
	{ 0xE291A4, 0x1A6A5 },
	{ 0xE291A5, 0x1A6A6 },
	{ 0xE291A6, 0x1A6A7 },
	{ 0xE291A7, 0x1A6A8 },
	{ 0xE291A8, 0x1A6A9 },
	{ 0xE291A9, 0x1A6AA },
	{ 0xE291B4, 0x1A6AB },
	{ 0xE291B5, 0x1A6AC },
	{ 0xE291B6, 0x1A6AD },
	{ 0xE291B7, 0x1A6AE },
	{ 0xE291B8, 0x1A6AF },
	{ 0xE291B9, 0x1A6B0 },
	{ 0xE291BA, 0x1A6B1 },
	{ 0xE291BB, 0x1A6B2 },
	{ 0xE291BC, 0x1A6B3 },
	{ 0xE291BD, 0x1A6B4 },
	{ 0xE29480, 0x1A3B9 },
	{ 0xE29482, 0x1A3BA },
	{ 0xE2948C, 0x1A3BC },
	{ 0xE29490, 0x1A3BD },
	{ 0xE29494, 0x1A3BE },
	{ 0xE29498, 0x1A3BF },
	{ 0xE2949C, 0x1A3B7 },
	{ 0xE294A4, 0x1A3B6 },
	{ 0xE294AC, 0x1A3B5 },
	{ 0xE294B4, 0x1A3B4 },
	{ 0xE294BC, 0x1A3B3 },
	{ 0xE29590, 0x1A3C4 },
	{ 0xE2959E, 0x1A3C5 },
	{ 0xE295A1, 0x1A3C7 },
	{ 0xE295AA, 0x1A3C6 },
	{ 0xE295AD, 0x1A3C0 },
	{ 0xE295AE, 0x1A3C1 },
	{ 0xE295AF, 0x1A3C3 },
	{ 0xE295B0, 0x1A3C2 },
	{ 0xE295B1, 0x1A3CC },
	{ 0xE295B2, 0x1A3CD },
	{ 0xE295B3, 0x1A3CE },
	{ 0xE29681, 0x1A3A4 },
	{ 0xE29682, 0x1A3A5 },
	{ 0xE29683, 0x1A3A6 },
	{ 0xE29684, 0x1A3A7 },
	{ 0xE29685, 0x1A3A8 },
	{ 0xE29686, 0x1A3A9 },
	{ 0xE29687, 0x1A3AA },
	{ 0xE29688, 0x1A3AB },
	{ 0xE29689, 0x1A3B2 },
	{ 0xE2968A, 0x1A3B1 },
	{ 0xE2968B, 0x1A3B0 },
	{ 0xE2968C, 0x1A3AF },
	{ 0xE2968D, 0x1A3AE },
	{ 0xE2968E, 0x1A3AD },
	{ 0xE2968F, 0x1A3AC },
	{ 0xE29694, 0x1A3B8 },
	{ 0xE29695, 0x1A3BB },
	{ 0xE296A0, 0x1A1FC },
	{ 0xE296A1, 0x1A1FB },
	{ 0xE296B2, 0x1A1F5 },
	{ 0xE296B3, 0x1A1F4 },
	{ 0xE296BC, 0x1A1FE },
	{ 0xE296BD, 0x1A1FD },
	{ 0xE29786, 0x1A1FA },
	{ 0xE29787, 0x1A1F9 },
	{ 0xE2978B, 0x1A1F2 },
	{ 0xE2978E, 0x1A1F6 },
	{ 0xE2978F, 0x1A1F3 },
	{ 0xE297A2, 0x1A3C8 },
	{ 0xE297A3, 0x1A3C9 },
	{ 0xE297A4, 0x1A3CB },
	{ 0xE297A5, 0x1A3CA },
	{ 0xE29885, 0x1A1F8 },
	{ 0xE29886, 0x1A1F7 },
	{ 0xE29889, 0x1A2D4 },
	{ 0xE29980, 0x1A2D1 },
	{ 0xE29981, 0x1A2D3 },
	{ 0xE29982, 0x1A2D2 },
	{ 0xE38080, 0x1A1A1 },
	{ 0xE38081, 0x1A1A3 },
	{ 0xE38082, 0x1A1A4 },
	{ 0xE38083, 0x1A1F1 },
	{ 0xE38088, 0x1A1D2 },
	{ 0xE38089, 0x1A1D3 },
	{ 0xE3808A, 0x1A1CE },
	{ 0xE3808B, 0x1A1CF },
	{ 0xE3808C, 0x1A1D6 },
	{ 0xE3808D, 0x1A1D7 },
	{ 0xE3808E, 0x1A1DA },
	{ 0xE3808F, 0x1A1DB },
	{ 0xE38090, 0x1A1CA },
	{ 0xE38091, 0x1A1CB },
	{ 0xE38092, 0x1A2E5 },
	{ 0xE38094, 0x1A1C6 },
	{ 0xE38095, 0x1A1C7 },
	{ 0xE3809D, 0x1A1E8 },
	{ 0xE3809E, 0x1A1E9 },
	{ 0xE380A1, 0x1A4B5 },
	{ 0xE380A2, 0x1A4B6 },
	{ 0xE380A3, 0x1A4B7 },
	{ 0xE380A4, 0x1A4B8 },
	{ 0xE380A5, 0x1A4B9 },
	{ 0xE380A6, 0x1A4BA },
	{ 0xE380A7, 0x1A4BB },
	{ 0xE380A8, 0x1A4BC },
	{ 0xE380A9, 0x1A4BD },
	{ 0xE383BB, 0x1A1A6 },
	{ 0xE38485, 0x1A5C7 },
	{ 0xE38486, 0x1A5C8 },
	{ 0xE38487, 0x1A5C9 },
	{ 0xE38488, 0x1A5CA },
	{ 0xE38489, 0x1A5CB },
	{ 0xE3848A, 0x1A5CC },
	{ 0xE3848B, 0x1A5CD },
	{ 0xE3848C, 0x1A5CE },
	{ 0xE3848D, 0x1A5CF },
	{ 0xE3848E, 0x1A5D0 },
	{ 0xE3848F, 0x1A5D1 },
	{ 0xE38490, 0x1A5D2 },
	{ 0xE38491, 0x1A5D3 },
	{ 0xE38492, 0x1A5D4 },
	{ 0xE38493, 0x1A5D5 },
	{ 0xE38494, 0x1A5D6 },
	{ 0xE38495, 0x1A5D7 },
	{ 0xE38496, 0x1A5D8 },
	{ 0xE38497, 0x1A5D9 },
	{ 0xE38498, 0x1A5DA },
	{ 0xE38499, 0x1A5DB },
	{ 0xE3849A, 0x1A5DC },
	{ 0xE3849B, 0x1A5DD },
	{ 0xE3849C, 0x1A5DE },
	{ 0xE3849D, 0x1A5DF },
	{ 0xE3849E, 0x1A5E0 },
	{ 0xE3849F, 0x1A5E1 },
	{ 0xE384A0, 0x1A5E2 },
	{ 0xE384A1, 0x1A5E3 },
	{ 0xE384A2, 0x1A5E4 },
	{ 0xE384A3, 0x1A5E5 },
	{ 0xE384A4, 0x1A5E6 },
	{ 0xE384A5, 0x1A5E7 },
	{ 0xE384A6, 0x1A5E8 },
	{ 0xE384A7, 0x1A5E9 },
	{ 0xE384A8, 0x1A5EA },
	{ 0xE384A9, 0x1A5EB },
	{ 0xE38AA3, 0x1A2A1 },
	{ 0xE38E8E, 0x1A2F5 },
	{ 0xE38E8F, 0x1A2F6 },
	{ 0xE38E9C, 0x1A2F0 },
	{ 0xE38E9D, 0x1A2F1 },
	{ 0xE38E9E, 0x1A2F2 },
	{ 0xE38EA1, 0x1A2F4 },
	{ 0xE38F84, 0x1A2F7 },
	{ 0xE38F8E, 0x1A2F3 },
	{ 0xE38F91, 0x1A2CC },
	{ 0xE38F92, 0x1A2CB },
	{ 0xE38F95, 0x1A2EF },
	{ 0xE39080, 0x6A2AC },
	{ 0xE39081, 0x4A2A4 },
	{ 0xE39084, 0x6A1B0 },
	{ 0xE39085, 0x6A1A3 },
	{ 0xE39086, 0xFA1EC },
	{ 0xE3908C, 0x4A1D7 },
	{ 0xE39096, 0x4A3B6 },
	{ 0xE3909C, 0x4A8B5 },
	{ 0xE390A1, 0x3B4BB },
	{ 0xE390A4, 0x3B9ED },
	{ 0xE390A8, 0x3A7C1 },
	{ 0xE390A9, 0x3A8EC },
	{ 0xE390AB, 0x3A3A3 },
	{ 0xE390AC, 0x4A3B7 },
	{ 0xE390AD, 0x4A5B4 },
	{ 0xE390AE, 0x3C0B4 },
	{ 0xE390B0, 0x4A1D9 },
	{ 0xE390B1, 0x3A1F5 },
	{ 0xE390B2, 0x3A1EE },
	{ 0xE390B3, 0x3A1F1 },
	{ 0xE390B4, 0x3A1F3 },
	{ 0xE390B6, 0xFA1C4 },
	{ 0xE390B8, 0x6A3CE },
	{ 0xE390B9, 0x3A2F1 },
	{ 0xE390BA, 0x4A2B1 },
	{ 0xE390BB, 0x3A2E9 },
	{ 0xE390BC, 0x3A2EA },
	{ 0xE390BE, 0xFA1F2 },
	{ 0xE39181, 0x5A3B4 },
	{ 0xE39182, 0x3A4CA },
	{ 0xE39183, 0x3A4C7 },
	{ 0xE39184, 0x3A4CD },
	{ 0xE39185, 0x6A5F1 },
	{ 0xE39189, 0x3A7C6 },
	{ 0xE3918A, 0x5A5A5 },
	{ 0xE3918B, 0x4A5B9 },
	{ 0xE3918C, 0x4A5BC },
	{ 0xE3918D, 0x3A7C5 },
	{ 0xE3918E, 0x5A5AB },
	{ 0xE3918F, 0x4A5BB },
	{ 0xE39190, 0x4A5B8 },
	{ 0xE39191, 0x3A7D0 },
	{ 0xE39193, 0xFA5CA },
	{ 0xE39197, 0x3ABB1 },
	{ 0xE39198, 0x6AEDA },
	{ 0xE39199, 0x4A8B9 },
	{ 0xE3919A, 0x3ABB0 },
	{ 0xE3919B, 0x5A8A1 },
	{ 0xE3919C, 0x4A8BA },
	{ 0xE3919D, 0x3ABAA },
	{ 0xE3919E, 0x4A8B7 },
	{ 0xE3919F, 0x4A8BC },
	{ 0xE391A3, 0x5ABEC },
	{ 0xE391A4, 0x3B4C9 },
	{ 0xE391A5, 0x3AFD2 },
	{ 0xE391A6, 0x4ABE5 },
	{ 0xE391A7, 0x6B5B8 },
	{ 0xE391AE, 0x4B0C5 },
	{ 0xE391AF, 0x3B4BE },
	{ 0xE391B0, 0x3B4C8 },
	{ 0xE391B1, 0x4B0CA },
	{ 0xE391B3, 0x4B6B8 },
	{ 0xE391B4, 0x3B9F3 },
	{ 0xE391B5, 0x4B6B2 },
	{ 0xE391B6, 0x4B6B7 },
	{ 0xE391B7, 0x6C6D5 },
	{ 0xE391B9, 0x6C9FB },
	{ 0xE391BA, 0x3B9F4 },
	{ 0xE391BB, 0x3C0B5 },
	{ 0xE391BC, 0x3C0B8 },
	{ 0xE391BD, 0x3C0BB },
	{ 0xE391BE, 0x4BCAC },
	{ 0xE391BF, 0x4BCAD },
	{ 0xE39280, 0x4BCA8 },
	{ 0xE39281, 0x4BCAA },
	{ 0xE39282, 0x5C4D7 },
	{ 0xE39283, 0x4C2B7 },
	{ 0xE39284, 0x4C2B3 },
	{ 0xE39285, 0x4C2AE },
	{ 0xE39286, 0x3C5F8 },
	{ 0xE39287, 0x6DAF3 },
	{ 0xE39288, 0x4C2AF },
	{ 0xE39289, 0x3C5F3 },
	{ 0xE3928A, 0x4CFD9 },
	{ 0xE3928B, 0x3C5F2 },
	{ 0xE3928C, 0x3C5EF },
	{ 0xE3928D, 0x3C5F7 },
	{ 0xE3928E, 0x4C2B2 },
	{ 0xE39291, 0x4C8FB },
	{ 0xE39292, 0x3CBA6 },
	{ 0xE39293, 0x3CBA5 },
	{ 0xE39294, 0x4C8FD },
	{ 0xE39295, 0x3CBA4 },
	{ 0xE39296, 0x3CBA8 },
	{ 0xE39297, 0x3CBAA },
	{ 0xE39299, 0x3D0B2 },
	{ 0xE3929A, 0x4CFDD },
	{ 0xE3929B, 0x5D3D9 },
	{ 0xE3929C, 0x4CFDB },
	{ 0xE3929D, 0x3D4BF },
	{ 0xE3929E, 0x3D7D3 },
	{ 0xE3929F, 0x4DAE7 },
	{ 0xE392A0, 0x4DAE8 },
	{ 0xE392A1, 0x4DFC9 },
	{ 0xE392A4, 0x4E3AF },
	{ 0xE392A5, 0x3DCB3 },
	{ 0xE392A6, 0x3DCB1 },
	{ 0xE392A7, 0x7D2F4 },
	{ 0xE392A8, 0x7D7CC },
	{ 0xE392A9, 0x4EAC1 },
	{ 0xE392AA, 0x3E1BC },
	{ 0xE392AB, 0x4A2B3 },
	{ 0xE392AC, 0xFA6DA },
	{ 0xE392AD, 0x4ABE9 },
	{ 0xE392AF, 0x3D7D4 },
	{ 0xE392B0, 0x3A1F6 },
	{ 0xE392B2, 0x3A2F9 },
	{ 0xE392B3, 0x3A4D5 },
	{ 0xE392B4, 0x5A3B7 },
	{ 0xE392B5, 0x6A5FB },
	{ 0xE392B6, 0x6A5FD },
	{ 0xE392B7, 0x3A4D6 },
	{ 0xE392B8, 0x3ABB8 },
	{ 0xE392B9, 0x7CDBD },
	{ 0xE392BA, 0x3AACC },
	{ 0xE392BB, 0x4B0CC },
	{ 0xE392BC, 0x5B1A6 },
	{ 0xE392BD, 0x4B6BD },
	{ 0xE392BE, 0x4BCB2 },
	{ 0xE392BF, 0x4EAC2 },
	{ 0xE39382, 0x3ABBA },
	{ 0xE39383, 0x3B9F8 },
	{ 0xE39384, 0x4C9A2 },
	{ 0xE39385, 0x3A1D0 },
	{ 0xE39387, 0x3A3A1 },
	{ 0xE39388, 0x3A4D8 },
	{ 0xE39389, 0x5A5AE },
	{ 0xE3938A, 0x3A7D7 },
	{ 0xE3938B, 0x3A7D6 },
	{ 0xE3938C, 0x3A7D8 },
	{ 0xE3938E, 0x4A8C3 },
	{ 0xE3938F, 0x3ABBC },
	{ 0xE39390, 0x3AFDD },
	{ 0xE39391, 0x3AFDC },
	{ 0xE39393, 0x4B0CD },
	{ 0xE39394, 0x3B9FB },
	{ 0xE39395, 0x3B9FC },
	{ 0xE39396, 0x4BCB4 },
	{ 0xE39397, 0x3C5F9 },
	{ 0xE39398, 0x5B1A9 },
	{ 0xE3939A, 0x4A1E1 },
	{ 0xE3939B, 0x6A2C1 },
	{ 0xE3939C, 0x3A1FE },
	{ 0xE3939D, 0x4A2BC },
	{ 0xE3939E, 0x5A2B0 },
	{ 0xE3939F, 0x4A3BE },
	{ 0xE393A0, 0x4A3BF },
	{ 0xE393A1, 0x4A5CA },
	{ 0xE393A2, 0x4A5CC },
	{ 0xE393A3, 0x4A5C8 },
	{ 0xE393A4, 0x4A5C7 },
	{ 0xE393A7, 0x3ABC1 },
	{ 0xE393A8, 0x3ABC5 },
	{ 0xE393A9, 0x3ABC2 },
	{ 0xE393AC, 0x5ABFC },
	{ 0xE393AD, 0x4B0D3 },
	{ 0xE393AE, 0x3AFE7 },
	{ 0xE393AF, 0x3AFE9 },
	{ 0xE393B1, 0x4B0D7 },
	{ 0xE393B2, 0x4B0D8 },
	{ 0xE393B3, 0x4B0D2 },
	{ 0xE393B4, 0x5B1AC },
	{ 0xE393B5, 0x4B0D4 },
	{ 0xE393B6, 0x4B0D9 },
	{ 0xE393B7, 0x3BAA4 },
	{ 0xE393B8, 0x6D0EC },
	{ 0xE393B9, 0x4B6C2 },
	{ 0xE393BA, 0x4B6C5 },
	{ 0xE393BB, 0x3BAA2 },
	{ 0xE393BC, 0x5BDF0 },
	{ 0xE393BD, 0x3C0C2 },
	{ 0xE393BE, 0x4C2C1 },
	{ 0xE39480, 0x4C2C3 },
	{ 0xE39481, 0x4C2C2 },
	{ 0xE39482, 0x4C2BC },
	{ 0xE39483, 0x3C5FD },
	{ 0xE39484, 0x3C5FB },
	{ 0xE39485, 0x4C2BF },
	{ 0xE39486, 0x4C2BE },
	{ 0xE39487, 0x3C5FC },
	{ 0xE3948A, 0x4C9A3 },
	{ 0xE3948B, 0x4CFE2 },
	{ 0xE3948C, 0x4CFE1 },
	{ 0xE3948D, 0x4CFE3 },
	{ 0xE3948E, 0x5E1BB },
	{ 0xE3948F, 0x4D5EC },
	{ 0xE39490, 0x7BEFD },
	{ 0xE39491, 0x4DFCA },
	{ 0xE39492, 0x4E3B0 },
	{ 0xE39493, 0x4A1E4 },
	{ 0xE39495, 0x4A2C0 },
	{ 0xE39497, 0x4A3C4 },
	{ 0xE39498, 0x3A4E4 },
	{ 0xE39499, 0x4A5CF },
	{ 0xE3949A, 0x6A9EF },
	{ 0xE3949C, 0x6AFA7 },
	{ 0xE3949D, 0x4ABF5 },
	{ 0xE3949E, 0x3AFEB },
	{ 0xE394A0, 0x4B0DA },
	{ 0xE394A1, 0x4B6CB },
	{ 0xE394A2, 0x3C6A2 },
	{ 0xE394A3, 0x4D5EF },
	{ 0xE394A4, 0x3D4C3 },
	{ 0xE394A5, 0x4D5F0 },
	{ 0xE394A6, 0x5D3E3 },
	{ 0xE394A7, 0x4DAEE },
	{ 0xE394A8, 0x4B0DC },
	{ 0xE394A9, 0x4B6CD },
	{ 0xE394AA, 0x5BDF8 },
	{ 0xE394AC, 0x6A9F2 },
	{ 0xE394AD, 0x3B4D3 },
	{ 0xE394AE, 0x5F0F8 },
	{ 0xE394AF, 0x4A3CB },
	{ 0xE394B0, 0x6A6B8 },
	{ 0xE394B1, 0x4ABF7 },
	{ 0xE394B2, 0x3BAA5 },
	{ 0xE394B3, 0x6D0F6 },
	{ 0xE394B4, 0x4BCBE },
	{ 0xE394B5, 0x5C4EC },
	{ 0xE394B6, 0x4EDD3 },
	{ 0xE394B7, 0x6A6B6 },
	{ 0xE394B8, 0x4B6D0 },
	{ 0xE394B9, 0x3A1D8 },
	{ 0xE394BA, 0x6A3F1 },
	{ 0xE394BB, 0x3A3AC },
	{ 0xE394BC, 0x6D0FA },
	{ 0xE394BD, 0x3A7E4 },
	{ 0xE394BE, 0x4A1AB },
	{ 0xE394BF, 0x6A1BB },
	{ 0xE39580, 0x6A8E4 },
	{ 0xE39581, 0x4A5D6 },
	{ 0xE39582, 0x3A3B0 },
	{ 0xE39583, 0x5A2BC },
	{ 0xE39584, 0x3A3AE },
	{ 0xE39585, 0x3A4EA },
	{ 0xE39586, 0x3A4E9 },
	{ 0xE39587, 0x3A4E8 },
	{ 0xE39588, 0x3A7E8 },
	{ 0xE39589, 0x6AAAA },
	{ 0xE3958A, 0x3ABCC },
	{ 0xE3958B, 0x3AFF0 },
	{ 0xE3958C, 0x4ABFA },
	{ 0xE3958D, 0x3AFF1 },
	{ 0xE3958E, 0x4B6D1 },
	{ 0xE3958F, 0x6D1A2 },
	{ 0xE39590, 0x5CCB1 },
	{ 0xE39591, 0x3C6A4 },
	{ 0xE39592, 0x4C9A7 },
	{ 0xE39594, 0x3E0F0 },
	{ 0xE39595, 0x3A1DD },
	{ 0xE39596, 0x3AFF2 },
	{ 0xE39597, 0x6BDE1 },
	{ 0xE39598, 0x3B4D6 },
	{ 0xE39599, 0x4C9A9 },
	{ 0xE3959A, 0x5A1C1 },
	{ 0xE3959B, 0x3A1DF },
	{ 0xE3959C, 0x3A3B2 },
	{ 0xE3959E, 0x4A5DA },
	{ 0xE3959F, 0x4A8D7 },
	{ 0xE395A0, 0x3BFF8 },
	{ 0xE395A1, 0x3C6A7 },
	{ 0xE395A2, 0x4C7D6 },
	{ 0xE395A3, 0x4A1EB },
	{ 0xE395A4, 0x3A2B0 },
	{ 0xE395A5, 0x3A2AC },
	{ 0xE395A6, 0x3A3B8 },
	{ 0xE395A7, 0x3A3B6 },
	{ 0xE395A9, 0x3A4EC },
	{ 0xE395AA, 0x4A3D1 },
	{ 0xE395AB, 0x3A4EB },
	{ 0xE395AC, 0x3A4F1 },
	{ 0xE395AD, 0x4A3D4 },
	{ 0xE395AE, 0x4A3D9 },
	{ 0xE395AF, 0x3A4F2 },
	{ 0xE395B0, 0x4A3D3 },
	{ 0xE395B1, 0x3A4EF },
	{ 0xE395B2, 0x3A4EE },
	{ 0xE395B3, 0x3A4FA },
	{ 0xE395B5, 0xFA3C9 },
	{ 0xE395B6, 0x3A5A5 },
	{ 0xE395B7, 0x3A7FA },
	{ 0xE395B8, 0x3A7ED },
	{ 0xE395B9, 0x4A5DD },
	{ 0xE395BA, 0x3A7F6 },
	{ 0xE395BB, 0x5A5C2 },
	{ 0xE395BC, 0x6AAB9 },
	{ 0xE39680, 0x3ABD2 },
	{ 0xE39681, 0x3ABE0 },
	{ 0xE39682, 0x3ABDF },
	{ 0xE39683, 0x3ABE2 },
	{ 0xE39684, 0x3ABDA },
	{ 0xE39685, 0x4A8D9 },
	{ 0xE39686, 0x4A8DC },
	{ 0xE39687, 0x3ABD6 },
	{ 0xE39688, 0xFA9DC },
	{ 0xE3968F, 0x4ACA5 },
	{ 0xE39690, 0x3AFFD },
	{ 0xE39691, 0x4ABFE },
	{ 0xE39692, 0x3AFF5 },
	{ 0xE39693, 0x3AFFC },
	{ 0xE39694, 0x4ACA1 },
	{ 0xE39695, 0x4ABFD },
	{ 0xE39696, 0x6B5FD },
	{ 0xE39697, 0x3B0A4 },
	{ 0xE39698, 0x5ACC3 },
	{ 0xE3969F, 0x3B4DD },
	{ 0xE396A0, 0x3B4E5 },
	{ 0xE396A1, 0x4B0EA },
	{ 0xE396A2, 0x5B6F0 },
	{ 0xE396A3, 0x3B4E3 },
	{ 0xE396A4, 0x3B4DC },
	{ 0xE396A5, 0x4B0F0 },
	{ 0xE396A6, 0x3B4DA },
	{ 0xE396A7, 0x4B0F3 },
	{ 0xE396A8, 0x4B0F1 },
	{ 0xE396A9, 0x4B0ED },
	{ 0xE396AA, 0x4B0EC },
	{ 0xE396AB, 0xFB3C3 },
	{ 0xE396B4, 0x3B8D3 },
	{ 0xE396B5, 0x4B0EF },
	{ 0xE396B6, 0x5B6F6 },
	{ 0xE396B7, 0x3BAB2 },
	{ 0xE396B8, 0x4B6E7 },
	{ 0xE396B9, 0x3BAB5 },
	{ 0xE396BA, 0x3BAAC },
	{ 0xE396BB, 0x4B6DE },
	{ 0xE396BC, 0x4B6D9 },
	{ 0xE396BD, 0x3BAB9 },
	{ 0xE396BE, 0x3BABE },
	{ 0xE396BF, 0x3BAAD },
	{ 0xE39780, 0x4B6E0 },
	{ 0xE39781, 0x3BABD },
	{ 0xE39782, 0x4B6DF },
	{ 0xE39783, 0x3BAB7 },
	{ 0xE39784, 0x6C7B9 },
	{ 0xE39785, 0x5B6F9 },
	{ 0xE39786, 0x5B6FA },
	{ 0xE39787, 0x3BAB0 },
	{ 0xE39788, 0x4B6D8 },
	{ 0xE39789, 0x4B6E5 },
	{ 0xE3978A, 0x4B6E3 },
	{ 0xE3978B, 0x3BAC1 },
	{ 0xE3978C, 0x5B6EE },
	{ 0xE3978D, 0x3BABF },
	{ 0xE39790, 0x3BABA },
	{ 0xE39793, 0x5BEB9 },
	{ 0xE39794, 0x4BCCA },
	{ 0xE39795, 0x4BCC6 },
	{ 0xE39796, 0x3C0CF },
	{ 0xE39797, 0x5BEBD },
	{ 0xE39798, 0x4BCC7 },
	{ 0xE39799, 0x4BCCC },
	{ 0xE3979A, 0x3C0CD },
	{ 0xE3979B, 0x3C0D0 },
	{ 0xE3979C, 0x6D1B2 },
	{ 0xE397A2, 0x4C2D2 },
	{ 0xE397A3, 0x3C6B2 },
	{ 0xE397A4, 0x3C6AF },
	{ 0xE397A5, 0x3C6AD },
	{ 0xE397A6, 0x4C2CF },
	{ 0xE397A7, 0x4C2CA },
	{ 0xE397A8, 0x4C2D5 },
	{ 0xE397A9, 0x3C6AB },
	{ 0xE397AA, 0x3CBBA },
	{ 0xE397AB, 0x4C2D3 },
	{ 0xE397AC, 0x4C2D6 },
	{ 0xE397AD, 0x4C2D1 },
	{ 0xE397B0, 0x5C5A2 },
	{ 0xE397B1, 0x4C9B0 },
	{ 0xE397B2, 0x4C9AC },
	{ 0xE397B3, 0x3CBC2 },
	{ 0xE397B4, 0x4C9AD },
	{ 0xE397B5, 0x3CBB6 },
	{ 0xE397B6, 0x7A1CE },
	{ 0xE397BB, 0x4CFEB },
	{ 0xE397BC, 0x4CFEC },
	{ 0xE397BD, 0x3D0C1 },
	{ 0xE397BE, 0x4CFE7 },
	{ 0xE397BF, 0x4CFEA },
	{ 0xE39880, 0x4CFEF },
	{ 0xE39881, 0x3D0BC },
	{ 0xE39882, 0x3D0BA },
	{ 0xE39885, 0x7B7B7 },
	{ 0xE39886, 0x4D5F2 },
	{ 0xE39887, 0x3D4C6 },
	{ 0xE39888, 0x4D5F3 },
	{ 0xE39889, 0x4CFED },
	{ 0xE3988A, 0x5E1C0 },
	{ 0xE3988B, 0x4DAF0 },
	{ 0xE3988C, 0x3D7D6 },
	{ 0xE3988D, 0x5E1C5 },
	{ 0xE39890, 0x4DFCC },
	{ 0xE39891, 0x5E7D9 },
	{ 0xE39893, 0x5EBF3 },
	{ 0xE39894, 0x3DCB5 },
	{ 0xE39895, 0x3DEA7 },
	{ 0xE39896, 0x4E6B2 },
	{ 0xE39899, 0x3E0AE },
	{ 0xE3989A, 0x3E0AD },
	{ 0xE3989B, 0x4ECEC },
	{ 0xE3989C, 0x7E2AF },
	{ 0xE3989D, 0x3A2B2 },
	{ 0xE3989E, 0x3A2A1 },
	{ 0xE3989F, 0x3A3BD },
	{ 0xE398A0, 0x5A5D3 },
	{ 0xE398A1, 0x3A7FE },
	{ 0xE398A2, 0x3ABE4 },
	{ 0xE398A3, 0x3B0A6 },
	{ 0xE398A4, 0x4C2D8 },
	{ 0xE398A5, 0x4E3B2 },
	{ 0xE398A6, 0x3A2B3 },
	{ 0xE398A7, 0x3A5AE },
	{ 0xE398A8, 0x4A3DF },
	{ 0xE398A9, 0x3A5B9 },
	{ 0xE398AA, 0x3A5BA },
	{ 0xE398AB, 0x4A3DE },
	{ 0xE398AC, 0x3A5BD },
	{ 0xE398AD, 0x3A5BF },
	{ 0xE398AF, 0x3A5BB },
	{ 0xE398B0, 0x3A5B4 },
	{ 0xE398B1, 0x3A8A7 },
	{ 0xE398B2, 0x4A5ED },
	{ 0xE398B3, 0x3A8AB },
	{ 0xE398B4, 0x3A8AC },
	{ 0xE398B6, 0x3ABF6 },
	{ 0xE398B7, 0x6AFE5 },
	{ 0xE398B8, 0x3ABF4 },
	{ 0xE398B9, 0x3ABF5 },
	{ 0xE398BA, 0x3ABF3 },
	{ 0xE398BB, 0x3ABEF },
	{ 0xE398BF, 0x3B0A9 },
	{ 0xE39980, 0x4ACAF },
	{ 0xE39981, 0x4ACB1 },
	{ 0xE39982, 0x3B0AD },
	{ 0xE39983, 0x3B0AC },
	{ 0xE39984, 0x3B0AE },
	{ 0xE39985, 0x3B0B1 },
	{ 0xE39987, 0x3B4EC },
	{ 0xE39988, 0x3B4ED },
	{ 0xE39989, 0x3B4F3 },
	{ 0xE3998A, 0x3B4EA },
	{ 0xE3998B, 0xFB3D7 },
	{ 0xE3998D, 0x4B1A1 },
	{ 0xE3998E, 0x4B6EB },
	{ 0xE3998F, 0x3BAC6 },
	{ 0xE39990, 0x4B6EE },
	{ 0xE39991, 0x3BAD1 },
	{ 0xE39992, 0x6C7CE },
	{ 0xE39993, 0x3BAC8 },
	{ 0xE39995, 0x3BACD },
	{ 0xE39999, 0x4BCD9 },
	{ 0xE3999A, 0x4BCDB },
	{ 0xE3999B, 0x3C0D3 },
	{ 0xE3999C, 0x3C0D5 },
	{ 0xE3999D, 0x4BCD6 },
	{ 0xE3999E, 0x4BCD8 },
	{ 0xE399A0, 0x4C2DE },
	{ 0xE399A1, 0x4C2DD },
	{ 0xE399A2, 0x4C2DB },
	{ 0xE399A3, 0x3C6BB },
	{ 0xE399A4, 0x4C2DF },
	{ 0xE399A5, 0x3C6B9 },
	{ 0xE399A7, 0x7A1EA },
	{ 0xE399A8, 0x3CBD2 },
	{ 0xE399A9, 0x3CBC8 },
	{ 0xE399AA, 0x4C9B3 },
	{ 0xE399AB, 0x3CBCA },
	{ 0xE399AC, 0x3CBCE },
	{ 0xE399AD, 0xFCEA5 },
	{ 0xE399AE, 0xFCEAE },
	{ 0xE399AF, 0x4C9AA },
	{ 0xE399B0, 0x3D0C4 },
	{ 0xE399B1, 0x4CFF8 },
	{ 0xE399B2, 0x3D0C7 },
	{ 0xE399B3, 0x3D0C2 },
	{ 0xE399B4, 0x3D0C3 },
	{ 0xE399B5, 0x3D0C6 },
	{ 0xE399B6, 0x3D0C5 },
	{ 0xE399B7, 0x4D5FC },
	{ 0xE399B8, 0x3D4CD },
	{ 0xE399B9, 0x3D4CA },
	{ 0xE399BA, 0x4D5FB },
	{ 0xE399BB, 0x7BFB0 },
	{ 0xE399BC, 0x3D7DD },
	{ 0xE399BE, 0x7C6C4 },
	{ 0xE39A80, 0x5EBF6 },
	{ 0xE39A81, 0x3E0F2 },
	{ 0xE39A82, 0x4ECEE },
	{ 0xE39A83, 0x5B7BC },
	{ 0xE39A84, 0x3CDC1 },
	{ 0xE39A85, 0x3ABF8 },
	{ 0xE39A87, 0x4A8E1 },
	{ 0xE39A89, 0x5A5D8 },
	{ 0xE39A8A, 0x4B6F7 },
	{ 0xE39A8B, 0x4C2E0 },
	{ 0xE39A8C, 0x3C6C7 },
	{ 0xE39A8D, 0x4DAFA },
	{ 0xE39A8E, 0x3A2BA },
	{ 0xE39A8F, 0x3A3C6 },
	{ 0xE39A90, 0x3A3C8 },
	{ 0xE39A92, 0x4A3E5 },
	{ 0xE39A93, 0x3A5CA },
	{ 0xE39A94, 0x4A5F1 },
	{ 0xE39A95, 0x5A5D9 },
	{ 0xE39A96, 0x4A5F7 },
	{ 0xE39A97, 0x4A5F3 },
	{ 0xE39A98, 0x4A5F8 },
	{ 0xE39A9A, 0x3ABFD },
	{ 0xE39A9C, 0x4B1A5 },
	{ 0xE39A9D, 0x6BEC2 },
	{ 0xE39A9E, 0x3B4FA },
	{ 0xE39A9F, 0x3BAD5 },
	{ 0xE39AA0, 0x4BCDC },
	{ 0xE39AA1, 0x3D0BE },
	{ 0xE39AA2, 0x3A1F4 },
	{ 0xE39AA3, 0x3A3CC },
	{ 0xE39AA4, 0x3A3CA },
	{ 0xE39AA5, 0x4A2D6 },
	{ 0xE39AA6, 0x4A2D9 },
	{ 0xE39AA7, 0x4A2D5 },
	{ 0xE39AA8, 0x3A3C9 },
	{ 0xE39AA9, 0x3A5D2 },
	{ 0xE39AAA, 0x3A5D7 },
	{ 0xE39AAB, 0x3A5D0 },
	{ 0xE39AAC, 0x3A5CF },
	{ 0xE39AAD, 0x3A5CD },
	{ 0xE39AAE, 0x3A5D4 },
	{ 0xE39AB0, 0x3A8B1 },
	{ 0xE39AB1, 0x3A8BB },
	{ 0xE39AB2, 0x4A5FB },
	{ 0xE39AB3, 0x3A8C2 },
	{ 0xE39AB4, 0x3A8B2 },
	{ 0xE39AB5, 0x3A8BA },
	{ 0xE39AB6, 0x3A8C3 },
	{ 0xE39AB7, 0x3A8C7 },
	{ 0xE39AB8, 0x3A8B4 },
	{ 0xE39AB9, 0x4A6A1 },
	{ 0xE39ABA, 0x3A8C4 },
	{ 0xE39ABB, 0x3A8BE },
	{ 0xE39ABC, 0x3A8B6 },
	{ 0xE39ABD, 0x3A8BC },
	{ 0xE39ABE, 0x5A5DD },
	{ 0xE39ABF, 0x3A8B9 },
	{ 0xE39B81, 0x3A8B0 },
	{ 0xE39B82, 0x4A8ED },
	{ 0xE39B83, 0x4A8E9 },
	{ 0xE39B84, 0x3ABFE },
	{ 0xE39B85, 0x3ACA2 },
	{ 0xE39B89, 0xFAAAA },
	{ 0xE39B8A, 0x4A8E7 },
	{ 0xE39B8D, 0x3B0BF },
	{ 0xE39B8E, 0x3B0C2 },
	{ 0xE39B8F, 0x3B0BD },
	{ 0xE39B90, 0x3B0C9 },
	{ 0xE39B91, 0x3B0C7 },
	{ 0xE39B92, 0x4ACBB },
	{ 0xE39B93, 0x3B0C3 },
	{ 0xE39B94, 0x3B0D0 },
	{ 0xE39B95, 0x3B0CC },
	{ 0xE39B96, 0x3B0C4 },
	{ 0xE39B97, 0x4ACBF },
	{ 0xE39B98, 0x4ACBA },
	{ 0xE39B99, 0x3B0B9 },
	{ 0xE39B9A, 0x4ACBC },
	{ 0xE39B9B, 0x3B0D1 },
	{ 0xE39B9C, 0x3B0C6 },
	{ 0xE39B9D, 0x3B0C1 },
	{ 0xE39B9E, 0x3B0BA },
	{ 0xE39BA1, 0xFAEEB },
	{ 0xE39BA2, 0xFAEF8 },
	{ 0xE39BA5, 0x4B1A9 },
	{ 0xE39BA6, 0x3B5A6 },
	{ 0xE39BA7, 0x3B5AD },
	{ 0xE39BA8, 0x3B5A1 },
	{ 0xE39BA9, 0x3B5B6 },
	{ 0xE39BAA, 0x4B1A8 },
	{ 0xE39BAB, 0x3B5AC },
	{ 0xE39BAC, 0x3B5A3 },
	{ 0xE39BAD, 0x3B5A5 },
	{ 0xE39BAE, 0x3BAF1 },
	{ 0xE39BAF, 0x3BAE7 },
	{ 0xE39BB0, 0x3BAF4 },
	{ 0xE39BB1, 0x3BAE4 },
	{ 0xE39BB2, 0x3BAF6 },
	{ 0xE39BB3, 0x3BAEC },
	{ 0xE39BB4, 0x3BAEA },
	{ 0xE39BB5, 0x3BAE5 },
	{ 0xE39BB6, 0x5B7CE },
	{ 0xE39BB7, 0x3BAEE },
	{ 0xE39BB8, 0x5B7C6 },
	{ 0xE39BB9, 0x4B6FE },
	{ 0xE39BBA, 0x3BAEF },
	{ 0xE39BBB, 0x3BADF },
	{ 0xE39BBC, 0x4B6FD },
	{ 0xE39BBD, 0x3BAF0 },
	{ 0xE39BBE, 0x3BADD },
	{ 0xE39C81, 0xFBABC },
	{ 0xE39C82, 0x3BAED },
	{ 0xE39C83, 0x3BAE9 },
	{ 0xE39C84, 0x3BAE8 },
	{ 0xE39C85, 0x4BCDF },
	{ 0xE39C86, 0x3C0E2 },
	{ 0xE39C87, 0x4BCE1 },
	{ 0xE39C88, 0x3C0EE },
	{ 0xE39C89, 0x3C0ED },
	{ 0xE39C8A, 0x3C0E8 },
	{ 0xE39C8B, 0x3C0E3 },
	{ 0xE39C8C, 0x4BCE4 },
	{ 0xE39C8D, 0x3C0E5 },
	{ 0xE39C8E, 0x4BCE3 },
	{ 0xE39C8F, 0x3C0F0 },
	{ 0xE39C90, 0x3C0EB },
	{ 0xE39C91, 0x3C0EF },
	{ 0xE39C92, 0x3C0EC },
	{ 0xE39C93, 0x3C0E9 },
	{ 0xE39C95, 0x3C6CB },
	{ 0xE39C96, 0x4C2E7 },
	{ 0xE39C97, 0x4C2EC },
	{ 0xE39C98, 0x4C2E8 },
	{ 0xE39C99, 0x4C2E6 },
	{ 0xE39C9A, 0x3C6C9 },
	{ 0xE39C9B, 0x3C6D2 },
	{ 0xE39C9C, 0x3C6D1 },
	{ 0xE39C9D, 0x4C2EB },
	{ 0xE39C9E, 0x4C2ED },
	{ 0xE39CA0, 0x3C6CD },
	{ 0xE39CA1, 0x3C6CE },
	{ 0xE39CA2, 0x4C2E9 },
	{ 0xE39CA3, 0x4C9BC },
	{ 0xE39CA4, 0x4C9BA },
	{ 0xE39CA5, 0x3CBD9 },
	{ 0xE39CA6, 0x3CBD7 },
	{ 0xE39CA7, 0x4C9C0 },
	{ 0xE39CA8, 0x3CBD5 },
	{ 0xE39CA9, 0x3D0D2 },
	{ 0xE39CAA, 0x3D0D5 },
	{ 0xE39CAB, 0x4D0A1 },
	{ 0xE39CAC, 0xFD4AA },
	{ 0xE39CAE, 0x4D6A2 },
	{ 0xE39CAF, 0x4D6A4 },
	{ 0xE39CB0, 0x3D7DF },
	{ 0xE39CB1, 0x3D7E0 },
	{ 0xE39CB2, 0x4DFD4 },
	{ 0xE39CB3, 0x5E7DE },
	{ 0xE39CB4, 0x3DAB0 },
	{ 0xE39CB5, 0x3DAB2 },
	{ 0xE39CB6, 0x3DCB7 },
	{ 0xE39CB7, 0x4E3B5 },
	{ 0xE39CB8, 0x3DCB8 },
	{ 0xE39CB9, 0x4E6B7 },
	{ 0xE39CBA, 0x4E8E5 },
	{ 0xE39CBB, 0x3E1E2 },
	{ 0xE39CBC, 0x3E1E3 },
	{ 0xE39CBD, 0x3A3CE },
	{ 0xE39CBE, 0x6A6F8 },
	{ 0xE39CBF, 0x4A3ED },
	{ 0xE39D80, 0x3A8C9 },
	{ 0xE39D81, 0x4A8F0 },
	{ 0xE39D82, 0x4ACC1 },
	{ 0xE39D83, 0x3B0D4 },
	{ 0xE39D84, 0x3BAFD },
	{ 0xE39D85, 0x4BCE7 },
	{ 0xE39D87, 0x7ADAD },
	{ 0xE39D88, 0x3E1BD },
	{ 0xE39D8A, 0x3A2BC },
	{ 0xE39D8C, 0x3A3CF },
	{ 0xE39D8D, 0x6A6F9 },
	{ 0xE39D8E, 0x3A5D9 },
	{ 0xE39D8F, 0x4A3F0 },
	{ 0xE39D90, 0x3A5DB },
	{ 0xE39D91, 0x6A6FA },
	{ 0xE39D92, 0x3A8CF },
	{ 0xE39D93, 0x5A8EE },
	{ 0xE39D94, 0x3ACB0 },
	{ 0xE39D95, 0x3ACB1 },
	{ 0xE39D96, 0x3ACB3 },
	{ 0xE39D97, 0x4ACC2 },
	{ 0xE39D98, 0x5ACFC },
	{ 0xE39D99, 0x6B6DD },
	{ 0xE39D9B, 0x3B5C2 },
	{ 0xE39D9C, 0x3B5BD },
	{ 0xE39D9D, 0x3B5BE },
	{ 0xE39D9E, 0x4B1AE },
	{ 0xE39D9F, 0x6BEDA },
	{ 0xE39DA0, 0x3B5C0 },
	{ 0xE39DA2, 0x3BBA1 },
	{ 0xE39DA3, 0x4B7A2 },
	{ 0xE39DA4, 0x4BCEA },
	{ 0xE39DA5, 0x4BCEC },
	{ 0xE39DA6, 0x4BCEF },
	{ 0xE39DA7, 0x3C0F7 },
	{ 0xE39DA9, 0x4C2F4 },
	{ 0xE39DAA, 0x4C2F5 },
	{ 0xE39DAB, 0x3CBE0 },
	{ 0xE39DAC, 0x4C2F7 },
	{ 0xE39DAD, 0x4C9C3 },
	{ 0xE39DAE, 0x4C9C5 },
	{ 0xE39DAF, 0x4C9C6 },
	{ 0xE39DB0, 0x4DAFD },
	{ 0xE39DB1, 0x3DEAB },
	{ 0xE39DB2, 0x7E2B5 },
	{ 0xE39DB4, 0x4A3F1 },
	{ 0xE39DB5, 0x4A6A6 },
	{ 0xE39DB6, 0x6B6E8 },
	{ 0xE39DB7, 0x3BBA2 },
	{ 0xE39DB8, 0x4ACCC },
	{ 0xE39DB9, 0x6BEE4 },
	{ 0xE39DBA, 0x4C2F8 },
	{ 0xE39DBB, 0x5CCE3 },
	{ 0xE39DBC, 0x4A2DD },
	{ 0xE39DBD, 0x4A3F4 },
	{ 0xE39DBE, 0x4A6A8 },
	{ 0xE39DBF, 0x4A6A7 },
	{ 0xE39E80, 0x4A8F4 },
	{ 0xE39E81, 0x4A8F5 },
	{ 0xE39E82, 0x4ACCD },
	{ 0xE39E83, 0x5B1F5 },
	{ 0xE39E84, 0x4B1B3 },
	{ 0xE39E85, 0x5B1F3 },
	{ 0xE39E86, 0x4B1B2 },
	{ 0xE39E87, 0x4B7A8 },
	{ 0xE39E88, 0x4B7A9 },
	{ 0xE39E89, 0x4BCF1 },
	{ 0xE39E8A, 0x4C2F9 },
	{ 0xE39E8B, 0x3A2C0 },
	{ 0xE39E8C, 0x3A3D3 },
	{ 0xE39E8F, 0x4A6AA },
	{ 0xE39E90, 0x3A8D2 },
	{ 0xE39E91, 0x3A8D3 },
	{ 0xE39E92, 0x4A8F9 },
	{ 0xE39E93, 0x4A8F8 },
	{ 0xE39E94, 0x3ACB9 },
	{ 0xE39E95, 0x3ACB8 },
	{ 0xE39E96, 0x3ACB6 },
	{ 0xE39E97, 0x4ACCE },
	{ 0xE39E98, 0x6BEEB },
	{ 0xE39E99, 0x3B5C5 },
	{ 0xE39E9A, 0x4B7AB },
	{ 0xE39E9B, 0x5B7E6 },
	{ 0xE39E9C, 0x4C2FD },
	{ 0xE39E9F, 0x4C9CA },
	{ 0xE39EA1, 0x3DAB7 },
	{ 0xE39EA2, 0x3A1E2 },
	{ 0xE39EA3, 0x4A3F7 },
	{ 0xE39EA4, 0x3A2C2 },
	{ 0xE39EA5, 0x3A2C3 },
	{ 0xE39EA6, 0x3A2C1 },
	{ 0xE39EA7, 0x3A2C4 },
	{ 0xE39EA8, 0x3A3D6 },
	{ 0xE39EA9, 0x4A2E1 },
	{ 0xE39EAA, 0x5A2D1 },
	{ 0xE39EAB, 0x4A3FB },
	{ 0xE39EAC, 0x5A2D0 },
	{ 0xE39EAD, 0x3A3D7 },
	{ 0xE39EAF, 0x3A3D8 },
	{ 0xE39EB0, 0x4A3F8 },
	{ 0xE39EB1, 0x4A3F9 },
	{ 0xE39EB2, 0x3A5E0 },
	{ 0xE39EB3, 0x5A3F0 },
	{ 0xE39EB4, 0x5A3F4 },
	{ 0xE39EB5, 0x3A5E4 },
	{ 0xE39EB6, 0x3A5E5 },
	{ 0xE39EB7, 0x4A3F6 },
	{ 0xE39EB9, 0x3A8DB },
	{ 0xE39EBA, 0x6AAFB },
	{ 0xE39EBB, 0x4A6B1 },
	{ 0xE39EBC, 0x4A6B2 },
	{ 0xE39EBD, 0x4A6AE },
	{ 0xE39EBE, 0x3A8D6 },
	{ 0xE39EBF, 0x6AAF6 },
	{ 0xE39F80, 0x3A8D9 },
	{ 0xE39F81, 0x3A8DA },
	{ 0xE39F83, 0x5A5EE },
	{ 0xE39F84, 0x3ACBA },
	{ 0xE39F85, 0x4A8FB },
	{ 0xE39F87, 0x4ACDB },
	{ 0xE39F88, 0x4ACD3 },
	{ 0xE39F89, 0x4ACD1 },
	{ 0xE39F8A, 0x3B0E0 },
	{ 0xE39F8B, 0x4ACDF },
	{ 0xE39F8C, 0x4ACD5 },
	{ 0xE39F8D, 0x3B0DC },
	{ 0xE39F8E, 0x4ACDA },
	{ 0xE39F8F, 0x4ACDE },
	{ 0xE39F90, 0x4ACD7 },
	{ 0xE39F91, 0x3B0DD },
	{ 0xE39F92, 0x6B6FC },
	{ 0xE39F93, 0x5ADAE },
	{ 0xE39F94, 0x3B0E5 },
	{ 0xE39F96, 0x4ACD4 },
	{ 0xE39F97, 0x3B5D6 },
	{ 0xE39F98, 0x3B5C9 },
	{ 0xE39F99, 0x4B1B7 },
	{ 0xE39F9A, 0x3B5CC },
	{ 0xE39F9B, 0x4B1BD },
	{ 0xE39F9C, 0x6BEF5 },
	{ 0xE39F9D, 0x3B5CD },
	{ 0xE39F9E, 0x4B1B9 },
	{ 0xE39F9F, 0x6BEF8 },
	{ 0xE39FA0, 0x3B5D0 },
	{ 0xE39FA2, 0xFB4BF },
	{ 0xE39FA5, 0x3B5D3 },
	{ 0xE39FA6, 0x3BBAF },
	{ 0xE39FA7, 0x3BBB2 },
	{ 0xE39FA8, 0x3BBA9 },
	{ 0xE39FA9, 0x4B7B2 },
	{ 0xE39FAA, 0x4B7B4 },
	{ 0xE39FAB, 0x3BBB5 },
	{ 0xE39FAC, 0x4BCF2 },
	{ 0xE39FAD, 0x3BBB0 },
	{ 0xE39FAF, 0x3BBAC },
	{ 0xE39FB0, 0x4BCF6 },
	{ 0xE39FB1, 0x4BCF3 },
	{ 0xE39FB2, 0x4BCFE },
	{ 0xE39FB3, 0x5BEED },
	{ 0xE39FB4, 0x4BDA1 },
	{ 0xE39FB5, 0x6D2B4 },
	{ 0xE39FB6, 0x3C0FB },
	{ 0xE39FB8, 0x4BCF7 },
	{ 0xE39FB9, 0x4C3A2 },
	{ 0xE39FBA, 0x6DCC4 },
	{ 0xE39FBB, 0x4C3AD },
	{ 0xE39FBC, 0x4C3AA },
	{ 0xE39FBD, 0x4C3A1 },
	{ 0xE39FBE, 0x3C6D5 },
	{ 0xE39FBF, 0x4C3A4 },
	{ 0xE3A080, 0x3C6DB },
	{ 0xE3A081, 0x3C6D8 },
	{ 0xE3A082, 0x4C3AE },
	{ 0xE3A084, 0x3C6D7 },
	{ 0xE3A085, 0x4C9D0 },
	{ 0xE3A086, 0x4C9CC },
	{ 0xE3A087, 0x5CCEC },
	{ 0xE3A088, 0x3CBE2 },
	{ 0xE3A089, 0x5CCE8 },
	{ 0xE3A08A, 0x4C9CB },
	{ 0xE3A08B, 0x4C9D3 },
	{ 0xE3A08C, 0x3CBE4 },
	{ 0xE3A08D, 0x4C9CF },
	{ 0xE3A08E, 0x4C9CD },
	{ 0xE3A08F, 0x3CBE1 },
	{ 0xE3A090, 0x4C9D4 },
	{ 0xE3A091, 0x4D0A6 },
	{ 0xE3A092, 0x4D0A7 },
	{ 0xE3A093, 0x4D6A8 },
	{ 0xE3A094, 0x4D0A5 },
	{ 0xE3A095, 0x5D4B6 },
	{ 0xE3A096, 0x3D0D9 },
	{ 0xE3A097, 0x7ADCC },
	{ 0xE3A098, 0x3D4DA },
	{ 0xE3A099, 0x3D4D6 },
	{ 0xE3A09A, 0x5DBBC },
	{ 0xE3A09B, 0x4D6A7 },
	{ 0xE3A09C, 0x3D4D8 },
	{ 0xE3A09D, 0x7BFC4 },
	{ 0xE3A0A0, 0x4DFDA },
	{ 0xE3A0A1, 0x5E7E3 },
	{ 0xE3A0A2, 0x5E7E4 },
	{ 0xE3A0A5, 0x4E6BA },
	{ 0xE3A0A6, 0x3DEAC },
	{ 0xE3A0A7, 0x4E8E8 },
	{ 0xE3A0A8, 0x5FBBD },
	{ 0xE3A0A9, 0x3A3DB },
	{ 0xE3A0AA, 0x6A1EE },
	{ 0xE3A0AD, 0x3BBB8 },
	{ 0xE3A0AE, 0x4C9D5 },
	{ 0xE3A0AF, 0x3A2C5 },
	{ 0xE3A0B1, 0x4B1C2 },
	{ 0xE3A0B2, 0x3A2C6 },
	{ 0xE3A0B4, 0x4A2E5 },
	{ 0xE3A0B5, 0x4A2E6 },
	{ 0xE3A0B6, 0x3A3DD },
	{ 0xE3A0B7, 0x4A4A2 },
	{ 0xE3A0B8, 0x4A4A4 },
	{ 0xE3A0B9, 0x3A5E9 },
	{ 0xE3A0BA, 0x4A4A1 },
	{ 0xE3A0BB, 0x3A5EA },
	{ 0xE3A0BC, 0xFA4A5 },
	{ 0xE3A0BD, 0x4A6B6 },
	{ 0xE3A0BE, 0x4A6B7 },
	{ 0xE3A0BF, 0x4A9A5 },
	{ 0xE3A180, 0x4A4A5 },
	{ 0xE3A181, 0x4A9A2 },
	{ 0xE3A182, 0x4A9A4 },
	{ 0xE3A183, 0x6B0E3 },
	{ 0xE3A184, 0x3ACC7 },
	{ 0xE3A185, 0x4A9A3 },
	{ 0xE3A186, 0x4A9A1 },
	{ 0xE3A187, 0x4ACE6 },
	{ 0xE3A188, 0x4ACE8 },
	{ 0xE3A189, 0x4B1C7 },
	{ 0xE3A18A, 0x4B1C8 },
	{ 0xE3A18B, 0x4B1C5 },
	{ 0xE3A18C, 0x4B1C9 },
	{ 0xE3A18E, 0x3B5DC },
	{ 0xE3A18F, 0x4B7BB },
	{ 0xE3A190, 0x4B7B6 },
	{ 0xE3A191, 0x4B7BD },
	{ 0xE3A192, 0x4B7BA },
	{ 0xE3A193, 0x3BBBC },
	{ 0xE3A194, 0x4B7BC },
	{ 0xE3A195, 0x3BBB9 },
	{ 0xE3A196, 0x4B7B9 },
	{ 0xE3A197, 0x4BDA8 },
	{ 0xE3A198, 0x4BDA3 },
	{ 0xE3A199, 0x4BDA7 },
	{ 0xE3A19A, 0x4BDA6 },
	{ 0xE3A19B, 0x4BDA9 },
	{ 0xE3A19C, 0x4C3B3 },
	{ 0xE3A19D, 0x4C3B2 },
	{ 0xE3A19E, 0x4C3B1 },
	{ 0xE3A19F, 0x4C3AF },
	{ 0xE3A1A0, 0x3CBEE },
	{ 0xE3A1A2, 0x3CBEF },
	{ 0xE3A1A3, 0x4D0A9 },
	{ 0xE3A1A5, 0x4D6AD },
	{ 0xE3A1A6, 0x4D6AB },
	{ 0xE3A1A7, 0x4E3BB },
	{ 0xE3A1A8, 0x4E3BA },
	{ 0xE3A1A9, 0x3DFC4 },
	{ 0xE3A1AA, 0x4E8EB },
	{ 0xE3A1AB, 0x6C8C4 },
	{ 0xE3A1AD, 0x3C6DE },
	{ 0xE3A1AE, 0x4D0AB },
	{ 0xE3A1AF, 0x3A3E0 },
	{ 0xE3A1B0, 0x3A3DF },
	{ 0xE3A1B1, 0x3A3DE },
	{ 0xE3A1B2, 0x3A5EC },
	{ 0xE3A1B3, 0x6A7C7 },
	{ 0xE3A1B4, 0x4A6B8 },
	{ 0xE3A1B5, 0x4A6BD },
	{ 0xE3A1B6, 0x4A6BB },
	{ 0xE3A1B7, 0x5A6A6 },
	{ 0xE3A1B8, 0x4A6BC },
	{ 0xE3A1B9, 0x3A8E4 },
	{ 0xE3A1BA, 0x4A6BA },
	{ 0xE3A1BB, 0x3A8E6 },
	{ 0xE3A1BC, 0xFAFB8 },
	{ 0xE3A1BD, 0x3ACC9 },
	{ 0xE3A1BE, 0x3ACCA },
	{ 0xE3A1BF, 0x4A9AA },
	{ 0xE3A280, 0x5A9A6 },
	{ 0xE3A281, 0x4A9A9 },
	{ 0xE3A282, 0x4A9A8 },
	{ 0xE3A283, 0x4ACEB },
	{ 0xE3A284, 0x4ACED },
	{ 0xE3A285, 0x4ACEC },
	{ 0xE3A286, 0x3B0ED },
	{ 0xE3A288, 0x3B5DE },
	{ 0xE3A289, 0x4B1CE },
	{ 0xE3A28A, 0x4B1CC },
	{ 0xE3A28B, 0x4B1CF },
	{ 0xE3A28C, 0x3B5DD },
	{ 0xE3A28D, 0x5B8A9 },
	{ 0xE3A28E, 0x4B7C0 },
	{ 0xE3A28F, 0x4B7C1 },
	{ 0xE3A290, 0x3BBC1 },
	{ 0xE3A291, 0x5BFA1 },
	{ 0xE3A292, 0x4C3B6 },
	{ 0xE3A293, 0x3C6DF },
	{ 0xE3A294, 0x4C3B9 },
	{ 0xE3A295, 0x4C3BA },
	{ 0xE3A296, 0x4C9DB },
	{ 0xE3A297, 0x4C9DC },
	{ 0xE3A298, 0x3CBF1 },
	{ 0xE3A299, 0x3D0DD },
	{ 0xE3A29A, 0x4D0AC },
	{ 0xE3A29B, 0x4D0AE },
	{ 0xE3A29C, 0x5D4C2 },
	{ 0xE3A29D, 0x4DFDE },
	{ 0xE3A29E, 0x4E3BC },
	{ 0xE3A29F, 0x4A4A9 },
	{ 0xE3A2A0, 0x3A8EA },
	{ 0xE3A2A1, 0x3C6E2 },
	{ 0xE3A2A3, 0x7ADDB },
	{ 0xE3A2A5, 0x4A9AB },
	{ 0xE3A2A6, 0x4BDAD },
	{ 0xE3A2A7, 0x6A1F9 },
	{ 0xE3A2A8, 0x4A2EA },
	{ 0xE3A2A9, 0x3A3E3 },
	{ 0xE3A2AA, 0x3A3E4 },
	{ 0xE3A2AC, 0x3A5F0 },
	{ 0xE3A2AE, 0x3A8EF },
	{ 0xE3A2AF, 0x4A6C0 },
	{ 0xE3A2B0, 0x4A6C1 },
	{ 0xE3A2B2, 0x3ACCE },
	{ 0xE3A2B3, 0x4A9AD },
	{ 0xE3A2B4, 0x6B0FA },
	{ 0xE3A2B5, 0x4A9AE },
	{ 0xE3A2B6, 0x3ACCF },
	{ 0xE3A2B8, 0x4ACF1 },
	{ 0xE3A2BA, 0x5B2C6 },
	{ 0xE3A2BB, 0x4B1D1 },
	{ 0xE3A2BC, 0x4ACF2 },
	{ 0xE3A2BD, 0x3BBC6 },
	{ 0xE3A2BE, 0x3BBC3 },
	{ 0xE3A380, 0x5BFA9 },
	{ 0xE3A381, 0x4BDAF },
	{ 0xE3A382, 0x4BDAE },
	{ 0xE3A383, 0x6D2CD },
	{ 0xE3A384, 0x4C9DD },
	{ 0xE3A385, 0x4C9DF },
	{ 0xE3A386, 0x3DEAE },
	{ 0xE3A387, 0x4A6C2 },
	{ 0xE3A388, 0x4D0B1 },
	{ 0xE3A389, 0x6A4F0 },
	{ 0xE3A38B, 0x3A8F3 },
	{ 0xE3A38C, 0x4A6C3 },
	{ 0xE3A38D, 0x3A8F2 },
	{ 0xE3A38E, 0x3B5E4 },
	{ 0xE3A38F, 0x3BBC8 },
	{ 0xE3A390, 0x3BBC9 },
	{ 0xE3A391, 0x4C3BB },
	{ 0xE3A392, 0x4C9E1 },
	{ 0xE3A393, 0x3D0DF },
	{ 0xE3A394, 0x3A2CB },
	{ 0xE3A398, 0x6ABBE },
	{ 0xE3A399, 0x3A8F4 },
	{ 0xE3A39A, 0x4A9B2 },
	{ 0xE3A39B, 0x4A9B4 },
	{ 0xE3A39C, 0x3ACD2 },
	{ 0xE3A39D, 0x5A9AF },
	{ 0xE3A39E, 0x5A9B3 },
	{ 0xE3A39F, 0x3ACD3 },
	{ 0xE3A3A0, 0x6B1A5 },
	{ 0xE3A3A2, 0x5ADC7 },
	{ 0xE3A3A3, 0xFAFBE },
	{ 0xE3A3A4, 0x4B1D4 },
	{ 0xE3A3A5, 0x3B5E6 },
	{ 0xE3A3A6, 0x3B5E7 },
	{ 0xE3A3AB, 0x4B7C9 },
	{ 0xE3A3AC, 0x3BBCA },
	{ 0xE3A3AD, 0x4B7C8 },
	{ 0xE3A3AF, 0x4BDB3 },
	{ 0xE3A3B0, 0x5C5E9 },
	{ 0xE3A3B1, 0x4C3BD },
	{ 0xE3A3B2, 0x6DCE7 },
	{ 0xE3A3B5, 0x3D0E0 },
	{ 0xE3A3B6, 0x4D0B4 },
	{ 0xE3A3B7, 0x4D6AF },
	{ 0xE3A3BA, 0x6A1FE },
	{ 0xE3A3BB, 0x3A3E5 },
	{ 0xE3A3BC, 0x3A3E8 },
	{ 0xE3A3BD, 0x4A4B1 },
	{ 0xE3A3BE, 0x5A2E7 },
	{ 0xE3A3BF, 0x4A2F0 },
	{ 0xE3A481, 0x3A8FB },
	{ 0xE3A482, 0x3A8FD },
	{ 0xE3A483, 0x3A5F9 },
	{ 0xE3A484, 0x4A4AE },
	{ 0xE3A485, 0x3A8FC },
	{ 0xE3A486, 0x4A4B0 },
	{ 0xE3A487, 0x4A4B3 },
	{ 0xE3A488, 0x3A5F3 },
	{ 0xE3A489, 0x4A4AF },
	{ 0xE3A48A, 0x4A4B2 },
	{ 0xE3A48B, 0x3A6A4 },
	{ 0xE3A48C, 0x3A8F9 },
	{ 0xE3A48D, 0x4A9B5 },
	{ 0xE3A48E, 0x4A9B7 },
	{ 0xE3A48F, 0x4A6CD },
	{ 0xE3A490, 0x3ACD9 },
	{ 0xE3A491, 0x3A9A4 },
	{ 0xE3A492, 0x4A6C8 },
	{ 0xE3A493, 0x3A9A3 },
	{ 0xE3A494, 0x4A6CE },
	{ 0xE3A495, 0x4A6CC },
	{ 0xE3A496, 0x4A6C6 },
	{ 0xE3A497, 0xFAABE },
	{ 0xE3A499, 0x3ACD8 },
	{ 0xE3A49A, 0x4A9C1 },
	{ 0xE3A49B, 0x3ACE2 },
	{ 0xE3A49C, 0x4A9BC },
	{ 0xE3A49D, 0x4A6C9 },
	{ 0xE3A49E, 0x4A9B9 },
	{ 0xE3A49F, 0x3B0FD },
	{ 0xE3A4A0, 0x6B7D4 },
	{ 0xE3A4A1, 0x4A9BD },
	{ 0xE3A4A2, 0x5A9B5 },
	{ 0xE3A4A3, 0x4ADA8 },
	{ 0xE3A4A4, 0x4A9C8 },
	{ 0xE3A4A5, 0x4A9BA },
	{ 0xE3A4A6, 0x4A9BB },
	{ 0xE3A4A7, 0x4A9C0 },
	{ 0xE3A4A8, 0x3ACD5 },
	{ 0xE3A4A9, 0x6B7DA },
	{ 0xE3A4AA, 0x3B0FC },
	{ 0xE3A4AC, 0x3ACDE },
	{ 0xE3A4AE, 0x4B1DB },
	{ 0xE3A4AF, 0x5ADDA },
	{ 0xE3A4B0, 0x3B5F3 },
	{ 0xE3A4B1, 0x4ADA2 },
	{ 0xE3A4B2, 0x3B5E9 },
	{ 0xE3A4B3, 0x3B0F5 },
	{ 0xE3A4B4, 0x4ADA3 },
	{ 0xE3A4B5, 0x3B5F0 },
	{ 0xE3A4B6, 0x4ADA4 },
	{ 0xE3A4B7, 0x3B0F7 },
	{ 0xE3A4B8, 0x6B7DE },
	{ 0xE3A4B9, 0x3B1A4 },
	{ 0xE3A4BA, 0x4ADAB },
	{ 0xE3A4BB, 0x4B1DA },
	{ 0xE3A4BE, 0x4B1DC },
	{ 0xE3A4BF, 0x4B1E2 },
	{ 0xE3A580, 0x3B5EB },
	{ 0xE3A581, 0x6C8EF },
	{ 0xE3A582, 0x4B1E3 },
	{ 0xE3A583, 0x3B5F5 },
	{ 0xE3A584, 0x4B1E0 },
	{ 0xE3A585, 0x5B2DB },
	{ 0xE3A586, 0x4B1DD },
	{ 0xE3A587, 0x3B5EC },
	{ 0xE3A588, 0x3BBCE },
	{ 0xE3A589, 0x4B1EC },
	{ 0xE3A58A, 0x4B1E7 },
	{ 0xE3A58B, 0x3BBCC },
	{ 0xE3A58C, 0x3B5ED },
	{ 0xE3A58D, 0x3B5F7 },
	{ 0xE3A58E, 0x3BBD7 },
	{ 0xE3A58F, 0x4B1E4 },
	{ 0xE3A590, 0x6C8F5 },
	{ 0xE3A591, 0x3BBD3 },
	{ 0xE3A592, 0x4B1E6 },
	{ 0xE3A593, 0x4B1DE },
	{ 0xE3A594, 0x5ADD7 },
	{ 0xE3A595, 0x3BBD2 },
	{ 0xE3A596, 0x5B8C2 },
	{ 0xE3A59A, 0x4B1EA },
	{ 0xE3A59B, 0x5B8C8 },
	{ 0xE3A59C, 0x4B7D6 },
	{ 0xE3A59D, 0x4B7D0 },
	{ 0xE3A59E, 0x3BBDC },
	{ 0xE3A59F, 0x4B7D9 },
	{ 0xE3A5A0, 0x3BBDF },
	{ 0xE3A5A1, 0x4B7D4 },
	{ 0xE3A5A2, 0x4B7CE },
	{ 0xE3A5A3, 0x5BFB2 },
	{ 0xE3A5A4, 0x3C1A5 },
	{ 0xE3A5A5, 0x4B7D5 },
	{ 0xE3A5A6, 0x4BDBE },
	{ 0xE3A5A7, 0x3BBE0 },
	{ 0xE3A5A8, 0x4BDB7 },
	{ 0xE3A5A9, 0x5B2D8 },
	{ 0xE3A5AB, 0x3BBDB },
	{ 0xE3A5AC, 0x3C1A6 },
	{ 0xE3A5AD, 0x3C1AD },
	{ 0xE3A5AE, 0x4BDBB },
	{ 0xE3A5AF, 0x4C3C3 },
	{ 0xE3A5B0, 0x5BFC2 },
	{ 0xE3A5B1, 0x6D2E9 },
	{ 0xE3A5B2, 0x3C6E7 },
	{ 0xE3A5B3, 0x4BDBA },
	{ 0xE3A5B4, 0x4BDBC },
	{ 0xE3A5B5, 0x3C1B0 },
	{ 0xE3A5B6, 0x3C6E5 },
	{ 0xE3A5B7, 0x4C3C2 },
	{ 0xE3A5B8, 0x4C3D0 },
	{ 0xE3A5B9, 0x3C6E6 },
	{ 0xE3A5BA, 0x3C1AF },
	{ 0xE3A5BC, 0x4C3C8 },
	{ 0xE3A5BD, 0x4C3C7 },
	{ 0xE3A5BE, 0x4C3C9 },
	{ 0xE3A5BF, 0x3CBFD },
	{ 0xE3A680, 0x4C3CD },
	{ 0xE3A681, 0x4C9E5 },
	{ 0xE3A682, 0x3CCA2 },
	{ 0xE3A683, 0x3C6E9 },
	{ 0xE3A684, 0x3CBFB },
	{ 0xE3A685, 0x4C3CA },
	{ 0xE3A686, 0x4C3CC },
	{ 0xE3A687, 0x4C3C6 },
	{ 0xE3A689, 0x3CCA7 },
	{ 0xE3A68A, 0x3CBF8 },
	{ 0xE3A68B, 0x4C3CB },
	{ 0xE3A68C, 0x4D0B8 },
	{ 0xE3A68D, 0x3CCAA },
	{ 0xE3A68E, 0x4C9E7 },
	{ 0xE3A68F, 0x4C9E9 },
	{ 0xE3A690, 0x4C9E8 },
	{ 0xE3A691, 0x4C9EB },
	{ 0xE3A692, 0x7A2FC },
	{ 0xE3A693, 0x4C9ED },
	{ 0xE3A694, 0x3D0E9 },
	{ 0xE3A695, 0x4C9EC },
	{ 0xE3A696, 0x3CCA6 },
	{ 0xE3A697, 0x4D0B9 },
	{ 0xE3A698, 0x5DBCC },
	{ 0xE3A69A, 0x4DBA3 },
	{ 0xE3A69B, 0x4DBA9 },
	{ 0xE3A69C, 0x4D6B6 },
	{ 0xE3A69D, 0x4DBA5 },
	{ 0xE3A69E, 0x3D7E7 },
	{ 0xE3A69F, 0x4DBA4 },
	{ 0xE3A6A0, 0xFDAA9 },
	{ 0xE3A6A1, 0x3D7E6 },
	{ 0xE3A6A2, 0x4D0BA },
	{ 0xE3A6A3, 0x5E7F8 },
	{ 0xE3A6A4, 0x4E3C3 },
	{ 0xE3A6A5, 0x4DFE4 },
	{ 0xE3A6A6, 0x5E7F3 },
	{ 0xE3A6A7, 0x7C7AC },
	{ 0xE3A6A8, 0x3DEB0 },
	{ 0xE3A6A9, 0x4E3C2 },
	{ 0xE3A6AA, 0x4E3C0 },
	{ 0xE3A6AB, 0x3DFC7 },
	{ 0xE3A6AC, 0x4E8EC },
	{ 0xE3A6AD, 0x3E1F8 },
	{ 0xE3A6AE, 0x3A3EA },
	{ 0xE3A6AF, 0x3A6A6 },
	{ 0xE3A6B0, 0x4A6D4 },
	{ 0xE3A6B2, 0x6ABD2 },
	{ 0xE3A6B4, 0x4ADAF },
	{ 0xE3A6B5, 0x4ADB0 },
	{ 0xE3A6B6, 0x5ADDD },
	{ 0xE3A6B7, 0x3B5FA },
	{ 0xE3A6B8, 0x3BBE5 },
	{ 0xE3A6B9, 0x4BDC2 },
	{ 0xE3A6BA, 0x4C3D4 },
	{ 0xE3A6BB, 0x5CDB7 },
	{ 0xE3A6BC, 0x3CCAB },
	{ 0xE3A6BD, 0x3D4E2 },
	{ 0xE3A6BE, 0x6A7EE },
	{ 0xE3A6BF, 0x4A6D5 },
	{ 0xE3A780, 0x4A6D6 },
	{ 0xE3A781, 0x4A9CD },
	{ 0xE3A782, 0x3ACE4 },
	{ 0xE3A783, 0x4A1FB },
	{ 0xE3A784, 0x4A1FA },
	{ 0xE3A785, 0x3A2CF },
	{ 0xE3A786, 0x4A2F4 },
	{ 0xE3A787, 0x4A2F3 },
	{ 0xE3A788, 0x4A2F5 },
	{ 0xE3A789, 0x4A4BA },
	{ 0xE3A78A, 0x4A4B6 },
	{ 0xE3A78B, 0x3A6AC },
	{ 0xE3A78C, 0x3A6AD },
	{ 0xE3A78D, 0x3A6B0 },
	{ 0xE3A78E, 0x3A6AB },
	{ 0xE3A792, 0x4A6D8 },
	{ 0xE3A793, 0x3A9AD },
	{ 0xE3A794, 0x5A6BA },
	{ 0xE3A795, 0x3A9AC },
	{ 0xE3A796, 0x3A9B8 },
	{ 0xE3A797, 0x4A9D5 },
	{ 0xE3A798, 0x4ADB3 },
	{ 0xE3A799, 0x4A6D9 },
	{ 0xE3A79A, 0x3A9AB },
	{ 0xE3A79E, 0xFA7AE },
	{ 0xE3A7A1, 0x4A9CE },
	{ 0xE3A7A2, 0x4A9D4 },
	{ 0xE3A7A3, 0x3ACE6 },
	{ 0xE3A7A4, 0x3A9A7 },
	{ 0xE3A7A5, 0x3ACE7 },
	{ 0xE3A7A6, 0x3ACE9 },
	{ 0xE3A7A7, 0x4ADBC },
	{ 0xE3A7A8, 0x3ACF1 },
	{ 0xE3A7A9, 0x4A9D6 },
	{ 0xE3A7AA, 0x3ACE8 },
	{ 0xE3A7AB, 0x4A9D2 },
	{ 0xE3A7AC, 0x4ADB2 },
	{ 0xE3A7AD, 0x4ADB1 },
	{ 0xE3A7AE, 0x3ACEA },
	{ 0xE3A7AF, 0x3ACE5 },
	{ 0xE3A7B1, 0x3B1B4 },
	{ 0xE3A7B2, 0x3B1AA },
	{ 0xE3A7B3, 0x3B5FB },
	{ 0xE3A7B4, 0x3B1B1 },
	{ 0xE3A7B5, 0x3B1BA },
	{ 0xE3A7B6, 0x4ADBB },
	{ 0xE3A7B7, 0x3B1AD },
	{ 0xE3A7B8, 0x3B1AB },
	{ 0xE3A7B9, 0x4B1FC },
	{ 0xE3A7BA, 0x4B2A1 },
	{ 0xE3A7BB, 0x4B1FB },
	{ 0xE3A7BC, 0x3B6AC },
	{ 0xE3A7BD, 0x6C0B2 },
	{ 0xE3A7BE, 0x4B2A5 },
	{ 0xE3A7BF, 0x3B6AF },
	{ 0xE3A880, 0x3B6B0 },
	{ 0xE3A881, 0x4B1F9 },
	{ 0xE3A882, 0x3B5FE },
	{ 0xE3A883, 0x4B1F1 },
	{ 0xE3A884, 0x3B6A5 },
	{ 0xE3A885, 0x4B1FE },
	{ 0xE3A886, 0x4B1FA },
	{ 0xE3A887, 0x3BBEB },
	{ 0xE3A888, 0x3B6AA },
	{ 0xE3A889, 0x4B7EE },
	{ 0xE3A88A, 0x4B7E2 },
	{ 0xE3A88B, 0x3B6A1 },
	{ 0xE3A88C, 0x4BDC5 },
	{ 0xE3A88D, 0x3C1B1 },
	{ 0xE3A88E, 0x4B7E4 },
	{ 0xE3A88F, 0x3BBEA },
	{ 0xE3A890, 0x4B7EB },
	{ 0xE3A891, 0x4B7E8 },
	{ 0xE3A892, 0x4B7E5 },
	{ 0xE3A893, 0x3BBEC },
	{ 0xE3A894, 0x3BBE9 },
	{ 0xE3A895, 0x4B7F0 },
	{ 0xE3A896, 0x4B7E1 },
	{ 0xE3A897, 0x3BBEE },
	{ 0xE3A899, 0x4BDD0 },
	{ 0xE3A89A, 0x4BDCF },
	{ 0xE3A89B, 0x3C1B7 },
	{ 0xE3A89C, 0x4BDCC },
	{ 0xE3A89D, 0x4BDCA },
	{ 0xE3A89E, 0x3C1B5 },
	{ 0xE3A89F, 0x3C1BB },
	{ 0xE3A8A0, 0x4BDC8 },
	{ 0xE3A8A1, 0x4BDCE },
	{ 0xE3A8A2, 0x3C1BC },
	{ 0xE3A8A3, 0x3C1CA },
	{ 0xE3A8A4, 0x3C1C3 },
	{ 0xE3A8A5, 0x3C1BF },
	{ 0xE3A8A6, 0x3C1C7 },
	{ 0xE3A8A7, 0x3C1C0 },
	{ 0xE3A8A8, 0x3C1C6 },
	{ 0xE3A8A9, 0x3C1C1 },
	{ 0xE3A8AA, 0x3C1B9 },
	{ 0xE3A8AD, 0x4C3D8 },
	{ 0xE3A8AE, 0x4C3E1 },
	{ 0xE3A8AF, 0x6DDB2 },
	{ 0xE3A8B0, 0x3C6F9 },
	{ 0xE3A8B1, 0x3C7AE },
	{ 0xE3A8B2, 0x3C7AD },
	{ 0xE3A8B3, 0x4C3D6 },
	{ 0xE3A8B4, 0x3C6FC },
	{ 0xE3A8B5, 0x3C7A7 },
	{ 0xE3A8B6, 0x3C7AF },
	{ 0xE3A8B7, 0x4C3DC },
	{ 0xE3A8B8, 0x3C6F7 },
	{ 0xE3A8B9, 0x5C6A5 },
	{ 0xE3A8BA, 0x3C6FD },
	{ 0xE3A8BB, 0x4C9F5 },
	{ 0xE3A8BC, 0x3CCB6 },
	{ 0xE3A8BD, 0x4C3E4 },
	{ 0xE3A8BE, 0x5C6A3 },
	{ 0xE3A8BF, 0x3C7AB },
	{ 0xE3A980, 0x3C7AC },
	{ 0xE3A983, 0x4CAA4 },
	{ 0xE3A984, 0x3CCB3 },
	{ 0xE3A985, 0x7A3BA },
	{ 0xE3A986, 0x4C9F9 },
	{ 0xE3A987, 0x4C9FA },
	{ 0xE3A988, 0x4C9F6 },
	{ 0xE3A989, 0x4CAA8 },
	{ 0xE3A98A, 0x4CAA2 },
	{ 0xE3A98B, 0x5CDBA },
	{ 0xE3A98C, 0x4C9FE },
	{ 0xE3A98D, 0x5CDBE },
	{ 0xE3A98E, 0x3CCBC },
	{ 0xE3A990, 0x4CAA3 },
	{ 0xE3A992, 0x3D0F4 },
	{ 0xE3A993, 0x4D6B9 },
	{ 0xE3A994, 0x4D0C5 },
	{ 0xE3A995, 0x3D0F3 },
	{ 0xE3A996, 0x3D0EE },
	{ 0xE3A997, 0x3D0F8 },
	{ 0xE3A998, 0x3D0F2 },
	{ 0xE3A999, 0x3D0F1 },
	{ 0xE3A99A, 0x3D4E5 },
	{ 0xE3A99B, 0x3D4EA },
	{ 0xE3A99C, 0x3D4E8 },
	{ 0xE3A99D, 0x3D4E3 },
	{ 0xE3A99E, 0x3D4E6 },
	{ 0xE3A9A0, 0x4DBAD },
	{ 0xE3A9A1, 0x3D7E9 },
	{ 0xE3A9A2, 0x4DBB2 },
	{ 0xE3A9A3, 0x4DBB0 },
	{ 0xE3A9A4, 0x4DBAE },
	{ 0xE3A9A5, 0x3D7EF },
	{ 0xE3A9A6, 0x3D7F1 },
	{ 0xE3A9A7, 0x4DBB1 },
	{ 0xE3A9A8, 0x3D7E8 },
	{ 0xE3A9A9, 0x4DBAF },
	{ 0xE3A9AA, 0x3D7F2 },
	{ 0xE3A9AB, 0xFDEF3 },
	{ 0xE3A9AC, 0x3DABD },
	{ 0xE3A9AD, 0x3DABE },
	{ 0xE3A9AF, 0x4E3C7 },
	{ 0xE3A9B0, 0x3DCC0 },
	{ 0xE3A9B1, 0x4E3C6 },
	{ 0xE3A9B2, 0x5F0A4 },
	{ 0xE3A9B3, 0x3DEB2 },
	{ 0xE3A9B4, 0x4E6C0 },
	{ 0xE3A9B5, 0x3E0B1 },
	{ 0xE3A9B6, 0x4EAC9 },
	{ 0xE3A9B7, 0x4EAC8 },
	{ 0xE3A9B9, 0x5F9AA },
	{ 0xE3A9BA, 0x4A6DB },
	{ 0xE3A9BB, 0x4ADC0 },
	{ 0xE3A9BC, 0x4ADBF },
	{ 0xE3A9BD, 0x4B2A7 },
	{ 0xE3A9BE, 0x4BDD4 },
	{ 0xE3A9BF, 0x4A4C0 },
	{ 0xE3AA80, 0x3A6BA },
	{ 0xE3AA81, 0x4A6DE },
	{ 0xE3AA82, 0x4A6DF },
	{ 0xE3AA84, 0x4A9DD },
	{ 0xE3AA85, 0x3ACF5 },
	{ 0xE3AA87, 0x3B1BE },
	{ 0xE3AA88, 0x4ADC2 },
	{ 0xE3AA89, 0x6B8AB },
	{ 0xE3AA8B, 0x3B6B3 },
	{ 0xE3AA8C, 0x4B2A8 },
	{ 0xE3AA8D, 0x3B6B5 },
	{ 0xE3AA8E, 0x4B2AC },
	{ 0xE3AA8F, 0x4B7F9 },
	{ 0xE3AA91, 0x4B7F5 },
	{ 0xE3AA92, 0x4B7F8 },
	{ 0xE3AA93, 0x4B7F7 },
	{ 0xE3AA95, 0x4B7F6 },
	{ 0xE3AA96, 0x5B8FC },
	{ 0xE3AA9A, 0x3BBF7 },
	{ 0xE3AA9C, 0x4BDDC },
	{ 0xE3AA9D, 0x4BDD9 },
	{ 0xE3AA9E, 0x4BDDB },
	{ 0xE3AA9F, 0x3C1CC },
	{ 0xE3AAA0, 0x4C3E6 },
	{ 0xE3AAA1, 0x5C6B0 },
	{ 0xE3AAA2, 0x5C6AE },
	{ 0xE3AAA3, 0x4C3E9 },
	{ 0xE3AAA4, 0x4CAAB },
	{ 0xE3AAA5, 0x4CAAA },
	{ 0xE3AAA6, 0x4CAA9 },
	{ 0xE3AAA8, 0x4D0C9 },
	{ 0xE3AAA9, 0x4D0CC },
	{ 0xE3AAAB, 0x3D7F3 },
	{ 0xE3AAAC, 0x4DBBA },
	{ 0xE3AAAD, 0x4E3CC },
	{ 0xE3AAAE, 0x4E6C3 },
	{ 0xE3AAAF, 0x3A6BB },
	{ 0xE3AAB0, 0x6B8AC },
	{ 0xE3AAB1, 0x3C1CF },
	{ 0xE3AAB4, 0x3A9BA },
	{ 0xE3AAB5, 0x4A9E1 },
	{ 0xE3AAB6, 0x3B1C1 },
	{ 0xE3AAB7, 0x3B9AB },
	{ 0xE3AAB8, 0x3BBF8 },
	{ 0xE3AAB9, 0x4CAAE },
	{ 0xE3AABA, 0x4D6BE },
	{ 0xE3AABB, 0x4EACB },
	{ 0xE3AABC, 0x4A9E2 },
	{ 0xE3AABE, 0x4ADC9 },
	{ 0xE3AABF, 0x6B8B0 },
	{ 0xE3AB80, 0x6C9E1 },
	{ 0xE3AB81, 0x6DDD1 },
	{ 0xE3AB82, 0x5CDCB },
	{ 0xE3AB83, 0x3A3F1 },
	{ 0xE3AB84, 0x6ABF0 },
	{ 0xE3AB85, 0x6B8B4 },
	{ 0xE3AB8A, 0x3B6BB },
	{ 0xE3AB8B, 0x3B6BE },
	{ 0xE3AB8D, 0x4BDE5 },
	{ 0xE3AB8E, 0x4CAB0 },
	{ 0xE3AB8F, 0x4CAB1 },
	{ 0xE3AB90, 0x4A2F8 },
	{ 0xE3AB91, 0x4A2F9 },
	{ 0xE3AB92, 0x4A4C3 },
	{ 0xE3AB93, 0x3A6BC },
	{ 0xE3AB94, 0x3A6BF },
	{ 0xE3AB95, 0x3A6BE },
	{ 0xE3AB97, 0x3A6C0 },
	{ 0xE3AB98, 0x3A9BF },
	{ 0xE3AB99, 0x3A9BD },
	{ 0xE3AB9A, 0x4A6E3 },
	{ 0xE3AB9B, 0x5A9CF },
	{ 0xE3AB9C, 0x4A9E3 },
	{ 0xE3AB9D, 0x3ACFB },
	{ 0xE3AB9E, 0x4A9E4 },
	{ 0xE3AB9F, 0x4A9E5 },
	{ 0xE3ABA0, 0x3ACF8 },
	{ 0xE3ABA1, 0x3ADA6 },
	{ 0xE3ABA4, 0x6B1E7 },
	{ 0xE3ABA5, 0x4ADCC },
	{ 0xE3ABA6, 0x4B2BB },
	{ 0xE3ABA7, 0x4ADCB },
	{ 0xE3ABA9, 0x3B1C7 },
	{ 0xE3ABAA, 0x6B8B7 },
	{ 0xE3ABAB, 0x3B1CA },
	{ 0xE3ABAC, 0xFAFEE },
	{ 0xE3ABAE, 0x4ADCD },
	{ 0xE3ABAF, 0x6C0D1 },
	{ 0xE3ABB0, 0x4B2B6 },
	{ 0xE3ABB1, 0x4B2BA },
	{ 0xE3ABB2, 0x4B2B7 },
	{ 0xE3ABB3, 0x3B6C3 },
	{ 0xE3ABB4, 0x6C0CF },
	{ 0xE3ABB5, 0x3BCA2 },
	{ 0xE3ABB6, 0x4B7FE },
	{ 0xE3ABB7, 0x3BBFA },
	{ 0xE3ABB8, 0x3BBFB },
	{ 0xE3ABB9, 0x4B8A5 },
	{ 0xE3ABBA, 0x3BCA7 },
	{ 0xE3ABBB, 0x4B8A2 },
	{ 0xE3ABBC, 0x6C9F3 },
	{ 0xE3ABBD, 0x3BCA1 },
	{ 0xE3AC81, 0x6D3BD },
	{ 0xE3AC82, 0x5BFE2 },
	{ 0xE3AC83, 0x3C1D2 },
	{ 0xE3AC84, 0x3C1D7 },
	{ 0xE3AC85, 0x3C1DA },
	{ 0xE3AC86, 0x3C1D5 },
	{ 0xE3AC87, 0x3C1D3 },
	{ 0xE3AC88, 0x3C1DC },
	{ 0xE3AC89, 0x3C1D8 },
	{ 0xE3AC8A, 0x4BDE8 },
	{ 0xE3AC8B, 0x4BDE7 },
	{ 0xE3AC8C, 0x3C1D4 },
	{ 0xE3AC8D, 0x3C7B8 },
	{ 0xE3AC8E, 0x4C3EE },
	{ 0xE3AC8F, 0x3C7B2 },
	{ 0xE3AC90, 0x3C7B6 },
	{ 0xE3AC92, 0x5CDD3 },
	{ 0xE3AC93, 0x4CAB2 },
	{ 0xE3AC94, 0x3CCC2 },
	{ 0xE3AC95, 0x3CCC5 },
	{ 0xE3AC97, 0x4D0D2 },
	{ 0xE3AC98, 0x4D0D1 },
	{ 0xE3AC99, 0x3D1A1 },
	{ 0xE3AC9A, 0x5CDD0 },
	{ 0xE3AC9B, 0x3D0FB },
	{ 0xE3AC9C, 0x3D0FC },
	{ 0xE3AC9D, 0x4D0D3 },
	{ 0xE3AC9E, 0x7AEDA },
	{ 0xE3ACA0, 0x3D4F3 },
	{ 0xE3ACA1, 0x3D4EE },
	{ 0xE3ACA2, 0x4D6C0 },
	{ 0xE3ACA3, 0x4DBC0 },
	{ 0xE3ACA5, 0x4DBC1 },
	{ 0xE3ACA6, 0x4DBBF },
	{ 0xE3ACA7, 0x7BFF6 },
	{ 0xE3ACA9, 0x3DAC0 },
	{ 0xE3ACAA, 0x3DAC1 },
	{ 0xE3ACAB, 0x3DCC4 },
	{ 0xE3ACAC, 0x3DFCC },
	{ 0xE3ACAD, 0x3DFCD },
	{ 0xE3ACAE, 0x5F5EE },
	{ 0xE3ACAF, 0x5F5ED },
	{ 0xE3ACB0, 0x3A3F4 },
	{ 0xE3ACB1, 0x4D0D6 },
	{ 0xE3ACB2, 0x3D4F4 },
	{ 0xE3ACB3, 0x3A9C4 },
	{ 0xE3ACB4, 0x3B1CE },
	{ 0xE3ACB5, 0x5AEA5 },
	{ 0xE3ACB6, 0x3B6C9 },
	{ 0xE3ACB8, 0x3BCA8 },
	{ 0xE3ACB9, 0x4BAC3 },
	{ 0xE3ACBB, 0x5C6C5 },
	{ 0xE3ACBC, 0x5CDD8 },
	{ 0xE3ACBF, 0x3D1A5 },
	{ 0xE3AD81, 0x3A3F6 },
	{ 0xE3AD82, 0x3A6C3 },
	{ 0xE3AD83, 0x4A4C8 },
	{ 0xE3AD84, 0x3A6C6 },
	{ 0xE3AD87, 0x3A9CB },
	{ 0xE3AD88, 0x3A9C6 },
	{ 0xE3AD89, 0xFA7CC },
	{ 0xE3AD8A, 0x3A9D0 },
	{ 0xE3AD8B, 0x3A9CD },
	{ 0xE3AD8C, 0x5A6D1 },
	{ 0xE3AD91, 0x3ADA8 },
	{ 0xE3AD92, 0x3ADAC },
	{ 0xE3AD93, 0x4A9EF },
	{ 0xE3AD94, 0x4A9EC },
	{ 0xE3AD95, 0x3ADA9 },
	{ 0xE3AD98, 0x4ADD7 },
	{ 0xE3AD99, 0x4ADD1 },
	{ 0xE3AD9A, 0x4ADD4 },
	{ 0xE3AD9B, 0x4ADD8 },
	{ 0xE3AD9C, 0x3B1D2 },
	{ 0xE3AD9D, 0x5AEAB },
	{ 0xE3AD9E, 0x4ADD2 },
	{ 0xE3AD9F, 0x4ADDB },
	{ 0xE3ADA0, 0x3B1D5 },
	{ 0xE3ADA1, 0x4ADD6 },
	{ 0xE3ADA2, 0x3B1D1 },
	{ 0xE3ADA8, 0x3B6D9 },
	{ 0xE3ADA9, 0x4B2C3 },
	{ 0xE3ADAA, 0x3B6CA },
	{ 0xE3ADAB, 0x3B6CF },
	{ 0xE3ADAC, 0x5B2F9 },
	{ 0xE3ADAD, 0x4B2C2 },
	{ 0xE3ADAE, 0x4B2C6 },
	{ 0xE3ADAF, 0x4B2C1 },
	{ 0xE3ADB0, 0x4B8B4 },
	{ 0xE3ADB1, 0x3B6D8 },
	{ 0xE3ADB2, 0x3B6DD },
	{ 0xE3ADB8, 0x4B8AF },
	{ 0xE3ADB9, 0x3BCAE },
	{ 0xE3ADBA, 0x4B8AC },
	{ 0xE3ADBB, 0x3BCBF },
	{ 0xE3ADBC, 0x3BCB0 },
	{ 0xE3ADBD, 0x4B8AA },
	{ 0xE3ADBE, 0x5B9B3 },
	{ 0xE3ADBF, 0x4B8AD },
	{ 0xE3AE80, 0x3BCAC },
	{ 0xE3AE81, 0x5B9B9 },
	{ 0xE3AE82, 0x4B8B5 },
	{ 0xE3AE83, 0x3BCB5 },
	{ 0xE3AE84, 0x4B8B7 },
	{ 0xE3AE85, 0x3BCB6 },
	{ 0xE3AE86, 0x3BCC3 },
	{ 0xE3AE87, 0x3BCAB },
	{ 0xE3AE88, 0x3BCAD },
	{ 0xE3AE8B, 0x4BDF8 },
	{ 0xE3AE8C, 0x3C1F1 },
	{ 0xE3AE8D, 0x3C1E6 },
	{ 0xE3AE8E, 0x3C1F0 },
	{ 0xE3AE8F, 0x4BDEB },
	{ 0xE3AE90, 0x4BDEE },
	{ 0xE3AE91, 0x4BDEF },
	{ 0xE3AE92, 0x3C1EC },
	{ 0xE3AE93, 0x3C1E9 },
	{ 0xE3AE94, 0x3C1E4 },
	{ 0xE3AE95, 0x4BDED },
	{ 0xE3AE96, 0x3C1DE },
	{ 0xE3AE97, 0x4BDF5 },
	{ 0xE3AE98, 0x3C1E2 },
	{ 0xE3AE99, 0x3C1E3 },
	{ 0xE3AE9A, 0x3C1FA },
	{ 0xE3AE9B, 0x3C1E1 },
	{ 0xE3AE9C, 0x3C1DF },
	{ 0xE3AE9D, 0x4C4A3 },
	{ 0xE3AE9E, 0x4BDF6 },
	{ 0xE3AE9F, 0x3C1E0 },
	{ 0xE3AEA1, 0x3C2DA },
	{ 0xE3AEA3, 0x3C1E7 },
	{ 0xE3AEA4, 0xFC8D5 },
	{ 0xE3AEA5, 0x4C4A4 },
	{ 0xE3AEA6, 0x4C3F5 },
	{ 0xE3AEA7, 0x4C4A1 },
	{ 0xE3AEA8, 0x4C3FC },
	{ 0xE3AEA9, 0x3C7BF },
	{ 0xE3AEAA, 0x4C3F8 },
	{ 0xE3AEAB, 0x4C3F3 },
	{ 0xE3AEAC, 0x3C7C1 },
	{ 0xE3AEAD, 0x4C3F4 },
	{ 0xE3AEAE, 0x3C7CA },
	{ 0xE3AEAF, 0x4C3FD },
	{ 0xE3AEB0, 0x4C3FE },
	{ 0xE3AEB1, 0x4C3FA },
	{ 0xE3AEB2, 0x4C4A2 },
	{ 0xE3AEB3, 0x3C7CF },
	{ 0xE3AEB4, 0x3C7C0 },
	{ 0xE3AEB5, 0x4C4A5 },
	{ 0xE3AEB6, 0x4C3F1 },
	{ 0xE3AEB7, 0x5C6CB },
	{ 0xE3AEB8, 0x3C7C9 },
	{ 0xE3AEB9, 0x4BDF2 },
	{ 0xE3AEBA, 0x3C7D0 },
	{ 0xE3AEBC, 0xFC8D2 },
	{ 0xE3AEBF, 0x3CCCE },
	{ 0xE3AF80, 0x5CDED },
	{ 0xE3AF81, 0x4CABA },
	{ 0xE3AF82, 0x3CCCC },
	{ 0xE3AF83, 0x5CDE1 },
	{ 0xE3AF84, 0x3CCD3 },
	{ 0xE3AF85, 0x4CAB7 },
	{ 0xE3AF86, 0x4CAB6 },
	{ 0xE3AF87, 0x3CCDD },
	{ 0xE3AF88, 0x3CCD8 },
	{ 0xE3AF89, 0x7A3EF },
	{ 0xE3AF8A, 0x4CAB8 },
	{ 0xE3AF8B, 0x4CAC2 },
	{ 0xE3AF8C, 0x3CCDA },
	{ 0xE3AF8D, 0x3CCDC },
	{ 0xE3AF8E, 0x3CCC8 },
	{ 0xE3AF8F, 0x3CCD5 },
	{ 0xE3AF90, 0x3D1C3 },
	{ 0xE3AF93, 0x3D1C2 },
	{ 0xE3AF94, 0x4D0E0 },
	{ 0xE3AF95, 0x4D0DA },
	{ 0xE3AF96, 0x3D1B7 },
	{ 0xE3AF97, 0x3D1B0 },
	{ 0xE3AF98, 0x4D0D9 },
	{ 0xE3AF99, 0x4CAB9 },
	{ 0xE3AF9A, 0x3D1BF },
	{ 0xE3AF9B, 0x3D1AA },
	{ 0xE3AF9C, 0x3D1BD },
	{ 0xE3AF9D, 0x4D6C9 },
	{ 0xE3AF9E, 0x3D1B3 },
	{ 0xE3AF9F, 0x3D1B9 },
	{ 0xE3AFA0, 0x3CCCB },
	{ 0xE3AFA1, 0x4D0DE },
	{ 0xE3AFA2, 0x3D1AD },
	{ 0xE3AFA3, 0x4D0E4 },
	{ 0xE3AFA4, 0x3D1B5 },
	{ 0xE3AFA5, 0x3D1B4 },
	{ 0xE3AFA6, 0x3D1B6 },
	{ 0xE3AFAA, 0x3D5A2 },
	{ 0xE3AFAB, 0x4D6C8 },
	{ 0xE3AFAC, 0x3D4FE },
	{ 0xE3AFAD, 0x3D5A5 },
	{ 0xE3AFAE, 0x3D4FD },
	{ 0xE3AFAF, 0x4D6CB },
	{ 0xE3AFB0, 0x7B8D5 },
	{ 0xE3AFB1, 0x5DBE8 },
	{ 0xE3AFB2, 0x3D4F7 },
	{ 0xE3AFB3, 0x3D5A6 },
	{ 0xE3AFB4, 0xFDFA9 },
	{ 0xE3AFB5, 0x3D4F9 },
	{ 0xE3AFB6, 0x3D5A8 },
	{ 0xE3AFB7, 0x4DBC8 },
	{ 0xE3AFB8, 0x4DBC4 },
	{ 0xE3AFB9, 0x3D7FC },
	{ 0xE3AFBA, 0x4DBCA },
	{ 0xE3AFBB, 0x4DBC9 },
	{ 0xE3AFBE, 0x4DFEF },
	{ 0xE3AFBF, 0x4DFF3 },
	{ 0xE3B080, 0x3DAC9 },
	{ 0xE3B081, 0x4DFF0 },
	{ 0xE3B082, 0x4DFEE },
	{ 0xE3B083, 0x4DFF2 },
	{ 0xE3B084, 0x4DFF5 },
	{ 0xE3B085, 0x3DACC },
	{ 0xE3B086, 0x3DACB },
	{ 0xE3B087, 0xFE2D3 },
	{ 0xE3B088, 0x3DACA },
	{ 0xE3B089, 0x3DCCC },
	{ 0xE3B08A, 0x3DCC6 },
	{ 0xE3B08B, 0x4E3D1 },
	{ 0xE3B08C, 0x4E3CF },
	{ 0xE3B08D, 0x3DCC8 },
	{ 0xE3B08E, 0x3DCCD },
	{ 0xE3B08F, 0x4E3D4 },
	{ 0xE3B090, 0x3DCCB },
	{ 0xE3B091, 0x3DCC5 },
	{ 0xE3B092, 0xFE5BE },
	{ 0xE3B094, 0x5F0A7 },
	{ 0xE3B095, 0x3DEB6 },
	{ 0xE3B096, 0x3DCCA },
	{ 0xE3B097, 0x3DFD0 },
	{ 0xE3B098, 0x4E8EE },
	{ 0xE3B099, 0x3E0B5 },
	{ 0xE3B09A, 0x3E0B3 },
	{ 0xE3B09B, 0x3E0B4 },
	{ 0xE3B09D, 0x5A4C8 },
	{ 0xE3B09E, 0x6A8B0 },
	{ 0xE3B09F, 0x4A6ED },
	{ 0xE3B0A0, 0x5A6D6 },
	{ 0xE3B0A1, 0x4A6F0 },
	{ 0xE3B0A2, 0x4A6EC },
	{ 0xE3B0A3, 0x4ADE0 },
	{ 0xE3B0A4, 0x4A9F0 },
	{ 0xE3B0A5, 0x4A9F1 },
	{ 0xE3B0A6, 0x6B1F8 },
	{ 0xE3B0A7, 0x4A9F4 },
	{ 0xE3B0A8, 0x4A9F3 },
	{ 0xE3B0A9, 0x5AEAE },
	{ 0xE3B0AA, 0x4ADDD },
	{ 0xE3B0AB, 0x4ADE1 },
	{ 0xE3B0AC, 0x4ADE2 },
	{ 0xE3B0AD, 0x4ADDE },
	{ 0xE3B0AE, 0x3B6E1 },
	{ 0xE3B0AF, 0x4B2C8 },
	{ 0xE3B0B0, 0x4B2C9 },
	{ 0xE3B0B1, 0x6C0EE },
	{ 0xE3B0B2, 0x4B8BB },
	{ 0xE3B0B3, 0x4B8B9 },
	{ 0xE3B0B4, 0x3BCC6 },
	{ 0xE3B0B5, 0x5B9C3 },
	{ 0xE3B0B6, 0x4B8BC },
	{ 0xE3B0B7, 0x6B8E4 },
	{ 0xE3B0B9, 0x4BEA1 },
	{ 0xE3B0BA, 0x4BDFC },
	{ 0xE3B0BB, 0x4BDFB },
	{ 0xE3B0BC, 0x4BDFD },
	{ 0xE3B0BD, 0x4BDFE },
	{ 0xE3B0BE, 0x4BEA2 },
	{ 0xE3B0BF, 0x3C7D2 },
	{ 0xE3B180, 0x6DDF7 },
	{ 0xE3B181, 0x4C4AA },
	{ 0xE3B182, 0x4CACC },
	{ 0xE3B183, 0x3CCE8 },
	{ 0xE3B184, 0x4D0E6 },
	{ 0xE3B185, 0x4D0E7 },
	{ 0xE3B186, 0x4D6CF },
	{ 0xE3B187, 0x4D6CE },
	{ 0xE3B188, 0x3D5AA },
	{ 0xE3B189, 0x3D5AC },
	{ 0xE3B18A, 0x4DFF7 },
	{ 0xE3B18B, 0x7CEA2 },
	{ 0xE3B18C, 0x4E8F1 },
	{ 0xE3B18D, 0x5F5F7 },
	{ 0xE3B18E, 0x5F9AF },
	{ 0xE3B18F, 0x6A5A5 },
	{ 0xE3B192, 0x3ADBE },
	{ 0xE3B194, 0x3ABFB },
	{ 0xE3B195, 0x3BCC8 },
	{ 0xE3B196, 0x4B8BF },
	{ 0xE3B197, 0x5C6DF },
	{ 0xE3B198, 0x3D8A4 },
	{ 0xE3B199, 0x4A2FC },
	{ 0xE3B19A, 0x3A9D7 },
	{ 0xE3B19B, 0x5A6E2 },
	{ 0xE3B19C, 0x4A6F5 },
	{ 0xE3B19E, 0x3ADBF },
	{ 0xE3B19F, 0x3ADC1 },
	{ 0xE3B1A0, 0x3ADC0 },
	{ 0xE3B1A1, 0x3B1E9 },
	{ 0xE3B1A2, 0x3B6E3 },
	{ 0xE3B1A3, 0x4B2CA },
	{ 0xE3B1A4, 0x4B8C5 },
	{ 0xE3B1A5, 0x4B8C4 },
	{ 0xE3B1A6, 0x4B8C6 },
	{ 0xE3B1A7, 0x4B8C2 },
	{ 0xE3B1A8, 0x3BCCA },
	{ 0xE3B1AA, 0x3C2A3 },
	{ 0xE3B1AB, 0x4BEA3 },
	{ 0xE3B1AC, 0x4BEA4 },
	{ 0xE3B1AD, 0x3C2A4 },
	{ 0xE3B1AF, 0x4C4B2 },
	{ 0xE3B1B0, 0x5C6E0 },
	{ 0xE3B1B1, 0x4C4B3 },
	{ 0xE3B1B2, 0x4C4B0 },
	{ 0xE3B1B3, 0x4CAD0 },
	{ 0xE3B1B4, 0x4CACF },
	{ 0xE3B1B5, 0x4D0EB },
	{ 0xE3B1B6, 0x4D0EA },
	{ 0xE3B1B8, 0x4D6D1 },
	{ 0xE3B1B9, 0x4E3D5 },
	{ 0xE3B1BA, 0x3DCCE },
	{ 0xE3B1BB, 0x5F5F8 },
	{ 0xE3B1BC, 0x5A4CE },
	{ 0xE3B1BD, 0x4A6F8 },
	{ 0xE3B1BE, 0x4ADE4 },
	{ 0xE3B1BF, 0x3B1EB },
	{ 0xE3B280, 0x4B2CF },
	{ 0xE3B281, 0x4B8C9 },
	{ 0xE3B282, 0x4B8CA },
	{ 0xE3B283, 0x4B8CB },
	{ 0xE3B284, 0x3C2A5 },
	{ 0xE3B285, 0x4C4B5 },
	{ 0xE3B286, 0x3D1C7 },
	{ 0xE3B287, 0x3D1C8 },
	{ 0xE3B288, 0x4D0EE },
	{ 0xE3B289, 0x4D6D3 },
	{ 0xE3B28A, 0x3D8A5 },
	{ 0xE3B28B, 0x4A9FB },
	{ 0xE3B28C, 0x3A3FB },
	{ 0xE3B28D, 0x4A6F9 },
	{ 0xE3B28E, 0x3A9DB },
	{ 0xE3B28F, 0x4A6FA },
	{ 0xE3B291, 0xFA7DB },
	{ 0xE3B292, 0x3ADC3 },
	{ 0xE3B293, 0x4ADE6 },
	{ 0xE3B294, 0x4B2D2 },
	{ 0xE3B295, 0x4B2D4 },
	{ 0xE3B296, 0x4B2D3 },
	{ 0xE3B297, 0x4B2D5 },
	{ 0xE3B298, 0x3B6E7 },
	{ 0xE3B299, 0x4ADE7 },
	{ 0xE3B29A, 0x4B2D1 },
	{ 0xE3B29B, 0x5B9DB },
	{ 0xE3B29C, 0x3BCCC },
	{ 0xE3B29D, 0x4B8CF },
	{ 0xE3B29E, 0x4B8CC },
	{ 0xE3B29F, 0x4BEA9 },
	{ 0xE3B2A0, 0x3C2A7 },
	{ 0xE3B2A1, 0x4BEA8 },
	{ 0xE3B2A2, 0x4BEA7 },
	{ 0xE3B2A3, 0x4C4BF },
	{ 0xE3B2A4, 0x4C4B8 },
	{ 0xE3B2A5, 0x4C4B9 },
	{ 0xE3B2A6, 0x4C4BA },
	{ 0xE3B2A7, 0x5C6E8 },
	{ 0xE3B2A8, 0x4C4BC },
	{ 0xE3B2AA, 0x4D0EF },
	{ 0xE3B2AB, 0x4D0F1 },
	{ 0xE3B2AC, 0x4D0F2 },
	{ 0xE3B2AD, 0x3D1C9 },
	{ 0xE3B2AF, 0x4DBD0 },
	{ 0xE3B2B0, 0x4DBCF },
	{ 0xE3B2B1, 0x3DAD0 },
	{ 0xE3B2B2, 0x4EDD7 },
	{ 0xE3B2B3, 0x4ADEA },
	{ 0xE3B2B4, 0x3A9DC },
	{ 0xE3B2B5, 0x3B6E8 },
	{ 0xE3B2B6, 0x3CCE9 },
	{ 0xE3B2B7, 0x3D1CA },
	{ 0xE3B2B8, 0x4A1CF },
	{ 0xE3B2B9, 0x3A2D6 },
	{ 0xE3B2BA, 0x3A2D5 },
	{ 0xE3B2BB, 0x3A4A2 },
	{ 0xE3B2BC, 0x5A1F4 },
	{ 0xE3B2BD, 0x4A3A2 },
	{ 0xE3B2BE, 0x3A6D4 },
	{ 0xE3B380, 0x3A6CF },
	{ 0xE3B381, 0x4A4CF },
	{ 0xE3B382, 0x3A6DD },
	{ 0xE3B383, 0x6A8C9 },
	{ 0xE3B384, 0x3A6DA },
	{ 0xE3B385, 0x4A4D1 },
	{ 0xE3B386, 0x3A6CB },
	{ 0xE3B387, 0x6A8CA },
	{ 0xE3B388, 0x6A8C4 },
	{ 0xE3B38A, 0x3A6D8 },
	{ 0xE3B38B, 0x3A9E1 },
	{ 0xE3B38C, 0x3A9DF },
	{ 0xE3B38D, 0x3A9DE },
	{ 0xE3B38E, 0x3A9E2 },
	{ 0xE3B38F, 0x3A9E0 },
	{ 0xE3B390, 0x4A6FE },
	{ 0xE3B391, 0x3A9E8 },
	{ 0xE3B392, 0x3A9E6 },
	{ 0xE3B393, 0xFA7E6 },
	{ 0xE3B396, 0x3ADC4 },
	{ 0xE3B397, 0x5AAA4 },
	{ 0xE3B398, 0x4A7A2 },
	{ 0xE3B399, 0x3ADD4 },
	{ 0xE3B39A, 0x5A9FB },
	{ 0xE3B39B, 0x5A9FC },
	{ 0xE3B39C, 0x4A9FE },
	{ 0xE3B39D, 0x3ADD6 },
	{ 0xE3B39E, 0x3ADCC },
	{ 0xE3B39F, 0xFB0C9 },
	{ 0xE3B3A4, 0x6B8F2 },
	{ 0xE3B3A5, 0x3B1F0 },
	{ 0xE3B3A6, 0x3B1F1 },
	{ 0xE3B3A7, 0x4ADEB },
	{ 0xE3B3A8, 0x6B9B3 },
	{ 0xE3B3A9, 0x3B1F4 },
	{ 0xE3B3AA, 0x4ADEC },
	{ 0xE3B3AB, 0x3B6E9 },
	{ 0xE3B3AC, 0x3B2A4 },
	{ 0xE3B3AD, 0x3B2A3 },
	{ 0xE3B3AE, 0x3B1FE },
	{ 0xE3B3B3, 0x3B1F5 },
	{ 0xE3B3B4, 0x4B2D7 },
	{ 0xE3B3B5, 0x3B6F1 },
	{ 0xE3B3B6, 0x4B2E3 },
	{ 0xE3B3B7, 0x4B2E4 },
	{ 0xE3B3B8, 0x3B6EE },
	{ 0xE3B3B9, 0x4B2DE },
	{ 0xE3B3BA, 0x3B7A2 },
	{ 0xE3B3BB, 0x3B6ED },
	{ 0xE3B3BC, 0x3BCCF },
	{ 0xE3B3BD, 0x3B6FE },
	{ 0xE3B3BE, 0x4B2D8 },
	{ 0xE3B3BF, 0x4B2E8 },
	{ 0xE3B480, 0x5B9DE },
	{ 0xE3B481, 0x4B2DA },
	{ 0xE3B482, 0x4B2DC },
	{ 0xE3B483, 0x6C1AB },
	{ 0xE3B484, 0x5B3BD },
	{ 0xE3B485, 0x3BCDE },
	{ 0xE3B486, 0x3B6FB },
	{ 0xE3B487, 0x3BCDF },
	{ 0xE3B488, 0x3B6F3 },
	{ 0xE3B489, 0x6C1C1 },
	{ 0xE3B48A, 0x3B6F8 },
	{ 0xE3B48E, 0xFB6B3 },
	{ 0xE3B48F, 0x4B8D1 },
	{ 0xE3B490, 0x4B8D6 },
	{ 0xE3B491, 0x3BCE5 },
	{ 0xE3B492, 0x4B8D2 },
	{ 0xE3B493, 0x3BCD9 },
	{ 0xE3B494, 0x4B8D9 },
	{ 0xE3B495, 0x3BCEA },
	{ 0xE3B496, 0x3BCE7 },
	{ 0xE3B497, 0x3BCD5 },
	{ 0xE3B498, 0x4B8D7 },
	{ 0xE3B499, 0x4B8DA },
	{ 0xE3B49A, 0x3BCD3 },
	{ 0xE3B49B, 0x3BCD7 },
	{ 0xE3B49C, 0x3BCE1 },
	{ 0xE3B49D, 0x3C2AB },
	{ 0xE3B49E, 0x6CAED },
	{ 0xE3B4A0, 0xFBCC3 },
	{ 0xE3B4A1, 0xFBCDA },
	{ 0xE3B4A5, 0x4BEB7 },
	{ 0xE3B4A6, 0x3C2AC },
	{ 0xE3B4A7, 0x3C2B7 },
	{ 0xE3B4A8, 0x3C2B5 },
	{ 0xE3B4A9, 0x3C2C8 },
	{ 0xE3B4AA, 0x3C2B8 },
	{ 0xE3B4AB, 0x4BEB0 },
	{ 0xE3B4AC, 0x4BEB9 },
	{ 0xE3B4AD, 0x4BEAD },
	{ 0xE3B4AE, 0x3C2C2 },
	{ 0xE3B4AF, 0x4BEB8 },
	{ 0xE3B4B0, 0x3C2B4 },
	{ 0xE3B4B1, 0x3C2BC },
	{ 0xE3B4B2, 0x4BEBC },
	{ 0xE3B4B3, 0x3C2AF },
	{ 0xE3B4B4, 0x3C2C1 },
	{ 0xE3B4B5, 0x5C0A7 },
	{ 0xE3B4B6, 0x4BEAF },
	{ 0xE3B4B7, 0x4BEB2 },
	{ 0xE3B4B8, 0x3C2B2 },
	{ 0xE3B4BB, 0x3C2C3 },
	{ 0xE3B4BC, 0x3C7D5 },
	{ 0xE3B4BD, 0x4C4C9 },
	{ 0xE3B4BE, 0x3C7E0 },
	{ 0xE3B4BF, 0x6DEBB },
	{ 0xE3B580, 0x3C7D9 },
	{ 0xE3B581, 0x6D4D0 },
	{ 0xE3B582, 0x3C7D8 },
	{ 0xE3B583, 0x4C4C6 },
	{ 0xE3B584, 0x4C4CD },
	{ 0xE3B585, 0x4C4CA },
	{ 0xE3B586, 0x6DEC0 },
	{ 0xE3B58A, 0x3CCEE },
	{ 0xE3B58B, 0x4CADF },
	{ 0xE3B58C, 0x4CAE1 },
	{ 0xE3B58D, 0x3CCEF },
	{ 0xE3B58E, 0x3CCFC },
	{ 0xE3B58F, 0x4CAE8 },
	{ 0xE3B590, 0x4CADD },
	{ 0xE3B591, 0x3CCED },
	{ 0xE3B592, 0x4CAD9 },
	{ 0xE3B593, 0x3CCF2 },
	{ 0xE3B594, 0x5C6F8 },
	{ 0xE3B595, 0x7A4E1 },
	{ 0xE3B596, 0x3CCF0 },
	{ 0xE3B597, 0x4D0F4 },
	{ 0xE3B598, 0x3D1CB },
	{ 0xE3B599, 0x3CCF6 },
	{ 0xE3B59D, 0x4D0F7 },
	{ 0xE3B59E, 0x4D0FD },
	{ 0xE3B59F, 0x5D5B6 },
	{ 0xE3B5A0, 0x4D0F6 },
	{ 0xE3B5A1, 0x3D1CF },
	{ 0xE3B5A2, 0x3D1CE },
	{ 0xE3B5A3, 0x4D0FA },
	{ 0xE3B5A4, 0x5D5AD },
	{ 0xE3B5A5, 0x3D1D3 },
	{ 0xE3B5A6, 0x3D1D7 },
	{ 0xE3B5A7, 0x4D0FB },
	{ 0xE3B5A8, 0x4D6D6 },
	{ 0xE3B5A9, 0x3D1D1 },
	{ 0xE3B5AA, 0x3D1CC },
	{ 0xE3B5AB, 0x4D0F8 },
	{ 0xE3B5AC, 0x3D1D2 },
	{ 0xE3B5AD, 0x4CAE2 },
	{ 0xE3B5AE, 0x5D5AE },
	{ 0xE3B5AF, 0x3D5B2 },
	{ 0xE3B5B0, 0x3D5B8 },
	{ 0xE3B5B1, 0x4D6DE },
	{ 0xE3B5B2, 0x4D6E0 },
	{ 0xE3B5B3, 0x3D5B4 },
	{ 0xE3B5B4, 0x4D6D8 },
	{ 0xE3B5B5, 0x3D5AE },
	{ 0xE3B5B6, 0x4D6D7 },
	{ 0xE3B5B7, 0x4D6DC },
	{ 0xE3B5B8, 0x3D5BB },
	{ 0xE3B5B9, 0x4D6D9 },
	{ 0xE3B5BA, 0x4D6DB },
	{ 0xE3B5BB, 0x3D5B3 },
	{ 0xE3B5BD, 0x4DBD6 },
	{ 0xE3B5BE, 0x4DBD4 },
	{ 0xE3B5BF, 0x4DBDA },
	{ 0xE3B680, 0x4DBD7 },
	{ 0xE3B681, 0x4DBE0 },
	{ 0xE3B684, 0x4DFFB },
	{ 0xE3B685, 0x4DFFD },
	{ 0xE3B686, 0x4DBDB },
	{ 0xE3B687, 0x4DFF9 },
	{ 0xE3B688, 0x3DAD1 },
	{ 0xE3B68C, 0x3DCD0 },
	{ 0xE3B68D, 0x4E3DA },
	{ 0xE3B68E, 0x4E3DE },
	{ 0xE3B68F, 0x4E3DB },
	{ 0xE3B691, 0x3DCD2 },
	{ 0xE3B692, 0x4E6C9 },
	{ 0xE3B693, 0x5F0BE },
	{ 0xE3B694, 0x4E6CA },
	{ 0xE3B695, 0x4E6CC },
	{ 0xE3B696, 0x4E8F3 },
	{ 0xE3B697, 0x3DEB9 },
	{ 0xE3B698, 0x3DEB8 },
	{ 0xE3B69A, 0x3DFD1 },
	{ 0xE3B69B, 0x4EACE },
	{ 0xE3B69C, 0x3E0B8 },
	{ 0xE3B69E, 0x4EBED },
	{ 0xE3B69F, 0x4EBEE },
	{ 0xE3B6A0, 0x3E1E6 },
	{ 0xE3B6A1, 0x3A4AA },
	{ 0xE3B6A3, 0x4A4D2 },
	{ 0xE3B6A4, 0x3A6E1 },
	{ 0xE3B6A5, 0xFA4EE },
	{ 0xE3B6A6, 0x3A9EE },
	{ 0xE3B6A7, 0x4A7A7 },
	{ 0xE3B6A8, 0x3A9F8 },
	{ 0xE3B6A9, 0xFA7EE },
	{ 0xE3B6AA, 0x3A9F3 },
	{ 0xE3B6AB, 0x3ADE7 },
	{ 0xE3B6AC, 0x3ADD9 },
	{ 0xE3B6AD, 0x3ADE6 },
	{ 0xE3B6AE, 0x3ADE1 },
	{ 0xE3B6AF, 0x3ADE0 },
	{ 0xE3B6B0, 0x3ADDB },
	{ 0xE3B6B2, 0x4AAA7 },
	{ 0xE3B6B3, 0x3B2AE },
	{ 0xE3B6B4, 0x4ADF3 },
	{ 0xE3B6B5, 0x3B2B2 },
	{ 0xE3B6B9, 0x3B7AB },
	{ 0xE3B6BA, 0x3B7AA },
	{ 0xE3B6BB, 0x3B7B4 },
	{ 0xE3B6BC, 0x4B2F1 },
	{ 0xE3B6BE, 0x4B2F6 },
	{ 0xE3B6BF, 0x4B2F0 },
	{ 0xE3B780, 0x4B2F7 },
	{ 0xE3B781, 0xFB6C8 },
	{ 0xE3B782, 0x3BCF6 },
	{ 0xE3B783, 0x4B8E5 },
	{ 0xE3B784, 0x4B8E1 },
	{ 0xE3B785, 0x3BCF5 },
	{ 0xE3B786, 0x4B8E2 },
	{ 0xE3B787, 0x4B8E4 },
	{ 0xE3B788, 0x4B8E0 },
	{ 0xE3B789, 0x3BBA3 },
	{ 0xE3B78A, 0x3BCFE },
	{ 0xE3B78B, 0x3BCF0 },
	{ 0xE3B78D, 0x3BCF8 },
	{ 0xE3B78E, 0x3C2D4 },
	{ 0xE3B78F, 0x3C2CD },
	{ 0xE3B790, 0x3C2D6 },
	{ 0xE3B791, 0x4BECB },
	{ 0xE3B792, 0x3C2CA },
	{ 0xE3B793, 0x3C2D5 },
	{ 0xE3B794, 0x4BEC8 },
	{ 0xE3B795, 0x4BEC6 },
	{ 0xE3B796, 0x4BEC9 },
	{ 0xE3B797, 0x6D4D4 },
	{ 0xE3B798, 0x3C2CB },
	{ 0xE3B799, 0x3C2D0 },
	{ 0xE3B79A, 0xFC2F8 },
	{ 0xE3B79B, 0xFC3BC },
	{ 0xE3B79F, 0x4C4D9 },
	{ 0xE3B7A0, 0x3C7F3 },
	{ 0xE3B7A1, 0x3C7E9 },
	{ 0xE3B7A2, 0x6D4E7 },
	{ 0xE3B7A3, 0x4C4D6 },
	{ 0xE3B7A4, 0x4C4DA },
	{ 0xE3B7A5, 0x4C4DC },
	{ 0xE3B7A6, 0x3C7F1 },
	{ 0xE3B7A8, 0xFC9D8 },
	{ 0xE3B7AB, 0x3CDA6 },
	{ 0xE3B7AC, 0x3CDA3 },
	{ 0xE3B7AD, 0x3CDAB },
	{ 0xE3B7AE, 0x3CDA1 },
	{ 0xE3B7AF, 0x3CDA7 },
	{ 0xE3B7B0, 0x4CAEA },
	{ 0xE3B7B3, 0x4D1A5 },
	{ 0xE3B7B4, 0x3D1DD },
	{ 0xE3B7B5, 0x3D1DB },
	{ 0xE3B7B6, 0x4D1AB },
	{ 0xE3B7B7, 0x3D1DF },
	{ 0xE3B7B8, 0x3D1E1 },
	{ 0xE3B7B9, 0x4D1A4 },
	{ 0xE3B7BB, 0x3D1E4 },
	{ 0xE3B7BC, 0x3D1E5 },
	{ 0xE3B7BE, 0x3D5BD },
	{ 0xE3B7BF, 0x4D6E2 },
	{ 0xE3B880, 0x3D5BF },
	{ 0xE3B881, 0x3D5C4 },
	{ 0xE3B882, 0x7B9A6 },
	{ 0xE3B883, 0x3D7D1 },
	{ 0xE3B884, 0x3D8AC },
	{ 0xE3B885, 0x4D6E4 },
	{ 0xE3B888, 0x3DCDA },
	{ 0xE3B889, 0x3DAD9 },
	{ 0xE3B88A, 0x3DCD4 },
	{ 0xE3B88B, 0x3DCDB },
	{ 0xE3B88C, 0x4E3DF },
	{ 0xE3B88D, 0x4E6CE },
	{ 0xE3B88E, 0x5F3D7 },
	{ 0xE3B88F, 0x4EAD0 },
	{ 0xE3B890, 0x3E0BA },
	{ 0xE3B891, 0x3E1FA },
	{ 0xE3B892, 0x4A7AC },
	{ 0xE3B893, 0x3A9FA },
	{ 0xE3B894, 0x3B7D8 },
	{ 0xE3B895, 0x3C7F4 },
	{ 0xE3B896, 0x3ADEA },
	{ 0xE3B897, 0x4ADF6 },
	{ 0xE3B898, 0x3B7B6 },
	{ 0xE3B899, 0x4B8EB },
	{ 0xE3B89A, 0x3A9FB },
	{ 0xE3B89B, 0x4AAAC },
	{ 0xE3B89C, 0x4B8EC },
	{ 0xE3B89D, 0x3A9FD },
	{ 0xE3B89E, 0x3A9FE },
	{ 0xE3B89F, 0x5AED3 },
	{ 0xE3B8A0, 0x6B9C0 },
	{ 0xE3B8A1, 0x4ADFA },
	{ 0xE3B8A2, 0x4C4DF },
	{ 0xE3B8A3, 0x7B9AD },
	{ 0xE3B8A4, 0x4DBE4 },
	{ 0xE3B8A5, 0x4E6D0 },
	{ 0xE3B8A6, 0x3A1EA },
	{ 0xE3B8A7, 0x3B2B3 },
	{ 0xE3B8A8, 0x4A3A6 },
	{ 0xE3B8A9, 0x3A6E5 },
	{ 0xE3B8AA, 0x4A4D5 },
	{ 0xE3B8AB, 0x6ACF1 },
	{ 0xE3B8AC, 0x4A7B3 },
	{ 0xE3B8AD, 0x5A6F7 },
	{ 0xE3B8AE, 0x4A7B2 },
	{ 0xE3B8AF, 0x4A7AF },
	{ 0xE3B8B0, 0x3ADEC },
	{ 0xE3B8B1, 0x3ADEF },
	{ 0xE3B8B2, 0x4AAAE },
	{ 0xE3B8B3, 0x3ADEE },
	{ 0xE3B8B5, 0x3B2B4 },
	{ 0xE3B8B6, 0x3B2B5 },
	{ 0xE3B8B7, 0x4ADFD },
	{ 0xE3B8B8, 0x4ADFC },
	{ 0xE3B8B9, 0x4B2FA },
	{ 0xE3B8BA, 0x5B3CD },
	{ 0xE3B8BB, 0x4B2F9 },
	{ 0xE3B8BC, 0x4B2FE },
	{ 0xE3B8BD, 0x3B7B8 },
	{ 0xE3B8BE, 0x6C1E6 },
	{ 0xE3B980, 0x3B7B7 },
	{ 0xE3B981, 0x4B8F0 },
	{ 0xE3B982, 0x4B8F2 },
	{ 0xE3B983, 0x4B8F3 },
	{ 0xE3B984, 0x4C4E3 },
	{ 0xE3B985, 0x6D4F8 },
	{ 0xE3B986, 0x4BECE },
	{ 0xE3B987, 0x3C2DE },
	{ 0xE3B989, 0x4C4E2 },
	{ 0xE3B98A, 0x4C4E0 },
	{ 0xE3B98B, 0x4C4E4 },
	{ 0xE3B98C, 0x4CAEF },
	{ 0xE3B98D, 0x4CAEE },
	{ 0xE3B98E, 0x4CAF2 },
	{ 0xE3B98F, 0x4CAF1 },
	{ 0xE3B990, 0x4CAF3 },
	{ 0xE3B991, 0x4D1AE },
	{ 0xE3B992, 0x4D1B0 },
	{ 0xE3B993, 0x4D1AF },
	{ 0xE3B994, 0x4D6E7 },
	{ 0xE3B995, 0x3D5C6 },
	{ 0xE3B996, 0x3D5C7 },
	{ 0xE3B997, 0x4DBE6 },
	{ 0xE3B998, 0x4DBE5 },
	{ 0xE3B999, 0x4E0A4 },
	{ 0xE3B99A, 0x7D3EB },
	{ 0xE3B99B, 0x4EAD1 },
	{ 0xE3B99C, 0x4A7B4 },
	{ 0xE3B99D, 0x4A4D9 },
	{ 0xE3B99E, 0x3A6ED },
	{ 0xE3B99F, 0x4A4D6 },
	{ 0xE3B9A0, 0x3A6EC },
	{ 0xE3B9A1, 0x6ACF5 },
	{ 0xE3B9A2, 0x4A7B9 },
	{ 0xE3B9A3, 0x5A7AE },
	{ 0xE3B9A4, 0x3AAA9 },
	{ 0xE3B9A5, 0x3AAA4 },
	{ 0xE3B9A6, 0x3AAA5 },
	{ 0xE3B9A7, 0x4A7BA },
	{ 0xE3B9AB, 0x4AAB2 },
	{ 0xE3B9AC, 0x4AAB4 },
	{ 0xE3B9AD, 0x4AAB5 },
	{ 0xE3B9AE, 0x3ADF2 },
	{ 0xE3B9AF, 0x6B2E7 },
	{ 0xE3B9B1, 0x3B2B7 },
	{ 0xE3B9B2, 0x5AEDC },
	{ 0xE3B9B3, 0x4AEA1 },
	{ 0xE3B9B4, 0x4ADFE },
	{ 0xE3B9B5, 0x4AEA2 },
	{ 0xE3B9B6, 0x4AEA6 },
	{ 0xE3B9B7, 0x6C1ED },
	{ 0xE3B9B8, 0x4AEA7 },
	{ 0xE3B9B9, 0x5B3D1 },
	{ 0xE3B9BA, 0x4B3A8 },
	{ 0xE3B9BB, 0x6C1F5 },
	{ 0xE3B9BC, 0x4B3A9 },
	{ 0xE3B9BD, 0x4B3A5 },
	{ 0xE3B9BE, 0x4B3AB },
	{ 0xE3B9BF, 0x4B3A7 },
	{ 0xE3BA80, 0x4B3AE },
	{ 0xE3BA81, 0x4B8F9 },
	{ 0xE3BA82, 0x4B8F7 },
	{ 0xE3BA83, 0x3BDAC },
	{ 0xE3BA84, 0x4B8FB },
	{ 0xE3BA85, 0x6CBC3 },
	{ 0xE3BA87, 0x4C4E5 },
	{ 0xE3BA88, 0x4BED4 },
	{ 0xE3BA89, 0x4C4E6 },
	{ 0xE3BA8A, 0x4BED3 },
	{ 0xE3BA8B, 0x3C2E0 },
	{ 0xE3BA8C, 0x4BED2 },
	{ 0xE3BA8E, 0x4C4EA },
	{ 0xE3BA8F, 0x6DEEE },
	{ 0xE3BA90, 0x4C4E9 },
	{ 0xE3BA91, 0x4C4E8 },
	{ 0xE3BA92, 0x4C4E7 },
	{ 0xE3BA93, 0x3C7F6 },
	{ 0xE3BA94, 0x4B8FA },
	{ 0xE3BA95, 0x4CAFB },
	{ 0xE3BA96, 0x4CAF6 },
	{ 0xE3BA97, 0x4CAFA },
	{ 0xE3BA98, 0x4CAFC },
	{ 0xE3BA9A, 0x7AFF4 },
	{ 0xE3BA9B, 0x4D1B2 },
	{ 0xE3BA9C, 0x4D1B4 },
	{ 0xE3BA9D, 0x3D5C8 },
	{ 0xE3BA9E, 0x4D6EA },
	{ 0xE3BA9F, 0x4D6EB },
	{ 0xE3BAA0, 0x4DBE7 },
	{ 0xE3BAA1, 0x5E8BB },
	{ 0xE3BAA3, 0x4E3E5 },
	{ 0xE3BAA4, 0x4E3E6 },
	{ 0xE3BAA5, 0x4E3E7 },
	{ 0xE3BAA6, 0x4E3E3 },
	{ 0xE3BAA7, 0x4EBEF },
	{ 0xE3BAA8, 0x3A4AE },
	{ 0xE3BAA9, 0x4A3A9 },
	{ 0xE3BAAA, 0x3A4B0 },
	{ 0xE3BAAB, 0x3A4B1 },
	{ 0xE3BAAC, 0x3A6F1 },
	{ 0xE3BAAD, 0x3A6EF },
	{ 0xE3BAAE, 0x3A6F0 },
	{ 0xE3BAB0, 0x3AAAE },
	{ 0xE3BAB1, 0x3ADF6 },
	{ 0xE3BAB2, 0x6ADA1 },
	{ 0xE3BAB3, 0x3AAB0 },
	{ 0xE3BAB4, 0x4A7BB },
	{ 0xE3BAB5, 0x3AAB1 },
	{ 0xE3BAB7, 0x3ADFD },
	{ 0xE3BAB8, 0x3B2BA },
	{ 0xE3BAB9, 0x4AAB7 },
	{ 0xE3BABA, 0x4AAB8 },
	{ 0xE3BABD, 0xFACB2 },
	{ 0xE3BABF, 0x4B3AF },
	{ 0xE3BB80, 0x3B2C3 },
	{ 0xE3BB81, 0x3B2C4 },
	{ 0xE3BB82, 0x3B2BB },
	{ 0xE3BB83, 0x4B3B0 },
	{ 0xE3BB84, 0x3B2C5 },
	{ 0xE3BB87, 0xFB1A7 },
	{ 0xE3BB88, 0x3B2C2 },
	{ 0xE3BB89, 0x3B7BF },
	{ 0xE3BB8A, 0x3B7C2 },
	{ 0xE3BB8B, 0x3B7C1 },
	{ 0xE3BB8C, 0x4B3B3 },
	{ 0xE3BB8D, 0x3B7BE },
	{ 0xE3BB8E, 0x3B7C3 },
	{ 0xE3BB91, 0x3BDB4 },
	{ 0xE3BB92, 0x4B8FD },
	{ 0xE3BB93, 0x5BAAD },
	{ 0xE3BB94, 0x3C2E3 },
	{ 0xE3BB95, 0x3BDB1 },
	{ 0xE3BB96, 0x3BDB0 },
	{ 0xE3BB97, 0x3C2EC },
	{ 0xE3BB99, 0xFB6D9 },
	{ 0xE3BB9A, 0xFBDBB },
	{ 0xE3BB9D, 0x4BED9 },
	{ 0xE3BB9E, 0x3C2E5 },
	{ 0xE3BB9F, 0x3C2E9 },
	{ 0xE3BBA0, 0x5C0CE },
	{ 0xE3BBA1, 0x3C2F2 },
	{ 0xE3BBA2, 0xFC3C9 },
	{ 0xE3BBA3, 0xFC3D6 },
	{ 0xE3BBA7, 0x3C8A4 },
	{ 0xE3BBA8, 0x7A5B7 },
	{ 0xE3BBAB, 0x4CBA2 },
	{ 0xE3BBAC, 0x4CBA1 },
	{ 0xE3BBAD, 0x3CDB7 },
	{ 0xE3BBAE, 0x3CDBC },
	{ 0xE3BBAF, 0x3CDB3 },
	{ 0xE3BBB0, 0x3CDB8 },
	{ 0xE3BBB1, 0x3CDB4 },
	{ 0xE3BBB2, 0x3CDB2 },
	{ 0xE3BBB5, 0x3D1E8 },
	{ 0xE3BBB6, 0x5D5DD },
	{ 0xE3BBB7, 0x4D1B7 },
	{ 0xE3BBB8, 0x3D1E9 },
	{ 0xE3BBB9, 0x3D5CA },
	{ 0xE3BBBA, 0x4D6EF },
	{ 0xE3BBBB, 0xFD5FA },
	{ 0xE3BBBC, 0xFD6A2 },
	{ 0xE3BBBD, 0x3D5CE },
	{ 0xE3BBBE, 0x4DBE9 },
	{ 0xE3BBBF, 0x3D5CC },
	{ 0xE3BC81, 0xFDBAD },
	{ 0xE3BC82, 0x3D8B1 },
	{ 0xE3BC84, 0x4E0AA },
	{ 0xE3BC85, 0xFE2F8 },
	{ 0xE3BC86, 0xFE2FB },
	{ 0xE3BC87, 0x3DCE1 },
	{ 0xE3BC89, 0x4AAB9 },
	{ 0xE3BC8A, 0x4AABA },
	{ 0xE3BC8B, 0x5AEE2 },
	{ 0xE3BC8C, 0x4AEAB },
	{ 0xE3BC8D, 0x4B3B5 },
	{ 0xE3BC8E, 0x4B3B4 },
	{ 0xE3BC8F, 0x4B8FE },
	{ 0xE3BC90, 0x4C4F0 },
	{ 0xE3BC91, 0x4C4F1 },
	{ 0xE3BC92, 0x4C4EF },
	{ 0xE3BC93, 0x4CBA3 },
	{ 0xE3BC94, 0x4CBA4 },
	{ 0xE3BC95, 0x4DBEC },
	{ 0xE3BC96, 0x4EDDA },
	{ 0xE3BC97, 0x4A4DE },
	{ 0xE3BC98, 0x5A7B2 },
	{ 0xE3BC99, 0x3AAB4 },
	{ 0xE3BC9A, 0x3AEA3 },
	{ 0xE3BC9B, 0x4AABD },
	{ 0xE3BC9C, 0x3B2CA },
	{ 0xE3BC9D, 0x3B2CB },
	{ 0xE3BC9E, 0x4AEAD },
	{ 0xE3BC9F, 0x3B2C9 },
	{ 0xE3BCA0, 0x4AEAC },
	{ 0xE3BCA1, 0x4B3BB },
	{ 0xE3BCA2, 0x4B9A1 },
	{ 0xE3BCA3, 0x4B3BA },
	{ 0xE3BCA4, 0x4B3B8 },
	{ 0xE3BCA5, 0x4B3B9 },
	{ 0xE3BCA6, 0x4B3B7 },
	{ 0xE3BCA7, 0x4B9A3 },
	{ 0xE3BCA8, 0x4B9A6 },
	{ 0xE3BCA9, 0x4B3BC },
	{ 0xE3BCAA, 0x4B9A4 },
	{ 0xE3BCAB, 0x4BEE2 },
	{ 0xE3BCAC, 0x4BEE1 },
	{ 0xE3BCAD, 0x4BEDD },
	{ 0xE3BCAE, 0x4BEE0 },
	{ 0xE3BCAF, 0x3C2F6 },
	{ 0xE3BCB0, 0x4BEE3 },
	{ 0xE3BCB1, 0x5C7C8 },
	{ 0xE3BCB2, 0x4C4F3 },
	{ 0xE3BCB3, 0x4C4F6 },
	{ 0xE3BCB4, 0x4C4F4 },
	{ 0xE3BCB5, 0x4C4F8 },
	{ 0xE3BCB6, 0x4C4F7 },
	{ 0xE3BCB7, 0x4C4F5 },
	{ 0xE3BCB8, 0x4CBA5 },
	{ 0xE3BCB9, 0x4CBA7 },
	{ 0xE3BCBA, 0x4CBA6 },
	{ 0xE3BCBB, 0x4D1BF },
	{ 0xE3BCBC, 0x3D1EF },
	{ 0xE3BCBD, 0x4D1C2 },
	{ 0xE3BCBE, 0x4D1C1 },
	{ 0xE3BCBF, 0x4D6F2 },
	{ 0xE3BD80, 0x4D6F3 },
	{ 0xE3BD81, 0x3D5D1 },
	{ 0xE3BD82, 0x4D6F5 },
	{ 0xE3BD83, 0x3D5D0 },
	{ 0xE3BD84, 0x4D6F1 },
	{ 0xE3BD86, 0x4DBEF },
	{ 0xE3BD87, 0x4DBEE },
	{ 0xE3BD88, 0x4E0AC },
	{ 0xE3BD89, 0x4E0AB },
	{ 0xE3BD8A, 0x4E8F5 },
	{ 0xE3BD8B, 0x4EBF0 },
	{ 0xE3BD8C, 0x4EAD3 },
	{ 0xE3BD8D, 0x3B2CC },
	{ 0xE3BD8E, 0x4BEE5 },
	{ 0xE3BD90, 0x3CDBF },
	{ 0xE3BD91, 0x4D6F8 },
	{ 0xE3BD92, 0x3BDC0 },
	{ 0xE3BD93, 0xFD0CE },
	{ 0xE3BD95, 0x5A4E3 },
	{ 0xE3BD96, 0x6A8E2 },
	{ 0xE3BD97, 0x3A6F2 },
	{ 0xE3BD98, 0x4AAC1 },
	{ 0xE3BD99, 0x3AEA9 },
	{ 0xE3BD9A, 0x4AAC3 },
	{ 0xE3BD9B, 0x4AEAF },
	{ 0xE3BD9C, 0x4AEB1 },
	{ 0xE3BD9D, 0x5B3E4 },
	{ 0xE3BD9E, 0x3B7C8 },
	{ 0xE3BD9F, 0x3BDC1 },
	{ 0xE3BDA0, 0x4B9A8 },
	{ 0xE3BDA1, 0x4BEE9 },
	{ 0xE3BDA2, 0x3C2F9 },
	{ 0xE3BDA3, 0x3C2FA },
	{ 0xE3BDA4, 0x4BEE8 },
	{ 0xE3BDA5, 0x4C4F9 },
	{ 0xE3BDA6, 0x3CDC0 },
	{ 0xE3BDA7, 0x4CBAA },
	{ 0xE3BDA8, 0x4CBA9 },
	{ 0xE3BDA9, 0x4D1C4 },
	{ 0xE3BDAA, 0x5DCAF },
	{ 0xE3BDAB, 0x4DBF2 },
	{ 0xE3BDAC, 0x4DBF3 },
	{ 0xE3BDAD, 0x4E0AE },
	{ 0xE3BDAE, 0x4E3E9 },
	{ 0xE3BDAF, 0x4EAD4 },
	{ 0xE3BDB0, 0x4BEED },
	{ 0xE3BDB1, 0x4A4E1 },
	{ 0xE3BDB2, 0x4A4E2 },
	{ 0xE3BDB4, 0x5A7B7 },
	{ 0xE3BDB5, 0x3AABC },
	{ 0xE3BDB7, 0x4AAC6 },
	{ 0xE3BDB8, 0x3AEAD },
	{ 0xE3BDB9, 0x4AAC9 },
	{ 0xE3BDBA, 0x3AEAC },
	{ 0xE3BDBB, 0x3AEAE },
	{ 0xE3BDBD, 0x3B2D6 },
	{ 0xE3BDBE, 0x4AEB7 },
	{ 0xE3BDBF, 0x4AEBB },
	{ 0xE3BE80, 0x4AEB5 },
	{ 0xE3BE81, 0x4AEB6 },
	{ 0xE3BE82, 0x3B2D4 },
	{ 0xE3BE83, 0x4AEB3 },
	{ 0xE3BE84, 0x4AEBF },
	{ 0xE3BE85, 0x4AEB9 },
	{ 0xE3BE86, 0x6B9EB },
	{ 0xE3BE87, 0x3B2D3 },
	{ 0xE3BE88, 0x4AEB8 },
	{ 0xE3BE89, 0x4AEBA },
	{ 0xE3BE8A, 0x5B3ED },
	{ 0xE3BE8B, 0x4B3C2 },
	{ 0xE3BE8C, 0x3B7CC },
	{ 0xE3BE8D, 0x4B3C0 },
	{ 0xE3BE8E, 0x4AEBC },
	{ 0xE3BE8F, 0x4B3BF },
	{ 0xE3BE90, 0x4B3C5 },
	{ 0xE3BE91, 0x3B7CB },
	{ 0xE3BE92, 0x4B3C3 },
	{ 0xE3BE93, 0x4B9B2 },
	{ 0xE3BE94, 0x4B9B3 },
	{ 0xE3BE95, 0x3BDC6 },
	{ 0xE3BE96, 0x3BDCB },
	{ 0xE3BE97, 0x6CBDA },
	{ 0xE3BE98, 0x3BDC9 },
	{ 0xE3BE99, 0x4B9B6 },
	{ 0xE3BE9A, 0x5C0E0 },
	{ 0xE3BE9B, 0x4B9AF },
	{ 0xE3BE9C, 0x4B9B0 },
	{ 0xE3BE9D, 0x3BDC8 },
	{ 0xE3BE9E, 0x3BDCA },
	{ 0xE3BE9F, 0x5BABB },
	{ 0xE3BEA0, 0x4B9B5 },
	{ 0xE3BEA1, 0x4B9B8 },
	{ 0xE3BEA2, 0x4BEF4 },
	{ 0xE3BEA3, 0x5C0E4 },
	{ 0xE3BEA4, 0x4BEEF },
	{ 0xE3BEA5, 0x4BEF8 },
	{ 0xE3BEA6, 0x4BEEE },
	{ 0xE3BEA7, 0x4BEF6 },
	{ 0xE3BEA8, 0x4BEF3 },
	{ 0xE3BEA9, 0x4BEFA },
	{ 0xE3BEAA, 0x4C5A4 },
	{ 0xE3BEAB, 0x4C5A8 },
	{ 0xE3BEAC, 0x6DFAD },
	{ 0xE3BEAD, 0x3C8AA },
	{ 0xE3BEAE, 0x3C8AC },
	{ 0xE3BEAF, 0x4C5A3 },
	{ 0xE3BEB0, 0x4C5A1 },
	{ 0xE3BEB6, 0x7A5D8 },
	{ 0xE3BEB7, 0x4CBB8 },
	{ 0xE3BEB8, 0x3CDC2 },
	{ 0xE3BEB9, 0x4CBB7 },
	{ 0xE3BEBA, 0x4CBB5 },
	{ 0xE3BEBB, 0x4CBB3 },
	{ 0xE3BEBC, 0x4CBAF },
	{ 0xE3BEBD, 0x7A5DC },
	{ 0xE3BEBE, 0x4CBAE },
	{ 0xE3BEBF, 0x5C7D9 },
	{ 0xE3BF81, 0x4CBBB },
	{ 0xE3BF82, 0x7B0B6 },
	{ 0xE3BF83, 0x4D1C8 },
	{ 0xE3BF84, 0x4D1C9 },
	{ 0xE3BF85, 0x3D1F5 },
	{ 0xE3BF86, 0x4D1CE },
	{ 0xE3BF87, 0x4D1CA },
	{ 0xE3BF88, 0x4D1D0 },
	{ 0xE3BF89, 0x4D7A6 },
	{ 0xE3BF8A, 0x4D7A2 },
	{ 0xE3BF8B, 0x4DBFB },
	{ 0xE3BF8C, 0x4DBF7 },
	{ 0xE3BF8D, 0x7C0EB },
	{ 0xE3BF8E, 0x4D7A5 },
	{ 0xE3BF8F, 0x7C0E7 },
	{ 0xE3BF91, 0x4E0B2 },
	{ 0xE3BF92, 0x4E0AF },
	{ 0xE3BF93, 0x4E0B0 },
	{ 0xE3BF95, 0x4E6D8 },
	{ 0xE3BF96, 0x4E6D9 },
	{ 0xE3BF97, 0x3DEC0 },
	{ 0xE3BF98, 0x5F3DC },
	{ 0xE3BF99, 0x4EAD5 },
	{ 0xE3BF9A, 0x4EBF2 },
	{ 0xE3BF9B, 0x4EBF1 },
	{ 0xE3BF9C, 0x3E2AD },
	{ 0xE3BF9D, 0x3A6F5 },
	{ 0xE3BF9E, 0x3AEB0 },
	{ 0xE3BF9F, 0x3B2D8 },
	{ 0xE3BFA1, 0x3B7CE },
	{ 0xE3BFA2, 0x3C3A2 },
	{ 0xE3BFA3, 0x3C8AD },
	{ 0xE3BFA4, 0x5C7DB },
	{ 0xE3BFA5, 0x5CED9 },
	{ 0xE3BFA6, 0x4D1D6 },
	{ 0xE3BFA7, 0x4E0B7 },
	{ 0xE3BFA8, 0x4E6DB },
	{ 0xE3BFA9, 0x4ECF3 },
	{ 0xE3BFAA, 0x4A7C6 },
	{ 0xE3BFAB, 0x4AACE },
	{ 0xE3BFAC, 0x3AEB1 },
	{ 0xE3BFAD, 0x4AEC6 },
	{ 0xE3BFAE, 0x4AEC5 },
	{ 0xE3BFAF, 0x4B3C7 },
	{ 0xE3BFB0, 0x4B3C8 },
	{ 0xE3BFB1, 0x4B9BA },
	{ 0xE3BFB2, 0x6D5D2 },
	{ 0xE3BFB3, 0x4C5B0 },
	{ 0xE3BFB4, 0x4C5B2 },
	{ 0xE3BFB5, 0x3C8AF },
	{ 0xE3BFB6, 0x3CDC3 },
	{ 0xE3BFB7, 0x4CBBD },
	{ 0xE3BFB8, 0x4D1D7 },
	{ 0xE3BFB9, 0x4DBFE },
	{ 0xE3BFBA, 0x4E3EC },
	{ 0xE3BFBB, 0x4A7C8 },
	{ 0xE3BFBC, 0x4AAD1 },
	{ 0xE3BFBD, 0x4AAD0 },
	{ 0xE3BFBE, 0x4AEC7 },
	{ 0xE3BFBF, 0x4AEC9 },
	{ 0xE48080, 0x3B2D9 },
	{ 0xE48081, 0x4B3CB },
	{ 0xE48082, 0x3B7CF },
	{ 0xE48083, 0x3BDCE },
	{ 0xE48084, 0x3C3A3 },
	{ 0xE48085, 0x5C0EF },
	{ 0xE48086, 0x3C8B2 },
	{ 0xE48087, 0x4D1DA },
	{ 0xE48088, 0x4C5B6 },
	{ 0xE48089, 0x4D7AC },
	{ 0xE4808A, 0x4E0B8 },
	{ 0xE4808B, 0x3DFB8 },
	{ 0xE4808D, 0x4EEC8 },
	{ 0xE4808E, 0x3A6F9 },
	{ 0xE4808F, 0x4A4E5 },
	{ 0xE48090, 0x4A7CE },
	{ 0xE48091, 0x4A7CF },
	{ 0xE48092, 0x4A7CD },
	{ 0xE48093, 0x4A7CC },
	{ 0xE48094, 0x4A7CA },
	{ 0xE48095, 0x4AAD3 },
	{ 0xE48096, 0x4AAD6 },
	{ 0xE48097, 0x4AAD7 },
	{ 0xE48098, 0x4AAD4 },
	{ 0xE48099, 0x4AAD8 },
	{ 0xE4809A, 0x5AAED },
	{ 0xE4809B, 0x4AADA },
	{ 0xE4809C, 0x6B3B8 },
	{ 0xE4809E, 0x3AEB4 },
	{ 0xE4809F, 0x4AED2 },
	{ 0xE480A0, 0x3B2DD },
	{ 0xE480A1, 0x3B2E6 },
	{ 0xE480A2, 0x3B2E0 },
	{ 0xE480A3, 0x4AECD },
	{ 0xE480A4, 0x3B2E1 },
	{ 0xE480A7, 0x5B3F6 },
	{ 0xE480A8, 0x4B3D0 },
	{ 0xE480A9, 0x4B3D1 },
	{ 0xE480AA, 0x3B7D6 },
	{ 0xE480AB, 0x3B7D4 },
	{ 0xE480AC, 0x4B3D2 },
	{ 0xE480AD, 0x4B3CE },
	{ 0xE480AE, 0x4B3CD },
	{ 0xE480AF, 0x3BDD0 },
	{ 0xE480B0, 0x4B9C9 },
	{ 0xE480B1, 0x3BDD4 },
	{ 0xE480B2, 0x4B9CA },
	{ 0xE480B3, 0x3BDD5 },
	{ 0xE480B4, 0x4B9C5 },
	{ 0xE480B5, 0x4B9C8 },
	{ 0xE480B6, 0x4B9BF },
	{ 0xE480B7, 0x4B9C1 },
	{ 0xE480B8, 0x4B9CB },
	{ 0xE480B9, 0x4B9C6 },
	{ 0xE480BA, 0x4B9CD },
	{ 0xE480BB, 0x4B9C7 },
	{ 0xE480BC, 0x4B9C3 },
	{ 0xE480BD, 0x4BFA2 },
	{ 0xE480BE, 0x4B9CC },
	{ 0xE480BF, 0x4B9C2 },
	{ 0xE48181, 0x4BFB0 },
	{ 0xE48182, 0x4BFAD },
	{ 0xE48183, 0x3C3A4 },
	{ 0xE48184, 0x4BFA5 },
	{ 0xE48185, 0x4BFA6 },
	{ 0xE48186, 0x4BFA7 },
	{ 0xE48187, 0x4BFAB },
	{ 0xE48188, 0x4BFAC },
	{ 0xE48189, 0x6D5E1 },
	{ 0xE4818A, 0x5C7E1 },
	{ 0xE4818B, 0x4C5B9 },
	{ 0xE4818C, 0x4C5C1 },
	{ 0xE4818D, 0x4C5BC },
	{ 0xE4818E, 0x4C5B7 },
	{ 0xE4818F, 0x3C8B7 },
	{ 0xE48190, 0x4C5C3 },
	{ 0xE48191, 0x4C5C6 },
	{ 0xE48192, 0x4C5BF },
	{ 0xE48193, 0x4C5C4 },
	{ 0xE48194, 0x3C8BA },
	{ 0xE48195, 0x4C5B8 },
	{ 0xE48197, 0x3CDC5 },
	{ 0xE48198, 0x4CBC5 },
	{ 0xE48199, 0x4CBC2 },
	{ 0xE4819A, 0x4CBC4 },
	{ 0xE4819B, 0x4CBC7 },
	{ 0xE4819C, 0x4CBC3 },
	{ 0xE4819D, 0x4CBCD },
	{ 0xE4819E, 0x3CDC7 },
	{ 0xE4819F, 0x5CEE0 },
	{ 0xE481A0, 0x4CBBF },
	{ 0xE481A2, 0x3D1F7 },
	{ 0xE481A3, 0x3D1F8 },
	{ 0xE481A4, 0x4D1DC },
	{ 0xE481A5, 0x4D1E0 },
	{ 0xE481A6, 0x3D1FC },
	{ 0xE481A7, 0x3D1FA },
	{ 0xE481A8, 0x4D1DD },
	{ 0xE481A9, 0x4D1E4 },
	{ 0xE481AB, 0x4D7B2 },
	{ 0xE481AC, 0x4D7AE },
	{ 0xE481AD, 0x4D7B1 },
	{ 0xE481AE, 0x4D7AF },
	{ 0xE481AF, 0x3D5DA },
	{ 0xE481B0, 0x4D7B0 },
	{ 0xE481B1, 0x4D7B3 },
	{ 0xE481B2, 0x4D7B4 },
	{ 0xE481B3, 0x5D6A2 },
	{ 0xE481B4, 0x5E2E9 },
	{ 0xE481B5, 0x4DCA7 },
	{ 0xE481B6, 0x4DCA9 },
	{ 0xE481B7, 0x4DCAA },
	{ 0xE481B8, 0x4DCA5 },
	{ 0xE481B9, 0x3D8B7 },
	{ 0xE481BA, 0x4DCA6 },
	{ 0xE481BB, 0x4E3F0 },
	{ 0xE481BC, 0x4E3EE },
	{ 0xE481BD, 0x4E3F1 },
	{ 0xE481BE, 0x4E3EF },
	{ 0xE481BF, 0x4E6DD },
	{ 0xE48280, 0x3DEC1 },
	{ 0xE48281, 0x4E8F8 },
	{ 0xE48282, 0x4EAD7 },
	{ 0xE48283, 0x4E8FA },
	{ 0xE48284, 0x4ECF5 },
	{ 0xE48285, 0x4EECD },
	{ 0xE48286, 0x4A7D1 },
	{ 0xE48287, 0x4AADF },
	{ 0xE48288, 0x4B3D7 },
	{ 0xE48289, 0x4C5CA },
	{ 0xE4828A, 0x3D5DD },
	{ 0xE4828C, 0x4D7B8 },
	{ 0xE4828D, 0x4E3F4 },
	{ 0xE4828E, 0x4EBF5 },
	{ 0xE4828F, 0x4AED7 },
	{ 0xE48290, 0x4AED8 },
	{ 0xE48291, 0x4B3DA },
	{ 0xE48292, 0x4B3D9 },
	{ 0xE48293, 0x6CCAB },
	{ 0xE48294, 0x4BFB3 },
	{ 0xE48295, 0x4C5CC },
	{ 0xE48296, 0x3A4B2 },
	{ 0xE48297, 0x3A6FA },
	{ 0xE48298, 0x4A7D3 },
	{ 0xE48299, 0xFA8FA },
	{ 0xE4829A, 0x4AAE4 },
	{ 0xE4829B, 0x3AEB8 },
	{ 0xE4829C, 0x4AAE2 },
	{ 0xE4829D, 0x3AEBC },
	{ 0xE4829E, 0x3ADBB },
	{ 0xE4829F, 0x4AEDF },
	{ 0xE482A0, 0x4AEDC },
	{ 0xE482A1, 0x4AEE2 },
	{ 0xE482A2, 0x5AFB4 },
	{ 0xE482A3, 0x3B7DB },
	{ 0xE482A4, 0x3B2EA },
	{ 0xE482A5, 0x3B2EB },
	{ 0xE482A6, 0x4AEDE },
	{ 0xE482A7, 0x4AEE1 },
	{ 0xE482A9, 0x4B3DE },
	{ 0xE482AA, 0x4B3E1 },
	{ 0xE482AB, 0x3B7DC },
	{ 0xE482AC, 0x4B3DF },
	{ 0xE482AD, 0x3B7DA },
	{ 0xE482AE, 0x4B3E0 },
	{ 0xE482AF, 0x3B7DE },
	{ 0xE482B0, 0x3BDDB },
	{ 0xE482B1, 0x5BAD9 },
	{ 0xE482B2, 0x6CCB3 },
	{ 0xE482B3, 0x4B9D8 },
	{ 0xE482B4, 0x3BDD8 },
	{ 0xE482B6, 0x4B9D3 },
	{ 0xE482B7, 0x4BFC0 },
	{ 0xE482B8, 0x4BFB9 },
	{ 0xE482B9, 0x4BFBF },
	{ 0xE482BA, 0x3C3AF },
	{ 0xE482BB, 0x4BFBC },
	{ 0xE482BC, 0x3C3B2 },
	{ 0xE482BD, 0x4BFBD },
	{ 0xE482BE, 0x3C3AC },
	{ 0xE482BF, 0x4BFBE },
	{ 0xE48380, 0x4BFB8 },
	{ 0xE48381, 0x4BFBA },
	{ 0xE48382, 0x4BFBB },
	{ 0xE48387, 0x4BFC2 },
	{ 0xE48388, 0x4C5CE },
	{ 0xE48389, 0x3C8C3 },
	{ 0xE4838A, 0x4C5D1 },
	{ 0xE4838B, 0x3C8C1 },
	{ 0xE4838C, 0x4C5CD },
	{ 0xE4838D, 0x4C5D5 },
	{ 0xE4838E, 0x4C5CF },
	{ 0xE4838F, 0x5C7F6 },
	{ 0xE48391, 0x4CBDC },
	{ 0xE48392, 0x4CBD8 },
	{ 0xE48393, 0x4CBD6 },
	{ 0xE48394, 0x4CBD5 },
	{ 0xE48395, 0x4CBDE },
	{ 0xE48396, 0x7A6A4 },
	{ 0xE48397, 0x4CBDB },
	{ 0xE48398, 0x3D2A3 },
	{ 0xE48399, 0x3D1FD },
	{ 0xE4839A, 0x4D1EC },
	{ 0xE4839B, 0x3D1FE },
	{ 0xE4839C, 0x7B0D9 },
	{ 0xE4839D, 0x5D6B3 },
	{ 0xE4839E, 0x4D1F0 },
	{ 0xE483A0, 0x4D1ED },
	{ 0xE483A1, 0x4D7BB },
	{ 0xE483A2, 0x4D7C1 },
	{ 0xE483A3, 0x3C8C2 },
	{ 0xE483A4, 0x4D7B9 },
	{ 0xE483A5, 0x3D5DE },
	{ 0xE483A6, 0x3D5DF },
	{ 0xE483A7, 0x4D7BF },
	{ 0xE483A9, 0x3D8C1 },
	{ 0xE483AA, 0x4DCAD },
	{ 0xE483AB, 0x3D8BD },
	{ 0xE483AC, 0x4DCB1 },
	{ 0xE483AD, 0x4DCAF },
	{ 0xE483AE, 0x4DCAE },
	{ 0xE483B0, 0x4E0BF },
	{ 0xE483B1, 0x7CEDC },
	{ 0xE483B2, 0x3DCE3 },
	{ 0xE483B3, 0x4E3F6 },
	{ 0xE483B4, 0x4E3F5 },
	{ 0xE483B5, 0x4E6DF },
	{ 0xE483B6, 0x4E6E0 },
	{ 0xE483B7, 0x4E6E1 },
	{ 0xE483B8, 0x4E8FC },
	{ 0xE483B9, 0x4E8FB },
	{ 0xE483BA, 0x3E0F5 },
	{ 0xE483BB, 0x3E1E7 },
	{ 0xE483BD, 0x3AEBF },
	{ 0xE483BE, 0x4AAE7 },
	{ 0xE483BF, 0x4AAE6 },
	{ 0xE48480, 0x6B3C8 },
	{ 0xE48481, 0x3B2EE },
	{ 0xE48482, 0x4AEE4 },
	{ 0xE48483, 0x3B2F1 },
	{ 0xE48484, 0x3B7E4 },
	{ 0xE48485, 0x4B3E3 },
	{ 0xE48486, 0x4B3E2 },
	{ 0xE48487, 0x3BDE1 },
	{ 0xE48488, 0x3BDE0 },
	{ 0xE48489, 0x4B9D9 },
	{ 0xE4848B, 0x4BFC5 },
	{ 0xE4848C, 0x4BFC4 },
	{ 0xE4848D, 0x3C3BA },
	{ 0xE4848E, 0x3C3BB },
	{ 0xE4848F, 0x3C3BE },
	{ 0xE48490, 0x4BFC7 },
	{ 0xE48491, 0x3C3BC },
	{ 0xE48492, 0x3C3BF },
	{ 0xE48493, 0x3C8C6 },
	{ 0xE48494, 0x5C8A4 },
	{ 0xE48495, 0x3C8C9 },
	{ 0xE48498, 0x5CEF6 },
	{ 0xE48499, 0x3CDCE },
	{ 0xE4849A, 0x4D1F6 },
	{ 0xE4849B, 0x3D2A5 },
	{ 0xE4849C, 0x4D1F4 },
	{ 0xE4849D, 0x4D1F5 },
	{ 0xE4849F, 0x4D7C2 },
	{ 0xE484A0, 0x3D8C6 },
	{ 0xE484A1, 0x3D8C7 },
	{ 0xE484A2, 0x3DAE4 },
	{ 0xE484A4, 0x4E6E3 },
	{ 0xE484A5, 0x3E2B4 },
	{ 0xE484A6, 0x5A4EE },
	{ 0xE484A7, 0x3A6FD },
	{ 0xE484A8, 0x5A7C6 },
	{ 0xE484A9, 0x6ADC9 },
	{ 0xE484AA, 0x4A7D6 },
	{ 0xE484AB, 0x3AAC0 },
	{ 0xE484AC, 0x3AAC1 },
	{ 0xE484AD, 0x3AAC3 },
	{ 0xE484AE, 0x4AAEA },
	{ 0xE484AF, 0x4AAEF },
	{ 0xE484B0, 0x4AAEB },
	{ 0xE484B1, 0x4AAE9 },
	{ 0xE484B2, 0x4AAEC },
	{ 0xE484B3, 0xFACED },
	{ 0xE484B6, 0x4AEE5 },
	{ 0xE484B7, 0x3B2F5 },
	{ 0xE484B8, 0x3B2FA },
	{ 0xE484BA, 0x6C2E6 },
	{ 0xE484BB, 0x4B3E7 },
	{ 0xE484BC, 0x4B3E6 },
	{ 0xE484BD, 0x3B7ED },
	{ 0xE484BE, 0x4B3E5 },
	{ 0xE484BF, 0x5B4BB },
	{ 0xE48580, 0x5B4B9 },
	{ 0xE48581, 0x4B3EA },
	{ 0xE48582, 0x4B3E9 },
	{ 0xE48583, 0x4B3EB },
	{ 0xE48584, 0x3B7E8 },
	{ 0xE48585, 0x4B3ED },
	{ 0xE48586, 0x5B4B8 },
	{ 0xE48587, 0x3B7EE },
	{ 0xE48588, 0xFB7BB },
	{ 0xE4858A, 0x4B3E4 },
	{ 0xE4858B, 0x5BAE5 },
	{ 0xE4858C, 0x4B9DE },
	{ 0xE4858D, 0x4B9E2 },
	{ 0xE4858E, 0x3BDE7 },
	{ 0xE4858F, 0x4B9E4 },
	{ 0xE48590, 0x3BDEA },
	{ 0xE48591, 0x4B9E3 },
	{ 0xE48592, 0x3BDEB },
	{ 0xE48593, 0x4B9E1 },
	{ 0xE48594, 0x4BFCF },
	{ 0xE48595, 0x3C3C0 },
	{ 0xE48596, 0x4BFCD },
	{ 0xE48597, 0x3C3C5 },
	{ 0xE48598, 0x4BFCC },
	{ 0xE48599, 0x3C3C2 },
	{ 0xE4859A, 0x4BFCB },
	{ 0xE4859B, 0x3C3C3 },
	{ 0xE4859C, 0x4C5D7 },
	{ 0xE4859D, 0x4BFC9 },
	{ 0xE4859E, 0x5C1B1 },
	{ 0xE485A0, 0x3C8D1 },
	{ 0xE485A1, 0x3C8CA },
	{ 0xE485A2, 0x4C5DB },
	{ 0xE485A3, 0x3C8D3 },
	{ 0xE485A4, 0x3C8CE },
	{ 0xE485A5, 0x4C5DA },
	{ 0xE485A6, 0x3C8CC },
	{ 0xE485A7, 0x4C5D8 },
	{ 0xE485A8, 0x6DFEB },
	{ 0xE485A9, 0x4C5D9 },
	{ 0xE485AC, 0x4CBE5 },
	{ 0xE485AD, 0x4CBE1 },
	{ 0xE485AE, 0x3CDD4 },
	{ 0xE485AF, 0x4CBE2 },
	{ 0xE485B0, 0x3CDD2 },
	{ 0xE485B1, 0x7A6B2 },
	{ 0xE485B2, 0x3CDD8 },
	{ 0xE485B3, 0x4CBE8 },
	{ 0xE485B4, 0x4CBE6 },
	{ 0xE485B5, 0x4CBE4 },
	{ 0xE485B6, 0x3CDD9 },
	{ 0xE485B7, 0x4D1FD },
	{ 0xE485B8, 0x4D1FC },
	{ 0xE485B9, 0x3D2AB },
	{ 0xE485BA, 0x4D1F9 },
	{ 0xE485BB, 0x4D1F8 },
	{ 0xE485BC, 0x4D1FA },
	{ 0xE485BD, 0x3D2AD },
	{ 0xE485BE, 0x4D7C5 },
	{ 0xE485BF, 0x3D5E3 },
	{ 0xE48680, 0x4D7C7 },
	{ 0xE48681, 0x3D8C8 },
	{ 0xE48682, 0x7C1AE },
	{ 0xE48683, 0x4DCB7 },
	{ 0xE48684, 0x4DCB5 },
	{ 0xE48685, 0x4DCB6 },
	{ 0xE48688, 0x3DEC6 },
	{ 0xE48689, 0x4E3F9 },
	{ 0xE4868A, 0x4E6E5 },
	{ 0xE4868B, 0x7D8CC },
	{ 0xE4868D, 0x4E6E4 },
	{ 0xE4868E, 0x4E8FE },
	{ 0xE4868F, 0x4E9A1 },
	{ 0xE48690, 0x3E2B9 },
	{ 0xE48691, 0x4A4E9 },
	{ 0xE48692, 0x6ADCE },
	{ 0xE48693, 0x3AEC6 },
	{ 0xE48694, 0x3AEC5 },
	{ 0xE48695, 0x4AAF1 },
	{ 0xE48696, 0x4AAF2 },
	{ 0xE48697, 0x3B3A1 },
	{ 0xE48698, 0x3B2FE },
	{ 0xE48699, 0x3B2FD },
	{ 0xE4869A, 0x4B3EF },
	{ 0xE4869B, 0x4B3F0 },
	{ 0xE4869C, 0x3B7EF },
	{ 0xE4869D, 0x5B4C5 },
	{ 0xE4869E, 0x4B3F2 },
	{ 0xE4869F, 0x4B3F1 },
	{ 0xE486A0, 0x6C2EF },
	{ 0xE486A1, 0x3BDEC },
	{ 0xE486A2, 0x4B9E7 },
	{ 0xE486A3, 0x3BDED },
	{ 0xE486A4, 0x6CCD3 },
	{ 0xE486A5, 0x3BDEE },
	{ 0xE486A6, 0x5C1B9 },
	{ 0xE486A7, 0x4BFD3 },
	{ 0xE486A8, 0x4BFD2 },
	{ 0xE486A9, 0x6D6A7 },
	{ 0xE486AA, 0x4C5E0 },
	{ 0xE486AB, 0x6DFF8 },
	{ 0xE486AC, 0x4CBEC },
	{ 0xE486AD, 0x5CFA3 },
	{ 0xE486AF, 0x5D4A4 },
	{ 0xE486B0, 0x4D2A5 },
	{ 0xE486B1, 0x4D2A2 },
	{ 0xE486B2, 0x4D2A4 },
	{ 0xE486B3, 0x7B0EF },
	{ 0xE486B5, 0x3D5E5 },
	{ 0xE486B6, 0x3D5E6 },
	{ 0xE486B7, 0x4D7CC },
	{ 0xE486B8, 0x4D7CD },
	{ 0xE486B9, 0x4D7CB },
	{ 0xE486BA, 0x4D7CF },
	{ 0xE486BB, 0x3D5E7 },
	{ 0xE486BC, 0x4DCB9 },
	{ 0xE486BD, 0x4DCBA },
	{ 0xE486BE, 0x4E0C8 },
	{ 0xE486BF, 0x4E0C9 },
	{ 0xE48780, 0x4E3FC },
	{ 0xE48781, 0x4E9A2 },
	{ 0xE48782, 0x3A4B4 },
	{ 0xE48783, 0x3AAC6 },
	{ 0xE48785, 0x4AAF6 },
	{ 0xE48786, 0x3AECA },
	{ 0xE48787, 0x3B3A5 },
	{ 0xE48788, 0x4AEED },
	{ 0xE48789, 0x3B3A2 },
	{ 0xE4878B, 0x5B4C6 },
	{ 0xE4878C, 0x3BDEF },
	{ 0xE4878D, 0x4B9EA },
	{ 0xE4878E, 0x3C3C8 },
	{ 0xE4878F, 0x4BFD4 },
	{ 0xE48790, 0x4BFD5 },
	{ 0xE48791, 0x4BFDA },
	{ 0xE48792, 0x4C5E3 },
	{ 0xE48793, 0x4D7D2 },
	{ 0xE48794, 0x4DCBB },
	{ 0xE48795, 0x3DAE8 },
	{ 0xE48796, 0x5ABA1 },
	{ 0xE48797, 0x4AEF5 },
	{ 0xE48798, 0x4AEF0 },
	{ 0xE48799, 0x3B3A8 },
	{ 0xE4879A, 0x4AEF7 },
	{ 0xE4879B, 0x3B3A9 },
	{ 0xE4879C, 0x4AEF3 },
	{ 0xE4879D, 0x4AEF2 },
	{ 0xE4879E, 0x4B3F6 },
	{ 0xE4879F, 0x4B3FD },
	{ 0xE487A0, 0x3B7F4 },
	{ 0xE487A1, 0x5B4C8 },
	{ 0xE487A2, 0x4B3F7 },
	{ 0xE487A3, 0x4B3FB },
	{ 0xE487A4, 0x3B7F5 },
	{ 0xE487A5, 0x6C2F6 },
	{ 0xE487A6, 0x4B3F8 },
	{ 0xE487A7, 0x4B9ED },
	{ 0xE487A8, 0x4B9F4 },
	{ 0xE487A9, 0x4B9F1 },
	{ 0xE487AA, 0x3BDF4 },
	{ 0xE487AB, 0x4BFDB },
	{ 0xE487AC, 0x4B9F2 },
	{ 0xE487AD, 0x3BDFA },
	{ 0xE487AE, 0x4B9F5 },
	{ 0xE487AF, 0x3BDF3 },
	{ 0xE487B0, 0x4B9EF },
	{ 0xE487B1, 0x6CCDB },
	{ 0xE487B2, 0x6CCD6 },
	{ 0xE487B5, 0x3C3D0 },
	{ 0xE487B6, 0x4BFE6 },
	{ 0xE487B7, 0x4BFE2 },
	{ 0xE487B8, 0x4BFE1 },
	{ 0xE487B9, 0x3C3D2 },
	{ 0xE487BA, 0x3C3D3 },
	{ 0xE487BB, 0x4BFDD },
	{ 0xE487BC, 0x3C3CE },
	{ 0xE487BD, 0x4BFE0 },
	{ 0xE487BE, 0x3C3CB },
	{ 0xE48880, 0x4BFE3 },
	{ 0xE48881, 0x5C8C6 },
	{ 0xE48882, 0x4B9F6 },
	{ 0xE48883, 0x4C5E5 },
	{ 0xE48884, 0x3C8DB },
	{ 0xE48885, 0x4C5EA },
	{ 0xE48886, 0x4C5E9 },
	{ 0xE48887, 0x3C8DF },
	{ 0xE48888, 0x4C5EE },
	{ 0xE48889, 0x4C5E8 },
	{ 0xE4888A, 0x3C8D9 },
	{ 0xE4888B, 0x4C5ED },
	{ 0xE4888C, 0x4C5E6 },
	{ 0xE4888D, 0x5C8B6 },
	{ 0xE4888E, 0x4CBFB },
	{ 0xE4888F, 0x4CBF5 },
	{ 0xE48890, 0x4CBF0 },
	{ 0xE48891, 0x3CDE1 },
	{ 0xE48892, 0x3CDDE },
	{ 0xE48893, 0x4CCA2 },
	{ 0xE48894, 0x3CDE7 },
	{ 0xE48895, 0x4CBFE },
	{ 0xE48896, 0x3CDE2 },
	{ 0xE48897, 0x4CCAE },
	{ 0xE48898, 0x5CFBB },
	{ 0xE48899, 0x3CDE4 },
	{ 0xE4889A, 0x4CCB0 },
	{ 0xE4889B, 0x4CCA5 },
	{ 0xE4889C, 0x4CCAD },
	{ 0xE4889D, 0x4CBF9 },
	{ 0xE4889E, 0x5CFB2 },
	{ 0xE4889F, 0x3CDDF },
	{ 0xE488A0, 0x5CFC5 },
	{ 0xE488A1, 0x4CCAC },
	{ 0xE488A2, 0x4CCA7 },
	{ 0xE488A3, 0x4CBF7 },
	{ 0xE488A4, 0x3CDE6 },
	{ 0xE488A5, 0x3CDE8 },
	{ 0xE488A6, 0x4CCA8 },
	{ 0xE488A7, 0x5CFB6 },
	{ 0xE488AA, 0x4D2B4 },
	{ 0xE488AB, 0x4D2BA },
	{ 0xE488AC, 0x3D2B1 },
	{ 0xE488AD, 0x4D2B7 },
	{ 0xE488AE, 0x4D2AB },
	{ 0xE488AF, 0x4D2B8 },
	{ 0xE488B0, 0x3D2B5 },
	{ 0xE488B1, 0x4D2B9 },
	{ 0xE488B2, 0x4D2BB },
	{ 0xE488B3, 0x4D2B6 },
	{ 0xE488B4, 0x4D2AF },
	{ 0xE488B5, 0x4D2BD },
	{ 0xE488B6, 0x4D2A9 },
	{ 0xE488B7, 0x3D2B2 },
	{ 0xE488B8, 0x4D7DB },
	{ 0xE488B9, 0x5DCED },
	{ 0xE488BA, 0x4D7DE },
	{ 0xE488BB, 0x4D7DA },
	{ 0xE488BC, 0x4D7E2 },
	{ 0xE488BD, 0x5DCFD },
	{ 0xE488BE, 0x4D7E5 },
	{ 0xE488BF, 0x4D7D3 },
	{ 0xE48980, 0x3D5EC },
	{ 0xE48981, 0x4D7D6 },
	{ 0xE48982, 0x4D7D8 },
	{ 0xE48983, 0x4D7D9 },
	{ 0xE48984, 0x5DCFE },
	{ 0xE48985, 0x4D7D5 },
	{ 0xE48986, 0x5DDB0 },
	{ 0xE48988, 0x4DCC4 },
	{ 0xE48989, 0x4DCCF },
	{ 0xE4898A, 0x4DCCB },
	{ 0xE4898B, 0x4DCD0 },
	{ 0xE4898C, 0x4DCC3 },
	{ 0xE4898D, 0x3D8CA },
	{ 0xE4898E, 0x4DCCA },
	{ 0xE4898F, 0x3DAEC },
	{ 0xE48990, 0x4DCC2 },
	{ 0xE48991, 0x4DCCC },
	{ 0xE48992, 0x7C1BF },
	{ 0xE48993, 0x4DCC6 },
	{ 0xE48994, 0x4DCC9 },
	{ 0xE48995, 0x4DCC0 },
	{ 0xE48996, 0x5E3B4 },
	{ 0xE48997, 0x4DCC8 },
	{ 0xE48998, 0x3D8CD },
	{ 0xE48999, 0x3D8CB },
	{ 0xE4899A, 0x5E3C1 },
	{ 0xE4899B, 0x4E0D6 },
	{ 0xE4899C, 0x5E8EE },
	{ 0xE4899D, 0x3DAEA },
	{ 0xE4899E, 0x4E0D3 },
	{ 0xE4899F, 0x5E8E6 },
	{ 0xE489A0, 0x3DAED },
	{ 0xE489A1, 0x3DAE9 },
	{ 0xE489A2, 0x3DAEB },
	{ 0xE489A3, 0x4DCD1 },
	{ 0xE489A5, 0x4E3FE },
	{ 0xE489A6, 0x4E6E9 },
	{ 0xE489A7, 0x4E6EC },
	{ 0xE489A8, 0x4E6EE },
	{ 0xE489A9, 0x3DECA },
	{ 0xE489AA, 0x4E6EA },
	{ 0xE489AB, 0x3DECD },
	{ 0xE489AC, 0x4E6E8 },
	{ 0xE489AD, 0x4E6ED },
	{ 0xE489AE, 0x3DFD6 },
	{ 0xE489AF, 0x5F0E1 },
	{ 0xE489B0, 0x4E9A6 },
	{ 0xE489B1, 0x4E9A8 },
	{ 0xE489B2, 0x4EADD },
	{ 0xE489B3, 0x4EAE1 },
	{ 0xE489B4, 0x4EADC },
	{ 0xE489B5, 0x3E0DF },
	{ 0xE489B6, 0x4EBF6 },
	{ 0xE489B7, 0x4EDDC },
	{ 0xE489B8, 0x4EDF6 },
	{ 0xE489B9, 0x7E5DD },
	{ 0xE489BA, 0x4AAF7 },
	{ 0xE489BB, 0x3B3AF },
	{ 0xE489BC, 0x3B3B3 },
	{ 0xE489BD, 0x6C3A2 },
	{ 0xE489BE, 0x4B4A5 },
	{ 0xE489BF, 0x5B4D9 },
	{ 0xE48A80, 0x3B7FC },
	{ 0xE48A81, 0x6CCE0 },
	{ 0xE48A82, 0x4B9FB },
	{ 0xE48A83, 0x4B9FC },
	{ 0xE48A84, 0x3BDFD },
	{ 0xE48A85, 0x3BDFC },
	{ 0xE48A86, 0x4B9FD },
	{ 0xE48A87, 0x3C3DA },
	{ 0xE48A88, 0x3C3D6 },
	{ 0xE48A89, 0x3C3D7 },
	{ 0xE48A8A, 0x3C3D9 },
	{ 0xE48A8B, 0x3C3DB },
	{ 0xE48A8D, 0x3C8E3 },
	{ 0xE48A8E, 0x4C5F2 },
	{ 0xE48A8F, 0x3C8E4 },
	{ 0xE48A90, 0x3C8E5 },
	{ 0xE48A91, 0x6E0AC },
	{ 0xE48A92, 0x3C8E6 },
	{ 0xE48A93, 0x3CDEB },
	{ 0xE48A94, 0x3CDEC },
	{ 0xE48A95, 0x3CDE9 },
	{ 0xE48A96, 0x3CDEA },
	{ 0xE48A97, 0x4CCB7 },
	{ 0xE48A98, 0x7A6D7 },
	{ 0xE48A99, 0x4CCB5 },
	{ 0xE48A9A, 0x3D2B6 },
	{ 0xE48A9B, 0x4D7ED },
	{ 0xE48A9C, 0x3D5F3 },
	{ 0xE48A9D, 0x3D5F2 },
	{ 0xE48A9E, 0x4D7E9 },
	{ 0xE48A9F, 0x4D7EA },
	{ 0xE48AA0, 0x3CDF4 },
	{ 0xE48AA1, 0x4D7EB },
	{ 0xE48AA3, 0x5E3CE },
	{ 0xE48AA4, 0x4DCD6 },
	{ 0xE48AA5, 0x3D8D2 },
	{ 0xE48AA6, 0x4DCD5 },
	{ 0xE48AA7, 0x4DCD4 },
	{ 0xE48AA8, 0x5E3D4 },
	{ 0xE48AA9, 0x3D8D3 },
	{ 0xE48AAA, 0x3DAF0 },
	{ 0xE48AAB, 0x4E0DB },
	{ 0xE48AAC, 0x4E0DD },
	{ 0xE48AAD, 0x4E4A3 },
	{ 0xE48AAE, 0x3DCE8 },
	{ 0xE48AAF, 0x7D4BA },
	{ 0xE48AB0, 0x5F0F0 },
	{ 0xE48AB1, 0x4EAE5 },
	{ 0xE48AB2, 0x5F6B9 },
	{ 0xE48AB3, 0x4ECFA },
	{ 0xE48AB4, 0x3E1C5 },
	{ 0xE48AB5, 0x4A7DC },
	{ 0xE48AB6, 0x6B3E4 },
	{ 0xE48AB7, 0x3AED7 },
	{ 0xE48AB8, 0x3AED5 },
	{ 0xE48AB9, 0x3AED8 },
	{ 0xE48ABA, 0x4AEF8 },
	{ 0xE48ABB, 0x4AEFE },
	{ 0xE48ABC, 0x3B3B5 },
	{ 0xE48ABD, 0x3B3B4 },
	{ 0xE48ABE, 0x4AEFC },
	{ 0xE48ABF, 0x3B3B9 },
	{ 0xE48B80, 0x4AFA1 },
	{ 0xE48B81, 0x3B3B8 },
	{ 0xE48B82, 0x4AEFD },
	{ 0xE48B83, 0x3B3B6 },
	{ 0xE48B84, 0x3B3BA },
	{ 0xE48B88, 0x4B4AE },
	{ 0xE48B89, 0x4B4A6 },
	{ 0xE48B8A, 0x3B8A3 },
	{ 0xE48B8B, 0x3B8AA },
	{ 0xE48B8C, 0x4B4A7 },
	{ 0xE48B8D, 0x4B4B0 },
	{ 0xE48B8E, 0x3B8AC },
	{ 0xE48B8F, 0x4B4AD },
	{ 0xE48B90, 0x4B4AB },
	{ 0xE48B91, 0x4B4A9 },
	{ 0xE48B92, 0x3B8A8 },
	{ 0xE48B93, 0x3B8AD },
	{ 0xE48B94, 0x3B8A5 },
	{ 0xE48B95, 0x3BEB6 },
	{ 0xE48B96, 0x5BBAC },
	{ 0xE48B97, 0x3BEAD },
	{ 0xE48B98, 0x3BEB2 },
	{ 0xE48B99, 0x3BEA7 },
	{ 0xE48B9A, 0x3BEB0 },
	{ 0xE48B9B, 0x3BEA5 },
	{ 0xE48B9C, 0x6CCF1 },
	{ 0xE48B9E, 0x3BEB1 },
	{ 0xE48B9F, 0x4BFEA },
	{ 0xE48BA0, 0x3C3E5 },
	{ 0xE48BA1, 0x3C3EB },
	{ 0xE48BA2, 0x4BFEE },
	{ 0xE48BA3, 0x4BFF3 },
	{ 0xE48BA4, 0x4BFEF },
	{ 0xE48BA5, 0x3C3E1 },
	{ 0xE48BA6, 0x3C3DD },
	{ 0xE48BA7, 0x3C8EC },
	{ 0xE48BA8, 0x4C5F5 },
	{ 0xE48BA9, 0x4C5FE },
	{ 0xE48BAA, 0x4C5F9 },
	{ 0xE48BAB, 0x4C6A1 },
	{ 0xE48BAC, 0x3C8E7 },
	{ 0xE48BAD, 0x3C3DF },
	{ 0xE48BAE, 0x3C8F2 },
	{ 0xE48BAF, 0x3C8F5 },
	{ 0xE48BB0, 0x4C6A3 },
	{ 0xE48BB1, 0x5C8D4 },
	{ 0xE48BB2, 0x3C8EF },
	{ 0xE48BB3, 0x3CEAA },
	{ 0xE48BB4, 0x5CFD3 },
	{ 0xE48BB5, 0x4CCBE },
	{ 0xE48BB6, 0x4CCBC },
	{ 0xE48BB7, 0x4CCC0 },
	{ 0xE48BB8, 0x3CDFB },
	{ 0xE48BB9, 0x3CEA1 },
	{ 0xE48BBA, 0x3CEAD },
	{ 0xE48BBB, 0x3CDF6 },
	{ 0xE48BBC, 0x3CDF9 },
	{ 0xE48BBD, 0x4CCBA },
	{ 0xE48BBE, 0x4CCBD },
	{ 0xE48BBF, 0x4CCBF },
	{ 0xE48C80, 0x3CDFA },
	{ 0xE48C81, 0x4CCC4 },
	{ 0xE48C82, 0x5CFD4 },
	{ 0xE48C83, 0x3CEA6 },
	{ 0xE48C84, 0x3CEA3 },
	{ 0xE48C85, 0x3D2BA },
	{ 0xE48C86, 0x4D2C9 },
	{ 0xE48C87, 0x3D2BC },
	{ 0xE48C88, 0x4D2C7 },
	{ 0xE48C89, 0x3D2BD },
	{ 0xE48C8A, 0x3D2BE },
	{ 0xE48C8C, 0x4D7F3 },
	{ 0xE48C8D, 0x3D5F8 },
	{ 0xE48C8E, 0x5DDBF },
	{ 0xE48C8F, 0x3D5F6 },
	{ 0xE48C90, 0x5DDC6 },
	{ 0xE48C91, 0x3D5F7 },
	{ 0xE48C92, 0x4D7EE },
	{ 0xE48C93, 0x3D5FC },
	{ 0xE48C94, 0x3D5FB },
	{ 0xE48C95, 0x7BAB9 },
	{ 0xE48C96, 0x4DCE2 },
	{ 0xE48C97, 0x4DCE0 },
	{ 0xE48C98, 0x4D7F2 },
	{ 0xE48C99, 0x3D8D7 },
	{ 0xE48C9A, 0x3D8D6 },
	{ 0xE48C9B, 0x3D9A9 },
	{ 0xE48C9C, 0x4E0E6 },
	{ 0xE48C9D, 0x4E0E3 },
	{ 0xE48C9E, 0x4E0E8 },
	{ 0xE48C9F, 0x4E0E2 },
	{ 0xE48CA0, 0x7C7CA },
	{ 0xE48CA1, 0x3DAF3 },
	{ 0xE48CA2, 0x3DAF1 },
	{ 0xE48CA3, 0x5EDA2 },
	{ 0xE48CA4, 0x3DCE9 },
	{ 0xE48CA5, 0x4E4A4 },
	{ 0xE48CA6, 0x3DCEA },
	{ 0xE48CA7, 0x3DCEB },
	{ 0xE48CA8, 0x3DECF },
	{ 0xE48CA9, 0x3DECE },
	{ 0xE48CAA, 0x4E9AA },
	{ 0xE48CAB, 0x7D8D8 },
	{ 0xE48CAC, 0x3DFD9 },
	{ 0xE48CAD, 0x4E9AB },
	{ 0xE48CAE, 0x4EAE6 },
	{ 0xE48CAF, 0x4EBF9 },
	{ 0xE48CB0, 0x4EBF8 },
	{ 0xE48CB1, 0x7DFB3 },
	{ 0xE48CB2, 0x3E0F8 },
	{ 0xE48CB3, 0x4ECFC },
	{ 0xE48CB4, 0x4ECFB },
	{ 0xE48CB5, 0x4EDF7 },
	{ 0xE48D82, 0x4AAF9 },
	{ 0xE48D83, 0x4AFA9 },
	{ 0xE48D84, 0x3B8AF },
	{ 0xE48D85, 0x3B8B2 },
	{ 0xE48D86, 0x5B4E0 },
	{ 0xE48D87, 0x4B4B4 },
	{ 0xE48D88, 0x3B8B0 },
	{ 0xE48D89, 0x4B4B3 },
	{ 0xE48D8A, 0x4BAA8 },
	{ 0xE48D8B, 0x4C6A5 },
	{ 0xE48D8C, 0x3C8F6 },
	{ 0xE48D8D, 0x4D2CE },
	{ 0xE48D8E, 0x4EAEB },
	{ 0xE48D8F, 0xFA1C7 },
	{ 0xE48D90, 0x3AACD },
	{ 0xE48D91, 0x3AEDC },
	{ 0xE48D92, 0x3AEDB },
	{ 0xE48D93, 0x3AED9 },
	{ 0xE48D94, 0x4AAFB },
	{ 0xE48D95, 0x4AFAA },
	{ 0xE48D96, 0x6BAEB },
	{ 0xE48D97, 0x4AFAD },
	{ 0xE48D98, 0x4B4B5 },
	{ 0xE48D99, 0x4BFF5 },
	{ 0xE48D9A, 0x4BAAA },
	{ 0xE48D9B, 0x3C3EC },
	{ 0xE48D9C, 0x3C3ED },
	{ 0xE48D9D, 0x5C1E5 },
	{ 0xE48D9E, 0x3C8FA },
	{ 0xE48D9F, 0x3C8FB },
	{ 0xE48DA1, 0x4D2CF },
	{ 0xE48DA2, 0x4D7F5 },
	{ 0xE48DA3, 0x4DCE5 },
	{ 0xE48DA4, 0x4E0ED },
	{ 0xE48DA5, 0x4E6FB },
	{ 0xE48DA6, 0x4EBFB },
	{ 0xE48DA7, 0x6BAF4 },
	{ 0xE48DA8, 0x4AFAE },
	{ 0xE48DA9, 0x3B1BF },
	{ 0xE48DAA, 0x4B4B8 },
	{ 0xE48DAB, 0x4B4B6 },
	{ 0xE48DAC, 0x4B4B7 },
	{ 0xE48DAD, 0x6C3BC },
	{ 0xE48DAE, 0x4BAAD },
	{ 0xE48DAF, 0x4BAB1 },
	{ 0xE48DB0, 0x4BAB0 },
	{ 0xE48DB1, 0x4BFF6 },
	{ 0xE48DB2, 0x3C8FE },
	{ 0xE48DB3, 0x4C6A7 },
	{ 0xE48DB4, 0x3C8FD },
	{ 0xE48DB5, 0x4C6A8 },
	{ 0xE48DB6, 0x3C8FC },
	{ 0xE48DB7, 0x4CCC9 },
	{ 0xE48DB8, 0x4D2D3 },
	{ 0xE48DB9, 0x3D2C1 },
	{ 0xE48DBA, 0x4D7F7 },
	{ 0xE48DBB, 0x4DCEA },
	{ 0xE48DBC, 0x4DCEB },
	{ 0xE48DBD, 0x4E9AC },
	{ 0xE48DBE, 0x3B3C0 },
	{ 0xE48DBF, 0x3B3C1 },
	{ 0xE48E80, 0x4B4BA },
	{ 0xE48E81, 0x3B8B3 },
	{ 0xE48E82, 0x4B4BB },
	{ 0xE48E83, 0x4B4BE },
	{ 0xE48E84, 0x4B4BC },
	{ 0xE48E85, 0x3B8B5 },
	{ 0xE48E86, 0x3B8B4 },
	{ 0xE48E87, 0x4BAB4 },
	{ 0xE48E88, 0x4BAB5 },
	{ 0xE48E89, 0x5BBBA },
	{ 0xE48E8A, 0x4BAB3 },
	{ 0xE48E8B, 0x3C3F0 },
	{ 0xE48E8C, 0x4BFF8 },
	{ 0xE48E8D, 0x3C3F1 },
	{ 0xE48E8E, 0x4BFF7 },
	{ 0xE48E8F, 0x3C3EF },
	{ 0xE48E90, 0x3C9A1 },
	{ 0xE48E91, 0x4C6AA },
	{ 0xE48E92, 0x4C6A9 },
	{ 0xE48E93, 0x4C6AB },
	{ 0xE48E94, 0x4D2D5 },
	{ 0xE48E95, 0x4D2D6 },
	{ 0xE48E96, 0x3D8DE },
	{ 0xE48E97, 0x3D8E0 },
	{ 0xE48E98, 0x3D8DF },
	{ 0xE48E99, 0x3DCEE },
	{ 0xE48E9A, 0x4E6FD },
	{ 0xE48E9C, 0x3BEB9 },
	{ 0xE48E9D, 0x3BEBA },
	{ 0xE48E9F, 0x4ABA7 },
	{ 0xE48EA0, 0x4ABA8 },
	{ 0xE48EA1, 0x4AFB8 },
	{ 0xE48EA2, 0x4ABA9 },
	{ 0xE48EA3, 0x3B8B8 },
	{ 0xE48EA4, 0x4BFFA },
	{ 0xE48EA6, 0x4C6AE },
	{ 0xE48EA7, 0x4C6AD },
	{ 0xE48EA8, 0x4C6AF },
	{ 0xE48EA9, 0x4C6B2 },
	{ 0xE48EAA, 0x4C6B0 },
	{ 0xE48EAB, 0x4CCCF },
	{ 0xE48EAD, 0x4D7FD },
	{ 0xE48EAE, 0x4D7FA },
	{ 0xE48EAF, 0x4D7FB },
	{ 0xE48EB0, 0x4DCF0 },
	{ 0xE48EB1, 0x4E7A1 },
	{ 0xE48EB2, 0x4A4ED },
	{ 0xE48EB3, 0x3B3C6 },
	{ 0xE48EB4, 0x3B3C5 },
	{ 0xE48EB5, 0x3B8BA },
	{ 0xE48EB6, 0x4B4C1 },
	{ 0xE48EB7, 0x4BAB9 },
	{ 0xE48EB8, 0x5C1F0 },
	{ 0xE48EB9, 0x3C3F4 },
	{ 0xE48EBA, 0x4C6B6 },
	{ 0xE48EBB, 0x4C6B4 },
	{ 0xE48EBC, 0x4C6B5 },
	{ 0xE48EBD, 0x4C6B7 },
	{ 0xE48EBE, 0x3C9A4 },
	{ 0xE48EBF, 0x3CEB3 },
	{ 0xE48F80, 0x4CCD2 },
	{ 0xE48F81, 0x4D2DA },
	{ 0xE48F82, 0x3D2C2 },
	{ 0xE48F83, 0x4D2DB },
	{ 0xE48F84, 0x4D8A1 },
	{ 0xE48F85, 0x4D8A4 },
	{ 0xE48F86, 0x4D8A3 },
	{ 0xE48F87, 0x4D8A2 },
	{ 0xE48F88, 0x3D8E4 },
	{ 0xE48F89, 0x4E4A8 },
	{ 0xE48F8A, 0x3DFDC },
	{ 0xE48F8B, 0x6D6ED },
	{ 0xE48F8C, 0x4A3AD },
	{ 0xE48F8D, 0x6A5C9 },
	{ 0xE48F8E, 0x4A4EF },
	{ 0xE48F8F, 0x4A4EE },
	{ 0xE48F90, 0x3AAD1 },
	{ 0xE48F91, 0x6BBA8 },
	{ 0xE48F92, 0x3AAD5 },
	{ 0xE48F93, 0x3AAD0 },
	{ 0xE48F94, 0x4A7E6 },
	{ 0xE48F95, 0xFA8D2 },
	{ 0xE48F96, 0x4A7E2 },
	{ 0xE48F97, 0x4A7E7 },
	{ 0xE48F98, 0x4A7E3 },
	{ 0xE48F99, 0x4A7E5 },
	{ 0xE48F9A, 0x5A7D8 },
	{ 0xE48F9B, 0x3AADA },
	{ 0xE48F9C, 0x3AAD3 },
	{ 0xE48F9E, 0x5ABB3 },
	{ 0xE48F9F, 0x4ABAF },
	{ 0xE48FA0, 0x4ABAA },
	{ 0xE48FA1, 0x4ABAC },
	{ 0xE48FA2, 0x3AEE2 },
	{ 0xE48FA3, 0x3AEDF },
	{ 0xE48FA4, 0x6B3FD },
	{ 0xE48FA5, 0x5ABB9 },
	{ 0xE48FA6, 0x3B3D1 },
	{ 0xE48FA7, 0x4AFC1 },
	{ 0xE48FA8, 0x4AFC6 },
	{ 0xE48FA9, 0x4AFC7 },
	{ 0xE48FAA, 0x4AFBF },
	{ 0xE48FAB, 0x6BBB1 },
	{ 0xE48FAC, 0x5AFED },
	{ 0xE48FAF, 0x3B8C6 },
	{ 0xE48FB0, 0x4B4CC },
	{ 0xE48FB1, 0x4B4C8 },
	{ 0xE48FB2, 0x3B8C4 },
	{ 0xE48FB3, 0x4B4CB },
	{ 0xE48FB4, 0x4B4D2 },
	{ 0xE48FB5, 0x4B4D1 },
	{ 0xE48FB6, 0x4B4CA },
	{ 0xE48FB7, 0x4B4D3 },
	{ 0xE48FB8, 0x6C3D8 },
	{ 0xE48FB9, 0x3B8C0 },
	{ 0xE48FBA, 0x3B8BF },
	{ 0xE48FBB, 0x3B8C3 },
	{ 0xE48FBC, 0x4BAC9 },
	{ 0xE48FBD, 0x4BABA },
	{ 0xE48FBE, 0x3BEBF },
	{ 0xE48FBF, 0x4BAC5 },
	{ 0xE49080, 0x5BBCD },
	{ 0xE49081, 0x4BACA },
	{ 0xE49082, 0x4BAC1 },
	{ 0xE49083, 0x4BAC0 },
	{ 0xE49084, 0x4BAC2 },
	{ 0xE49085, 0x4BABD },
	{ 0xE49087, 0x3BEC6 },
	{ 0xE49088, 0x4BABF },
	{ 0xE49089, 0x4BAC4 },
	{ 0xE4908A, 0x4BACB },
	{ 0xE4908B, 0x6C9FE },
	{ 0xE4908C, 0x6CDD4 },
	{ 0xE4908D, 0x6D6F6 },
	{ 0xE4908E, 0x4C0A7 },
	{ 0xE4908F, 0x3C3F8 },
	{ 0xE49090, 0x4C0AA },
	{ 0xE49091, 0x4C0A3 },
	{ 0xE49092, 0x4C0A6 },
	{ 0xE49093, 0x3C3FA },
	{ 0xE49094, 0x4BFFD },
	{ 0xE49095, 0x4C0A8 },
	{ 0xE49096, 0x3C4A1 },
	{ 0xE49097, 0x4C0AC },
	{ 0xE49098, 0x3C3FD },
	{ 0xE49099, 0x3C3F9 },
	{ 0xE4909A, 0x5B4EA },
	{ 0xE4909B, 0x4C0A5 },
	{ 0xE4909C, 0x4C6C5 },
	{ 0xE4909D, 0x4C6BE },
	{ 0xE4909E, 0x4C6BC },
	{ 0xE4909F, 0x4C6BD },
	{ 0xE490A0, 0x4C6BF },
	{ 0xE490A1, 0x3D2C8 },
	{ 0xE490A2, 0x4C6C2 },
	{ 0xE490A3, 0x4C6C0 },
	{ 0xE490A4, 0x4C6BB },
	{ 0xE490A5, 0x3C9A9 },
	{ 0xE490A6, 0x3C9A8 },
	{ 0xE490A7, 0x4C6B8 },
	{ 0xE490A8, 0x4C6C7 },
	{ 0xE490A9, 0x4C6C1 },
	{ 0xE490AB, 0x4CCDD },
	{ 0xE490AC, 0x4CCD8 },
	{ 0xE490AD, 0x4CCDE },
	{ 0xE490AE, 0x4CCD5 },
	{ 0xE490AF, 0x4CCDC },
	{ 0xE490B0, 0x6E0EF },
	{ 0xE490B1, 0x4CCD4 },
	{ 0xE490B2, 0x4CCDB },
	{ 0xE490B3, 0x4CCDF },
	{ 0xE490B4, 0x5C2A8 },
	{ 0xE490B5, 0x4D2E3 },
	{ 0xE490B6, 0x4D2E4 },
	{ 0xE490B7, 0x3D2C6 },
	{ 0xE490B8, 0x3D2C5 },
	{ 0xE490B9, 0x4D2DE },
	{ 0xE490BA, 0x4D2E1 },
	{ 0xE490BB, 0x4D2E2 },
	{ 0xE490BC, 0x4D2E6 },
	{ 0xE490BD, 0xFD1D5 },
	{ 0xE490BE, 0x5DDDB },
	{ 0xE490BF, 0x4D8AB },
	{ 0xE49180, 0x4D8A8 },
	{ 0xE49181, 0x4D8AC },
	{ 0xE49182, 0x4DCF4 },
	{ 0xE49183, 0x3D8E6 },
	{ 0xE49184, 0x4DCF6 },
	{ 0xE49185, 0x3D8E7 },
	{ 0xE49186, 0x3DAF6 },
	{ 0xE49187, 0x4E0F4 },
	{ 0xE49188, 0x4E0F3 },
	{ 0xE49189, 0x5EDAC },
	{ 0xE4918A, 0x4E4AA },
	{ 0xE4918B, 0x4E7A2 },
	{ 0xE4918C, 0x4E7A4 },
	{ 0xE4918D, 0x4E7A3 },
	{ 0xE4918E, 0x4E7A5 },
	{ 0xE4918F, 0x4E9B0 },
	{ 0xE49190, 0x6C3E4 },
	{ 0xE49191, 0x7C2A4 },
	{ 0xE49192, 0x3ABC4 },
	{ 0xE49193, 0x3C4A4 },
	{ 0xE49194, 0x4AFCA },
	{ 0xE49195, 0x4B4D8 },
	{ 0xE49197, 0x4CCE3 },
	{ 0xE49198, 0x4D2EB },
	{ 0xE49199, 0x3B3D3 },
	{ 0xE4919A, 0x3B3D4 },
	{ 0xE4919B, 0x3B8CA },
	{ 0xE4919C, 0x4CCE4 },
	{ 0xE4919D, 0x6E1A1 },
	{ 0xE4919E, 0x3D2CB },
	{ 0xE4919F, 0x3DED4 },
	{ 0xE491A0, 0x4A7EF },
	{ 0xE491A1, 0x4ABB3 },
	{ 0xE491A2, 0x4ABB2 },
	{ 0xE491A3, 0x3AEE7 },
	{ 0xE491A4, 0x3B3D6 },
	{ 0xE491A5, 0x4AFD0 },
	{ 0xE491A6, 0x3B8CB },
	{ 0xE491A7, 0x6C3F1 },
	{ 0xE491A8, 0x6C3F0 },
	{ 0xE491AA, 0x3BECA },
	{ 0xE491AB, 0x4BACE },
	{ 0xE491AC, 0x4BACF },
	{ 0xE491AD, 0x6CDE3 },
	{ 0xE491AF, 0x5C2AD },
	{ 0xE491B0, 0x4C0AF },
	{ 0xE491B1, 0x4C6CF },
	{ 0xE491B2, 0x4C6D1 },
	{ 0xE491B3, 0x4C6D0 },
	{ 0xE491B4, 0x3C9AC },
	{ 0xE491B5, 0x6E1A4 },
	{ 0xE491B6, 0x5C9AC },
	{ 0xE491B9, 0x3CEBE },
	{ 0xE491BA, 0x4CCE8 },
	{ 0xE491BB, 0x4CCE5 },
	{ 0xE491BC, 0x4D2EC },
	{ 0xE491BD, 0x4D2ED },
	{ 0xE491BF, 0x4D8B0 },
	{ 0xE49280, 0x4D8B4 },
	{ 0xE49281, 0x4D8B3 },
	{ 0xE49282, 0x3D6A5 },
	{ 0xE49283, 0x3D6A6 },
	{ 0xE49284, 0x5DDE7 },
	{ 0xE49285, 0x5DCCD },
	{ 0xE49286, 0x4D8B2 },
	{ 0xE49288, 0x4DCFC },
	{ 0xE49289, 0x4E4AD },
	{ 0xE4928A, 0x4AFD3 },
	{ 0xE4928B, 0x4B4DC },
	{ 0xE4928C, 0x4D2EF },
	{ 0xE4928D, 0x4D2EE },
	{ 0xE4928E, 0x4D8B5 },
	{ 0xE4928F, 0x4DCFD },
	{ 0xE49290, 0x4E9B3 },
	{ 0xE49292, 0x6A5CF },
	{ 0xE49293, 0x3A4B7 },
	{ 0xE49294, 0x3A4B9 },
	{ 0xE49295, 0x3A7A7 },
	{ 0xE49296, 0x4A4F6 },
	{ 0xE49297, 0x4A4FD },
	{ 0xE49298, 0x3A7AC },
	{ 0xE4929A, 0x3AAE3 },
	{ 0xE4929B, 0x3AAE7 },
	{ 0xE4929C, 0x3AAE4 },
	{ 0xE4929D, 0x3AAEA },
	{ 0xE4929E, 0x4A7F2 },
	{ 0xE4929F, 0x3AAE2 },
	{ 0xE492A0, 0x4A8A1 },
	{ 0xE492A1, 0x4A7F3 },
	{ 0xE492A2, 0x3AAE5 },
	{ 0xE492A3, 0x3AAE9 },
	{ 0xE492A4, 0x5A7E3 },
	{ 0xE492A5, 0x3AAE1 },
	{ 0xE492A6, 0x3AEED },
	{ 0xE492A7, 0x4ABB6 },
	{ 0xE492A8, 0x3AEF0 },
	{ 0xE492A9, 0x3AEF1 },
	{ 0xE492AA, 0x3AEEC },
	{ 0xE492AB, 0x3AEF3 },
	{ 0xE492AC, 0x3AEF5 },
	{ 0xE492AD, 0x6B4BA },
	{ 0xE492B0, 0x4AFD5 },
	{ 0xE492B1, 0x3B3E1 },
	{ 0xE492B2, 0x4AFE1 },
	{ 0xE492B3, 0x3B3E4 },
	{ 0xE492B4, 0x3B3DB },
	{ 0xE492B5, 0x3B3DE },
	{ 0xE492B6, 0x6BBD6 },
	{ 0xE492B7, 0x3B3DD },
	{ 0xE492B8, 0x4AFDE },
	{ 0xE492B9, 0x3B3DC },
	{ 0xE492BA, 0x3B3E5 },
	{ 0xE492BB, 0x5B0A1 },
	{ 0xE492BC, 0x4AFD9 },
	{ 0xE492BD, 0x4AFE4 },
	{ 0xE49381, 0x3B3E0 },
	{ 0xE49382, 0x4B4DE },
	{ 0xE49383, 0x4B4EC },
	{ 0xE49384, 0x4B4F1 },
	{ 0xE49385, 0x3B8DA },
	{ 0xE49386, 0x4B4E9 },
	{ 0xE49387, 0x4B4E5 },
	{ 0xE49388, 0x3B8D6 },
	{ 0xE49389, 0x4B4E6 },
	{ 0xE4938A, 0x4B4E2 },
	{ 0xE4938B, 0x4B4DD },
	{ 0xE4938C, 0x4B4E3 },
	{ 0xE4938D, 0x6C4AC },
	{ 0xE4938E, 0x3B8CC },
	{ 0xE4938F, 0x6C4A8 },
	{ 0xE49390, 0x5B5AA },
	{ 0xE49391, 0x3B8D9 },
	{ 0xE49392, 0x3B8DC },
	{ 0xE49393, 0x5B5A4 },
	{ 0xE49397, 0x4BAEC },
	{ 0xE49398, 0x4BAE0 },
	{ 0xE49399, 0x4BADF },
	{ 0xE4939A, 0x4BAE4 },
	{ 0xE4939B, 0x4BAD9 },
	{ 0xE4939C, 0x5BBD6 },
	{ 0xE4939D, 0x4BADB },
	{ 0xE4939E, 0x4BAD6 },
	{ 0xE4939F, 0x3BED3 },
	{ 0xE493A0, 0x4BADE },
	{ 0xE493A1, 0x3BED4 },
	{ 0xE493A2, 0x3BED1 },
	{ 0xE493A3, 0x4BADC },
	{ 0xE493A4, 0x4BAE1 },
	{ 0xE493A5, 0x3BED5 },
	{ 0xE493A6, 0x6CEA7 },
	{ 0xE493A7, 0x3BECC },
	{ 0xE493AA, 0xFBEEB },
	{ 0xE493AD, 0x4C0B0 },
	{ 0xE493AE, 0x4C0B2 },
	{ 0xE493AF, 0x4BAE5 },
	{ 0xE493B0, 0x3C4B7 },
	{ 0xE493B1, 0x4C6E9 },
	{ 0xE493B2, 0x4C0C7 },
	{ 0xE493B3, 0x4C0C9 },
	{ 0xE493B4, 0x4C0BA },
	{ 0xE493B5, 0x3C4AB },
	{ 0xE493B6, 0x3C4A9 },
	{ 0xE493B7, 0x3C4B4 },
	{ 0xE493B8, 0x4C0C8 },
	{ 0xE493B9, 0x3C4BD },
	{ 0xE493BA, 0x4C0CC },
	{ 0xE493BC, 0x4C6E5 },
	{ 0xE493BD, 0x3C9AF },
	{ 0xE493BE, 0x4C6D7 },
	{ 0xE493BF, 0x6E1C4 },
	{ 0xE49480, 0x4C6E4 },
	{ 0xE49481, 0x3C9B1 },
	{ 0xE49482, 0x4C6D3 },
	{ 0xE49483, 0x5C9BC },
	{ 0xE49484, 0x4C6E1 },
	{ 0xE49485, 0x3C9B0 },
	{ 0xE49486, 0x4C6ED },
	{ 0xE49487, 0x4C6E0 },
	{ 0xE49488, 0x4C6DC },
	{ 0xE49489, 0x3C9B4 },
	{ 0xE4948A, 0x5C9BB },
	{ 0xE4948B, 0x6E1D8 },
	{ 0xE4948C, 0x3C9B7 },
	{ 0xE4948D, 0x3C9C0 },
	{ 0xE4948E, 0x3CEC3 },
	{ 0xE4948F, 0x4CCF2 },
	{ 0xE49490, 0x3CEBF },
	{ 0xE49491, 0x4CCF0 },
	{ 0xE49492, 0x4CDA4 },
	{ 0xE49493, 0x4CCEB },
	{ 0xE49494, 0x3CEC1 },
	{ 0xE49495, 0x4CCF1 },
	{ 0xE49496, 0x3CED3 },
	{ 0xE49497, 0x4CCED },
	{ 0xE49498, 0x4CCF3 },
	{ 0xE49499, 0x3CEC7 },
	{ 0xE4949A, 0x3CEC5 },
	{ 0xE4949B, 0x3CED6 },
	{ 0xE4949C, 0x4CCFD },
	{ 0xE4949D, 0x3D2D1 },
	{ 0xE4949E, 0x4CCEC },
	{ 0xE4949F, 0x3CECA },
	{ 0xE494A0, 0x4CCEE },
	{ 0xE494A1, 0x3CEC8 },
	{ 0xE494A2, 0x3CED5 },
	{ 0xE494A3, 0x3CEC9 },
	{ 0xE494A4, 0x5D0C6 },
	{ 0xE494A5, 0x3CED0 },
	{ 0xE494A6, 0xFD1E5 },
	{ 0xE494A7, 0xFD1F3 },
	{ 0xE494A8, 0xFD1F6 },
	{ 0xE494A9, 0x4CDA1 },
	{ 0xE494AA, 0x4CCEF },
	{ 0xE494AB, 0x3CED1 },
	{ 0xE494AC, 0x4CCF7 },
	{ 0xE494AD, 0x4D2F7 },
	{ 0xE494AE, 0x4D2FB },
	{ 0xE494AF, 0x4D2F9 },
	{ 0xE494B0, 0x4D3AC },
	{ 0xE494B1, 0x4D3A1 },
	{ 0xE494B2, 0x4D2F6 },
	{ 0xE494B3, 0x3D2D3 },
	{ 0xE494B4, 0x4D3A5 },
	{ 0xE494B5, 0x3D2D7 },
	{ 0xE494B6, 0x4D2FE },
	{ 0xE494B7, 0x3D2CD },
	{ 0xE494B8, 0x4D3A3 },
	{ 0xE494B9, 0x4D2FA },
	{ 0xE494BA, 0x4D2FC },
	{ 0xE494BB, 0x4D2F2 },
	{ 0xE494BC, 0x5E4AD },
	{ 0xE494BD, 0x3D2CC },
	{ 0xE494BE, 0x4D3A2 },
	{ 0xE494BF, 0x4D2F3 },
	{ 0xE49580, 0x3D2CE },
	{ 0xE49581, 0x4D3A7 },
	{ 0xE49583, 0x4D3B1 },
	{ 0xE49584, 0x4C6E7 },
	{ 0xE49585, 0x4D8C4 },
	{ 0xE49586, 0x4D8BC },
	{ 0xE49587, 0x4D8B8 },
	{ 0xE49588, 0x4D8C2 },
	{ 0xE49589, 0x5DDF9 },
	{ 0xE4958A, 0x4D8B6 },
	{ 0xE4958B, 0x4D8BB },
	{ 0xE4958C, 0x3D6AE },
	{ 0xE4958D, 0x3D6A7 },
	{ 0xE4958E, 0x4D8BD },
	{ 0xE4958F, 0x3D6AA },
	{ 0xE49591, 0x3D6AF },
	{ 0xE49592, 0x3D8E9 },
	{ 0xE49593, 0x4DCFE },
	{ 0xE49594, 0x4DDAB },
	{ 0xE49595, 0x3D8ED },
	{ 0xE49596, 0x3D8F0 },
	{ 0xE49597, 0x3D8EA },
	{ 0xE49598, 0x3D8F1 },
	{ 0xE49599, 0x4DDA3 },
	{ 0xE4959A, 0x7C2B8 },
	{ 0xE4959B, 0x4DDA1 },
	{ 0xE4959C, 0xFE0CE },
	{ 0xE4959D, 0x7BBB2 },
	{ 0xE4959E, 0x4E0F7 },
	{ 0xE4959F, 0x3DCF3 },
	{ 0xE495A0, 0x3DBA3 },
	{ 0xE495A1, 0x4E0F8 },
	{ 0xE495A2, 0x3DBA1 },
	{ 0xE495A4, 0x3DBA4 },
	{ 0xE495A5, 0x7C9D3 },
	{ 0xE495A6, 0x4E4AF },
	{ 0xE495A7, 0x4E4B4 },
	{ 0xE495A8, 0x3DCFD },
	{ 0xE495A9, 0x4E4B3 },
	{ 0xE495AA, 0x3DCF4 },
	{ 0xE495AB, 0x7D4E8 },
	{ 0xE495AC, 0x3DCF9 },
	{ 0xE495AD, 0x4E4B2 },
	{ 0xE495AE, 0x4E4B8 },
	{ 0xE495AF, 0x3DCFA },
	{ 0xE495B0, 0x4E4B0 },
	{ 0xE495B1, 0x3DCF5 },
	{ 0xE495B2, 0x4E4B6 },
	{ 0xE495B3, 0x4E7A7 },
	{ 0xE495B4, 0x3DED9 },
	{ 0xE495B5, 0x4E7A8 },
	{ 0xE495B7, 0xFE8B9 },
	{ 0xE495B8, 0x3DFDD },
	{ 0xE495B9, 0x4E9B7 },
	{ 0xE495BA, 0x7D8F2 },
	{ 0xE495BB, 0x3E0C1 },
	{ 0xE495BC, 0x3E0C2 },
	{ 0xE495BD, 0x5F8A5 },
	{ 0xE495BE, 0x4EBFD },
	{ 0xE495BF, 0x4EDDE },
	{ 0xE49680, 0x4ECFD },
	{ 0xE49681, 0x3E1EA },
	{ 0xE49682, 0x4EDF9 },
	{ 0xE49683, 0x4EDFB },
	{ 0xE49684, 0xFECEC },
	{ 0xE49685, 0x4EEB7 },
	{ 0xE49686, 0x4EEB6 },
	{ 0xE49687, 0x5FCBE },
	{ 0xE49688, 0x3AAED },
	{ 0xE49689, 0x4ABBE },
	{ 0xE4968A, 0x4AFE7 },
	{ 0xE4968B, 0x3B3E7 },
	{ 0xE4968C, 0x3B3E6 },
	{ 0xE4968D, 0x3B3E8 },
	{ 0xE4968E, 0x5B5B5 },
	{ 0xE4968F, 0x3B8E2 },
	{ 0xE49690, 0x5BBF0 },
	{ 0xE49691, 0x3BEE0 },
	{ 0xE49692, 0x3C4C1 },
	{ 0xE49693, 0x5C2D4 },
	{ 0xE49694, 0x5C2D3 },
	{ 0xE49695, 0x3C4C2 },
	{ 0xE49696, 0x3C4C3 },
	{ 0xE49697, 0x4CDA6 },
	{ 0xE49698, 0x4D3B6 },
	{ 0xE49699, 0x4DDB2 },
	{ 0xE4969A, 0x5E4BB },
	{ 0xE4969B, 0x5E4BA },
	{ 0xE4969C, 0x4E4BA },
	{ 0xE4969D, 0x3A7AE },
	{ 0xE4969E, 0x3AEFD },
	{ 0xE4969F, 0x3AFA1 },
	{ 0xE496A0, 0x3AFA2 },
	{ 0xE496A1, 0x4AFE9 },
	{ 0xE496A2, 0x4AFEB },
	{ 0xE496A3, 0x6BBE9 },
	{ 0xE496A4, 0x3B8E8 },
	{ 0xE496A5, 0x3B8E7 },
	{ 0xE496A6, 0x4B4FC },
	{ 0xE496A7, 0x3B8E5 },
	{ 0xE496A8, 0x4B4FB },
	{ 0xE496A9, 0x4B4F9 },
	{ 0xE496AA, 0x5BCA6 },
	{ 0xE496AB, 0x6C4C8 },
	{ 0xE496AD, 0x4BAF2 },
	{ 0xE496AE, 0x3BEE7 },
	{ 0xE496AF, 0x4BAF4 },
	{ 0xE496B0, 0x3BEE5 },
	{ 0xE496B1, 0x5BBF4 },
	{ 0xE496B2, 0x4BAF0 },
	{ 0xE496B3, 0x4BAED },
	{ 0xE496B4, 0x3BEE4 },
	{ 0xE496B5, 0x3BEE6 },
	{ 0xE496B6, 0x4C0D6 },
	{ 0xE496B7, 0x4C0D7 },
	{ 0xE496B8, 0x3C4CB },
	{ 0xE496B9, 0x3C4C7 },
	{ 0xE496BA, 0x4C0DB },
	{ 0xE496BB, 0x4BAEE },
	{ 0xE496BC, 0x4C0DD },
	{ 0xE496BD, 0x3C4CA },
	{ 0xE496BF, 0x4C6F8 },
	{ 0xE49780, 0x3C9C6 },
	{ 0xE49781, 0x4C6F2 },
	{ 0xE49782, 0x4C6F3 },
	{ 0xE49783, 0x4C6F1 },
	{ 0xE49784, 0x4C6F5 },
	{ 0xE49785, 0x3C9C7 },
	{ 0xE49786, 0x4C6F0 },
	{ 0xE49787, 0x4C6F6 },
	{ 0xE49788, 0x6E1E9 },
	{ 0xE49789, 0x3C9C8 },
	{ 0xE4978A, 0x4C6FB },
	{ 0xE4978B, 0x3CEDA },
	{ 0xE4978C, 0x3CEDC },
	{ 0xE4978D, 0x7A8C2 },
	{ 0xE4978E, 0x3CED7 },
	{ 0xE4978F, 0x3CED8 },
	{ 0xE49790, 0x4CDB0 },
	{ 0xE49791, 0x3CEDB },
	{ 0xE49792, 0x4C6F9 },
	{ 0xE49793, 0x4CDB6 },
	{ 0xE49794, 0x4CDAF },
	{ 0xE49795, 0x3C9CD },
	{ 0xE49797, 0x4D3BE },
	{ 0xE49798, 0x3D2DC },
	{ 0xE49799, 0x7B2F3 },
	{ 0xE4979A, 0x4D3BD },
	{ 0xE4979B, 0x4D8CD },
	{ 0xE4979C, 0x3D2E0 },
	{ 0xE4979D, 0x7B2F5 },
	{ 0xE4979E, 0x3D2E1 },
	{ 0xE4979F, 0x5DEB2 },
	{ 0xE497A0, 0x4D8D7 },
	{ 0xE497A1, 0x4D8D2 },
	{ 0xE497A2, 0x3D6B7 },
	{ 0xE497A3, 0x4D8D8 },
	{ 0xE497A4, 0x4D8CF },
	{ 0xE497A5, 0x4D8D6 },
	{ 0xE497A6, 0x3D6B8 },
	{ 0xE497A7, 0x4D8CE },
	{ 0xE497A8, 0x3D6B2 },
	{ 0xE497A9, 0x4D8D4 },
	{ 0xE497AA, 0x4D8DF },
	{ 0xE497AB, 0x3D6B5 },
	{ 0xE497AC, 0x3D6BC },
	{ 0xE497AE, 0x3D6B1 },
	{ 0xE497AF, 0x4DDBB },
	{ 0xE497B0, 0x5DEB5 },
	{ 0xE497B1, 0x4DDB9 },
	{ 0xE497B2, 0x3D8F2 },
	{ 0xE497B4, 0x4E1A4 },
	{ 0xE497B5, 0x5E9C1 },
	{ 0xE497B6, 0x3DBAA },
	{ 0xE497B7, 0x4E1A1 },
	{ 0xE497B8, 0x4E1A5 },
	{ 0xE497B9, 0xFE3EE },
	{ 0xE497BA, 0x5EDCB },
	{ 0xE497BC, 0x4E4BB },
	{ 0xE497BD, 0x4E4BC },
	{ 0xE497BE, 0x4E4C0 },
	{ 0xE497BF, 0x4E4BE },
	{ 0xE49880, 0x4E4C1 },
	{ 0xE49881, 0x3DDA6 },
	{ 0xE49882, 0x3DEDE },
	{ 0xE49883, 0x4E7B0 },
	{ 0xE49884, 0x4E4BD },
	{ 0xE49885, 0x4E9BE },
	{ 0xE49886, 0x3DFDE },
	{ 0xE49887, 0x3DFE0 },
	{ 0xE49888, 0x3E0C4 },
	{ 0xE49889, 0x7D9A5 },
	{ 0xE4988A, 0x7DCDE },
	{ 0xE4988B, 0x4EAF8 },
	{ 0xE4988C, 0x7DCE3 },
	{ 0xE4988D, 0x3E1C8 },
	{ 0xE4988E, 0x4EEB9 },
	{ 0xE4988F, 0x3AFA5 },
	{ 0xE49890, 0x6BBF3 },
	{ 0xE49891, 0x3B8E9 },
	{ 0xE49892, 0x3C4CC },
	{ 0xE49893, 0x4C7A3 },
	{ 0xE49894, 0x4CDB7 },
	{ 0xE49895, 0x4AFEF },
	{ 0xE49896, 0x4BAF8 },
	{ 0xE49897, 0x3CEDE },
	{ 0xE49898, 0x4D3CA },
	{ 0xE49899, 0x3DBAE },
	{ 0xE4989A, 0x3AAEE },
	{ 0xE4989C, 0x3AFA8 },
	{ 0xE4989D, 0x4ABC6 },
	{ 0xE4989F, 0x5B0BD },
	{ 0xE498A0, 0x4AFF2 },
	{ 0xE498A1, 0x5B0B9 },
	{ 0xE498A2, 0x4B5AA },
	{ 0xE498A3, 0x4BAFA },
	{ 0xE498A4, 0x4B5AD },
	{ 0xE498A5, 0x4B5AE },
	{ 0xE498A6, 0x4B5AC },
	{ 0xE498A7, 0xFB2D1 },
	{ 0xE498A8, 0x4BAF9 },
	{ 0xE498A9, 0x3BEF1 },
	{ 0xE498AA, 0x4B5B0 },
	{ 0xE498AB, 0x3BEEE },
	{ 0xE498AC, 0x3BEEC },
	{ 0xE498AD, 0x3BEEB },
	{ 0xE498AE, 0x3AFCA },
	{ 0xE498AF, 0x4C0E2 },
	{ 0xE498B0, 0x4C7A5 },
	{ 0xE498B1, 0x6D8AB },
	{ 0xE498B3, 0x3C9D3 },
	{ 0xE498B4, 0x4C7AD },
	{ 0xE498B5, 0x5C9EC },
	{ 0xE498B6, 0x5C9ED },
	{ 0xE498B7, 0x4C0E6 },
	{ 0xE498B8, 0x4C7B1 },
	{ 0xE498B9, 0x4C7A7 },
	{ 0xE498BA, 0x3C9D5 },
	{ 0xE498BB, 0x4C0E0 },
	{ 0xE498BC, 0x4C7AA },
	{ 0xE498BD, 0x4C7AE },
	{ 0xE498BE, 0x4C7A6 },
	{ 0xE498BF, 0x4C7AB },
	{ 0xE49980, 0x3C9DA },
	{ 0xE49981, 0x3C9D0 },
	{ 0xE49982, 0x3C9DB },
	{ 0xE49983, 0x4CDBC },
	{ 0xE49984, 0x4CDBF },
	{ 0xE49985, 0x4CDBA },
	{ 0xE49986, 0x4CDB9 },
	{ 0xE49987, 0x4CDC2 },
	{ 0xE49988, 0x4CDC0 },
	{ 0xE49989, 0x4CDC7 },
	{ 0xE4998E, 0x4D3D2 },
	{ 0xE4998F, 0x4D3D5 },
	{ 0xE49990, 0x4D3D6 },
	{ 0xE49991, 0x3CEE3 },
	{ 0xE49992, 0x4D3CF },
	{ 0xE49994, 0x4D8E3 },
	{ 0xE49995, 0x4D8E7 },
	{ 0xE49996, 0x3D6C5 },
	{ 0xE49997, 0x3D6C3 },
	{ 0xE49998, 0x4D8E4 },
	{ 0xE49999, 0x3D6BE },
	{ 0xE4999A, 0x7BBD9 },
	{ 0xE4999B, 0x3D6C4 },
	{ 0xE4999C, 0x4D8E5 },
	{ 0xE4999D, 0x3D6C1 },
	{ 0xE4999E, 0x5E4D6 },
	{ 0xE4999F, 0x4DDCA },
	{ 0xE499A0, 0x4DDC8 },
	{ 0xE499A1, 0x4DDC9 },
	{ 0xE499A2, 0x4DDC4 },
	{ 0xE499A3, 0x4DDC6 },
	{ 0xE499A4, 0x4E1AA },
	{ 0xE499A5, 0x7C3A2 },
	{ 0xE499A6, 0x4E4C3 },
	{ 0xE499A7, 0x7D0A5 },
	{ 0xE499A8, 0x3DDA7 },
	{ 0xE499A9, 0x4E4C4 },
	{ 0xE499AA, 0x3DEDF },
	{ 0xE499AC, 0x4EAFB },
	{ 0xE499AD, 0x7D9B2 },
	{ 0xE499AE, 0x3E0FA },
	{ 0xE499AF, 0x4ECA6 },
	{ 0xE499B0, 0x3E0F9 },
	{ 0xE499B1, 0x4EDFD },
	{ 0xE499B2, 0x5ABC7 },
	{ 0xE499B3, 0x4AFF3 },
	{ 0xE499B4, 0x4B5B1 },
	{ 0xE499B5, 0x4BBA1 },
	{ 0xE499B7, 0x3B3F9 },
	{ 0xE499B8, 0x3B3F8 },
	{ 0xE499B9, 0x4B5B3 },
	{ 0xE499BA, 0x4B5B5 },
	{ 0xE499BC, 0x4BBA3 },
	{ 0xE499BD, 0x5BCB5 },
	{ 0xE499BE, 0x4BBA2 },
	{ 0xE499BF, 0x3BEF3 },
	{ 0xE49A80, 0x3C4D0 },
	{ 0xE49A81, 0x3C4D1 },
	{ 0xE49A82, 0x4C7B6 },
	{ 0xE49A83, 0x4C7B8 },
	{ 0xE49A84, 0x4CDCA },
	{ 0xE49A85, 0x4CDC8 },
	{ 0xE49A86, 0x4D3DA },
	{ 0xE49A87, 0x4D3DB },
	{ 0xE49A88, 0x5D8B2 },
	{ 0xE49A89, 0x4D3DC },
	{ 0xE49A8A, 0x5DEC3 },
	{ 0xE49A8B, 0x4D8E8 },
	{ 0xE49A8C, 0x4D8E9 },
	{ 0xE49A8D, 0x4DDCE },
	{ 0xE49A8E, 0x4DDD0 },
	{ 0xE49A8F, 0x4E1AD },
	{ 0xE49A90, 0x4E1AE },
	{ 0xE49A91, 0x3DBB0 },
	{ 0xE49A92, 0x4E1AC },
	{ 0xE49A93, 0x4E1B0 },
	{ 0xE49A94, 0x3DEE0 },
	{ 0xE49A96, 0x3E2BC },
	{ 0xE49A97, 0x4B5BA },
	{ 0xE49A98, 0x3C4D3 },
	{ 0xE49A99, 0x4C0E7 },
	{ 0xE49A9A, 0x3C4D2 },
	{ 0xE49A9B, 0x4C7BA },
	{ 0xE49A9C, 0x4CDD1 },
	{ 0xE49A9D, 0x4CDCC },
	{ 0xE49A9E, 0x4CDCE },
	{ 0xE49A9F, 0x4CDD3 },
	{ 0xE49AA0, 0x4CDCF },
	{ 0xE49AA1, 0x4D3E4 },
	{ 0xE49AA2, 0x4D3E1 },
	{ 0xE49AA3, 0x4D3E2 },
	{ 0xE49AA5, 0x4D8EB },
	{ 0xE49AA6, 0x4D8EA },
	{ 0xE49AA7, 0x5E4E3 },
	{ 0xE49AA8, 0x4E1B1 },
	{ 0xE49AA9, 0x4E1B4 },
	{ 0xE49AAA, 0x4E4C6 },
	{ 0xE49AAB, 0x4E4C7 },
	{ 0xE49AAD, 0x4EDA2 },
	{ 0xE49AAE, 0x3AFAB },
	{ 0xE49AAF, 0x5ABC9 },
	{ 0xE49AB0, 0x3AFAD },
	{ 0xE49AB1, 0x4AFFE },
	{ 0xE49AB2, 0x3B3FD },
	{ 0xE49AB3, 0x4B5C1 },
	{ 0xE49AB4, 0x3B8FC },
	{ 0xE49AB5, 0x3B8F8 },
	{ 0xE49AB6, 0x5B5D7 },
	{ 0xE49AB7, 0x4B5C4 },
	{ 0xE49AB8, 0x5B5DE },
	{ 0xE49AB9, 0x3B9A4 },
	{ 0xE49ABA, 0x3B9A8 },
	{ 0xE49ABB, 0x3B9A1 },
	{ 0xE49ABC, 0x4B5BF },
	{ 0xE49ABD, 0x3B8FD },
	{ 0xE49ABE, 0x3B9A7 },
	{ 0xE49ABF, 0x4B5C3 },
	{ 0xE49B80, 0x5B5DD },
	{ 0xE49B81, 0x6C4ED },
	{ 0xE49B82, 0x3B9A6 },
	{ 0xE49B83, 0x5B5D6 },
	{ 0xE49B84, 0x4BBB3 },
	{ 0xE49B85, 0x3BEF9 },
	{ 0xE49B86, 0x3BEFA },
	{ 0xE49B87, 0x4BBB6 },
	{ 0xE49B88, 0x4BBB5 },
	{ 0xE49B89, 0x3BEF6 },
	{ 0xE49B8A, 0x3BEFB },
	{ 0xE49B8B, 0x3BEF7 },
	{ 0xE49B8C, 0x4BBB4 },
	{ 0xE49B8D, 0x4BBAA },
	{ 0xE49B8E, 0x4BBA9 },
	{ 0xE49B8F, 0x4BBAB },
	{ 0xE49B90, 0x3BFA6 },
	{ 0xE49B91, 0x6CEEB },
	{ 0xE49B92, 0x3BFA5 },
	{ 0xE49B94, 0x3C4D7 },
	{ 0xE49B95, 0x6D8C1 },
	{ 0xE49B96, 0x3C4DE },
	{ 0xE49B97, 0x4C0EE },
	{ 0xE49B98, 0x4C0ED },
	{ 0xE49B99, 0x4C0EC },
	{ 0xE49B9A, 0x3C4DA },
	{ 0xE49B9B, 0x3C4DF },
	{ 0xE49B9C, 0x3C4E2 },
	{ 0xE49B9D, 0x4C7BD },
	{ 0xE49B9E, 0x4C7C0 },
	{ 0xE49B9F, 0x4C7CA },
	{ 0xE49BA0, 0x4C7BC },
	{ 0xE49BA1, 0x3C9EA },
	{ 0xE49BA2, 0x4C7C6 },
	{ 0xE49BA3, 0x4C7C2 },
	{ 0xE49BA4, 0x3C9E1 },
	{ 0xE49BA5, 0x4C7C3 },
	{ 0xE49BA6, 0x3C9E9 },
	{ 0xE49BA7, 0x3C9E7 },
	{ 0xE49BA8, 0x3C9DD },
	{ 0xE49BA9, 0x4CDD9 },
	{ 0xE49BAA, 0x4CDD6 },
	{ 0xE49BAB, 0x4CDDC },
	{ 0xE49BAC, 0x4CDDE },
	{ 0xE49BAD, 0x3CEE8 },
	{ 0xE49BAE, 0x4CDE1 },
	{ 0xE49BAF, 0x4CDD8 },
	{ 0xE49BB0, 0x4CDDB },
	{ 0xE49BB1, 0x3CEED },
	{ 0xE49BB2, 0x4CDDF },
	{ 0xE49BB3, 0x4CDDA },
	{ 0xE49BB4, 0x3CEEB },
	{ 0xE49BB5, 0x4CDE0 },
	{ 0xE49BB6, 0x7A8F9 },
	{ 0xE49BB7, 0x4CDD5 },
	{ 0xE49BB8, 0x3CEF1 },
	{ 0xE49BB9, 0x4D3EA },
	{ 0xE49BBA, 0x3D2EC },
	{ 0xE49BBB, 0x3D2ED },
	{ 0xE49BBC, 0x7B3CD },
	{ 0xE49BBD, 0x4D3EB },
	{ 0xE49BBE, 0x3D6C7 },
	{ 0xE49BBF, 0x4D8F0 },
	{ 0xE49C80, 0x3D6CB },
	{ 0xE49C81, 0x3D6CC },
	{ 0xE49C82, 0x5DED5 },
	{ 0xE49C83, 0x4DDDA },
	{ 0xE49C84, 0x7CAA5 },
	{ 0xE49C85, 0x4DDD7 },
	{ 0xE49C86, 0x4DDDB },
	{ 0xE49C87, 0x3D9A2 },
	{ 0xE49C88, 0x3D9A5 },
	{ 0xE49C89, 0x4DDD4 },
	{ 0xE49C8A, 0x3D9A7 },
	{ 0xE49C8B, 0x4E1C0 },
	{ 0xE49C8C, 0x5E9D2 },
	{ 0xE49C8D, 0x3DBB3 },
	{ 0xE49C8E, 0x4E1BB },
	{ 0xE49C8F, 0x4E1BD },
	{ 0xE49C90, 0x4E1C5 },
	{ 0xE49C91, 0x5E9D1 },
	{ 0xE49C92, 0x4E4CE },
	{ 0xE49C93, 0x3DDAD },
	{ 0xE49C94, 0x7D0B1 },
	{ 0xE49C95, 0x4E4CC },
	{ 0xE49C96, 0x3DDAF },
	{ 0xE49C97, 0x4E4C8 },
	{ 0xE49C98, 0x3DDB1 },
	{ 0xE49C99, 0x4E7BD },
	{ 0xE49C9A, 0x4E7BF },
	{ 0xE49C9B, 0x7D5B2 },
	{ 0xE49C9C, 0x4E7BE },
	{ 0xE49C9D, 0x4E7C0 },
	{ 0xE49C9E, 0x4E7B9 },
	{ 0xE49C9F, 0x7D9B8 },
	{ 0xE49CA0, 0x3DFE3 },
	{ 0xE49CA1, 0x4E9C8 },
	{ 0xE49CA2, 0x5F6CC },
	{ 0xE49CAA, 0x4ABC9 },
	{ 0xE49CAB, 0x4B0A3 },
	{ 0xE49CAC, 0x6CEFA },
	{ 0xE49CAD, 0x3BFA7 },
	{ 0xE49CAE, 0x4C7CC },
	{ 0xE49CAF, 0x3CEF7 },
	{ 0xE49CB0, 0x4D8F5 },
	{ 0xE49CB1, 0x4DDE1 },
	{ 0xE49CB2, 0x4E9CC },
	{ 0xE49CB4, 0x4B5CA },
	{ 0xE49CB5, 0x3BFA8 },
	{ 0xE49CB6, 0x4C0F4 },
	{ 0xE49CB7, 0x4C7CE },
	{ 0xE49CB8, 0x4C7CF },
	{ 0xE49CB9, 0x3C9EC },
	{ 0xE49CBA, 0x4CDE4 },
	{ 0xE49CBB, 0x3D2F0 },
	{ 0xE49CBC, 0x4D3F3 },
	{ 0xE49CBD, 0x3D2EF },
	{ 0xE49CBE, 0x4D3F2 },
	{ 0xE49CBF, 0x3D2F1 },
	{ 0xE49D80, 0x4D8F6 },
	{ 0xE49D81, 0x4D8F7 },
	{ 0xE49D82, 0x3D6CE },
	{ 0xE49D83, 0x4E7C4 },
	{ 0xE49D84, 0x4EDA4 },
	{ 0xE49D85, 0x4B0A5 },
	{ 0xE49D86, 0x4B5CB },
	{ 0xE49D87, 0x6C5A2 },
	{ 0xE49D88, 0x4B5CC },
	{ 0xE49D89, 0xFC4F4 },
	{ 0xE49D8A, 0x4CDE7 },
	{ 0xE49D8B, 0x4CDE5 },
	{ 0xE49D8C, 0x4CDE8 },
	{ 0xE49D8D, 0x4D3F5 },
	{ 0xE49D8E, 0x4D3F7 },
	{ 0xE49D8F, 0x4DDE4 },
	{ 0xE49D90, 0x4E1C8 },
	{ 0xE49D91, 0x4E1C6 },
	{ 0xE49D92, 0x4E7C5 },
	{ 0xE49D93, 0x3DFE5 },
	{ 0xE49D94, 0x3E1CC },
	{ 0xE49D95, 0x4EDA5 },
	{ 0xE49D96, 0x4B5D0 },
	{ 0xE49D97, 0x6C5A4 },
	{ 0xE49D98, 0x3B9AF },
	{ 0xE49D9A, 0x4BBBE },
	{ 0xE49D9C, 0x3C9EE },
	{ 0xE49D9D, 0x3CEF9 },
	{ 0xE49D9E, 0x3CEF8 },
	{ 0xE49D9F, 0x3D2F2 },
	{ 0xE49DA0, 0x3D6D0 },
	{ 0xE49DA1, 0x3D9AC },
	{ 0xE49DA2, 0x3D9AD },
	{ 0xE49DA3, 0x4E1CA },
	{ 0xE49DA4, 0x7CAC1 },
	{ 0xE49DA5, 0x3DBB7 },
	{ 0xE49DA6, 0x4DDE8 },
	{ 0xE49DA7, 0x4B5D1 },
	{ 0xE49DA8, 0x4B5D4 },
	{ 0xE49DA9, 0x5BCCC },
	{ 0xE49DAA, 0x4BBBF },
	{ 0xE49DAB, 0x4BBC1 },
	{ 0xE49DAC, 0x3BFAE },
	{ 0xE49DAD, 0x4BBC2 },
	{ 0xE49DAE, 0x6CFA9 },
	{ 0xE49DAF, 0x4BBC3 },
	{ 0xE49DB0, 0x4C1A1 },
	{ 0xE49DB1, 0x3C4E6 },
	{ 0xE49DB2, 0x3C4E8 },
	{ 0xE49DB3, 0x5CAA9 },
	{ 0xE49DB4, 0x6E2EA },
	{ 0xE49DB5, 0x3C9EF },
	{ 0xE49DB6, 0x3CEFB },
	{ 0xE49DB7, 0x3CEFC },
	{ 0xE49DB8, 0x4CDEE },
	{ 0xE49DB9, 0x4CDEC },
	{ 0xE49DBA, 0x7A9B6 },
	{ 0xE49DBB, 0x4CDED },
	{ 0xE49DBD, 0x5D1B9 },
	{ 0xE49DBE, 0x3CFA1 },
	{ 0xE49DBF, 0x3D2F4 },
	{ 0xE49E80, 0x4D3FD },
	{ 0xE49E81, 0x4D3F9 },
	{ 0xE49E82, 0x4D3FB },
	{ 0xE49E83, 0x4D3FA },
	{ 0xE49E84, 0x3D2F6 },
	{ 0xE49E85, 0x7BCB3 },
	{ 0xE49E86, 0x4D8FA },
	{ 0xE49E87, 0xFE0FA },
	{ 0xE49E88, 0x4D3FE },
	{ 0xE49E89, 0x3DDB5 },
	{ 0xE49E8A, 0x3DEE4 },
	{ 0xE49E8B, 0x4EBA1 },
	{ 0xE49E91, 0x5B0CB },
	{ 0xE49E92, 0x5C3B4 },
	{ 0xE49E93, 0x4C7D9 },
	{ 0xE49E94, 0x4C7D8 },
	{ 0xE49E95, 0x4E7C8 },
	{ 0xE49E96, 0x5B0CC },
	{ 0xE49E97, 0x4B0A7 },
	{ 0xE49E98, 0x4B0A8 },
	{ 0xE49E99, 0x4B5D5 },
	{ 0xE49E9A, 0x4B5D6 },
	{ 0xE49E9B, 0x3B9B4 },
	{ 0xE49E9C, 0x3B9B6 },
	{ 0xE49E9D, 0x3BFB1 },
	{ 0xE49E9E, 0x4BBC5 },
	{ 0xE49E9F, 0x3BFB6 },
	{ 0xE49EA0, 0x3BFB2 },
	{ 0xE49EA1, 0x5BCD2 },
	{ 0xE49EA2, 0x3BFB5 },
	{ 0xE49EA3, 0x4BBC8 },
	{ 0xE49EA4, 0x4BBC7 },
	{ 0xE49EA5, 0x4C1A6 },
	{ 0xE49EA6, 0x4C1A7 },
	{ 0xE49EA7, 0x5C3BC },
	{ 0xE49EA8, 0x3C4EA },
	{ 0xE49EA9, 0x4C1A8 },
	{ 0xE49EAA, 0x5C3B8 },
	{ 0xE49EAB, 0x4C7DA },
	{ 0xE49EAC, 0x6E2F5 },
	{ 0xE49EAD, 0x4C7DB },
	{ 0xE49EAE, 0x3C9F6 },
	{ 0xE49EAF, 0x5CAB4 },
	{ 0xE49EB0, 0x3C9F7 },
	{ 0xE49EB1, 0x5CAB2 },
	{ 0xE49EB3, 0x3CFA7 },
	{ 0xE49EB4, 0x4CDF3 },
	{ 0xE49EB5, 0x4CDF1 },
	{ 0xE49EB6, 0x3CFA4 },
	{ 0xE49EB7, 0x4CDF4 },
	{ 0xE49EB8, 0x7A9BD },
	{ 0xE49EB9, 0x4D4A6 },
	{ 0xE49EBA, 0x5D8DC },
	{ 0xE49EBB, 0x5D8D5 },
	{ 0xE49EBC, 0x3D2F8 },
	{ 0xE49EBD, 0x4D8FD },
	{ 0xE49EBE, 0x4D9A5 },
	{ 0xE49EBF, 0x4D8FC },
	{ 0xE49F80, 0x5DEED },
	{ 0xE49F81, 0x4DDED },
	{ 0xE49F82, 0x3D9AF },
	{ 0xE49F83, 0x4DDEC },
	{ 0xE49F84, 0x4DDEA },
	{ 0xE49F85, 0x4DDEE },
	{ 0xE49F86, 0x3D9B0 },
	{ 0xE49F87, 0x4E1CD },
	{ 0xE49F88, 0x3DDB6 },
	{ 0xE49F89, 0x4E4D5 },
	{ 0xE49F8A, 0x4E4D3 },
	{ 0xE49F8B, 0x4E4D6 },
	{ 0xE49F8C, 0x4E7CA },
	{ 0xE49F8D, 0x4E9CE },
	{ 0xE49F8E, 0x3DFE6 },
	{ 0xE49F8F, 0x4E9CF },
	{ 0xE49F90, 0x4EBA3 },
	{ 0xE49F91, 0x4ECA8 },
	{ 0xE49F92, 0x4EDA7 },
	{ 0xE49F93, 0x4ABCC },
	{ 0xE49F94, 0x3AFAF },
	{ 0xE49F95, 0x4B0AA },
	{ 0xE49F96, 0x3B3FE },
	{ 0xE49F97, 0x4B5DE },
	{ 0xE49F98, 0x4B5D9 },
	{ 0xE49F99, 0x5B5F2 },
	{ 0xE49F9A, 0x3B9BB },
	{ 0xE49F9B, 0x4B5DB },
	{ 0xE49F9C, 0x4B5DC },
	{ 0xE49F9D, 0x4B5DD },
	{ 0xE49F9E, 0x3B9BC },
	{ 0xE49F9F, 0x5BCE3 },
	{ 0xE49FA0, 0x4BBCC },
	{ 0xE49FA1, 0x4BBD0 },
	{ 0xE49FA2, 0x3BFBD },
	{ 0xE49FA3, 0x4BBCD },
	{ 0xE49FA4, 0x4BBC9 },
	{ 0xE49FA5, 0x6CFB6 },
	{ 0xE49FA6, 0x6CFBC },
	{ 0xE49FA7, 0x5BCDC },
	{ 0xE49FA8, 0x4BBCA },
	{ 0xE49FA9, 0x4BBCB },
	{ 0xE49FAA, 0x4BBCF },
	{ 0xE49FAB, 0x3BFBC },
	{ 0xE49FAC, 0x5BCDF },
	{ 0xE49FAD, 0x4BBD1 },
	{ 0xE49FAE, 0x4C1A9 },
	{ 0xE49FAF, 0x5C3CB },
	{ 0xE49FB0, 0x3C4EC },
	{ 0xE49FB1, 0x3C4EE },
	{ 0xE49FB3, 0xFC5D8 },
	{ 0xE49FB4, 0x5CABE },
	{ 0xE49FB5, 0x4C7DE },
	{ 0xE49FB6, 0x4C7E1 },
	{ 0xE49FB7, 0x4C7DF },
	{ 0xE49FB8, 0x4C7E2 },
	{ 0xE49FB9, 0x4C7E5 },
	{ 0xE49FBA, 0x3C9F8 },
	{ 0xE49FBB, 0x4C7E4 },
	{ 0xE49FBC, 0x3CFA8 },
	{ 0xE49FBD, 0x3C4EF },
	{ 0xE49FBE, 0x4CDF7 },
	{ 0xE49FBF, 0x4CEA2 },
	{ 0xE4A080, 0x3CFAA },
	{ 0xE4A081, 0x7A9CE },
	{ 0xE4A082, 0x3CFAE },
	{ 0xE4A083, 0x3CFA9 },
	{ 0xE4A084, 0x4CDFE },
	{ 0xE4A085, 0x4CEA1 },
	{ 0xE4A086, 0x4CDFD },
	{ 0xE4A087, 0x4CDF9 },
	{ 0xE4A088, 0x4CDF8 },
	{ 0xE4A089, 0x4CDF6 },
	{ 0xE4A08A, 0x3CFAD },
	{ 0xE4A08B, 0x4CEA3 },
	{ 0xE4A08D, 0x4D4AE },
	{ 0xE4A08E, 0x3D2FD },
	{ 0xE4A08F, 0x3D2FA },
	{ 0xE4A090, 0x4D4AF },
	{ 0xE4A091, 0x4D4AD },
	{ 0xE4A092, 0x5D8E2 },
	{ 0xE4A093, 0x4D4B0 },
	{ 0xE4A094, 0x3D2F9 },
	{ 0xE4A095, 0x5DEFB },
	{ 0xE4A097, 0x4D9AB },
	{ 0xE4A098, 0x4D9AC },
	{ 0xE4A099, 0x4D9A6 },
	{ 0xE4A09A, 0xFDCF8 },
	{ 0xE4A09B, 0x4D9AA },
	{ 0xE4A09C, 0x4D9A8 },
	{ 0xE4A09D, 0x3D6D3 },
	{ 0xE4A09E, 0x3D9B3 },
	{ 0xE4A09F, 0x4DDF4 },
	{ 0xE4A0A0, 0x4DDF8 },
	{ 0xE4A0A1, 0x4DDF2 },
	{ 0xE4A0A2, 0x4DDF5 },
	{ 0xE4A0A3, 0x7CAD7 },
	{ 0xE4A0A4, 0x4E1D0 },
	{ 0xE4A0A5, 0x3D9B4 },
	{ 0xE4A0A6, 0x4E1D1 },
	{ 0xE4A0A7, 0x4DDF7 },
	{ 0xE4A0A8, 0x4E4DB },
	{ 0xE4A0A9, 0x4E4DA },
	{ 0xE4A0AA, 0x4E7D0 },
	{ 0xE4A0AB, 0x4E7CC },
	{ 0xE4A0AC, 0x5F4CB },
	{ 0xE4A0AD, 0x4EBA4 },
	{ 0xE4A0AE, 0x7DCF7 },
	{ 0xE4A0AF, 0x4ECA9 },
	{ 0xE4A0B0, 0x3E1CF },
	{ 0xE4A0B1, 0x3E2AE },
	{ 0xE4A0B2, 0x3BFC2 },
	{ 0xE4A0B3, 0x5BCE7 },
	{ 0xE4A0B4, 0x4BBD2 },
	{ 0xE4A0B5, 0x4BBD3 },
	{ 0xE4A0B6, 0x3BFC1 },
	{ 0xE4A0B7, 0x3C4F1 },
	{ 0xE4A0B8, 0x3C4F0 },
	{ 0xE4A0B9, 0x3C4F2 },
	{ 0xE4A0BB, 0x4CEA6 },
	{ 0xE4A0BC, 0x4D4B2 },
	{ 0xE4A0BD, 0x4D9B0 },
	{ 0xE4A0BE, 0x3D6D6 },
	{ 0xE4A0BF, 0x3DBBE },
	{ 0xE4A180, 0x4E4DF },
	{ 0xE4A181, 0x3E0CC },
	{ 0xE4A182, 0x4ABCD },
	{ 0xE4A183, 0x4ABCE },
	{ 0xE4A184, 0xFADD3 },
	{ 0xE4A185, 0x3B4A2 },
	{ 0xE4A186, 0x3B9C3 },
	{ 0xE4A187, 0x3B9C4 },
	{ 0xE4A188, 0x3B9C8 },
	{ 0xE4A189, 0x4B5E1 },
	{ 0xE4A18A, 0x4B5E2 },
	{ 0xE4A18B, 0x3B9C5 },
	{ 0xE4A18C, 0x3B9C6 },
	{ 0xE4A18D, 0x3B9C2 },
	{ 0xE4A18E, 0x6C5C5 },
	{ 0xE4A18F, 0x3BFC8 },
	{ 0xE4A190, 0x3BFC3 },
	{ 0xE4A191, 0x4BBD4 },
	{ 0xE4A192, 0x3BFCA },
	{ 0xE4A193, 0x3C4F5 },
	{ 0xE4A194, 0x4C1AA },
	{ 0xE4A195, 0x3C4F4 },
	{ 0xE4A196, 0x6D9A4 },
	{ 0xE4A197, 0x4C1AC },
	{ 0xE4A198, 0x4C7E6 },
	{ 0xE4A199, 0x4C7E9 },
	{ 0xE4A19A, 0x4C7E7 },
	{ 0xE4A19B, 0x3C9FE },
	{ 0xE4A19C, 0x4CEA8 },
	{ 0xE4A19D, 0x4CEA7 },
	{ 0xE4A19E, 0x4CEAA },
	{ 0xE4A19F, 0x4CEA9 },
	{ 0xE4A1A0, 0x3D3A3 },
	{ 0xE4A1A1, 0x5D8F2 },
	{ 0xE4A1A2, 0x4D4B3 },
	{ 0xE4A1A3, 0x4D4B4 },
	{ 0xE4A1A4, 0x5D1E1 },
	{ 0xE4A1A5, 0x3D6D8 },
	{ 0xE4A1A6, 0x4D9B2 },
	{ 0xE4A1A7, 0x4D9B5 },
	{ 0xE4A1A8, 0x4D9B7 },
	{ 0xE4A1A9, 0x3D6D7 },
	{ 0xE4A1AA, 0x4D9B1 },
	{ 0xE4A1AB, 0x4DDFC },
	{ 0xE4A1AC, 0x4DDFB },
	{ 0xE4A1AD, 0x4DDFA },
	{ 0xE4A1AE, 0x5E5B5 },
	{ 0xE4A1AF, 0x4DDFD },
	{ 0xE4A1B0, 0x4DDFE },
	{ 0xE4A1B2, 0x4E1D9 },
	{ 0xE4A1B3, 0x4E1D8 },
	{ 0xE4A1B4, 0x4E1D7 },
	{ 0xE4A1B5, 0x4E4E0 },
	{ 0xE4A1B6, 0x4E4E1 },
	{ 0xE4A1B7, 0x4E7D2 },
	{ 0xE4A1B8, 0xFE8D3 },
	{ 0xE4A1B9, 0x3DFE8 },
	{ 0xE4A1BA, 0x3DFE7 },
	{ 0xE4A1BC, 0x3E0FD },
	{ 0xE4A1BD, 0x4EDE1 },
	{ 0xE4A1BE, 0x4EEA1 },
	{ 0xE4A1BF, 0x3E2BD },
	{ 0xE4A283, 0x4CEAE },
	{ 0xE4A284, 0x3DDB9 },
	{ 0xE4A285, 0x4C7EB },
	{ 0xE4A286, 0xFCCE7 },
	{ 0xE4A287, 0x3CFB8 },
	{ 0xE4A288, 0x4E4E3 },
	{ 0xE4A289, 0x7D0D6 },
	{ 0xE4A28A, 0x3A7B2 },
	{ 0xE4A28B, 0x4A5A2 },
	{ 0xE4A28C, 0xFA8F2 },
	{ 0xE4A28D, 0x3AAEF },
	{ 0xE4A28E, 0x5A7E9 },
	{ 0xE4A290, 0x4ABD3 },
	{ 0xE4A291, 0x4ABD0 },
	{ 0xE4A292, 0x3B4A3 },
	{ 0xE4A293, 0x4B0AD },
	{ 0xE4A294, 0x4B0B0 },
	{ 0xE4A295, 0x3B4A4 },
	{ 0xE4A296, 0x4B0AE },
	{ 0xE4A299, 0x3B9C9 },
	{ 0xE4A29A, 0x4B5E9 },
	{ 0xE4A29B, 0x3B9CD },
	{ 0xE4A29C, 0x3BFD3 },
	{ 0xE4A29D, 0x4BBD7 },
	{ 0xE4A29E, 0x3BFCE },
	{ 0xE4A29F, 0x6CFC8 },
	{ 0xE4A2A0, 0x3BFD2 },
	{ 0xE4A2A1, 0x4C1AF },
	{ 0xE4A2A2, 0x3CAA5 },
	{ 0xE4A2A4, 0x4C7EC },
	{ 0xE4A2A5, 0x3CAA3 },
	{ 0xE4A2A6, 0x3CFBA },
	{ 0xE4A2A7, 0x4CEB1 },
	{ 0xE4A2A8, 0x4CEB5 },
	{ 0xE4A2A9, 0x3CFBD },
	{ 0xE4A2AA, 0x3D3AA },
	{ 0xE4A2AB, 0x3D3A8 },
	{ 0xE4A2AC, 0x3D3A9 },
	{ 0xE4A2AD, 0x4D9B8 },
	{ 0xE4A2AE, 0x4D9B9 },
	{ 0xE4A2AF, 0x7C3F7 },
	{ 0xE4A2B0, 0x3D9B9 },
	{ 0xE4A2B1, 0x4E1DE },
	{ 0xE4A2B2, 0x4ECAC },
	{ 0xE4A2B3, 0x3A2DF },
	{ 0xE4A2B4, 0x4A3B2 },
	{ 0xE4A2B5, 0x3A7B6 },
	{ 0xE4A2B6, 0x3A7B7 },
	{ 0xE4A2B7, 0x3A7B8 },
	{ 0xE4A2B8, 0x3AAF6 },
	{ 0xE4A2B9, 0x4A8A9 },
	{ 0xE4A2BB, 0x3AFB6 },
	{ 0xE4A2BC, 0x4ABD6 },
	{ 0xE4A2BD, 0x3C5A2 },
	{ 0xE4A2BE, 0x3AFBD },
	{ 0xE4A2BF, 0x4ABD4 },
	{ 0xE4A380, 0x4ABD8 },
	{ 0xE4A381, 0x3AFB9 },
	{ 0xE4A382, 0x3AFBA },
	{ 0xE4A383, 0x6B4ED },
	{ 0xE4A384, 0x4B0B8 },
	{ 0xE4A385, 0x4B0B4 },
	{ 0xE4A386, 0x3B4A8 },
	{ 0xE4A387, 0x4B0B3 },
	{ 0xE4A388, 0x4C7F1 },
	{ 0xE4A38A, 0x4B5EC },
	{ 0xE4A38B, 0x4B5EE },
	{ 0xE4A38C, 0x4B5F3 },
	{ 0xE4A38D, 0x4B5EB },
	{ 0xE4A38E, 0x3B9D0 },
	{ 0xE4A38F, 0x4B5F0 },
	{ 0xE4A390, 0x4BBDE },
	{ 0xE4A391, 0x3BFD8 },
	{ 0xE4A393, 0x4C1B4 },
	{ 0xE4A394, 0x4C1B6 },
	{ 0xE4A395, 0x3C5A1 },
	{ 0xE4A396, 0x4D9BC },
	{ 0xE4A397, 0x4C1B8 },
	{ 0xE4A398, 0x4C7ED },
	{ 0xE4A399, 0x4C7EE },
	{ 0xE4A39A, 0x3CAA9 },
	{ 0xE4A39B, 0x3CAA8 },
	{ 0xE4A39C, 0x5CAE0 },
	{ 0xE4A39D, 0x4C7F0 },
	{ 0xE4A39E, 0x3CFBE },
	{ 0xE4A39F, 0x4CEBD },
	{ 0xE4A3A0, 0x4CEBC },
	{ 0xE4A3A1, 0x5D8FE },
	{ 0xE4A3A2, 0x5DFBC },
	{ 0xE4A3A3, 0x3E0CD },
	{ 0xE4A3A4, 0x4EBA6 },
	{ 0xE4A3A5, 0x3AFBF },
	{ 0xE4A3A7, 0x3B4AB },
	{ 0xE4A3A8, 0x3B4AC },
	{ 0xE4A3A9, 0x4B5F8 },
	{ 0xE4A3AA, 0x4B5F4 },
	{ 0xE4A3AB, 0x3B9D3 },
	{ 0xE4A3AC, 0x5B6B6 },
	{ 0xE4A3AD, 0x4B5F5 },
	{ 0xE4A3AE, 0x4BBE0 },
	{ 0xE4A3AF, 0x3BFDA },
	{ 0xE4A3B0, 0x3BFDB },
	{ 0xE4A3B1, 0x3BFDC },
	{ 0xE4A3B2, 0x4BBE4 },
	{ 0xE4A3B4, 0x6D9CC },
	{ 0xE4A3B5, 0x3C5A6 },
	{ 0xE4A3B6, 0x4C1BD },
	{ 0xE4A3B7, 0x4C1BC },
	{ 0xE4A3B8, 0x4C1BF },
	{ 0xE4A3B9, 0x4C1BE },
	{ 0xE4A3BA, 0x4C7F3 },
	{ 0xE4A3BB, 0x4C7F4 },
	{ 0xE4A3BC, 0x4CEBF },
	{ 0xE4A3BD, 0x4CEC1 },
	{ 0xE4A3BE, 0x4CEBE },
	{ 0xE4A3BF, 0x4CEC0 },
	{ 0xE4A481, 0x4D4BD },
	{ 0xE4A482, 0x4D4BC },
	{ 0xE4A483, 0x4D4BA },
	{ 0xE4A484, 0x3D3AE },
	{ 0xE4A485, 0x4D4C0 },
	{ 0xE4A486, 0x4D4BB },
	{ 0xE4A487, 0x7B4D4 },
	{ 0xE4A488, 0x3D3B0 },
	{ 0xE4A489, 0x4D9BD },
	{ 0xE4A48A, 0x4D9C2 },
	{ 0xE4A48B, 0x7BCF0 },
	{ 0xE4A48C, 0x4D9C1 },
	{ 0xE4A48D, 0x5E5C5 },
	{ 0xE4A48E, 0x4E1E1 },
	{ 0xE4A48F, 0x4E1E4 },
	{ 0xE4A490, 0x4E1E3 },
	{ 0xE4A491, 0x4E1E2 },
	{ 0xE4A492, 0x4E1E5 },
	{ 0xE4A493, 0x4E7DA },
	{ 0xE4A494, 0x4E7DB },
	{ 0xE4A495, 0x4E9D4 },
	{ 0xE4A496, 0x4E9D3 },
	{ 0xE4A497, 0x4ECAE },
	{ 0xE4A498, 0x4ECAD },
	{ 0xE4A499, 0x4EEBD },
	{ 0xE4A49A, 0x4B5FA },
	{ 0xE4A49B, 0x6BCE3 },
	{ 0xE4A49C, 0x3B9DA },
	{ 0xE4A49D, 0x3BFDF },
	{ 0xE4A49E, 0x3BFE4 },
	{ 0xE4A49F, 0x3BFE1 },
	{ 0xE4A4A0, 0x3BFE7 },
	{ 0xE4A4A1, 0x3C5AC },
	{ 0xE4A4A2, 0x5C3ED },
	{ 0xE4A4A4, 0x3CAAE },
	{ 0xE4A4A5, 0x4C7F9 },
	{ 0xE4A4A6, 0x3CAB6 },
	{ 0xE4A4A7, 0x4C7F6 },
	{ 0xE4A4A8, 0x4C7FB },
	{ 0xE4A4AA, 0x4C7F8 },
	{ 0xE4A4AB, 0x3CFCF },
	{ 0xE4A4AC, 0x4CEC3 },
	{ 0xE4A4AD, 0x3CFC7 },
	{ 0xE4A4AE, 0x3CFC6 },
	{ 0xE4A4AF, 0x7AAB8 },
	{ 0xE4A4B0, 0x3CFCA },
	{ 0xE4A4B1, 0x7AABE },
	{ 0xE4A4B3, 0x3D3B3 },
	{ 0xE4A4B4, 0x3D3B4 },
	{ 0xE4A4B5, 0x4D4C8 },
	{ 0xE4A4B6, 0x4D4C6 },
	{ 0xE4A4B7, 0x7BCFB },
	{ 0xE4A4B8, 0x3D6E9 },
	{ 0xE4A4B9, 0x7BCF7 },
	{ 0xE4A4BA, 0x4D9C5 },
	{ 0xE4A4BB, 0x4D9C4 },
	{ 0xE4A4BC, 0xFDDCC },
	{ 0xE4A4BD, 0x3D9BF },
	{ 0xE4A4BE, 0x3D9C1 },
	{ 0xE4A4BF, 0x4DEAF },
	{ 0xE4A580, 0x4DEAC },
	{ 0xE4A581, 0x7C4B9 },
	{ 0xE4A582, 0x4DEA7 },
	{ 0xE4A583, 0x5E5CF },
	{ 0xE4A584, 0x4DEAB },
	{ 0xE4A585, 0x3D9C8 },
	{ 0xE4A586, 0x3D9C7 },
	{ 0xE4A588, 0x3DBC6 },
	{ 0xE4A589, 0x4E1E6 },
	{ 0xE4A58A, 0x3DBCB },
	{ 0xE4A58B, 0x3DBC0 },
	{ 0xE4A58C, 0x3DBD2 },
	{ 0xE4A58D, 0x4E1E9 },
	{ 0xE4A58E, 0x5EAB3 },
	{ 0xE4A58F, 0x4E1E8 },
	{ 0xE4A590, 0x3DBD1 },
	{ 0xE4A591, 0x3DBCC },
	{ 0xE4A592, 0x3DBC9 },
	{ 0xE4A593, 0xFE4B4 },
	{ 0xE4A594, 0x3DDBB },
	{ 0xE4A595, 0x4E1EC },
	{ 0xE4A596, 0x3DDC0 },
	{ 0xE4A597, 0x4E4E6 },
	{ 0xE4A598, 0x4E4EC },
	{ 0xE4A599, 0x5EEB5 },
	{ 0xE4A59A, 0x3DDC8 },
	{ 0xE4A59B, 0x4E4ED },
	{ 0xE4A59D, 0x4E7DF },
	{ 0xE4A59E, 0x3DEEB },
	{ 0xE4A59F, 0x4E4E9 },
	{ 0xE4A5A0, 0x4E7E1 },
	{ 0xE4A5A1, 0x3DEEC },
	{ 0xE4A5A2, 0x4E7E3 },
	{ 0xE4A5A3, 0x7D5E8 },
	{ 0xE4A5A4, 0x3DEE9 },
	{ 0xE4A5A5, 0x3DEEE },
	{ 0xE4A5A6, 0x3DEEF },
	{ 0xE4A5A7, 0x3DFEF },
	{ 0xE4A5A8, 0x3E0D1 },
	{ 0xE4A5A9, 0x5F1D5 },
	{ 0xE4A5AA, 0x7D9E7 },
	{ 0xE4A5AB, 0x3DFED },
	{ 0xE4A5AC, 0x7D9E8 },
	{ 0xE4A5AD, 0x3DFF0 },
	{ 0xE4A5AE, 0x5F4D5 },
	{ 0xE4A5AF, 0x4EBAA },
	{ 0xE4A5B0, 0x5F6DF },
	{ 0xE4A5B1, 0x4EBA7 },
	{ 0xE4A5B2, 0x3E0CE },
	{ 0xE4A5B3, 0x3E0D0 },
	{ 0xE4A5B4, 0x3E1A3 },
	{ 0xE4A5B5, 0x3E1A1 },
	{ 0xE4A5B6, 0x4ECB0 },
	{ 0xE4A5B7, 0x3E1A4 },
	{ 0xE4A5B8, 0x3E1EE },
	{ 0xE4A687, 0x6BCE5 },
	{ 0xE4A688, 0x4BBE7 },
	{ 0xE4A689, 0xFBFF6 },
	{ 0xE4A68A, 0x4C1C9 },
	{ 0xE4A68B, 0x4DEB2 },
	{ 0xE4A68C, 0x3B9DB },
	{ 0xE4A68D, 0x4B5FC },
	{ 0xE4A68E, 0x3BFEA },
	{ 0xE4A68F, 0x4BBEB },
	{ 0xE4A690, 0x3BFEE },
	{ 0xE4A691, 0x3BFEB },
	{ 0xE4A692, 0x3C5BB },
	{ 0xE4A693, 0x4C1D0 },
	{ 0xE4A694, 0x4C1CE },
	{ 0xE4A695, 0x4C8A3 },
	{ 0xE4A696, 0x3CABB },
	{ 0xE4A697, 0x3CABF },
	{ 0xE4A698, 0x3CABA },
	{ 0xE4A699, 0x5CAEE },
	{ 0xE4A69A, 0x3CABC },
	{ 0xE4A69C, 0x7AAC6 },
	{ 0xE4A69D, 0x4CEC8 },
	{ 0xE4A69E, 0x3CFD4 },
	{ 0xE4A69F, 0x3CFD7 },
	{ 0xE4A6A0, 0x4D4CF },
	{ 0xE4A6A1, 0x4D4CB },
	{ 0xE4A6A2, 0x3D3BF },
	{ 0xE4A6A3, 0x4D4CC },
	{ 0xE4A6A4, 0x3D3C1 },
	{ 0xE4A6A5, 0x3D3C3 },
	{ 0xE4A6A6, 0x3D3C6 },
	{ 0xE4A6A7, 0x3D3C5 },
	{ 0xE4A6A8, 0x7B4F3 },
	{ 0xE4A6AA, 0x4D9CE },
	{ 0xE4A6AB, 0x4D9CF },
	{ 0xE4A6AC, 0x4D9D4 },
	{ 0xE4A6AD, 0x3D6EE },
	{ 0xE4A6AE, 0x3D6EC },
	{ 0xE4A6AF, 0x4D9CD },
	{ 0xE4A6B1, 0x4D9D2 },
	{ 0xE4A6B2, 0x4E7E6 },
	{ 0xE4A6B3, 0x4E4F1 },
	{ 0xE4A6B4, 0x5F1DB },
	{ 0xE4A6B5, 0x4E9D5 },
	{ 0xE4A6B9, 0x5A1FD },
	{ 0xE4A6BA, 0x3A2E0 },
	{ 0xE4A6BB, 0x3A4BE },
	{ 0xE4A6BC, 0x5A4FB },
	{ 0xE4A6BD, 0x6A9B5 },
	{ 0xE4A781, 0x4A8B1 },
	{ 0xE4A782, 0x4A8B2 },
	{ 0xE4A783, 0x3AAFA },
	{ 0xE4A784, 0x5ABE4 },
	{ 0xE4A785, 0x4ABDA },
	{ 0xE4A786, 0x3AFC1 },
	{ 0xE4A787, 0x4ABD9 },
	{ 0xE4A789, 0x4B0C0 },
	{ 0xE4A78A, 0x4B0BD },
	{ 0xE4A78B, 0x3B4B5 },
	{ 0xE4A78C, 0x4B0BE },
	{ 0xE4A78D, 0x3B4B7 },
	{ 0xE4A78E, 0x4B0BC },
	{ 0xE4A790, 0x3B9E3 },
	{ 0xE4A791, 0x3B9DD },
	{ 0xE4A792, 0x4B5FD },
	{ 0xE4A793, 0x3B9E0 },
	{ 0xE4A794, 0x3B9E2 },
	{ 0xE4A795, 0x3B9E4 },
	{ 0xE4A796, 0x3B9DF },
	{ 0xE4A797, 0x3BFEF },
	{ 0xE4A798, 0x4BBED },
	{ 0xE4A799, 0x3BFF4 },
	{ 0xE4A79A, 0x3C5BF },
	{ 0xE4A79B, 0x3C5BE },
	{ 0xE4A79C, 0x4C1D5 },
	{ 0xE4A79D, 0x4C1D4 },
	{ 0xE4A79E, 0x3C5BD },
	{ 0xE4A79F, 0x3C5C1 },
	{ 0xE4A7A0, 0x3CAC1 },
	{ 0xE4A7A1, 0x3CAC0 },
	{ 0xE4A7A2, 0x3CAC3 },
	{ 0xE4A7A3, 0x3CAC2 },
	{ 0xE4A7A4, 0x3CFD9 },
	{ 0xE4A7A5, 0x3CFD8 },
	{ 0xE4A7A6, 0x7AAD4 },
	{ 0xE4A7A7, 0x3D3C7 },
	{ 0xE4A7A8, 0x4D4D3 },
	{ 0xE4A7AA, 0x4D4D1 },
	{ 0xE4A7AC, 0x4D9D5 },
	{ 0xE4A7AE, 0x3DBD4 },
	{ 0xE4A7AF, 0x4E4F3 },
	{ 0xE4A7B0, 0x4E7E7 },
	{ 0xE4A7B1, 0x3B4B8 },
	{ 0xE4A7B2, 0x4B6A4 },
	{ 0xE4A7B3, 0x3BFFA },
	{ 0xE4A7B4, 0x3BFF6 },
	{ 0xE4A7B5, 0x3BFF9 },
	{ 0xE4A7B6, 0x3BFF7 },
	{ 0xE4A7B7, 0x4C1D6 },
	{ 0xE4A7B8, 0x3C5C4 },
	{ 0xE4A7B9, 0x3C5C3 },
	{ 0xE4A7BA, 0x3C5C5 },
	{ 0xE4A7BB, 0x3CAC8 },
	{ 0xE4A7BC, 0x3CFDD },
	{ 0xE4A7BD, 0x3CFDC },
	{ 0xE4A7BE, 0x3D3CB },
	{ 0xE4A7BF, 0x3D3CA },
	{ 0xE4A880, 0x3D2B8 },
	{ 0xE4A881, 0x4D9D8 },
	{ 0xE4A882, 0x3D6F2 },
	{ 0xE4A883, 0x3D9CC },
	{ 0xE4A884, 0x3DBD5 },
	{ 0xE4A885, 0x3DDCA },
	{ 0xE4A886, 0x3DBD6 },
	{ 0xE4A887, 0x3DDCB },
	{ 0xE4A888, 0x4E9D6 },
	{ 0xE4A889, 0x3E1D1 },
	{ 0xE4A88A, 0x3E2C0 },
	{ 0xE4A88B, 0x3B9E6 },
	{ 0xE4A88C, 0x3BFFD },
	{ 0xE4A88D, 0x6D0B1 },
	{ 0xE4A88E, 0x3C5C8 },
	{ 0xE4A88F, 0x4C8AD },
	{ 0xE4A890, 0x4C8B1 },
	{ 0xE4A891, 0x4C8AE },
	{ 0xE4A892, 0x3CACA },
	{ 0xE4A893, 0x4C8B4 },
	{ 0xE4A894, 0x3CACB },
	{ 0xE4A895, 0x4C8B3 },
	{ 0xE4A896, 0x6E3FB },
	{ 0xE4A897, 0x3CFDE },
	{ 0xE4A898, 0x3CFE1 },
	{ 0xE4A899, 0x3CFDF },
	{ 0xE4A89B, 0x4D4D9 },
	{ 0xE4A89C, 0x3D3CF },
	{ 0xE4A89D, 0x3D3CE },
	{ 0xE4A89E, 0x4D9E0 },
	{ 0xE4A89F, 0x3D6F3 },
	{ 0xE4A8A0, 0x3D6F7 },
	{ 0xE4A8A1, 0x4D4D8 },
	{ 0xE4A8A2, 0x3D6F6 },
	{ 0xE4A8A3, 0x4D9DD },
	{ 0xE4A8A4, 0x4D9DF },
	{ 0xE4A8A5, 0x4DEB5 },
	{ 0xE4A8A6, 0x3D9CD },
	{ 0xE4A8A7, 0x3D9CE },
	{ 0xE4A8A8, 0x4DEB6 },
	{ 0xE4A8A9, 0x7C4D8 },
	{ 0xE4A8AA, 0x7C4E0 },
	{ 0xE4A8AB, 0x4E1F4 },
	{ 0xE4A8AC, 0x4E1F3 },
	{ 0xE4A8AD, 0x3DBD7 },
	{ 0xE4A8AE, 0x3DBD8 },
	{ 0xE4A8AF, 0x3DBD9 },
	{ 0xE4A8B0, 0x4E4F5 },
	{ 0xE4A8B1, 0x3DDCD },
	{ 0xE4A8B2, 0x4E9D8 },
	{ 0xE4A8B3, 0x4E9DA },
	{ 0xE4A8B4, 0x4E9DB },
	{ 0xE4A8B5, 0x3E0D8 },
	{ 0xE4A8B6, 0x3E1D3 },
	{ 0xE4A8B7, 0x3E1A7 },
	{ 0xE4A8B8, 0x3E1D2 },
	{ 0xE4A8B9, 0x3E2A4 },
	{ 0xE4A8BA, 0x3E2C4 },
	{ 0xE4A8BB, 0x3E2C6 },
	{ 0xE4A8BC, 0x4E9DC },
	{ 0xE4A8BD, 0x4B6A8 },
	{ 0xE4A8BE, 0x4B6AA },
	{ 0xE4A8BF, 0x4BBF4 },
	{ 0xE4A980, 0x4CECC },
	{ 0xE4A981, 0x4E4FB },
	{ 0xE4A982, 0x4C1DA },
	{ 0xE4A983, 0x3C5CA },
	{ 0xE4A985, 0x3CACD },
	{ 0xE4A986, 0x4C8B8 },
	{ 0xE4A987, 0x4C8B7 },
	{ 0xE4A988, 0x4D4DD },
	{ 0xE4A989, 0x4D4DC },
	{ 0xE4A98A, 0x4D9E2 },
	{ 0xE4A98B, 0x4E4FC },
	{ 0xE4A98C, 0x4E7EE },
	{ 0xE4A98D, 0x5F1E3 },
	{ 0xE4A98F, 0x4ECB3 },
	{ 0xE4A990, 0x4BBF9 },
	{ 0xE4A991, 0x3C0A3 },
	{ 0xE4A992, 0x4BBF6 },
	{ 0xE4A993, 0x3C5CD },
	{ 0xE4A994, 0x4C1DD },
	{ 0xE4A995, 0x4C1DF },
	{ 0xE4A996, 0x3C5CC },
	{ 0xE4A997, 0xFC6B2 },
	{ 0xE4A998, 0x6DAA8 },
	{ 0xE4A999, 0x4C8BA },
	{ 0xE4A99A, 0x4C8C0 },
	{ 0xE4A99B, 0x4C8BB },
	{ 0xE4A99C, 0x3CACF },
	{ 0xE4A99D, 0x3CAD0 },
	{ 0xE4A99E, 0x4C8BD },
	{ 0xE4A99F, 0x4CECF },
	{ 0xE4A9A0, 0x4D4E3 },
	{ 0xE4A9A1, 0x4D4E1 },
	{ 0xE4A9A2, 0x4D4E0 },
	{ 0xE4A9A3, 0x4D4E4 },
	{ 0xE4A9A4, 0x4D4E2 },
	{ 0xE4A9A5, 0x4D9E3 },
	{ 0xE4A9A6, 0x4D4E8 },
	{ 0xE4A9A7, 0x3D3D2 },
	{ 0xE4A9A8, 0x3D6FC },
	{ 0xE4A9A9, 0x4D9E8 },
	{ 0xE4A9AA, 0x4D9E4 },
	{ 0xE4A9AB, 0x7BDD6 },
	{ 0xE4A9AC, 0x3D6F9 },
	{ 0xE4A9AD, 0x3D6FD },
	{ 0xE4A9AE, 0x3D6FE },
	{ 0xE4A9AF, 0x4DEBE },
	{ 0xE4A9B0, 0x5E5FE },
	{ 0xE4A9B1, 0x4DEC2 },
	{ 0xE4A9B2, 0x4DEBC },
	{ 0xE4A9B3, 0x5E5F3 },
	{ 0xE4A9B4, 0x5E5FB },
	{ 0xE4A9B5, 0x4DEBB },
	{ 0xE4A9B6, 0x4DEC1 },
	{ 0xE4A9B7, 0x3DBDC },
	{ 0xE4A9B8, 0x3DBDB },
	{ 0xE4A9B9, 0x4E1F7 },
	{ 0xE4A9BA, 0x4E1FB },
	{ 0xE4A9BB, 0x3DBDA },
	{ 0xE4A9BC, 0x4E5A3 },
	{ 0xE4A9BD, 0x4E4FE },
	{ 0xE4A9BE, 0x5EEC9 },
	{ 0xE4A9BF, 0x7D6A7 },
	{ 0xE4AA80, 0x7D6A5 },
	{ 0xE4AA81, 0x4E7F2 },
	{ 0xE4AA82, 0x4E7F0 },
	{ 0xE4AA83, 0x5F1E9 },
	{ 0xE4AA84, 0x7D6A6 },
	{ 0xE4AA85, 0x3DFF4 },
	{ 0xE4AA86, 0x5F4E2 },
	{ 0xE4AA87, 0x4EBAC },
	{ 0xE4AA88, 0x3E0DA },
	{ 0xE4AA89, 0x4ECB4 },
	{ 0xE4AA8A, 0x4EDAD },
	{ 0xE4AA8B, 0x3E1D4 },
	{ 0xE4AA8C, 0x4EDE5 },
	{ 0xE4AA8D, 0x3E1F0 },
	{ 0xE4AA8E, 0x4EEA2 },
	{ 0xE4AA8F, 0x4C1E1 },
	{ 0xE4AA90, 0x4C8C3 },
	{ 0xE4AA91, 0x4C8C1 },
	{ 0xE4AA92, 0x4C8C2 },
	{ 0xE4AA93, 0x4C8C4 },
	{ 0xE4AA94, 0x3D3D4 },
	{ 0xE4AA95, 0x4D9EB },
	{ 0xE4AA96, 0x7C4F7 },
	{ 0xE4AA97, 0x4DEC5 },
	{ 0xE4AA98, 0x3D9D2 },
	{ 0xE4AA99, 0x4E1FD },
	{ 0xE4AA9A, 0x4E1FE },
	{ 0xE4AA9B, 0x4E7F3 },
	{ 0xE4AA9C, 0x4E9E0 },
	{ 0xE4AA9D, 0x3E0DB },
	{ 0xE4AA9E, 0x3C5CE },
	{ 0xE4AAA0, 0x3D7A1 },
	{ 0xE4AAA1, 0x3DBE3 },
	{ 0xE4AAA2, 0x3DBE2 },
	{ 0xE4AAA3, 0x3DDD2 },
	{ 0xE4AAA4, 0x4E7F5 },
	{ 0xE4AAA5, 0x4EBAD },
	{ 0xE4AAA6, 0x3C0A5 },
	{ 0xE4AAA7, 0x3C0A6 },
	{ 0xE4AAA8, 0x3C0A7 },
	{ 0xE4AAA9, 0x3C5D1 },
	{ 0xE4AAAB, 0x4D4EA },
	{ 0xE4AAAC, 0x4D4E9 },
	{ 0xE4AAAD, 0x3D9D3 },
	{ 0xE4AAAE, 0x4E2A2 },
	{ 0xE4AAAF, 0x4E2A3 },
	{ 0xE4AAB0, 0x3DFF5 },
	{ 0xE4AAB1, 0x4BBFB },
	{ 0xE4AAB2, 0xFC0AD },
	{ 0xE4AAB3, 0x4C1E5 },
	{ 0xE4AAB4, 0x4C1E4 },
	{ 0xE4AAB5, 0x5C4B4 },
	{ 0xE4AAB6, 0x5CBBE },
	{ 0xE4AAB7, 0x4C8CD },
	{ 0xE4AAB8, 0x3CAD1 },
	{ 0xE4AAB9, 0x4C8CE },
	{ 0xE4AABA, 0x3CAD3 },
	{ 0xE4AABB, 0x4C8CC },
	{ 0xE4AABC, 0x4C8CB },
	{ 0xE4AABD, 0x5CBBF },
	{ 0xE4AABE, 0x4C8C7 },
	{ 0xE4AABF, 0x3CFE8 },
	{ 0xE4AB80, 0x4CED9 },
	{ 0xE4AB81, 0x4CEDC },
	{ 0xE4AB82, 0x5D2E0 },
	{ 0xE4AB83, 0x4D4ED },
	{ 0xE4AB84, 0x4D4EF },
	{ 0xE4AB85, 0x3D3D6 },
	{ 0xE4AB86, 0x4CEDD },
	{ 0xE4AB87, 0x3D3E0 },
	{ 0xE4AB88, 0x3D3D7 },
	{ 0xE4AB89, 0x3D3DE },
	{ 0xE4AB8A, 0x7B5D1 },
	{ 0xE4AB8B, 0x3D7A5 },
	{ 0xE4AB8C, 0x4D9F3 },
	{ 0xE4AB8D, 0x7BDE9 },
	{ 0xE4AB8E, 0x3D7A2 },
	{ 0xE4AB8F, 0x4D9F7 },
	{ 0xE4AB90, 0x3D7A3 },
	{ 0xE4AB91, 0x3D7A4 },
	{ 0xE4AB92, 0x3D7A7 },
	{ 0xE4AB93, 0x3D7A9 },
	{ 0xE4AB94, 0x4DECE },
	{ 0xE4AB95, 0x3D9D4 },
	{ 0xE4AB96, 0x4DEC9 },
	{ 0xE4AB97, 0x4DEC7 },
	{ 0xE4AB98, 0x4DECB },
	{ 0xE4AB99, 0x3D9D7 },
	{ 0xE4AB9A, 0x3D9D5 },
	{ 0xE4AB9B, 0x4DECD },
	{ 0xE4AB9C, 0x4DECC },
	{ 0xE4AB9D, 0x3D9DA },
	{ 0xE4AB9E, 0x4E2A7 },
	{ 0xE4AB9F, 0x4E2A9 },
	{ 0xE4ABA0, 0x4E2AD },
	{ 0xE4ABA1, 0x4E2A6 },
	{ 0xE4ABA2, 0x4E2AC },
	{ 0xE4ABA3, 0x3DBE4 },
	{ 0xE4ABA4, 0x4E2A5 },
	{ 0xE4ABA5, 0x4E2AF },
	{ 0xE4ABA6, 0x4E2A8 },
	{ 0xE4ABA7, 0x4E2AB },
	{ 0xE4ABA8, 0x4E5AF },
	{ 0xE4ABA9, 0x4E5B1 },
	{ 0xE4ABAA, 0x4E5B0 },
	{ 0xE4ABAB, 0x3DDD4 },
	{ 0xE4ABAC, 0x4E7F7 },
	{ 0xE4ABAD, 0x4E7F9 },
	{ 0xE4ABAE, 0x4E7F6 },
	{ 0xE4ABAF, 0x4E7FC },
	{ 0xE4ABB0, 0x4E7FB },
	{ 0xE4ABB1, 0x7D6B2 },
	{ 0xE4ABB2, 0x4E9E3 },
	{ 0xE4ABB3, 0x3DFF6 },
	{ 0xE4ABB4, 0x4E9E2 },
	{ 0xE4ABB5, 0x4ECB9 },
	{ 0xE4ABB6, 0x5F8C8 },
	{ 0xE4ABB7, 0x3E1D5 },
	{ 0xE4ABB8, 0x4B6AB },
	{ 0xE4ABB9, 0x4BBFE },
	{ 0xE4ABBA, 0x3C5D3 },
	{ 0xE4ABBB, 0x4C1ED },
	{ 0xE4ABBC, 0x4C1F2 },
	{ 0xE4ABBD, 0x4C1EE },
	{ 0xE4ABBE, 0x4C8D1 },
	{ 0xE4ABBF, 0x4C8D6 },
	{ 0xE4AC80, 0x4C8D9 },
	{ 0xE4AC81, 0x4C8D0 },
	{ 0xE4AC82, 0x4C8D4 },
	{ 0xE4AC83, 0x3CAD7 },
	{ 0xE4AC84, 0x4CEE0 },
	{ 0xE4AC85, 0x4CEE1 },
	{ 0xE4AC86, 0x4D4F6 },
	{ 0xE4AC87, 0x4D4F7 },
	{ 0xE4AC88, 0x4D4F3 },
	{ 0xE4AC89, 0x4D4F4 },
	{ 0xE4AC8A, 0x4D4F5 },
	{ 0xE4AC8B, 0x4D9FD },
	{ 0xE4AC8C, 0x4DAA2 },
	{ 0xE4AC8D, 0x4DAA1 },
	{ 0xE4AC8E, 0x4D9FC },
	{ 0xE4AC8F, 0x4D9FA },
	{ 0xE4AC90, 0x4D9FE },
	{ 0xE4AC91, 0x4DED1 },
	{ 0xE4AC92, 0x7C4FE },
	{ 0xE4AC93, 0x4DED0 },
	{ 0xE4AC94, 0x4DED2 },
	{ 0xE4AC95, 0x3D9DD },
	{ 0xE4AC96, 0x3D9DE },
	{ 0xE4AC97, 0x3D9DF },
	{ 0xE4AC98, 0x4E2B2 },
	{ 0xE4AC99, 0x3DBE7 },
	{ 0xE4AC9A, 0x3DBE6 },
	{ 0xE4AC9B, 0x4E5B6 },
	{ 0xE4AC9C, 0x3DDD5 },
	{ 0xE4AC9D, 0x4E7FE },
	{ 0xE4AC9E, 0x4EBB0 },
	{ 0xE4AC9F, 0x4ECBA },
	{ 0xE4ACA0, 0x3D7AB },
	{ 0xE4ACA1, 0x3D9E0 },
	{ 0xE4ACA2, 0x3B4BA },
	{ 0xE4ACA3, 0x4B6AC },
	{ 0xE4ACA4, 0x3C0A9 },
	{ 0xE4ACA5, 0x3C0AA },
	{ 0xE4ACA6, 0x4BCA4 },
	{ 0xE4ACA7, 0x3C0A8 },
	{ 0xE4ACA8, 0x4BCA5 },
	{ 0xE4ACA9, 0x3C5DD },
	{ 0xE4ACAA, 0x3C0AC },
	{ 0xE4ACAB, 0x4C1F7 },
	{ 0xE4ACAC, 0x4C1F4 },
	{ 0xE4ACAD, 0x3CADC },
	{ 0xE4ACAE, 0x3C5DE },
	{ 0xE4ACAF, 0x4C1F5 },
	{ 0xE4ACB0, 0x3C5D6 },
	{ 0xE4ACB1, 0x3C5D5 },
	{ 0xE4ACB2, 0x3C5DA },
	{ 0xE4ACB3, 0x4C1F9 },
	{ 0xE4ACB4, 0x4C1FA },
	{ 0xE4ACB5, 0x3CAD8 },
	{ 0xE4ACB6, 0x3CAD9 },
	{ 0xE4ACB7, 0x4C8DB },
	{ 0xE4ACB8, 0x7ABB8 },
	{ 0xE4ACB9, 0x3CADA },
	{ 0xE4ACBA, 0x4C8DC },
	{ 0xE4ACBB, 0x6E4C0 },
	{ 0xE4ACBC, 0x3CFEA },
	{ 0xE4ACBD, 0x4CEE5 },
	{ 0xE4ACBE, 0x4CEE4 },
	{ 0xE4ACBF, 0x4CEE7 },
	{ 0xE4AD80, 0x4CEE6 },
	{ 0xE4AD81, 0x4D4F8 },
	{ 0xE4AD82, 0x4CEE9 },
	{ 0xE4AD83, 0x4D4FC },
	{ 0xE4AD84, 0x4D4FD },
	{ 0xE4AD85, 0x4D4FA },
	{ 0xE4AD86, 0x4DAA7 },
	{ 0xE4AD87, 0x4D5A2 },
	{ 0xE4AD88, 0x4DAA8 },
	{ 0xE4AD89, 0x4DAAA },
	{ 0xE4AD8A, 0x5E0B1 },
	{ 0xE4AD8B, 0x3D7AD },
	{ 0xE4AD8C, 0x3D9E4 },
	{ 0xE4AD8D, 0x5E0AC },
	{ 0xE4AD8E, 0x3D7AC },
	{ 0xE4AD90, 0x4DED8 },
	{ 0xE4AD91, 0x4DED7 },
	{ 0xE4AD92, 0x4DEDB },
	{ 0xE4AD93, 0x4DED9 },
	{ 0xE4AD94, 0x4DEDA },
	{ 0xE4AD95, 0x4E5B9 },
	{ 0xE4AD96, 0x4E2B6 },
	{ 0xE4AD97, 0x3DBE8 },
	{ 0xE4AD98, 0x4E5BC },
	{ 0xE4AD99, 0x4E5BB },
	{ 0xE4AD9A, 0x3DDD7 },
	{ 0xE4AD9B, 0x3DDD9 },
	{ 0xE4AD9D, 0x4E8A4 },
	{ 0xE4AD9E, 0x4E8A3 },
	{ 0xE4AD9F, 0x3DEFD },
	{ 0xE4ADA0, 0x4E8A2 },
	{ 0xE4ADA1, 0x4E9E7 },
	{ 0xE4ADA2, 0x4E9E5 },
	{ 0xE4ADA3, 0x3DFF7 },
	{ 0xE4ADA4, 0x4E9E8 },
	{ 0xE4ADA5, 0x4EBB1 },
	{ 0xE4ADA6, 0x3E1D6 },
	{ 0xE4ADA7, 0x4EDB0 },
	{ 0xE4ADA8, 0x4EDE7 },
	{ 0xE4ADA9, 0x4EEA5 },
	{ 0xE4ADAB, 0x3CFEC },
	{ 0xE4ADAC, 0x3D3E7 },
	{ 0xE4ADAD, 0x4DEDF },
	{ 0xE4ADAE, 0x4E2BC },
	{ 0xE4ADAF, 0x4C8DD },
	{ 0xE4ADB0, 0x3D7AF },
	{ 0xE4ADB1, 0x4D5A6 },
	{ 0xE4ADB2, 0x3D7AE },
	{ 0xE4ADB3, 0x3E1F1 },
	{ 0xE4ADB4, 0x3C0AD },
	{ 0xE4ADB5, 0x5C4CA },
	{ 0xE4ADB6, 0x3C5E0 },
	{ 0xE4ADB7, 0x4C8DE },
	{ 0xE4ADB8, 0x3CAE5 },
	{ 0xE4ADB9, 0x4C8DF },
	{ 0xE4ADBA, 0x3CADF },
	{ 0xE4ADBB, 0x3CAE7 },
	{ 0xE4ADBC, 0x3CAE8 },
	{ 0xE4ADBD, 0x3CAEB },
	{ 0xE4ADBE, 0x3CAE9 },
	{ 0xE4ADBF, 0x4CEEF },
	{ 0xE4AE80, 0x3CFF1 },
	{ 0xE4AE81, 0x3CFF0 },
	{ 0xE4AE82, 0x4CEEE },
	{ 0xE4AE83, 0x3CFEF },
	{ 0xE4AE84, 0x4CEED },
	{ 0xE4AE85, 0x4CEF0 },
	{ 0xE4AE86, 0x3D3EF },
	{ 0xE4AE87, 0x3D3EE },
	{ 0xE4AE88, 0x3D3ED },
	{ 0xE4AE89, 0x5DAAC },
	{ 0xE4AE8A, 0x3D3E9 },
	{ 0xE4AE8B, 0x4D5AD },
	{ 0xE4AE8C, 0x5DAAE },
	{ 0xE4AE8D, 0x7B6A8 },
	{ 0xE4AE8E, 0x4DAAE },
	{ 0xE4AE8F, 0x3D7B2 },
	{ 0xE4AE90, 0x3D7B5 },
	{ 0xE4AE91, 0x4DAAD },
	{ 0xE4AE92, 0x3D7B1 },
	{ 0xE4AE93, 0x4DEE7 },
	{ 0xE4AE94, 0x5EAEE },
	{ 0xE4AE95, 0x4DEE2 },
	{ 0xE4AE96, 0x3D9E8 },
	{ 0xE4AE97, 0x4DEE8 },
	{ 0xE4AE98, 0x3D9E9 },
	{ 0xE4AE99, 0x4DEE3 },
	{ 0xE4AE9A, 0x4DEE5 },
	{ 0xE4AE9B, 0x3D9EC },
	{ 0xE4AE9C, 0x4E2C1 },
	{ 0xE4AE9D, 0x4E2BF },
	{ 0xE4AE9E, 0x3DBEA },
	{ 0xE4AE9F, 0x4E2C6 },
	{ 0xE4AEA0, 0x4E2C0 },
	{ 0xE4AEA1, 0x4E2C4 },
	{ 0xE4AEA2, 0x4E2C5 },
	{ 0xE4AEA3, 0x4E5C1 },
	{ 0xE4AEA4, 0x4E5C0 },
	{ 0xE4AEA5, 0x3DDDD },
	{ 0xE4AEA6, 0x3DDDB },
	{ 0xE4AEA7, 0x4E5C7 },
	{ 0xE4AEA8, 0x5EEE6 },
	{ 0xE4AEA9, 0x5EEED },
	{ 0xE4AEAA, 0x3DDDC },
	{ 0xE4AEAB, 0x4E8A9 },
	{ 0xE4AEAC, 0x4E8AA },
	{ 0xE4AEAD, 0x4E8AB },
	{ 0xE4AEAE, 0x4E8AD },
	{ 0xE4AEAF, 0x3DFA3 },
	{ 0xE4AEB0, 0x5F2AD },
	{ 0xE4AEB1, 0x4E8A8 },
	{ 0xE4AEB2, 0x7DABE },
	{ 0xE4AEB3, 0x5F4F6 },
	{ 0xE4AEB4, 0x4E9EB },
	{ 0xE4AEB5, 0x4E9E9 },
	{ 0xE4AEB6, 0x3DFFA },
	{ 0xE4AEB7, 0x4EBB3 },
	{ 0xE4AEB8, 0x4EBB4 },
	{ 0xE4AEB9, 0x4EBB2 },
	{ 0xE4AEBA, 0x3E1AB },
	{ 0xE4AEBB, 0x7E0AE },
	{ 0xE4AEBC, 0x7E0AD },
	{ 0xE4AEBD, 0x3E1D7 },
	{ 0xE4AEBE, 0x4EDE8 },
	{ 0xE4AEBF, 0x3E2A7 },
	{ 0xE4AF80, 0x4EEBF },
	{ 0xE4AF81, 0x3E2B7 },
	{ 0xE4AF82, 0x4EED7 },
	{ 0xE4AF86, 0x3B9E9 },
	{ 0xE4AF87, 0x3C0AE },
	{ 0xE4AF88, 0x4C8E2 },
	{ 0xE4AF89, 0x3CAED },
	{ 0xE4AF8A, 0x3CFF5 },
	{ 0xE4AF8B, 0x4CEF5 },
	{ 0xE4AF8C, 0x4CEF3 },
	{ 0xE4AF8D, 0x4CEF6 },
	{ 0xE4AF8E, 0x3CFF8 },
	{ 0xE4AF8F, 0x3D3F2 },
	{ 0xE4AF90, 0x3D3F3 },
	{ 0xE4AF91, 0x4D5B0 },
	{ 0xE4AF92, 0x4D5B2 },
	{ 0xE4AF93, 0x4D5AF },
	{ 0xE4AF94, 0x4D5AE },
	{ 0xE4AF95, 0x3D7B9 },
	{ 0xE4AF96, 0x4DAB1 },
	{ 0xE4AF97, 0x4DAB5 },
	{ 0xE4AF98, 0x4DAB0 },
	{ 0xE4AF99, 0x3D7B8 },
	{ 0xE4AF9A, 0x4DAB3 },
	{ 0xE4AF9B, 0x5E6D1 },
	{ 0xE4AF9C, 0x4DEEE },
	{ 0xE4AF9D, 0x3DBF0 },
	{ 0xE4AF9E, 0x4E2C8 },
	{ 0xE4AF9F, 0x4E2C7 },
	{ 0xE4AFA0, 0x4E5C9 },
	{ 0xE4AFA1, 0x3DDDF },
	{ 0xE4AFA2, 0x4E8B0 },
	{ 0xE4AFA3, 0x4E9EE },
	{ 0xE4AFA4, 0x4EBB5 },
	{ 0xE4AFA5, 0x4ECBE },
	{ 0xE4AFA6, 0x4EDB3 },
	{ 0xE4AFA7, 0x3C0B0 },
	{ 0xE4AFA8, 0x4C2A2 },
	{ 0xE4AFAA, 0x4E2CA },
	{ 0xE4AFAB, 0x5F4FA },
	{ 0xE4AFAC, 0x7E4F5 },
	{ 0xE4AFAD, 0x3C0B1 },
	{ 0xE4AFAE, 0x5BDD2 },
	{ 0xE4AFAF, 0x6E4DE },
	{ 0xE4AFB0, 0x4C8EA },
	{ 0xE4AFB1, 0x4C8E9 },
	{ 0xE4AFB2, 0x4C8E7 },
	{ 0xE4AFB3, 0x3CAF4 },
	{ 0xE4AFB4, 0x5CBD9 },
	{ 0xE4AFB5, 0x4CEFB },
	{ 0xE4AFB6, 0x3CFFA },
	{ 0xE4AFB7, 0x4D5B5 },
	{ 0xE4AFB8, 0x4D5B6 },
	{ 0xE4AFB9, 0x4DAB8 },
	{ 0xE4AFBA, 0x3D7BD },
	{ 0xE4AFBC, 0x4DABB },
	{ 0xE4AFBD, 0x4DEF0 },
	{ 0xE4AFBE, 0x4DEF3 },
	{ 0xE4AFBF, 0x3D9EE },
	{ 0xE4B080, 0x4DEF4 },
	{ 0xE4B081, 0x4DEF6 },
	{ 0xE4B082, 0x4DEF5 },
	{ 0xE4B083, 0x4DEF7 },
	{ 0xE4B084, 0x4E2CE },
	{ 0xE4B085, 0x3DBF2 },
	{ 0xE4B086, 0x4E2CC },
	{ 0xE4B088, 0x4E5CD },
	{ 0xE4B089, 0x4E5CF },
	{ 0xE4B08A, 0x4E5CE },
	{ 0xE4B08B, 0x7D1F9 },
	{ 0xE4B08C, 0x5F2BF },
	{ 0xE4B08D, 0x3DFA6 },
	{ 0xE4B08E, 0x4E9F2 },
	{ 0xE4B08F, 0x4ECC3 },
	{ 0xE4B090, 0x4ECC1 },
	{ 0xE4B091, 0x3E1AD },
	{ 0xE4B092, 0x5F8D2 },
	{ 0xE4B093, 0x4EDB5 },
	{ 0xE4B094, 0x7E1EA },
	{ 0xE4B095, 0x4EDE9 },
	{ 0xE4B096, 0x4EEC9 },
	{ 0xE4B097, 0x7D1FD },
	{ 0xE4B098, 0x5F2C1 },
	{ 0xE4B099, 0x3CAF7 },
	{ 0xE4B09A, 0x3CAF6 },
	{ 0xE4B09B, 0x3CDBE },
	{ 0xE4B09C, 0x3D3F6 },
	{ 0xE4B09D, 0x7DACB },
	{ 0xE4B09E, 0x3E1D8 },
	{ 0xE4B09F, 0x3CAF9 },
	{ 0xE4B0A0, 0x4CFA4 },
	{ 0xE4B0A1, 0x4CFA5 },
	{ 0xE4B0A2, 0x4D5BF },
	{ 0xE4B0A3, 0x3D3F7 },
	{ 0xE4B0A4, 0x4DEFE },
	{ 0xE4B0A5, 0x3D9F0 },
	{ 0xE4B0A6, 0x4DEFD },
	{ 0xE4B0A7, 0x4DEFC },
	{ 0xE4B0A8, 0x3DBF3 },
	{ 0xE4B0A9, 0x5E6E8 },
	{ 0xE4B0AA, 0x3DDE5 },
	{ 0xE4B0AB, 0x4E9F7 },
	{ 0xE4B0AC, 0x4E9F6 },
	{ 0xE4B0AD, 0x7DACF },
	{ 0xE4B0AF, 0x4ECC8 },
	{ 0xE4B0B0, 0x4ECC9 },
	{ 0xE4B0B1, 0x4EED8 },
	{ 0xE4B0B2, 0x5BDD4 },
	{ 0xE4B0B4, 0x4C8ED },
	{ 0xE4B0B5, 0x5CBE4 },
	{ 0xE4B0B7, 0x4CFA8 },
	{ 0xE4B0B8, 0x4CFB4 },
	{ 0xE4B0B9, 0x3D0A1 },
	{ 0xE4B0BA, 0x7ABEA },
	{ 0xE4B0BB, 0x4CFB9 },
	{ 0xE4B0BC, 0x4CFB2 },
	{ 0xE4B0BD, 0x4CFAB },
	{ 0xE4B0BE, 0x4CFA9 },
	{ 0xE4B0BF, 0x3D4A7 },
	{ 0xE4B180, 0x4D5C4 },
	{ 0xE4B181, 0x4D5C2 },
	{ 0xE4B182, 0x4D5C8 },
	{ 0xE4B183, 0x3D3FE },
	{ 0xE4B184, 0x3D4A8 },
	{ 0xE4B185, 0x4D5C1 },
	{ 0xE4B186, 0x3D4A6 },
	{ 0xE4B187, 0x3D4A4 },
	{ 0xE4B188, 0x3D4A2 },
	{ 0xE4B189, 0x3D3FB },
	{ 0xE4B18A, 0x4DAC0 },
	{ 0xE4B18B, 0x3D7C1 },
	{ 0xE4B18C, 0x4DFA1 },
	{ 0xE4B18D, 0x7BEC9 },
	{ 0xE4B18E, 0x4DAC2 },
	{ 0xE4B18F, 0x3D9F2 },
	{ 0xE4B190, 0x4DFA3 },
	{ 0xE4B191, 0x5E6EE },
	{ 0xE4B192, 0x4DFA7 },
	{ 0xE4B193, 0x4DFA5 },
	{ 0xE4B194, 0x3D9F8 },
	{ 0xE4B195, 0x4DFA4 },
	{ 0xE4B196, 0x3D9F7 },
	{ 0xE4B197, 0x4DFA9 },
	{ 0xE4B198, 0x4DFAB },
	{ 0xE4B199, 0x4E2DD },
	{ 0xE4B19A, 0x5EBB5 },
	{ 0xE4B19B, 0x4E2E7 },
	{ 0xE4B19C, 0x4E2D7 },
	{ 0xE4B19D, 0x4E2E1 },
	{ 0xE4B19E, 0x4E2D9 },
	{ 0xE4B19F, 0x4E2D4 },
	{ 0xE4B1A0, 0x3DBF6 },
	{ 0xE4B1A1, 0x5EBB1 },
	{ 0xE4B1A2, 0x4E2E2 },
	{ 0xE4B1A3, 0x5EBAB },
	{ 0xE4B1A4, 0x4E2E0 },
	{ 0xE4B1A5, 0x4E2E4 },
	{ 0xE4B1A6, 0x3DBF8 },
	{ 0xE4B1A7, 0x3DBFB },
	{ 0xE4B1A8, 0x3DBFC },
	{ 0xE4B1A9, 0xFE4F2 },
	{ 0xE4B1AB, 0x3DDF7 },
	{ 0xE4B1AC, 0x4E5D5 },
	{ 0xE4B1AD, 0x7D2B1 },
	{ 0xE4B1AE, 0x4E5DB },
	{ 0xE4B1AF, 0x3DDEC },
	{ 0xE4B1B0, 0x7D2B3 },
	{ 0xE4B1B1, 0x4E5D3 },
	{ 0xE4B1B2, 0x3DDEB },
	{ 0xE4B1B3, 0x3DDED },
	{ 0xE4B1B5, 0x4E8BD },
	{ 0xE4B1B6, 0x3DFAD },
	{ 0xE4B1B7, 0x3DFB0 },
	{ 0xE4B1B8, 0x4E8BC },
	{ 0xE4B1B9, 0x3DFAE },
	{ 0xE4B1BA, 0x3DFAB },
	{ 0xE4B1BB, 0x4E8BA },
	{ 0xE4B1BC, 0x3DFA9 },
	{ 0xE4B1BD, 0x3DFAF },
	{ 0xE4B1BE, 0x4E9FD },
	{ 0xE4B1BF, 0x3DFFD },
	{ 0xE4B280, 0x4EAA1 },
	{ 0xE4B281, 0x4E9FC },
	{ 0xE4B282, 0x3DFFC },
	{ 0xE4B283, 0x4E9FE },
	{ 0xE4B284, 0x3E0A4 },
	{ 0xE4B285, 0x4E9FB },
	{ 0xE4B286, 0x3E0A1 },
	{ 0xE4B288, 0xFEABF },
	{ 0xE4B289, 0x4EBBC },
	{ 0xE4B28A, 0x4EBBD },
	{ 0xE4B28B, 0x4EBC0 },
	{ 0xE4B28C, 0x4EBBB },
	{ 0xE4B28D, 0x7DEA3 },
	{ 0xE4B28E, 0x3E0E7 },
	{ 0xE4B28F, 0x3E0E4 },
	{ 0xE4B290, 0x5F8DB },
	{ 0xE4B291, 0x5F8D6 },
	{ 0xE4B292, 0x3E1B0 },
	{ 0xE4B293, 0x4ECCD },
	{ 0xE4B294, 0x4ECCE },
	{ 0xE4B295, 0x5F7A4 },
	{ 0xE4B296, 0x3E1DA },
	{ 0xE4B297, 0x4EDB9 },
	{ 0xE4B299, 0x3E1B1 },
	{ 0xE4B29A, 0x4EEAC },
	{ 0xE4B29B, 0x4EEAD },
	{ 0xE4B29C, 0x4EEDB },
	{ 0xE4B2A5, 0x3C5E5 },
	{ 0xE4B2A6, 0x3CAFA },
	{ 0xE4B2A7, 0x3CAFB },
	{ 0xE4B2A8, 0x3CAFC },
	{ 0xE4B2A9, 0x3CAFE },
	{ 0xE4B2AA, 0x5CBEB },
	{ 0xE4B2AB, 0x3CAFD },
	{ 0xE4B2AC, 0x5D3B8 },
	{ 0xE4B2AD, 0x4CFBF },
	{ 0xE4B2AE, 0x3D0A3 },
	{ 0xE4B2AF, 0x4CFC4 },
	{ 0xE4B2B0, 0x4CFBB },
	{ 0xE4B2B1, 0x7ABED },
	{ 0xE4B2B2, 0x4CFC0 },
	{ 0xE4B2B3, 0x3D0A8 },
	{ 0xE4B2B4, 0x3D0A9 },
	{ 0xE4B2B5, 0x3D0A6 },
	{ 0xE4B2B7, 0x3CCE3 },
	{ 0xE4B2B8, 0x4CFC1 },
	{ 0xE4B2B9, 0x4D5CE },
	{ 0xE4B2BA, 0x3D4AF },
	{ 0xE4B2BB, 0x4D5CD },
	{ 0xE4B2BC, 0x3D4B0 },
	{ 0xE4B2BD, 0x4D5CF },
	{ 0xE4B2BE, 0x3D4AB },
	{ 0xE4B2BF, 0x4D5D4 },
	{ 0xE4B380, 0x7B6CA },
	{ 0xE4B381, 0x4D5CA },
	{ 0xE4B382, 0x3D4AE },
	{ 0xE4B383, 0x4D5D7 },
	{ 0xE4B384, 0x3D7CB },
	{ 0xE4B385, 0x4D5CB },
	{ 0xE4B386, 0x3D4B1 },
	{ 0xE4B387, 0x4D5D5 },
	{ 0xE4B388, 0x3D4B4 },
	{ 0xE4B389, 0x4D5D0 },
	{ 0xE4B38A, 0x7B6D1 },
	{ 0xE4B38B, 0x3D6B3 },
	{ 0xE4B38C, 0x3D7CC },
	{ 0xE4B38D, 0x4DAD1 },
	{ 0xE4B38E, 0x3D7C7 },
	{ 0xE4B38F, 0x3D7C9 },
	{ 0xE4B390, 0x3D7C6 },
	{ 0xE4B391, 0x4DAD2 },
	{ 0xE4B392, 0x3D7CE },
	{ 0xE4B393, 0x4DAD0 },
	{ 0xE4B394, 0x4DFAF },
	{ 0xE4B395, 0x4DFB5 },
	{ 0xE4B396, 0x4DFAC },
	{ 0xE4B397, 0x3DAA1 },
	{ 0xE4B398, 0x3D9FC },
	{ 0xE4B399, 0x4DFB2 },
	{ 0xE4B39A, 0x4DFB1 },
	{ 0xE4B39B, 0x5E7A6 },
	{ 0xE4B39C, 0x4DFB8 },
	{ 0xE4B39D, 0x4E2EA },
	{ 0xE4B39E, 0x3DCA1 },
	{ 0xE4B39F, 0x4E2EC },
	{ 0xE4B3A0, 0x4E5E1 },
	{ 0xE4B3A1, 0x3DCA8 },
	{ 0xE4B3A2, 0x4E2EF },
	{ 0xE4B3A3, 0x5EBBC },
	{ 0xE4B3A4, 0x4DFB6 },
	{ 0xE4B3A5, 0xFE4F5 },
	{ 0xE4B3A6, 0x3DDF8 },
	{ 0xE4B3A7, 0x4E5EC },
	{ 0xE4B3A8, 0x3DDFD },
	{ 0xE4B3A9, 0x3DDFB },
	{ 0xE4B3AA, 0x4E5EA },
	{ 0xE4B3AB, 0x4E5E4 },
	{ 0xE4B3AC, 0x3DDFC },
	{ 0xE4B3AD, 0x7D2C2 },
	{ 0xE4B3AE, 0x4E5E2 },
	{ 0xE4B3AF, 0x4E5EB },
	{ 0xE4B3B0, 0x3DDFE },
	{ 0xE4B3B1, 0x3DFB4 },
	{ 0xE4B3B2, 0x4E8C0 },
	{ 0xE4B3B3, 0x4E8C2 },
	{ 0xE4B3B4, 0x4E8C1 },
	{ 0xE4B3B5, 0x5F2E3 },
	{ 0xE4B3B6, 0x3DFB3 },
	{ 0xE4B3B7, 0x4EAA7 },
	{ 0xE4B3B8, 0x4EAAC },
	{ 0xE4B3BA, 0x3E0A8 },
	{ 0xE4B3BB, 0x4EAA6 },
	{ 0xE4B3BC, 0x3E0A6 },
	{ 0xE4B3BD, 0x3E0A7 },
	{ 0xE4B3BE, 0x4EBC5 },
	{ 0xE4B3BF, 0x3E0EB },
	{ 0xE4B480, 0x5F7AC },
	{ 0xE4B481, 0x4EBC4 },
	{ 0xE4B482, 0x5F7B4 },
	{ 0xE4B483, 0x4EBC7 },
	{ 0xE4B484, 0x3E0EA },
	{ 0xE4B485, 0x3E0E9 },
	{ 0xE4B486, 0x4EBC8 },
	{ 0xE4B487, 0x4ECD0 },
	{ 0xE4B488, 0x4ECD2 },
	{ 0xE4B489, 0x4ECD1 },
	{ 0xE4B48A, 0x3E1B6 },
	{ 0xE4B48B, 0x4ECD4 },
	{ 0xE4B48C, 0x4EDBD },
	{ 0xE4B48D, 0x3E1DC },
	{ 0xE4B48E, 0x7E3B7 },
	{ 0xE4B48F, 0x3E2AA },
	{ 0xE4B490, 0x3E2BE },
	{ 0xE4B491, 0x4EED9 },
	{ 0xE4B492, 0x3E2C3 },
	{ 0xE4B49A, 0x4CFC7 },
	{ 0xE4B49B, 0x4DFB9 },
	{ 0xE4B49C, 0x7D7A9 },
	{ 0xE4B49D, 0x4EBCD },
	{ 0xE4B49E, 0x5F9F3 },
	{ 0xE4B49F, 0x5CBED },
	{ 0xE4B4A0, 0x4CFC9 },
	{ 0xE4B4A1, 0x4CFCA },
	{ 0xE4B4A2, 0x3D0AD },
	{ 0xE4B4A3, 0x3D4B8 },
	{ 0xE4B4A4, 0x4D5D8 },
	{ 0xE4B4A5, 0x7B6DC },
	{ 0xE4B4A6, 0x3DAA3 },
	{ 0xE4B4A7, 0x4E2F2 },
	{ 0xE4B4A9, 0x3DFB9 },
	{ 0xE4B4AA, 0x3E1B7 },
	{ 0xE4B4AB, 0x3E1B8 },
	{ 0xE4B4AC, 0x4C8F3 },
	{ 0xE4B4AD, 0x4C8F4 },
	{ 0xE4B4AE, 0x3CBA1 },
	{ 0xE4B4AF, 0x4CFCD },
	{ 0xE4B4B0, 0x4CFCB },
	{ 0xE4B4B1, 0x4D5D9 },
	{ 0xE4B4B2, 0x4D5DC },
	{ 0xE4B4B3, 0x4D5DA },
	{ 0xE4B4B4, 0x4D5DD },
	{ 0xE4B4B5, 0x3D7CF },
	{ 0xE4B4B6, 0x4DFBC },
	{ 0xE4B4B7, 0x4DFBB },
	{ 0xE4B4B8, 0x3DAA7 },
	{ 0xE4B4B9, 0x4E2F9 },
	{ 0xE4B4BA, 0x4E2F6 },
	{ 0xE4B4BB, 0x4E2FD },
	{ 0xE4B4BC, 0x4E2F7 },
	{ 0xE4B4BD, 0x4E2FC },
	{ 0xE4B4BE, 0x4E8C9 },
	{ 0xE4B4BF, 0x4E8C8 },
	{ 0xE4B580, 0x4E8CA },
	{ 0xE4B581, 0x5F5CD },
	{ 0xE4B582, 0x5F5C8 },
	{ 0xE4B583, 0x4EBCE },
	{ 0xE4B584, 0x3E1B9 },
	{ 0xE4B585, 0x7DAFD },
	{ 0xE4B586, 0x4EDC1 },
	{ 0xE4B587, 0x7ACB1 },
	{ 0xE4B588, 0x4E5F1 },
	{ 0xE4B589, 0x4E5F2 },
	{ 0xE4B58A, 0x7B6E5 },
	{ 0xE4B58B, 0x4DFBD },
	{ 0xE4B58C, 0x4E3A1 },
	{ 0xE4B58D, 0x4E5F6 },
	{ 0xE4B58E, 0x4E8CB },
	{ 0xE4B58F, 0x4EBD2 },
	{ 0xE4B590, 0x4ECDA },
	{ 0xE4B591, 0x7ACB3 },
	{ 0xE4B592, 0x4D5DE },
	{ 0xE4B593, 0x7B6E7 },
	{ 0xE4B594, 0x5EFD2 },
	{ 0xE4B595, 0x4E5F9 },
	{ 0xE4B596, 0x5EFD4 },
	{ 0xE4B597, 0x4E8CC },
	{ 0xE4B598, 0x4E8CE },
	{ 0xE4B599, 0x4E8CD },
	{ 0xE4B59A, 0x4EAB1 },
	{ 0xE4B59B, 0x4EBD5 },
	{ 0xE4B59C, 0x4EDC2 },
	{ 0xE4B59D, 0x4C2AC },
	{ 0xE4B59E, 0x3CBA3 },
	{ 0xE4B59F, 0x4CFD2 },
	{ 0xE4B5A0, 0x4CFD3 },
	{ 0xE4B5A1, 0x4D5DF },
	{ 0xE4B5A2, 0x4DADF },
	{ 0xE4B5A3, 0x5E1A3 },
	{ 0xE4B5A4, 0x5E7C0 },
	{ 0xE4B5A5, 0x5E7BD },
	{ 0xE4B5A6, 0x4DFBF },
	{ 0xE4B5A7, 0x5E7C1 },
	{ 0xE4B5A8, 0x4E3A3 },
	{ 0xE4B5A9, 0x3DCAB },
	{ 0xE4B5AA, 0x4E5FC },
	{ 0xE4B5AB, 0x4E6A1 },
	{ 0xE4B5AC, 0x4E5FD },
	{ 0xE4B5AD, 0x5EFD8 },
	{ 0xE4B5AE, 0x4E8D2 },
	{ 0xE4B5AF, 0x3DFBB },
	{ 0xE4B5B0, 0x4EBD6 },
	{ 0xE4B5B1, 0x4ECDB },
	{ 0xE4B5B2, 0x4EDC4 },
	{ 0xE4B5B3, 0x3E1DE },
	{ 0xE4B5B4, 0x4EDC3 },
	{ 0xE4B5B5, 0x4EDEF },
	{ 0xE4B5B6, 0x4DFC0 },
	{ 0xE4B5B7, 0x3DCAC },
	{ 0xE4B5B8, 0x4EAB7 },
	{ 0xE4B5B9, 0x3E1BA },
	{ 0xE4B5BA, 0x4D5E1 },
	{ 0xE4B5BB, 0x4ECE1 },
	{ 0xE4B5BC, 0x4ECE2 },
	{ 0xE4B5BD, 0x4DFC3 },
	{ 0xE4B5BE, 0x4DFC2 },
	{ 0xE4B5BF, 0x4DFC4 },
	{ 0xE4B680, 0x4E3A6 },
	{ 0xE4B681, 0x4E8D9 },
	{ 0xE4B682, 0x4D5E2 },
	{ 0xE4B683, 0x4DAE3 },
	{ 0xE4B684, 0x4DFC5 },
	{ 0xE4B685, 0x4E3A7 },
	{ 0xE4B686, 0x4E8DA },
	{ 0xE4B687, 0x3E0AA },
	{ 0xE4B688, 0x4EBD8 },
	{ 0xE4B689, 0x4EBDB },
	{ 0xE4B68A, 0x3DAAC },
	{ 0xE4B68B, 0x4DFC6 },
	{ 0xE4B68C, 0x3DEA3 },
	{ 0xE4B68D, 0x7D2E7 },
	{ 0xE4B68E, 0x5EFE1 },
	{ 0xE4B68F, 0x4E8DC },
	{ 0xE4B690, 0x4EEB1 },
	{ 0xE4B691, 0x5FBFA },
	{ 0xE4B692, 0x4DAE6 },
	{ 0xE4B693, 0x5E1AD },
	{ 0xE4B694, 0x4DFC8 },
	{ 0xE4B695, 0x4E3A9 },
	{ 0xE4B696, 0x4E3AB },
	{ 0xE4B697, 0x4E6A7 },
	{ 0xE4B698, 0x4E6A5 },
	{ 0xE4B699, 0x4E6A6 },
	{ 0xE4B69A, 0x3DFBD },
	{ 0xE4B69B, 0x4E8E1 },
	{ 0xE4B69C, 0x4EABD },
	{ 0xE4B69D, 0x4EABC },
	{ 0xE4B69E, 0x3E0EE },
	{ 0xE4B69F, 0x5F7CD },
	{ 0xE4B6A0, 0x4ECE9 },
	{ 0xE4B6A1, 0x4ECE6 },
	{ 0xE4B6A2, 0x4ECEA },
	{ 0xE4B6A3, 0x4EDCC },
	{ 0xE4B6A4, 0x4EDCB },
	{ 0xE4B6A5, 0x4EDF0 },
	{ 0xE4B6A6, 0x3E1F6 },
	{ 0xE4B6A7, 0x3E2AB },
	{ 0xE4B6A8, 0x3E2B2 },
	{ 0xE4B6A9, 0x4EECB },
	{ 0xE4B6AA, 0x4EECC },
	{ 0xE4B6AB, 0x4EEDA },
	{ 0xE4B6AC, 0x5F5E1 },
	{ 0xE4B6AF, 0x5EBE9 },
	{ 0xE4B6B0, 0x5ECC4 },
	{ 0xE4B6B1, 0x4E8E2 },
	{ 0xE4B6B3, 0x4E8E3 },
	{ 0xE4B6B4, 0x4EDD1 },
	{ 0xE4B6B5, 0x3E2AC },
	{ 0xE4B880, 0x1C4A1 },
	{ 0xE4B881, 0x1C4A3 },
	{ 0xE4B882, 0x4A1A6 },
	{ 0xE4B883, 0x1C4A4 },
	{ 0xE4B884, 0x3A1A6 },
	{ 0xE4B885, 0x3A1A5 },
	{ 0xE4B887, 0x2A1A6 },
	{ 0xE4B888, 0x1C4B7 },
	{ 0xE4B889, 0x1C4B5 },
	{ 0xE4B88A, 0x1C4B8 },
	{ 0xE4B88B, 0x1C4B6 },
	{ 0xE4B88C, 0x2A1A7 },
	{ 0xE4B88D, 0x1C4E2 },
	{ 0xE4B88E, 0x2A1AF },
	{ 0xE4B88F, 0x2A1AD },
	{ 0xE4B890, 0x1C4E1 },
	{ 0xE4B891, 0x1C4E0 },
	{ 0xE4B892, 0x4A1B9 },
	{ 0xE4B894, 0x1C5E2 },
	{ 0xE4B895, 0x1C5E1 },
	{ 0xE4B896, 0x1C5E0 },
	{ 0xE4B897, 0x4A1D5 },
	{ 0xE4B898, 0x1C5E3 },
	{ 0xE4B899, 0x1C5DF },
	{ 0xE4B89E, 0x1C7A2 },
	{ 0xE4B89F, 0x1C7A3 },
	{ 0xE4B8A0, 0x3A2E2 },
	{ 0xE4B8A1, 0x3A2E1 },
	{ 0xE4B8A2, 0x3A2E3 },
	{ 0xE4B8A3, 0x4A3B5 },
	{ 0xE4B8A4, 0x3A4BF },
	{ 0xE4B8A6, 0x1CBE4 },
	{ 0xE4B8A8, 0x3A1A1 },
	{ 0xE4B8A9, 0x4A1A7 },
	{ 0xE4B8AA, 0x3A1AC },
	{ 0xE4B8AB, 0x1C4B9 },
	{ 0xE4B8AD, 0x1C4E3 },
	{ 0xE4B8AE, 0x2A1B0 },
	{ 0xE4B8AF, 0x4A1BA },
	{ 0xE4B8B0, 0x1C4E4 },
	{ 0xE4B8B1, 0x2A1C3 },
	{ 0xE4B8B2, 0x1C8EB },
	{ 0xE4B8B3, 0x2A5B1 },
	{ 0xE4B8B5, 0x4ABDE },
	{ 0xE4B8B6, 0x3A1A2 },
	{ 0xE4B8B8, 0x1C4BA },
	{ 0xE4B8B9, 0x1C4E5 },
	{ 0xE4B8BB, 0x1C5E4 },
	{ 0xE4B8BC, 0x2A1C4 },
	{ 0xE4B8BD, 0x3A7C0 },
	{ 0xE4B8BF, 0x3A1A3 },
	{ 0xE4B980, 0x4A1A2 },
	{ 0xE4B981, 0x4A1A3 },
	{ 0xE4B982, 0x2A1A1 },
	{ 0xE4B983, 0x1C4A5 },
	{ 0xE4B985, 0x1C4BC },
	{ 0xE4B986, 0x3A1B0 },
	{ 0xE4B987, 0x2A1A8 },
	{ 0xE4B988, 0x1C4BD },
	{ 0xE4B989, 0x3A1AE },
	{ 0xE4B98B, 0x1C4E6 },
	{ 0xE4B98D, 0x1C5E5 },
	{ 0xE4B98E, 0x1C5E7 },
	{ 0xE4B98F, 0x1C5E6 },
	{ 0xE4B991, 0x4A2A7 },
	{ 0xE4B992, 0x1C7A4 },
	{ 0xE4B993, 0x1C7A5 },
	{ 0xE4B994, 0x3A3C5 },
	{ 0xE4B996, 0x1CBE5 },
	{ 0xE4B997, 0x3ABA2 },
	{ 0xE4B998, 0x1D3FD },
	{ 0xE4B999, 0x1C4A2 },
	{ 0xE4B99A, 0x4A1A4 },
	{ 0xE4B99C, 0x2A1A2 },
	{ 0xE4B99D, 0x1C4A6 },
	{ 0xE4B99E, 0x1C4BF },
	{ 0xE4B99F, 0x1C4BE },
	{ 0xE4B9A2, 0x3A1C6 },
	{ 0xE4B9A3, 0x3A1C5 },
	{ 0xE4B9A8, 0x3A2E4 },
	{ 0xE4B9A9, 0x1C7A6 },
	{ 0xE4B9AA, 0x4A2A8 },
	{ 0xE4B9B1, 0x3A4C0 },
	{ 0xE4B9B3, 0x1CBE6 },
	{ 0xE4B9B4, 0x4A5B1 },
	{ 0xE4B9B5, 0x4A5B0 },
	{ 0xE4B9B9, 0x3ABA3 },
	{ 0xE4B9BE, 0x1D8F1 },
	{ 0xE4B9BF, 0x2B3CE },
	{ 0xE4BA80, 0x3B9EC },
	{ 0xE4BA81, 0x3B9EE },
	{ 0xE4BA82, 0x1E3AA },
	{ 0xE4BA83, 0x2C1D6 },
	{ 0xE4BA84, 0x2C1D7 },
	{ 0xE4BA85, 0x3A1A4 },
	{ 0xE4BA86, 0x1C4A7 },
	{ 0xE4BA87, 0x3A1AD },
	{ 0xE4BA88, 0x1C4E8 },
	{ 0xE4BA89, 0x3A2E5 },
	{ 0xE4BA8B, 0x1CBE7 },
	{ 0xE4BA8C, 0x1C4A8 },
	{ 0xE4BA8D, 0x2A1A9 },
	{ 0xE4BA8E, 0x1C4C0 },
	{ 0xE4BA8F, 0x3A1B1 },
	{ 0xE4BA91, 0x1C4E9 },
	{ 0xE4BA92, 0x1C4EB },
	{ 0xE4BA93, 0x2A1B1 },
	{ 0xE4BA94, 0x1C4EC },
	{ 0xE4BA95, 0x1C4EA },
	{ 0xE4BA96, 0x4A1BB },
	{ 0xE4BA97, 0x3A1EC },
	{ 0xE4BA98, 0x3A2E6 },
	{ 0xE4BA99, 0x1C7A7 },
	{ 0xE4BA9B, 0x1CBE8 },
	{ 0xE4BA9C, 0x3A4C2 },
	{ 0xE4BA9D, 0x3A7C2 },
	{ 0xE4BA9E, 0x1CBE9 },
	{ 0xE4BA9F, 0x1CFE7 },
	{ 0xE4BAA0, 0x1A7A8 },
	{ 0xE4BAA1, 0x1C4C1 },
	{ 0xE4BAA2, 0x1C4ED },
	{ 0xE4BAA3, 0x3A1C7 },
	{ 0xE4BAA4, 0x1C7A8 },
	{ 0xE4BAA5, 0x1C7AA },
	{ 0xE4BAA6, 0x1C7A9 },
	{ 0xE4BAA8, 0x1C8EC },
	{ 0xE4BAAB, 0x1CBEA },
	{ 0xE4BAAC, 0x1CBEB },
	{ 0xE4BAAD, 0x1CFE8 },
	{ 0xE4BAAE, 0x1CFE9 },
	{ 0xE4BAAF, 0x3ABA6 },
	{ 0xE4BAB0, 0x3ABA5 },
	{ 0xE4BAB1, 0x3ABA7 },
	{ 0xE4BAB2, 0x3ABA4 },
	{ 0xE4BAB3, 0x1D3FE },
	{ 0xE4BAB4, 0x4B6AE },
	{ 0xE4BAB6, 0x2C1D8 },
	{ 0xE4BAB7, 0x3C0B3 },
	{ 0xE4BAB9, 0x2EDC4 },
	{ 0xE4BABA, 0x1C4A9 },
	{ 0xE4BABC, 0x3A1B2 },
	{ 0xE4BABE, 0x3A1B3 },
	{ 0xE4BB80, 0x1C4EF },
	{ 0xE4BB81, 0x1C4EE },
	{ 0xE4BB82, 0x2A1B2 },
	{ 0xE4BB83, 0x1C4F0 },
	{ 0xE4BB84, 0x1C4F6 },
	{ 0xE4BB85, 0x3A1C9 },
	{ 0xE4BB86, 0x1C4F1 },
	{ 0xE4BB87, 0x1C4F2 },
	{ 0xE4BB88, 0x2A1B4 },
	{ 0xE4BB89, 0x2A1B3 },
	{ 0xE4BB8A, 0x1C4F4 },
	{ 0xE4BB8B, 0x1C4F5 },
	{ 0xE4BB8C, 0x3A1CC },
	{ 0xE4BB8D, 0x1C4F3 },
	{ 0xE4BB8E, 0x3A1CB },
	{ 0xE4BB8F, 0x3A1CA },
	{ 0xE4BB90, 0x4A1BC },
	{ 0xE4BB94, 0x1C5EA },
	{ 0xE4BB95, 0x1C5EB },
	{ 0xE4BB96, 0x1C5EC },
	{ 0xE4BB97, 0x1C5ED },
	{ 0xE4BB98, 0x1C5E9 },
	{ 0xE4BB99, 0x1C5F0 },
	{ 0xE4BB9A, 0x2A1CA },
	{ 0xE4BB9B, 0x4A1DB },
	{ 0xE4BB9C, 0x2A1C6 },
	{ 0xE4BB9D, 0x2A1C9 },
	{ 0xE4BB9E, 0x1C5F1 },
	{ 0xE4BB9F, 0x1C6A3 },
	{ 0xE4BBA0, 0x3A1ED },
	{ 0xE4BBA1, 0x2A1C8 },
	{ 0xE4BBA2, 0x4A1DA },
	{ 0xE4BBA3, 0x1C5EE },
	{ 0xE4BBA4, 0x1C5EF },
	{ 0xE4BBA5, 0x1C5E8 },
	{ 0xE4BBA6, 0x3A1F2 },
	{ 0xE4BBA7, 0x3A1F0 },
	{ 0xE4BBA8, 0x2A1C5 },
	{ 0xE4BBA9, 0x2A1C7 },
	{ 0xE4BBAE, 0x3A2EF },
	{ 0xE4BBAF, 0x3A2E8 },
	{ 0xE4BBB0, 0x1C7B7 },
	{ 0xE4BBB1, 0x2A1EF },
	{ 0xE4BBB2, 0x1C7B4 },
	{ 0xE4BBB3, 0x1C7B8 },
	{ 0xE4BBB4, 0x2A1F9 },
	{ 0xE4BBB5, 0x2A1ED },
	{ 0xE4BBB6, 0x1C7B5 },
	{ 0xE4BBB7, 0x2A1F1 },
	{ 0xE4BBB8, 0x3A2EB },
	{ 0xE4BBB9, 0x3A2E7 },
	{ 0xE4BBBA, 0x3A2F6 },
	{ 0xE4BBBB, 0x1C7B6 },
	{ 0xE4BBBC, 0x3A2EE },
	{ 0xE4BBBD, 0x1C7B9 },
	{ 0xE4BBBE, 0x4A2AD },
	{ 0xE4BBBF, 0x1C7AB },
	{ 0xE4BC80, 0x2A1F0 },
	{ 0xE4BC81, 0x1C7BA },
	{ 0xE4BC82, 0x2A1F4 },
	{ 0xE4BC83, 0x3A2ED },
	{ 0xE4BC84, 0x2A1F8 },
	{ 0xE4BC85, 0x2A1F5 },
	{ 0xE4BC86, 0x3A2EC },
	{ 0xE4BC87, 0x3A2F4 },
	{ 0xE4BC88, 0x2A1F2 },
	{ 0xE4BC89, 0x1C7AC },
	{ 0xE4BC8A, 0x1C7AE },
	{ 0xE4BC8B, 0x1C7BB },
	{ 0xE4BC8C, 0x4A2AA },
	{ 0xE4BC8D, 0x1C7B0 },
	{ 0xE4BC8E, 0x2A1EA },
	{ 0xE4BC8F, 0x1C7B3 },
	{ 0xE4BC90, 0x1C7B1 },
	{ 0xE4BC91, 0x1C7B2 },
	{ 0xE4BC92, 0x2A1FA },
	{ 0xE4BC93, 0x2A1F7 },
	{ 0xE4BC94, 0x2A1EE },
	{ 0xE4BC95, 0x1C7AF },
	{ 0xE4BC96, 0x3A2F0 },
	{ 0xE4BC97, 0x3A2F7 },
	{ 0xE4BC98, 0x2A1EB },
	{ 0xE4BC99, 0x1C7AD },
	{ 0xE4BC9A, 0x3A2F5 },
	{ 0xE4BC9B, 0x4A2AE },
	{ 0xE4BC9C, 0x3A2F3 },
	{ 0xE4BC9D, 0x2A1F3 },
	{ 0xE4BCA2, 0x2A1F6 },
	{ 0xE4BCA8, 0x3A2F2 },
	{ 0xE4BCA9, 0xFA1F1 },
	{ 0xE4BCAC, 0x2A1EC },
	{ 0xE4BCAD, 0x2A3A8 },
	{ 0xE4BCAE, 0x4A3B9 },
	{ 0xE4BCAF, 0x1C9A4 },
	{ 0xE4BCB0, 0x1C8F5 },
	{ 0xE4BCB1, 0x3A4D0 },
	{ 0xE4BCB2, 0x3A4C8 },
	{ 0xE4BCB3, 0x2A3A9 },
	{ 0xE4BCB4, 0x1C8F2 },
	{ 0xE4BCB5, 0x3A4CF },
	{ 0xE4BCB6, 0x1C9A6 },
	{ 0xE4BCB7, 0x3A4C6 },
	{ 0xE4BCB8, 0x1C8FA },
	{ 0xE4BCB9, 0x3A4C5 },
	{ 0xE4BCBA, 0x1C8F9 },
	{ 0xE4BCBB, 0x2A2FB },
	{ 0xE4BCBC, 0x1C8FD },
	{ 0xE4BCBD, 0x1C8F8 },
	{ 0xE4BCBE, 0x2A3A2 },
	{ 0xE4BCBF, 0x2A3AA },
	{ 0xE4BD80, 0x3A4CE },
	{ 0xE4BD81, 0x2A3A6 },
	{ 0xE4BD82, 0x3A4C9 },
	{ 0xE4BD83, 0x1C8FB },
	{ 0xE4BD84, 0x3A4CB },
	{ 0xE4BD85, 0x3A4C3 },
	{ 0xE4BD86, 0x1C8FE },
	{ 0xE4BD87, 0x1C8EF },
	{ 0xE4BD88, 0x1C9A9 },
	{ 0xE4BD89, 0x2A2FD },
	{ 0xE4BD8A, 0x3A4C4 },
	{ 0xE4BD8B, 0x3A4CC },
	{ 0xE4BD8C, 0x2A5BD },
	{ 0xE4BD8D, 0x1C8ED },
	{ 0xE4BD8E, 0x1C9A5 },
	{ 0xE4BD8F, 0x1C8EE },
	{ 0xE4BD90, 0x1C8F6 },
	{ 0xE4BD91, 0x1C8F7 },
	{ 0xE4BD92, 0x2A3A4 },
	{ 0xE4BD93, 0x2A2FE },
	{ 0xE4BD94, 0x1C8FC },
	{ 0xE4BD95, 0x1C8F4 },
	{ 0xE4BD96, 0x2A2FA },
	{ 0xE4BD97, 0x1C8F0 },
	{ 0xE4BD98, 0x2A3A7 },
	{ 0xE4BD99, 0x1C9A7 },
	{ 0xE4BD9A, 0x1C9AA },
	{ 0xE4BD9B, 0x1C8F3 },
	{ 0xE4BD9C, 0x1C9A2 },
	{ 0xE4BD9D, 0x1C9A8 },
	{ 0xE4BD9E, 0x1C8F1 },
	{ 0xE4BD9F, 0x2A3A5 },
	{ 0xE4BDA0, 0x1C9A3 },
	{ 0xE4BDA1, 0x2A3AB },
	{ 0xE4BDA2, 0x2A2FC },
	{ 0xE4BDA3, 0x1C9A1 },
	{ 0xE4BDA4, 0x2A3A1 },
	{ 0xE4BDA6, 0x3E4C8 },
	{ 0xE4BDA7, 0x2A3A3 },
	{ 0xE4BDA8, 0x3E4C9 },
	{ 0xE4BDA9, 0x1CBF9 },
	{ 0xE4BDAA, 0x2A5BF },
	{ 0xE4BDAB, 0x2A5CB },
	{ 0xE4BDAC, 0x1CBF1 },
	{ 0xE4BDAD, 0x3A7C7 },
	{ 0xE4BDAE, 0x2A5CC },
	{ 0xE4BDAF, 0x1CBEC },
	{ 0xE4BDB0, 0x1CBF6 },
	{ 0xE4BDB1, 0x4A5BE },
	{ 0xE4BDB2, 0x3A7CF },
	{ 0xE4BDB3, 0x1CBEF },
	{ 0xE4BDB4, 0x2A5B9 },
	{ 0xE4BDB5, 0x1CBF7 },
	{ 0xE4BDB6, 0x2A5B8 },
	{ 0xE4BDB7, 0x2A5BC },
	{ 0xE4BDB8, 0x2A5C3 },
	{ 0xE4BDB9, 0x2A5C1 },
	{ 0xE4BDBA, 0x1CCA1 },
	{ 0xE4BDBB, 0x1CBFA },
	{ 0xE4BDBC, 0x2A5B3 },
	{ 0xE4BDBD, 0x2A5B5 },
	{ 0xE4BDBE, 0x1CBFC },
	{ 0xE4BDBF, 0x1CBF0 },
	{ 0xE4BE80, 0x2A5B6 },
	{ 0xE4BE81, 0x2A5C2 },
	{ 0xE4BE82, 0x2A5C9 },
	{ 0xE4BE83, 0x1CBF5 },
	{ 0xE4BE84, 0x2A5BB },
	{ 0xE4BE85, 0x2A5B4 },
	{ 0xE4BE86, 0x1CBF4 },
	{ 0xE4BE87, 0x2A5B7 },
	{ 0xE4BE88, 0x1CBF8 },
	{ 0xE4BE89, 0x2A5BA },
	{ 0xE4BE8A, 0x3A7C4 },
	{ 0xE4BE8B, 0x1CBF3 },
	{ 0xE4BE8C, 0x3A7D1 },
	{ 0xE4BE8D, 0x1CBEE },
	{ 0xE4BE8E, 0x3A7C8 },
	{ 0xE4BE8F, 0x1CBFD },
	{ 0xE4BE90, 0x2A5C4 },
	{ 0xE4BE91, 0x1CBFE },
	{ 0xE4BE92, 0x2A5C8 },
	{ 0xE4BE93, 0x3A7C3 },
	{ 0xE4BE94, 0x2A5C6 },
	{ 0xE4BE95, 0x2A5CA },
	{ 0xE4BE96, 0x1CBFB },
	{ 0xE4BE97, 0x2A5BE },
	{ 0xE4BE98, 0x2A5B2 },
	{ 0xE4BE99, 0x4A5B6 },
	{ 0xE4BE9A, 0x2A5C0 },
	{ 0xE4BE9B, 0x1CBF2 },
	{ 0xE4BE9C, 0x2A5C5 },
	{ 0xE4BE9D, 0x1CBED },
	{ 0xE4BE9E, 0x2A5C7 },
	{ 0xE4BE9F, 0x3A7CC },
	{ 0xE4BEA0, 0x3A7C9 },
	{ 0xE4BEA1, 0x3A7CB },
	{ 0xE4BEA2, 0x3A7CA },
	{ 0xE4BEA3, 0x3A7CD },
	{ 0xE4BEAB, 0xFA5C4 },
	{ 0xE4BEAE, 0x1CFF8 },
	{ 0xE4BEAF, 0x1CFEC },
	{ 0xE4BEB0, 0x3ABAD },
	{ 0xE4BEB1, 0x3ABAE },
	{ 0xE4BEB2, 0x2A9A2 },
	{ 0xE4BEB3, 0x2A9AA },
	{ 0xE4BEB4, 0x3ABB6 },
	{ 0xE4BEB5, 0x1CFEB },
	{ 0xE4BEB6, 0x1CFF3 },
	{ 0xE4BEB7, 0x1D0A1 },
	{ 0xE4BEB8, 0x3ABAC },
	{ 0xE4BEB9, 0x2A9B0 },
	{ 0xE4BEBA, 0x2A9AE },
	{ 0xE4BEBB, 0x2A9A9 },
	{ 0xE4BEBC, 0x4A8B8 },
	{ 0xE4BEBD, 0x4A8BE },
	{ 0xE4BEBE, 0x3ABAB },
	{ 0xE4BEBF, 0x1CFED },
	{ 0xE4BF80, 0x2A9AF },
	{ 0xE4BF81, 0x2A9A5 },
	{ 0xE4BF82, 0x1CFFB },
	{ 0xE4BF83, 0x1CFF2 },
	{ 0xE4BF84, 0x1CFFA },
	{ 0xE4BF85, 0x2A8FE },
	{ 0xE4BF86, 0x3ABB2 },
	{ 0xE4BF87, 0x2A9AC },
	{ 0xE4BF88, 0x3ABAF },
	{ 0xE4BF89, 0x2A9A3 },
	{ 0xE4BF8A, 0x1CFF6 },
	{ 0xE4BF8B, 0x2A9A4 },
	{ 0xE4BF8C, 0x3ABB3 },
	{ 0xE4BF8D, 0x2A8FD },
	{ 0xE4BF8E, 0x1CFFD },
	{ 0xE4BF8F, 0x1CFF0 },
	{ 0xE4BF90, 0x1CFF9 },
	{ 0xE4BF91, 0x1CFEF },
	{ 0xE4BF92, 0x3ABA8 },
	{ 0xE4BF93, 0x2A9A1 },
	{ 0xE4BF94, 0x2A9A6 },
	{ 0xE4BF95, 0x3ABA9 },
	{ 0xE4BF96, 0x2A9AD },
	{ 0xE4BF97, 0x1CFF7 },
	{ 0xE4BF98, 0x1CFF4 },
	{ 0xE4BF99, 0x2A9A8 },
	{ 0xE4BF9A, 0x1CFFC },
	{ 0xE4BF9B, 0x2A9AB },
	{ 0xE4BF9C, 0x2A9A7 },
	{ 0xE4BF9D, 0x1CFF1 },
	{ 0xE4BF9E, 0x1CFFE },
	{ 0xE4BF9F, 0x1CFF5 },
	{ 0xE4BFA0, 0x1CFEE },
	{ 0xE4BFA1, 0x1CFEA },
	{ 0xE4BFA2, 0x4A8BF },
	{ 0xE4BFA3, 0x3ABB5 },
	{ 0xE4BFA4, 0xFA9AD },
	{ 0xE4BFA5, 0x3ABB4 },
	{ 0xE4BFA7, 0x3E4CA },
	{ 0xE4BFA9, 0x4A8BD },
	{ 0xE4BFAC, 0x2A9B1 },
	{ 0xE4BFAE, 0x1D4BA },
	{ 0xE4BFAF, 0x1D4A4 },
	{ 0xE4BFB0, 0x3AFC8 },
	{ 0xE4BFB1, 0x1D4B4 },
	{ 0xE4BFB2, 0x3AFCD },
	{ 0xE4BFB3, 0x1D4B9 },
	{ 0xE4BFB4, 0x2ADF1 },
	{ 0xE4BFB5, 0x2ADF0 },
	{ 0xE4BFB6, 0x2ADF5 },
	{ 0xE4BFB7, 0x2ADF6 },
	{ 0xE4BFB8, 0x1D4A7 },
	{ 0xE4BFB9, 0x3AFC4 },
	{ 0xE4BFBA, 0x1D4B0 },
	{ 0xE4BFBB, 0x3AFD8 },
	{ 0xE4BFBC, 0x3AFCC },
	{ 0xE4BFBD, 0x3AFD6 },
	{ 0xE4BFBE, 0x1D4BD },
	{ 0xE4BFBF, 0x3AFC6 },
	{ 0xE58080, 0x1D4B1 },
	{ 0xE58081, 0x4ABE2 },
	{ 0xE58082, 0x3AFCB },
	{ 0xE58083, 0x3AFC9 },
	{ 0xE58084, 0x3AFC7 },
	{ 0xE58085, 0x2ADEA },
	{ 0xE58086, 0x1D4AA },
	{ 0xE58087, 0x2ADEB },
	{ 0xE58088, 0x3AFCF },
	{ 0xE58089, 0x1D4BF },
	{ 0xE5808A, 0x4ABE4 },
	{ 0xE5808B, 0x1D4B6 },
	{ 0xE5808C, 0x1D4A1 },
	{ 0xE5808D, 0x1D4A2 },
	{ 0xE5808E, 0x2ADFE },
	{ 0xE5808F, 0x1D9A4 },
	{ 0xE58090, 0x3AFD3 },
	{ 0xE58091, 0x1D4AF },
	{ 0xE58092, 0x1D4AE },
	{ 0xE58093, 0x2ADEC },
	{ 0xE58094, 0x1D4B2 },
	{ 0xE58095, 0x2B3DE },
	{ 0xE58096, 0x1D4A9 },
	{ 0xE58097, 0x2ADF7 },
	{ 0xE58098, 0x1D4B8 },
	{ 0xE58099, 0x1D4B7 },
	{ 0xE5809A, 0x1D4AD },
	{ 0xE5809B, 0x2ADEF },
	{ 0xE5809C, 0x2ADF8 },
	{ 0xE5809D, 0x3AFC5 },
	{ 0xE5809E, 0x2ADE9 },
	{ 0xE5809F, 0x1D4AC },
	{ 0xE580A0, 0x2ADF9 },
	{ 0xE580A1, 0x1D4B5 },
	{ 0xE580A2, 0x2ADED },
	{ 0xE580A3, 0x1D4A3 },
	{ 0xE580A4, 0x3AFCE },
	{ 0xE580A5, 0x1D4A6 },
	{ 0xE580A6, 0x1D4A5 },
	{ 0xE580A7, 0x2ADFA },
	{ 0xE580A8, 0x1D4B3 },
	{ 0xE580A9, 0x1D4A8 },
	{ 0xE580AA, 0x1D4BC },
	{ 0xE580AB, 0x1D4BE },
	{ 0xE580AC, 0x2ADF4 },
	{ 0xE580AD, 0x1D4BB },
	{ 0xE580AE, 0x3AFD1 },
	{ 0xE580AF, 0x2ADFC },
	{ 0xE580B0, 0x2ADEE },
	{ 0xE580B1, 0x2ADFD },
	{ 0xE580B2, 0x3AFC3 },
	{ 0xE580B3, 0x2ADF2 },
	{ 0xE580B4, 0x4ABE1 },
	{ 0xE580B5, 0x2ADFB },
	{ 0xE580B6, 0x3AFD0 },
	{ 0xE580B7, 0x2ADF3 },
	{ 0xE580B8, 0x3AFD4 },
	{ 0xE580B9, 0x3AFD5 },
	{ 0xE580BC, 0x1D4AB },
	{ 0xE580BF, 0x3E4CB },
	{ 0xE58180, 0x2B3E6 },
	{ 0xE58181, 0x2B3DA },
	{ 0xE58182, 0x3B4BC },
	{ 0xE58183, 0x1D8F6 },
	{ 0xE58184, 0x3B4BF },
	{ 0xE58185, 0x2B3DF },
	{ 0xE58186, 0x2B3E5 },
	{ 0xE58187, 0x1D8F5 },
	{ 0xE58188, 0x2B3D8 },
	{ 0xE58189, 0x1D8F9 },
	{ 0xE5818A, 0x2B3DC },
	{ 0xE5818B, 0x2B3D5 },
	{ 0xE5818C, 0x1D8F7 },
	{ 0xE5818D, 0x2B3D9 },
	{ 0xE5818E, 0x1D8FC },
	{ 0xE5818F, 0x1D9A3 },
	{ 0xE58190, 0x3B4C4 },
	{ 0xE58191, 0x2B3EA },
	{ 0xE58192, 0x3B4C1 },
	{ 0xE58193, 0x2B3D4 },
	{ 0xE58194, 0x3B4C2 },
	{ 0xE58195, 0x1D8FD },
	{ 0xE58196, 0x3AFD7 },
	{ 0xE58197, 0x2B3E9 },
	{ 0xE58198, 0x3B4C7 },
	{ 0xE58199, 0x3B4BD },
	{ 0xE5819A, 0x1D8F8 },
	{ 0xE5819B, 0x2B3DB },
	{ 0xE5819C, 0x1D8F4 },
	{ 0xE5819D, 0x2B3D6 },
	{ 0xE5819E, 0x2B3D2 },
	{ 0xE5819F, 0x2B3E0 },
	{ 0xE581A0, 0x2B3D3 },
	{ 0xE581A1, 0x2B3D1 },
	{ 0xE581A2, 0x2B3DD },
	{ 0xE581A3, 0x2B3E3 },
	{ 0xE581A4, 0x2B3E4 },
	{ 0xE581A5, 0x1D8FA },
	{ 0xE581A6, 0x3B4C0 },
	{ 0xE581A7, 0x4B0C7 },
	{ 0xE581A8, 0x2BABF },
	{ 0xE581A9, 0x2B3E1 },
	{ 0xE581AA, 0x2B3D0 },
	{ 0xE581AB, 0x2B3E2 },
	{ 0xE581AC, 0x3B4CB },
	{ 0xE581AD, 0x1D9A6 },
	{ 0xE581AE, 0x2B3E7 },
	{ 0xE581AF, 0x1D9A5 },
	{ 0xE581B0, 0x2B3CF },
	{ 0xE581B1, 0x3B4C3 },
	{ 0xE581B2, 0x2B3D7 },
	{ 0xE581B3, 0x2B3E8 },
	{ 0xE581B4, 0x1D9A1 },
	{ 0xE581B5, 0x1D8FE },
	{ 0xE581B6, 0x1D8FB },
	{ 0xE581B7, 0x1D9A2 },
	{ 0xE581B8, 0x3B4CC },
	{ 0xE581B9, 0x3B4CA },
	{ 0xE581BA, 0x1D8F2 },
	{ 0xE581BB, 0x3B4C5 },
	{ 0xE581BC, 0x3B4C6 },
	{ 0xE581BD, 0x1D8F3 },
	{ 0xE58280, 0x1DEAE },
	{ 0xE58281, 0x3B9F5 },
	{ 0xE58282, 0x2BAC2 },
	{ 0xE58283, 0x2BABB },
	{ 0xE58284, 0x4B6B4 },
	{ 0xE58285, 0x1DEAB },
	{ 0xE58286, 0x4B6B3 },
	{ 0xE58287, 0x2BAC3 },
	{ 0xE58288, 0x3B9F1 },
	{ 0xE58289, 0x3B9F2 },
	{ 0xE5828A, 0x4B6B6 },
	{ 0xE5828B, 0x2BAB9 },
	{ 0xE5828C, 0x2BABC },
	{ 0xE5828D, 0x1DEAA },
	{ 0xE5828E, 0x2BABD },
	{ 0xE5828F, 0x3B9EF },
	{ 0xE58290, 0x4B6B1 },
	{ 0xE58291, 0x1DEAD },
	{ 0xE58292, 0x2BAC1 },
	{ 0xE58293, 0x4B6BC },
	{ 0xE58294, 0x2BAB7 },
	{ 0xE58295, 0x2BAB6 },
	{ 0xE58296, 0x1DEAF },
	{ 0xE58297, 0x3B9F0 },
	{ 0xE58298, 0x1DEB0 },
	{ 0xE58299, 0x1DEAC },
	{ 0xE5829A, 0x1DEB1 },
	{ 0xE5829B, 0x2BAB5 },
	{ 0xE5829C, 0x2BAC0 },
	{ 0xE5829D, 0x2BABE },
	{ 0xE5829E, 0x2BAB8 },
	{ 0xE5829F, 0x4B6B9 },
	{ 0xE582A0, 0x4B6B0 },
	{ 0xE582A1, 0x4B6BA },
	{ 0xE582A2, 0x1DEA9 },
	{ 0xE582A3, 0x2BABA },
	{ 0xE582A6, 0x3E4CD },
	{ 0xE582AA, 0x3C0B9 },
	{ 0xE582AB, 0x3C0BC },
	{ 0xE582AC, 0x1E3B1 },
	{ 0xE582AD, 0x1E3AB },
	{ 0xE582AE, 0x2C1DC },
	{ 0xE582AF, 0x1E3B4 },
	{ 0xE582B0, 0x2C1E2 },
	{ 0xE582B1, 0x2C1E5 },
	{ 0xE582B2, 0x1E3AD },
	{ 0xE582B3, 0x1E3AE },
	{ 0xE582B4, 0x2C1DF },
	{ 0xE582B5, 0x1E3AC },
	{ 0xE582B6, 0x2C1E8 },
	{ 0xE582B7, 0x1E3B2 },
	{ 0xE582B8, 0x2C1E9 },
	{ 0xE582B9, 0x3C0BA },
	{ 0xE582BA, 0x2C1E4 },
	{ 0xE582BB, 0x1E3B3 },
	{ 0xE582BC, 0x3C0B7 },
	{ 0xE582BD, 0x2C1D9 },
	{ 0xE582BE, 0x1E3B0 },
	{ 0xE582BF, 0x2C1DA },
	{ 0xE58380, 0x4BCA9 },
	{ 0xE58381, 0x2C1E3 },
	{ 0xE58382, 0x2C1E1 },
	{ 0xE58383, 0x3C0BD },
	{ 0xE58384, 0x2C1DD },
	{ 0xE58385, 0x1E3AF },
	{ 0xE58386, 0x2C1DB },
	{ 0xE58387, 0x1E3B5 },
	{ 0xE58388, 0x2C1E0 },
	{ 0xE58389, 0x2C1E7 },
	{ 0xE5838A, 0x2C1DE },
	{ 0xE5838B, 0x2C1E6 },
	{ 0xE5838C, 0x3C0B6 },
	{ 0xE5838D, 0x3C0BE },
	{ 0xE5838E, 0x1E7FC },
	{ 0xE5838F, 0x1E7F9 },
	{ 0xE58390, 0x3C5EB },
	{ 0xE58391, 0x1E7FA },
	{ 0xE58392, 0x4C2AD },
	{ 0xE58393, 0x2C9A1 },
	{ 0xE58394, 0x2C8F7 },
	{ 0xE58395, 0x1E7F8 },
	{ 0xE58396, 0x1E7F5 },
	{ 0xE58397, 0x2C8F8 },
	{ 0xE58398, 0x3C5EE },
	{ 0xE58399, 0x3C5EC },
	{ 0xE5839A, 0x1E7F7 },
	{ 0xE5839B, 0x2C8FB },
	{ 0xE5839C, 0x3C5ED },
	{ 0xE5839D, 0x2C8FD },
	{ 0xE5839E, 0x3C5F6 },
	{ 0xE5839F, 0x4C2B5 },
	{ 0xE583A0, 0x2C9A6 },
	{ 0xE583A1, 0x3C5F0 },
	{ 0xE583A2, 0x3C5F5 },
	{ 0xE583A3, 0x2C9A5 },
	{ 0xE583A4, 0x2C8FE },
	{ 0xE583A5, 0x1E7F4 },
	{ 0xE583A6, 0x2C8F6 },
	{ 0xE583A7, 0x1E7F2 },
	{ 0xE583A8, 0x2C8F9 },
	{ 0xE583A9, 0x1E7FD },
	{ 0xE583AA, 0x2C8FC },
	{ 0xE583AB, 0x3C5F1 },
	{ 0xE583AC, 0x2C9A2 },
	{ 0xE583AD, 0x1E7F6 },
	{ 0xE583AE, 0x1E7F3 },
	{ 0xE583AF, 0x2C9A4 },
	{ 0xE583B0, 0x2C9A3 },
	{ 0xE583B1, 0x1E7FB },
	{ 0xE583B3, 0x2C8FA },
	{ 0xE583B4, 0x3C5F4 },
	{ 0xE583B5, 0x1ECA3 },
	{ 0xE583B6, 0x2CFD4 },
	{ 0xE583B7, 0x3CBA9 },
	{ 0xE583B8, 0x2CFD1 },
	{ 0xE583B9, 0x1ECA4 },
	{ 0xE583BA, 0x4C8F9 },
	{ 0xE583BB, 0x1ECA2 },
	{ 0xE583BC, 0x3CBAB },
	{ 0xE583BD, 0x2CFD8 },
	{ 0xE583BE, 0x2CFD5 },
	{ 0xE583BF, 0x2CFCE },
	{ 0xE58480, 0x1ECA1 },
	{ 0xE58481, 0x3CBAD },
	{ 0xE58482, 0x1ECA5 },
	{ 0xE58483, 0x2CFCF },
	{ 0xE58484, 0x1EBFE },
	{ 0xE58485, 0x1ECA8 },
	{ 0xE58486, 0x2CFD2 },
	{ 0xE58487, 0x2CFD3 },
	{ 0xE58488, 0x1ECA6 },
	{ 0xE58489, 0x1ECA7 },
	{ 0xE5848A, 0x2CFD9 },
	{ 0xE5848B, 0x2CFD6 },
	{ 0xE5848C, 0x2CFD7 },
	{ 0xE5848D, 0x3CBAC },
	{ 0xE5848E, 0x3CBA7 },
	{ 0xE5848F, 0x3E4CE },
	{ 0xE58490, 0x1F0B3 },
	{ 0xE58491, 0x2D6C3 },
	{ 0xE58492, 0x1F0B0 },
	{ 0xE58493, 0x2D6C0 },
	{ 0xE58494, 0x1F0B2 },
	{ 0xE58495, 0x1F0B4 },
	{ 0xE58496, 0x3D0B1 },
	{ 0xE58497, 0x2D6C1 },
	{ 0xE58498, 0x1F0B1 },
	{ 0xE58499, 0x4CFDA },
	{ 0xE5849A, 0x2D6C2 },
	{ 0xE5849B, 0x3D0B5 },
	{ 0xE5849C, 0x2D6BF },
	{ 0xE5849D, 0x3D0B0 },
	{ 0xE5849E, 0x3D0B4 },
	{ 0xE5849F, 0x1F3C1 },
	{ 0xE584A0, 0x2DCC9 },
	{ 0xE584A1, 0x1F3C2 },
	{ 0xE584A2, 0x2DCC7 },
	{ 0xE584A3, 0x4D5E5 },
	{ 0xE584A4, 0x2DCC8 },
	{ 0xE584A5, 0x2DCC6 },
	{ 0xE584A6, 0x2DCC5 },
	{ 0xE584A7, 0x3D4C1 },
	{ 0xE584A8, 0x3D4C0 },
	{ 0xE584A9, 0x2DCCA },
	{ 0xE584AA, 0x1F3C0 },
	{ 0xE584AB, 0x3D0B3 },
	{ 0xE584AC, 0x4D5E9 },
	{ 0xE584AD, 0x2E1C4 },
	{ 0xE584AE, 0x2E1C5 },
	{ 0xE584AF, 0x3D7D2 },
	{ 0xE584B0, 0x2CFD0 },
	{ 0xE584B1, 0x2E1C3 },
	{ 0xE584B2, 0x1F3C3 },
	{ 0xE584B3, 0x1F8AB },
	{ 0xE584B4, 0x2E5B7 },
	{ 0xE584B5, 0x2E5B8 },
	{ 0xE584B6, 0x3DCB2 },
	{ 0xE584B7, 0x1FAE2 },
	{ 0xE584B8, 0x1FAE3 },
	{ 0xE584B9, 0x2EBCF },
	{ 0xE584BA, 0x2EBCE },
	{ 0xE584BB, 0x1FBD8 },
	{ 0xE584BC, 0x1FBD7 },
	{ 0xE584BD, 0x2EEFD },
	{ 0xE584BE, 0x3E0EF },
	{ 0xE584BF, 0x1C4AA },
	{ 0xE58580, 0x1C4C2 },
	{ 0xE58581, 0x1C4F8 },
	{ 0xE58582, 0x4A1BD },
	{ 0xE58583, 0x1C4F7 },
	{ 0xE58584, 0x1C5F3 },
	{ 0xE58585, 0x1C5F2 },
	{ 0xE58586, 0x1C7BE },
	{ 0xE58587, 0x1C7BD },
	{ 0xE58588, 0x1C7BF },
	{ 0xE58589, 0x1C7BC },
	{ 0xE5858A, 0x3A2F8 },
	{ 0xE5858B, 0x1C9AC },
	{ 0xE5858C, 0x1C9AB },
	{ 0xE5858D, 0x1C9AD },
	{ 0xE5858E, 0x3A4D4 },
	{ 0xE5858F, 0x4A3BB },
	{ 0xE58590, 0x3A4D3 },
	{ 0xE58591, 0x3A4D1 },
	{ 0xE58592, 0x1CCA3 },
	{ 0xE58593, 0x4A5BF },
	{ 0xE58594, 0x1CCA2 },
	{ 0xE58595, 0x1CCA4 },
	{ 0xE58596, 0x3A7D2 },
	{ 0xE58597, 0x1D0A2 },
	{ 0xE58598, 0x4A8C0 },
	{ 0xE58599, 0x1A2F9 },
	{ 0xE5859A, 0x2AEA1 },
	{ 0xE5859B, 0x1A2FA },
	{ 0xE5859C, 0x1D9A7 },
	{ 0xE5859D, 0x1A2FC },
	{ 0xE5859E, 0x1A2FB },
	{ 0xE5859F, 0x2BAC4 },
	{ 0xE585A0, 0x3B9F6 },
	{ 0xE585A1, 0x1A2FD },
	{ 0xE585A2, 0x1E7FE },
	{ 0xE585A3, 0x1A2FE },
	{ 0xE585A4, 0x3DEA5 },
	{ 0xE585A5, 0x1C4AB },
	{ 0xE585A6, 0x3A1B4 },
	{ 0xE585A7, 0x1C4F9 },
	{ 0xE585A8, 0x1C7C0 },
	{ 0xE585A9, 0x1CCA5 },
	{ 0xE585AA, 0x3ABB7 },
	{ 0xE585AB, 0x1C4AC },
	{ 0xE585AC, 0x1C4FC },
	{ 0xE585AD, 0x1C4FA },
	{ 0xE585AE, 0x1C4FB },
	{ 0xE585B1, 0x1C7C1 },
	{ 0xE585B2, 0x3A2FA },
	{ 0xE585B3, 0x4A2B4 },
	{ 0xE585B5, 0x1C9AE },
	{ 0xE585B6, 0x1CCA7 },
	{ 0xE585B7, 0x1CCA6 },
	{ 0xE585B8, 0x1CCA8 },
	{ 0xE585B9, 0x3AEFB },
	{ 0xE585BC, 0x1D4C0 },
	{ 0xE585BE, 0x3C0BF },
	{ 0xE585BF, 0x3E4D3 },
	{ 0xE58680, 0x1F0B5 },
	{ 0xE58682, 0x3A1A7 },
	{ 0xE58683, 0x4A1BE },
	{ 0xE58684, 0x3A1CD },
	{ 0xE58685, 0x3A1C8 },
	{ 0xE58686, 0x3A1CE },
	{ 0xE58687, 0x2A1AE },
	{ 0xE58688, 0x4A1D2 },
	{ 0xE58689, 0x1C5F4 },
	{ 0xE5868A, 0x1C5F5 },
	{ 0xE5868B, 0x3A1F8 },
	{ 0xE5868C, 0x3A1F9 },
	{ 0xE5868D, 0x1C7C2 },
	{ 0xE5868E, 0x4A2B6 },
	{ 0xE5868F, 0x2A3AC },
	{ 0xE58690, 0x3A7D5 },
	{ 0xE58691, 0x1D0A4 },
	{ 0xE58692, 0x1D0A3 },
	{ 0xE58693, 0x2AEA3 },
	{ 0xE58694, 0x2AEA2 },
	{ 0xE58695, 0x1D9A8 },
	{ 0xE58696, 0x3A1A8 },
	{ 0xE58697, 0x1C4FD },
	{ 0xE58698, 0x2A1B5 },
	{ 0xE58699, 0x3A1FA },
	{ 0xE5869D, 0x3A4D7 },
	{ 0xE5869E, 0x2A5CD },
	{ 0xE5869F, 0x3ABB9 },
	{ 0xE586A0, 0x1D0A5 },
	{ 0xE586A1, 0x3AFDB },
	{ 0xE586A2, 0x1D4C3 },
	{ 0xE586A3, 0x3AFD9 },
	{ 0xE586A4, 0x1D4C1 },
	{ 0xE586A5, 0x1D4C2 },
	{ 0xE586A6, 0x3AFDA },
	{ 0xE586A8, 0x3B4CD },
	{ 0xE586A9, 0xFC6DC },
	{ 0xE586AA, 0x1F0B6 },
	{ 0xE586AB, 0x1A7AF },
	{ 0xE586AC, 0x1C5F6 },
	{ 0xE586AD, 0x4A1DE },
	{ 0xE586B0, 0x1C7C3 },
	{ 0xE586B1, 0x2A1FB },
	{ 0xE586B2, 0x3A2FE },
	{ 0xE586B3, 0x3A2FD },
	{ 0xE586B4, 0x3A2FC },
	{ 0xE586B5, 0x3A4D9 },
	{ 0xE586B6, 0x1C9AF },
	{ 0xE586B7, 0x1C9B0 },
	{ 0xE586B8, 0x3A4DA },
	{ 0xE586B9, 0x2A3AD },
	{ 0xE586BA, 0x4A3BD },
	{ 0xE586BC, 0x2A5CE },
	{ 0xE586BD, 0x1CCA9 },
	{ 0xE586BE, 0x2A5CF },
	{ 0xE586BF, 0x4A5C0 },
	{ 0xE58780, 0x4A5C3 },
	{ 0xE58781, 0x3ABBB },
	{ 0xE58782, 0x3ABBD },
	{ 0xE58783, 0x3ABBE },
	{ 0xE58784, 0x2AEA5 },
	{ 0xE58785, 0x2AEA6 },
	{ 0xE58786, 0x1D4C6 },
	{ 0xE58787, 0x3AFDE },
	{ 0xE58788, 0x2AEA7 },
	{ 0xE58789, 0x3AFDF },
	{ 0xE5878A, 0x2AEA4 },
	{ 0xE5878B, 0x1D4C7 },
	{ 0xE5878C, 0x1D4C5 },
	{ 0xE5878D, 0x1D4C4 },
	{ 0xE5878E, 0x2AEA8 },
	{ 0xE5878F, 0x3B4CF },
	{ 0xE58790, 0x2B3EB },
	{ 0xE58791, 0x3B4CE },
	{ 0xE58792, 0x3B9FD },
	{ 0xE58793, 0x3B9FA },
	{ 0xE58794, 0x2BAC5 },
	{ 0xE58795, 0x4B6BF },
	{ 0xE58796, 0x3B9FE },
	{ 0xE58797, 0x2C1EA },
	{ 0xE58798, 0x2C9A7 },
	{ 0xE58799, 0x3CBAF },
	{ 0xE5879A, 0x3CBAE },
	{ 0xE5879B, 0x3CBB0 },
	{ 0xE5879C, 0x1ECA9 },
	{ 0xE5879D, 0x1F0B7 },
	{ 0xE5879E, 0x2D6C4 },
	{ 0xE5879F, 0x3D4C2 },
	{ 0xE587A0, 0x1C4AD },
	{ 0xE587A1, 0x1C4BB },
	{ 0xE587A2, 0x3A1AF },
	{ 0xE587A3, 0x3A1B5 },
	{ 0xE587A4, 0x3A1D1 },
	{ 0xE587A5, 0x3A1FB },
	{ 0xE587A8, 0x3A3A2 },
	{ 0xE587AA, 0xFA2D9 },
	{ 0xE587AC, 0x3A4DB },
	{ 0xE587AD, 0x3A7D9 },
	{ 0xE587AE, 0x4A5C5 },
	{ 0xE587B0, 0x1D9A9 },
	{ 0xE587B1, 0x1DEB3 },
	{ 0xE587B2, 0x6C6E5 },
	{ 0xE587B3, 0x1E8A1 },
	{ 0xE587B4, 0x3C5FA },
	{ 0xE587B5, 0x2A1A3 },
	{ 0xE587B6, 0x1C4FE },
	{ 0xE587B7, 0x4A1E0 },
	{ 0xE587B8, 0x1C5F9 },
	{ 0xE587B9, 0x1C5F7 },
	{ 0xE587BA, 0x1C5F8 },
	{ 0xE587BD, 0x1CCAA },
	{ 0xE587BE, 0x3A7DA },
	{ 0xE58880, 0x1C4AE },
	{ 0xE58881, 0x1C4AF },
	{ 0xE58882, 0x4A1AA },
	{ 0xE58883, 0x1C4C3 },
	{ 0xE58884, 0x3A1B6 },
	{ 0xE58885, 0x3A1D2 },
	{ 0xE58886, 0x1C5A1 },
	{ 0xE58887, 0x1C5A2 },
	{ 0xE58888, 0x1C5A3 },
	{ 0xE58889, 0x2A1CC },
	{ 0xE5888A, 0x1C5FA },
	{ 0xE5888B, 0x3A1FD },
	{ 0xE5888C, 0x2A1CB },
	{ 0xE5888E, 0x1C7C7 },
	{ 0xE5888F, 0x3A3A5 },
	{ 0xE58890, 0x2A1FD },
	{ 0xE58891, 0x1C7C5 },
	{ 0xE58892, 0x1C7C6 },
	{ 0xE58893, 0x2A1FC },
	{ 0xE58894, 0x3A3A4 },
	{ 0xE58895, 0x3A3A6 },
	{ 0xE58896, 0x1C7C8 },
	{ 0xE58897, 0x1C7C4 },
	{ 0xE58898, 0x3A3A7 },
	{ 0xE5889C, 0x2A3AE },
	{ 0xE5889D, 0x1CFCF },
	{ 0xE5889E, 0x2A3AF },
	{ 0xE5889F, 0x3A4DF },
	{ 0xE588A0, 0x3A4E1 },
	{ 0xE588A1, 0x2A3B0 },
	{ 0xE588A2, 0x4A3C0 },
	{ 0xE588A3, 0x3A4DC },
	{ 0xE588A4, 0x1C9B2 },
	{ 0xE588A5, 0x1C9B1 },
	{ 0xE588A6, 0x3A4DE },
	{ 0xE588A7, 0x3A4DD },
	{ 0xE588A8, 0x1C9B5 },
	{ 0xE588A9, 0x1C9B3 },
	{ 0xE588AA, 0x1C9B4 },
	{ 0xE588AB, 0x3A4E0 },
	{ 0xE588AE, 0x1CCB0 },
	{ 0xE588AF, 0x3A7DB },
	{ 0xE588B0, 0x1CCAF },
	{ 0xE588B1, 0x2A5D4 },
	{ 0xE588B2, 0x2A5D1 },
	{ 0xE588B3, 0x2A5D2 },
	{ 0xE588B4, 0x3A7DE },
	{ 0xE588B5, 0x2A5D0 },
	{ 0xE588B6, 0x1CCB1 },
	{ 0xE588B7, 0x1CCAD },
	{ 0xE588B8, 0x1CCAC },
	{ 0xE588B9, 0x3A7DF },
	{ 0xE588BA, 0x1CCAE },
	{ 0xE588BB, 0x1CCAB },
	{ 0xE588BC, 0x3A7DD },
	{ 0xE588BD, 0x4A5CE },
	{ 0xE588BE, 0x3E4CF },
	{ 0xE58981, 0x1CCB2 },
	{ 0xE58983, 0x1D0A7 },
	{ 0xE58984, 0x2A9B2 },
	{ 0xE58985, 0x3ABBF },
	{ 0xE58986, 0x2A5D3 },
	{ 0xE58987, 0x1D0AC },
	{ 0xE58988, 0x3ABC0 },
	{ 0xE58989, 0x2A9B3 },
	{ 0xE5898A, 0x1D0A8 },
	{ 0xE5898B, 0x1D0AB },
	{ 0xE5898C, 0x1D0AA },
	{ 0xE5898D, 0x1D0A9 },
	{ 0xE5898E, 0x1D0A6 },
	{ 0xE5898F, 0x3ABC3 },
	{ 0xE58992, 0x2AEAB },
	{ 0xE58993, 0x3AFE8 },
	{ 0xE58994, 0x1D4CA },
	{ 0xE58995, 0x2AEAE },
	{ 0xE58996, 0x1D4C8 },
	{ 0xE58997, 0x3AFE5 },
	{ 0xE58998, 0x4ABEE },
	{ 0xE58999, 0x3AFE2 },
	{ 0xE5899A, 0x2AEAA },
	{ 0xE5899B, 0x1D4CB },
	{ 0xE5899C, 0x1D4C9 },
	{ 0xE5899D, 0x1D4CC },
	{ 0xE5899E, 0x2AEAC },
	{ 0xE5899F, 0x2AEAD },
	{ 0xE589A0, 0x3AFE0 },
	{ 0xE589A1, 0x2AEA9 },
	{ 0xE589A2, 0x2AEAF },
	{ 0xE589A3, 0x3AFE6 },
	{ 0xE589A4, 0x3AFE1 },
	{ 0xE589A5, 0x3AFE3 },
	{ 0xE589A6, 0xFAEAD },
	{ 0xE589A7, 0x3AFE4 },
	{ 0xE589A8, 0x3B4D0 },
	{ 0xE589A9, 0x1DEB7 },
	{ 0xE589AA, 0x1D9AA },
	{ 0xE589AB, 0x2B3EC },
	{ 0xE589AC, 0x2B3EE },
	{ 0xE589AD, 0x2B3ED },
	{ 0xE589AE, 0x2B3EF },
	{ 0xE589AF, 0x1D9AB },
	{ 0xE589B0, 0x3BAA3 },
	{ 0xE589B2, 0x1DEB4 },
	{ 0xE589B3, 0x3BAA1 },
	{ 0xE589B4, 0x1DEB5 },
	{ 0xE589B5, 0x1DEB6 },
	{ 0xE589B6, 0x3B4D1 },
	{ 0xE589B7, 0x1E3B7 },
	{ 0xE589B8, 0x2C1EC },
	{ 0xE589B9, 0x3C0C1 },
	{ 0xE589BA, 0x2C1EB },
	{ 0xE589BB, 0x2C1ED },
	{ 0xE589BC, 0x2C1EE },
	{ 0xE589BD, 0x1E3B8 },
	{ 0xE589BE, 0x3C0C0 },
	{ 0xE589BF, 0x1E3B6 },
	{ 0xE58A80, 0x2C9A8 },
	{ 0xE58A81, 0x2C9A9 },
	{ 0xE58A82, 0x1E8A3 },
	{ 0xE58A83, 0x1E8A2 },
	{ 0xE58A84, 0x2CCE1 },
	{ 0xE58A85, 0x4C9A5 },
	{ 0xE58A86, 0x3CBB1 },
	{ 0xE58A87, 0x1ECAA },
	{ 0xE58A88, 0x1ECAB },
	{ 0xE58A89, 0x1ECAC },
	{ 0xE58A8A, 0x1ECAE },
	{ 0xE58A8B, 0x2CFDA },
	{ 0xE58A8C, 0x2CFDB },
	{ 0xE58A8D, 0x1ECAD },
	{ 0xE58A8E, 0x3CBB2 },
	{ 0xE58A90, 0x3D0B6 },
	{ 0xE58A91, 0x1F0B8 },
	{ 0xE58A92, 0x4CFE4 },
	{ 0xE58A93, 0x1F0B9 },
	{ 0xE58A94, 0x3D0B7 },
	{ 0xE58A95, 0x4D5ED },
	{ 0xE58A96, 0x2E5B9 },
	{ 0xE58A97, 0x2EBD1 },
	{ 0xE58A98, 0x2EBD0 },
	{ 0xE58A99, 0x2EEFE },
	{ 0xE58A9A, 0x3E0AC },
	{ 0xE58A9B, 0x1C4B0 },
	{ 0xE58A9C, 0x3A1B7 },
	{ 0xE58A9D, 0x3A1D4 },
	{ 0xE58A9E, 0x3A1D3 },
	{ 0xE58A9F, 0x1C5FC },
	{ 0xE58AA0, 0x1C5FB },
	{ 0xE58AA3, 0x1C7C9 },
	{ 0xE58AA4, 0x4A2C2 },
	{ 0xE58AA5, 0x4A2BF },
	{ 0xE58AA6, 0x2A1FE },
	{ 0xE58AA7, 0x4A2C1 },
	{ 0xE58AA8, 0x3A3A8 },
	{ 0xE58AA9, 0x1C9B7 },
	{ 0xE58AAA, 0x1C9B8 },
	{ 0xE58AAB, 0x1C9B6 },
	{ 0xE58AAC, 0x1C9B9 },
	{ 0xE58AAD, 0x2A3B1 },
	{ 0xE58AAE, 0x2A3B2 },
	{ 0xE58AAF, 0x4A3C6 },
	{ 0xE58AB0, 0x4A3C7 },
	{ 0xE58AB1, 0x4A3C8 },
	{ 0xE58AB3, 0x3A4E3 },
	{ 0xE58AB4, 0x3A4E2 },
	{ 0xE58AB5, 0x3A7E1 },
	{ 0xE58AB6, 0x5A5BA },
	{ 0xE58AB7, 0x5A5B7 },
	{ 0xE58AB8, 0x5A5B8 },
	{ 0xE58AB9, 0x3A7E0 },
	{ 0xE58ABA, 0x5A5BB },
	{ 0xE58ABB, 0x1CCB4 },
	{ 0xE58ABC, 0x2A5D5 },
	{ 0xE58ABD, 0x4A5D0 },
	{ 0xE58ABE, 0x1CCB3 },
	{ 0xE58ABF, 0x3A7E2 },
	{ 0xE58B80, 0x2A9B4 },
	{ 0xE58B81, 0x1D0B0 },
	{ 0xE58B82, 0x2A9B5 },
	{ 0xE58B83, 0x1D0AF },
	{ 0xE58B84, 0x3ABC8 },
	{ 0xE58B85, 0x3ABC6 },
	{ 0xE58B86, 0x4A8C9 },
	{ 0xE58B87, 0x1D0AD },
	{ 0xE58B88, 0x4A8CB },
	{ 0xE58B89, 0x1D0AE },
	{ 0xE58B8A, 0x3ABC7 },
	{ 0xE58B8C, 0x3AFEF },
	{ 0xE58B8D, 0x2AEB0 },
	{ 0xE58B8E, 0x3AFEC },
	{ 0xE58B8F, 0x3AFEA },
	{ 0xE58B90, 0x3AFED },
	{ 0xE58B91, 0x3AFEE },
	{ 0xE58B92, 0x1D9AC },
	{ 0xE58B93, 0x2B3F1 },
	{ 0xE58B94, 0x3B4D2 },
	{ 0xE58B95, 0x1D9AF },
	{ 0xE58B96, 0x2B3F0 },
	{ 0xE58B97, 0x1DBAB },
	{ 0xE58B98, 0x1D9AE },
	{ 0xE58B99, 0x1D9AD },
	{ 0xE58B9B, 0x1DEBA },
	{ 0xE58B9C, 0x5B6EA },
	{ 0xE58B9D, 0x1DEB9 },
	{ 0xE58B9E, 0x1DEB8 },
	{ 0xE58B9F, 0x1E3B9 },
	{ 0xE58BA0, 0x3C0C5 },
	{ 0xE58BA1, 0x3C0C4 },
	{ 0xE58BA2, 0x1E3BC },
	{ 0xE58BA3, 0x1E3BD },
	{ 0xE58BA4, 0x1E3BB },
	{ 0xE58BA5, 0x4BCBC },
	{ 0xE58BA6, 0x1E3BA },
	{ 0xE58BA7, 0x3C0C6 },
	{ 0xE58BA8, 0x5C4E7 },
	{ 0xE58BA9, 0x2C9AA },
	{ 0xE58BAA, 0x3C6A1 },
	{ 0xE58BAB, 0x2C9AB },
	{ 0xE58BAC, 0x5C4E3 },
	{ 0xE58BAD, 0x3C5FE },
	{ 0xE58BAE, 0x3CBB3 },
	{ 0xE58BAF, 0x2CFDD },
	{ 0xE58BB0, 0x1ECAF },
	{ 0xE58BB1, 0x2CFDC },
	{ 0xE58BB2, 0x3CDAC },
	{ 0xE58BB3, 0x1F0BA },
	{ 0xE58BB4, 0x2DCCB },
	{ 0xE58BB5, 0x1F3C4 },
	{ 0xE58BB6, 0x5D3E2 },
	{ 0xE58BB7, 0x2E5BA },
	{ 0xE58BB8, 0x1F9E1 },
	{ 0xE58BB9, 0x1A7B4 },
	{ 0xE58BBA, 0x1C4C4 },
	{ 0xE58BBB, 0x1C5A4 },
	{ 0xE58BBC, 0x2A1B6 },
	{ 0xE58BBD, 0x3A1D5 },
	{ 0xE58BBE, 0x1C5A5 },
	{ 0xE58BBF, 0x1C5A6 },
	{ 0xE58C80, 0x3A1D6 },
	{ 0xE58C81, 0xFA1B0 },
	{ 0xE58C83, 0x3A2A3 },
	{ 0xE58C84, 0x3A2A2 },
	{ 0xE58C85, 0x1C5FD },
	{ 0xE58C86, 0x1C5FE },
	{ 0xE58C87, 0x3A2A4 },
	{ 0xE58C88, 0x1C7CA },
	{ 0xE58C89, 0x2A3B3 },
	{ 0xE58C8A, 0x2A5D6 },
	{ 0xE58C8B, 0x2A5D7 },
	{ 0xE58C8C, 0x4A5D1 },
	{ 0xE58C8D, 0x1D0B1 },
	{ 0xE58C8E, 0x2AEB1 },
	{ 0xE58C8F, 0x1D9B1 },
	{ 0xE58C90, 0x1D9B0 },
	{ 0xE58C91, 0x2BAC7 },
	{ 0xE58C92, 0x2BAC6 },
	{ 0xE58C93, 0x6D0F4 },
	{ 0xE58C94, 0x3D0B8 },
	{ 0xE58C95, 0x1C4B1 },
	{ 0xE58C96, 0x1C5A7 },
	{ 0xE58C97, 0x1C6A1 },
	{ 0xE58C98, 0x4B0DE },
	{ 0xE58C99, 0x1D9B2 },
	{ 0xE58C9A, 0x2A1A4 },
	{ 0xE58C9B, 0x4A1E5 },
	{ 0xE58C9C, 0x2A1CD },
	{ 0xE58C9D, 0x1C6A2 },
	{ 0xE58C9E, 0x3A2A6 },
	{ 0xE58C9F, 0x2A2A2 },
	{ 0xE58CA0, 0x1C7CC },
	{ 0xE58CA1, 0x1C7CB },
	{ 0xE58CA2, 0x2A2A1 },
	{ 0xE58CA3, 0x1C9BA },
	{ 0xE58CA4, 0x3E4D0 },
	{ 0xE58CA5, 0x3A4E5 },
	{ 0xE58CA7, 0x3ABC9 },
	{ 0xE58CA8, 0x4A8CE },
	{ 0xE58CA9, 0x4A8D0 },
	{ 0xE58CAA, 0x1D4CD },
	{ 0xE58CAB, 0x4ABF8 },
	{ 0xE58CAC, 0x4B0DF },
	{ 0xE58CAD, 0x2B3F2 },
	{ 0xE58CAF, 0x1E3BE },
	{ 0xE58CB0, 0x2C9AC },
	{ 0xE58CB1, 0x1E8A4 },
	{ 0xE58CB2, 0x3C6A3 },
	{ 0xE58CB3, 0x3CBB4 },
	{ 0xE58CB4, 0x2D6C5 },
	{ 0xE58CB5, 0x3D4C4 },
	{ 0xE58CB6, 0x3DCB4 },
	{ 0xE58CB7, 0x2E8EA },
	{ 0xE58CB8, 0x3A1A9 },
	{ 0xE58CB9, 0x1C5A8 },
	{ 0xE58CBA, 0x3A1D7 },
	{ 0xE58CBB, 0x3A4E6 },
	{ 0xE58CBC, 0x2A5D8 },
	{ 0xE58CBD, 0x2A9B6 },
	{ 0xE58CBE, 0x1D9B5 },
	{ 0xE58CBF, 0x1D9B3 },
	{ 0xE58D80, 0x1D9B4 },
	{ 0xE58D81, 0x1C4B2 },
	{ 0xE58D82, 0x4A1B0 },
	{ 0xE58D83, 0x1C4C5 },
	{ 0xE58D84, 0x1A4BF },
	{ 0xE58D84, 0x3A1B8 },
	{ 0xE58D85, 0x1C5AB },
	{ 0xE58D86, 0x3A1D9 },
	{ 0xE58D87, 0x1C5AA },
	{ 0xE58D88, 0x1C5A9 },
	{ 0xE58D89, 0x1C6A5 },
	{ 0xE58D8A, 0x1C6A4 },
	{ 0xE58D8B, 0x3A3AA },
	{ 0xE58D8C, 0x2A1CE },
	{ 0xE58D8D, 0x2A2A3 },
	{ 0xE58D8E, 0xFA2AC },
	{ 0xE58D8F, 0x3A3AB },
	{ 0xE58D90, 0x3A3AD },
	{ 0xE58D91, 0x1CCB8 },
	{ 0xE58D92, 0x1CCB5 },
	{ 0xE58D93, 0x1CCB7 },
	{ 0xE58D94, 0x1CCB6 },
	{ 0xE58D95, 0x3A7E3 },
	{ 0xE58D97, 0x1D0B2 },
	{ 0xE58D98, 0x3ABCA },
	{ 0xE58D99, 0x4B0E0 },
	{ 0xE58D9A, 0x1DEBB },
	{ 0xE58D9B, 0x4E6B0 },
	{ 0xE58D9C, 0x1C4B3 },
	{ 0xE58D9D, 0x3A1DA },
	{ 0xE58D9E, 0x1C5AC },
	{ 0xE58D9F, 0x3A2A7 },
	{ 0xE58DA0, 0x1C6A7 },
	{ 0xE58DA1, 0x1C6A6 },
	{ 0xE58DA3, 0x2A3B4 },
	{ 0xE58DA4, 0x4A3CD },
	{ 0xE58DA5, 0x3E4D1 },
	{ 0xE58DA6, 0x1CCB9 },
	{ 0xE58DA7, 0x3AADC },
	{ 0xE58DA8, 0x4B0E4 },
	{ 0xE58DA9, 0x3A1AA },
	{ 0xE58DAA, 0x4A1B1 },
	{ 0xE58DAC, 0x2A1B7 },
	{ 0xE58DAD, 0x3A2A8 },
	{ 0xE58DAE, 0x1C6A9 },
	{ 0xE58DAF, 0x1C6A8 },
	{ 0xE58DB0, 0x1C7CD },
	{ 0xE58DB1, 0x1C7CE },
	{ 0xE58DB2, 0x2A3B5 },
	{ 0xE58DB3, 0x1C9BB },
	{ 0xE58DB4, 0x3A4E7 },
	{ 0xE58DB5, 0x1C9BC },
	{ 0xE58DB6, 0x3A7E5 },
	{ 0xE58DB7, 0x1CCBA },
	{ 0xE58DB8, 0x1CCBB },
	{ 0xE58DB9, 0x1CCBC },
	{ 0xE58DBA, 0x3A7E6 },
	{ 0xE58DBB, 0x1D0B3 },
	{ 0xE58DBC, 0x2A9B7 },
	{ 0xE58DBD, 0x3ABCB },
	{ 0xE58DBE, 0x4B0E5 },
	{ 0xE58DBF, 0x1D4CE },
	{ 0xE58E80, 0x3C0C7 },
	{ 0xE58E82, 0x2A1A5 },
	{ 0xE58E83, 0x4A1C4 },
	{ 0xE58E84, 0x1C5AD },
	{ 0xE58E86, 0x3A1DB },
	{ 0xE58E87, 0x4A1E7 },
	{ 0xE58E88, 0x4A1E6 },
	{ 0xE58E89, 0x3A2A9 },
	{ 0xE58E8A, 0x2A2A4 },
	{ 0xE58E8B, 0x3A3AF },
	{ 0xE58E8E, 0x2A3B6 },
	{ 0xE58E8F, 0x2A3B7 },
	{ 0xE58E92, 0x2A5D9 },
	{ 0xE58E93, 0x3A7E7 },
	{ 0xE58E94, 0x2A5DA },
	{ 0xE58E96, 0x2A9B9 },
	{ 0xE58E97, 0x2A9B8 },
	{ 0xE58E98, 0x2A9BB },
	{ 0xE58E99, 0x2A9BA },
	{ 0xE58E9A, 0x1D0B4 },
	{ 0xE58E9B, 0x3E4D2 },
	{ 0xE58E9C, 0x2B3F3 },
	{ 0xE58E9D, 0x1D4D0 },
	{ 0xE58E9E, 0x2AEB2 },
	{ 0xE58E9F, 0x1D4CF },
	{ 0xE58EA0, 0x3B4D4 },
	{ 0xE58EA1, 0x4B0E8 },
	{ 0xE58EA4, 0x2BAC8 },
	{ 0xE58EA5, 0x1DEBC },
	{ 0xE58EA6, 0x3BAA8 },
	{ 0xE58EA7, 0x2BAC9 },
	{ 0xE58EA8, 0x3BAA7 },
	{ 0xE58EA9, 0x3C0CA },
	{ 0xE58EAA, 0x3C0C9 },
	{ 0xE58EAB, 0x3C0C8 },
	{ 0xE58EAC, 0x2C9AD },
	{ 0xE58EAD, 0x1E8A5 },
	{ 0xE58EAE, 0x3C6A5 },
	{ 0xE58EAF, 0x4BCC0 },
	{ 0xE58EB0, 0x3C6A6 },
	{ 0xE58EB1, 0x3CBB5 },
	{ 0xE58EB2, 0x1ECB0 },
	{ 0xE58EB3, 0x3D4C5 },
	{ 0xE58EB4, 0x2E5BB },
	{ 0xE58EB5, 0xFEDAE },
	{ 0xE58EB6, 0x3A1AB },
	{ 0xE58EB7, 0x3A1DC },
	{ 0xE58EB8, 0x4A1C5 },
	{ 0xE58EB9, 0x2A1B8 },
	{ 0xE58EBA, 0x3A2AA },
	{ 0xE58EBB, 0x1C6AA },
	{ 0xE58EBD, 0x4A2C8 },
	{ 0xE58EBE, 0x3A3B1 },
	{ 0xE58F80, 0x4A5D9 },
	{ 0xE58F81, 0x3A7E9 },
	{ 0xE58F82, 0x3A7EA },
	{ 0xE58F83, 0x1D9B6 },
	{ 0xE58F84, 0x3B4D5 },
	{ 0xE58F85, 0x3BAA9 },
	{ 0xE58F88, 0x1C4B4 },
	{ 0xE58F89, 0x1C4C6 },
	{ 0xE58F8A, 0x1C5AF },
	{ 0xE58F8B, 0x1C5AE },
	{ 0xE58F8C, 0x3A1DE },
	{ 0xE58F8D, 0x1C5B0 },
	{ 0xE58F8E, 0x3A1E0 },
	{ 0xE58F8F, 0x4A1E9 },
	{ 0xE58F90, 0x3A2AB },
	{ 0xE58F92, 0x3A3B3 },
	{ 0xE58F93, 0x4A3CF },
	{ 0xE58F94, 0x1CCBE },
	{ 0xE58F95, 0x3A7EB },
	{ 0xE58F96, 0x1CCBD },
	{ 0xE58F97, 0x1CCBF },
	{ 0xE58F99, 0x3ABD0 },
	{ 0xE58F9A, 0x3ABCF },
	{ 0xE58F9B, 0x1D0B5 },
	{ 0xE58F9C, 0x3ABCE },
	{ 0xE58F9D, 0x3ABCD },
	{ 0xE58F9E, 0x6B5F8 },
	{ 0xE58F9F, 0x1D4D1 },
	{ 0xE58FA0, 0x3C0CB },
	{ 0xE58FA1, 0x2D6C6 },
	{ 0xE58FA2, 0x1F6BB },
	{ 0xE58FA3, 0x1C4C7 },
	{ 0xE58FA4, 0x1C6AC },
	{ 0xE58FA5, 0x1C6BB },
	{ 0xE58FA6, 0x1C6B6 },
	{ 0xE58FA7, 0x4A1EC },
	{ 0xE58FA8, 0x1C6B1 },
	{ 0xE58FA9, 0x1C6B0 },
	{ 0xE58FAA, 0x1C6B7 },
	{ 0xE58FAB, 0x1C6B5 },
	{ 0xE58FAC, 0x1C6AE },
	{ 0xE58FAD, 0x1C6BC },
	{ 0xE58FAE, 0x1C6AF },
	{ 0xE58FAF, 0x1C6AB },
	{ 0xE58FB0, 0x1C6BA },
	{ 0xE58FB1, 0x1C6B9 },
	{ 0xE58FB2, 0x1C6B8 },
	{ 0xE58FB3, 0x1C6AD },
	{ 0xE58FB4, 0x3A2B1 },
	{ 0xE58FB5, 0x1C6B4 },
	{ 0xE58FB6, 0x3A2AD },
	{ 0xE58FB7, 0x3A2AE },
	{ 0xE58FB8, 0x1C6B3 },
	{ 0xE58FB9, 0x3A2AF },
	{ 0xE58FBA, 0xFA1D0 },
	{ 0xE58FBB, 0x1C6BD },
	{ 0xE58FBC, 0x1C6B2 },
	{ 0xE58FBD, 0x4A1EA },
	{ 0xE58FBF, 0x3A3B5 },
	{ 0xE59080, 0x3A3B7 },
	{ 0xE59081, 0x1C7D4 },
	{ 0xE59082, 0x4A2CC },
	{ 0xE59083, 0x1C7DA },
	{ 0xE59084, 0x1C7D6 },
	{ 0xE59085, 0x3A3B9 },
	{ 0xE59086, 0x1C7DC },
	{ 0xE59087, 0x2A2A5 },
	{ 0xE59088, 0x1C7D9 },
	{ 0xE59089, 0x1C7CF },
	{ 0xE5908A, 0x1C7D2 },
	{ 0xE5908B, 0x1C7D5 },
	{ 0xE5908C, 0x1C7D1 },
	{ 0xE5908D, 0x1C7D8 },
	{ 0xE5908E, 0x1C7DB },
	{ 0xE5908F, 0x1C7D0 },
	{ 0xE59090, 0x1C7D3 },
	{ 0xE59091, 0x1C7D7 },
	{ 0xE59092, 0x1C7DD },
	{ 0xE59093, 0x3A3BA },
	{ 0xE59095, 0x3A3BB },
	{ 0xE59096, 0x3A3B4 },
	{ 0xE59098, 0x2A3C0 },
	{ 0xE59099, 0x2A3BD },
	{ 0xE5909A, 0x3A4F6 },
	{ 0xE5909B, 0x1C9C9 },
	{ 0xE5909C, 0x2A3BE },
	{ 0xE5909D, 0x1C9BD },
	{ 0xE5909E, 0x1C9BF },
	{ 0xE5909F, 0x1C9D7 },
	{ 0xE590A0, 0x1C9D2 },
	{ 0xE590A1, 0x3A4F9 },
	{ 0xE590A2, 0x3A4FE },
	{ 0xE590A3, 0x3A4F5 },
	{ 0xE590A4, 0x2A3C5 },
	{ 0xE590A5, 0x2A3BF },
	{ 0xE590A6, 0x1C9C1 },
	{ 0xE590A7, 0x1C9C3 },
	{ 0xE590A8, 0x2A3C4 },
	{ 0xE590A9, 0x1C9CA },
	{ 0xE590AA, 0x2A3BA },
	{ 0xE590AB, 0x1C9D6 },
	{ 0xE590AC, 0x1C9D8 },
	{ 0xE590AD, 0x1C9BE },
	{ 0xE590AE, 0x1C9CF },
	{ 0xE590AF, 0x3A5A4 },
	{ 0xE590B0, 0x2A3B8 },
	{ 0xE590B1, 0x1C9D5 },
	{ 0xE590B2, 0x3A4F7 },
	{ 0xE590B3, 0x1C9C6 },
	{ 0xE590B4, 0x3A4FB },
	{ 0xE590B5, 0x1C9D0 },
	{ 0xE590B6, 0x1C9D1 },
	{ 0xE590B7, 0x2A3B9 },
	{ 0xE590B8, 0x1C9CE },
	{ 0xE590B9, 0x1C9CC },
	{ 0xE590BA, 0x3A4F0 },
	{ 0xE590BB, 0x1C9CD },
	{ 0xE590BC, 0x1C9D3 },
	{ 0xE590BD, 0x2A3C1 },
	{ 0xE590BE, 0x1C9C0 },
	{ 0xE590BF, 0x3A5A1 },
	{ 0xE59180, 0x1C9D4 },
	{ 0xE59181, 0x2A3C3 },
	{ 0xE59182, 0x1C9C8 },
	{ 0xE59183, 0x1C9C5 },
	{ 0xE59184, 0x3A4F3 },
	{ 0xE59185, 0x2A3BC },
	{ 0xE59186, 0x1C9C4 },
	{ 0xE59187, 0x2A3C6 },
	{ 0xE59188, 0x1C9C7 },
	{ 0xE59189, 0x3A4FC },
	{ 0xE5918A, 0x1C9CB },
	{ 0xE5918B, 0x3A4F8 },
	{ 0xE5918C, 0x3A4F4 },
	{ 0xE5918D, 0x3A4ED },
	{ 0xE5918E, 0x1C9C2 },
	{ 0xE5918F, 0x2A3C2 },
	{ 0xE59190, 0x3A4FD },
	{ 0xE59191, 0x3A5A2 },
	{ 0xE59194, 0x2A3BB },
	{ 0xE5919A, 0x3A5A3 },
	{ 0xE5919D, 0x4A5E4 },
	{ 0xE5919E, 0x4A5E3 },
	{ 0xE5919F, 0x3A7EE },
	{ 0xE591A0, 0x2A5EB },
	{ 0xE591A1, 0x2A5EA },
	{ 0xE591A2, 0x1CCD1 },
	{ 0xE591A3, 0x2A5ED },
	{ 0xE591A4, 0x2A5EF },
	{ 0xE591A5, 0x2A5E4 },
	{ 0xE591A6, 0x2A5E7 },
	{ 0xE591A7, 0x2A5EE },
	{ 0xE591A8, 0x1CCD2 },
	{ 0xE591A9, 0x3A7F4 },
	{ 0xE591AA, 0x3A7F8 },
	{ 0xE591AB, 0x2A5E1 },
	{ 0xE591AC, 0x2A5E5 },
	{ 0xE591AD, 0x3A7F5 },
	{ 0xE591AE, 0x4A5DF },
	{ 0xE591AF, 0x2A5E9 },
	{ 0xE591B0, 0x2A9CA },
	{ 0xE591B1, 0x1CCCD },
	{ 0xE591B2, 0x2A9CE },
	{ 0xE591B3, 0x1CCC0 },
	{ 0xE591B4, 0x2A5E6 },
	{ 0xE591B5, 0x1CCC1 },
	{ 0xE591B6, 0x1CCCE },
	{ 0xE591B7, 0x1CCC7 },
	{ 0xE591B8, 0x1CCC3 },
	{ 0xE591B9, 0x3A7F1 },
	{ 0xE591BA, 0x2A5E2 },
	{ 0xE591BB, 0x1CCC6 },
	{ 0xE591BC, 0x1CCCB },
	{ 0xE591BD, 0x1CCD4 },
	{ 0xE591BE, 0x2A5E3 },
	{ 0xE591BF, 0x2A5DC },
	{ 0xE59280, 0x1CCC5 },
	{ 0xE59281, 0x2A5DD },
	{ 0xE59282, 0x2A5DF },
	{ 0xE59283, 0x4A5E0 },
	{ 0xE59284, 0x1CCC8 },
	{ 0xE59285, 0x3A7EC },
	{ 0xE59286, 0x1CCCA },
	{ 0xE59287, 0x2A5DB },
	{ 0xE59288, 0x2A5E0 },
	{ 0xE59289, 0x3A7F0 },
	{ 0xE5928A, 0x3A7F9 },
	{ 0xE5928B, 0x1CCD3 },
	{ 0xE5928C, 0x1CCCF },
	{ 0xE5928D, 0x2A5E8 },
	{ 0xE5928E, 0x1CCD5 },
	{ 0xE5928F, 0x3A7F3 },
	{ 0xE59290, 0x1CCCC },
	{ 0xE59291, 0x2A5DE },
	{ 0xE59292, 0x1CCC9 },
	{ 0xE59293, 0x3A7EF },
	{ 0xE59294, 0x3A7F7 },
	{ 0xE59295, 0x1CCC4 },
	{ 0xE59296, 0x1CCC2 },
	{ 0xE59298, 0x2A5EC },
	{ 0xE5929A, 0x1CCD0 },
	{ 0xE5929C, 0xFA5F1 },
	{ 0xE5929E, 0x3ABDC },
	{ 0xE5929F, 0x3ABDD },
	{ 0xE592A0, 0x2A9C9 },
	{ 0xE592A1, 0x2A9BD },
	{ 0xE592A2, 0x2A9CC },
	{ 0xE592A3, 0x3ABD7 },
	{ 0xE592A4, 0x3ABD9 },
	{ 0xE592A5, 0x2A9BF },
	{ 0xE592A6, 0x1D0BC },
	{ 0xE592A7, 0x1D0CA },
	{ 0xE592A8, 0x1D0B8 },
	{ 0xE592A9, 0x1D0C9 },
	{ 0xE592AA, 0x1D0C1 },
	{ 0xE592AB, 0x1D0C6 },
	{ 0xE592AC, 0x1D0B6 },
	{ 0xE592AD, 0x2A9BE },
	{ 0xE592AE, 0x2A9C4 },
	{ 0xE592AF, 0x1D0C5 },
	{ 0xE592B0, 0x2A9D0 },
	{ 0xE592B1, 0x1D0C7 },
	{ 0xE592B2, 0x3ABDB },
	{ 0xE592B3, 0x1D0BD },
	{ 0xE592B4, 0x3ABD4 },
	{ 0xE592B5, 0x3ABDE },
	{ 0xE592B6, 0x2A9C6 },
	{ 0xE592B7, 0x2A9C3 },
	{ 0xE592B8, 0x1D0BB },
	{ 0xE592B9, 0x3ABD1 },
	{ 0xE592BA, 0x2A9BC },
	{ 0xE592BB, 0x1D0C8 },
	{ 0xE592BC, 0x2A9CB },
	{ 0xE592BD, 0x1D0C0 },
	{ 0xE592BE, 0x2A9CD },
	{ 0xE592BF, 0x1D0CB },
	{ 0xE59380, 0x1D0B7 },
	{ 0xE59381, 0x1D0C2 },
	{ 0xE59382, 0x1D0BF },
	{ 0xE59383, 0x2A9C1 },
	{ 0xE59384, 0x1D0C3 },
	{ 0xE59385, 0x2A9C7 },
	{ 0xE59386, 0x2A9C8 },
	{ 0xE59387, 0x1D0BE },
	{ 0xE59388, 0x1D0C4 },
	{ 0xE59389, 0x1D0BA },
	{ 0xE5938A, 0x3ABD5 },
	{ 0xE5938B, 0x3E4D4 },
	{ 0xE5938C, 0x3ABE3 },
	{ 0xE5938D, 0x3ABE1 },
	{ 0xE5938E, 0x1D0B9 },
	{ 0xE5938F, 0x2A9C0 },
	{ 0xE59390, 0x3ABD3 },
	{ 0xE59396, 0x2A9C5 },
	{ 0xE5939A, 0x3ABD8 },
	{ 0xE5939E, 0x2A9CF },
	{ 0xE593A0, 0x2AEC6 },
	{ 0xE593A1, 0x1D4DE },
	{ 0xE593A2, 0x2AEB4 },
	{ 0xE593A3, 0x4ACAD },
	{ 0xE593A4, 0x2AEB9 },
	{ 0xE593A5, 0x1D4D7 },
	{ 0xE593A6, 0x1D4E2 },
	{ 0xE593A7, 0x2AEB7 },
	{ 0xE593A8, 0x1D4D2 },
	{ 0xE593A9, 0x1D4DC },
	{ 0xE593AA, 0x1D4E1 },
	{ 0xE593AB, 0x2AEBE },
	{ 0xE593AC, 0x4ACA6 },
	{ 0xE593AD, 0x1D4DD },
	{ 0xE593AE, 0x1D4E0 },
	{ 0xE593AF, 0x3AFF7 },
	{ 0xE593B0, 0x3B0A1 },
	{ 0xE593B1, 0x2AEC1 },
	{ 0xE593B2, 0x1D4D8 },
	{ 0xE593B3, 0x2AEB8 },
	{ 0xE593B4, 0x3AFF4 },
	{ 0xE593B5, 0x3AFF8 },
	{ 0xE593B6, 0x3B0A2 },
	{ 0xE593B7, 0x2AEC4 },
	{ 0xE593B8, 0x2AEC5 },
	{ 0xE593B9, 0x3AFF9 },
	{ 0xE593BA, 0x1D4DA },
	{ 0xE593BB, 0x2AEC3 },
	{ 0xE593BC, 0x1D4D6 },
	{ 0xE593BD, 0x1D4E5 },
	{ 0xE593BE, 0x4ACA9 },
	{ 0xE593BF, 0x2AEBB },
	{ 0xE59480, 0x3AFFB },
	{ 0xE59481, 0x1D4D4 },
	{ 0xE59482, 0x3AFFA },
	{ 0xE59483, 0x2AEC8 },
	{ 0xE59484, 0x2AEBC },
	{ 0xE59485, 0x2AEC0 },
	{ 0xE59486, 0x1D4D9 },
	{ 0xE59487, 0x1D4E4 },
	{ 0xE59488, 0x2AEBD },
	{ 0xE59489, 0x1D4DF },
	{ 0xE5948A, 0x2AEC2 },
	{ 0xE5948B, 0x2AEC9 },
	{ 0xE5948C, 0x2B4A4 },
	{ 0xE5948D, 0x3AFF3 },
	{ 0xE5948E, 0x2AEC7 },
	{ 0xE5948F, 0x1D4E6 },
	{ 0xE59490, 0x1D4D3 },
	{ 0xE59491, 0x2AEBF },
	{ 0xE59492, 0x2AEB6 },
	{ 0xE59493, 0x3AFF6 },
	{ 0xE59494, 0x1D4DB },
	{ 0xE59495, 0x4ACA8 },
	{ 0xE59496, 0x4ACAE },
	{ 0xE59497, 0x2AEB5 },
	{ 0xE59498, 0x3AFFE },
	{ 0xE59499, 0x3B0A5 },
	{ 0xE5949A, 0x2AEBA },
	{ 0xE5949B, 0xFA9D4 },
	{ 0xE594A0, 0xFAEC2 },
	{ 0xE594A1, 0xFAECA },
	{ 0xE594A6, 0x2AEB3 },
	{ 0xE594A7, 0x1D4E3 },
	{ 0xE594A8, 0x3E7A1 },
	{ 0xE594A9, 0x3B4DF },
	{ 0xE594AA, 0x2B3FA },
	{ 0xE594AB, 0x3B4E8 },
	{ 0xE594AC, 0x1D9C9 },
	{ 0xE594AD, 0x2B4AA },
	{ 0xE594AE, 0x1D9C7 },
	{ 0xE594AF, 0x1D9C4 },
	{ 0xE594B0, 0x2B4A1 },
	{ 0xE594B1, 0x1D9C0 },
	{ 0xE594B2, 0x2B4A5 },
	{ 0xE594B3, 0x1D9CB },
	{ 0xE594B4, 0x2B3F9 },
	{ 0xE594B5, 0x2B3FE },
	{ 0xE594B6, 0x2B3FD },
	{ 0xE594B7, 0x1D4D5 },
	{ 0xE594B8, 0x1D9C6 },
	{ 0xE594B9, 0x2B4A8 },
	{ 0xE594BA, 0x3B4E6 },
	{ 0xE594BB, 0x2B4AB },
	{ 0xE594BC, 0x2B3F6 },
	{ 0xE594BD, 0x4B0F7 },
	{ 0xE594BE, 0x1DECE },
	{ 0xE594BF, 0x3B4E7 },
	{ 0xE59580, 0x2B4AC },
	{ 0xE59581, 0x1D9CC },
	{ 0xE59582, 0x4B0F2 },
	{ 0xE59583, 0x1D9BE },
	{ 0xE59584, 0x1D9BB },
	{ 0xE59585, 0x2B4A3 },
	{ 0xE59586, 0x1D9B8 },
	{ 0xE59587, 0x4B0F4 },
	{ 0xE59588, 0x2B4A9 },
	{ 0xE59589, 0x3B4DB },
	{ 0xE5958A, 0x1D9BF },
	{ 0xE5958B, 0x2B4AD },
	{ 0xE5958C, 0x3B4D8 },
	{ 0xE5958D, 0x2B3F7 },
	{ 0xE5958E, 0x2B4A7 },
	{ 0xE5958F, 0x1D9C2 },
	{ 0xE59590, 0x2B3F8 },
	{ 0xE59591, 0x2B3FB },
	{ 0xE59592, 0x2B4A2 },
	{ 0xE59593, 0x3B4E2 },
	{ 0xE59594, 0x3B4E1 },
	{ 0xE59595, 0x1D9C3 },
	{ 0xE59596, 0x1D9C1 },
	{ 0xE59597, 0x1D9CD },
	{ 0xE59598, 0x3B4D7 },
	{ 0xE59599, 0x3BAB6 },
	{ 0xE5959A, 0x3B4E4 },
	{ 0xE5959B, 0x4B0EB },
	{ 0xE5959C, 0x1D9C8 },
	{ 0xE5959D, 0x3B4DE },
	{ 0xE5959E, 0x1D9BC },
	{ 0xE5959F, 0x1DAF6 },
	{ 0xE595A0, 0x4B0FA },
	{ 0xE595A1, 0x1D9BD },
	{ 0xE595A2, 0x2B3FC },
	{ 0xE595A3, 0x1D9CA },
	{ 0xE595A4, 0x1D9C5 },
	{ 0xE595A5, 0x2B4A6 },
	{ 0xE595A6, 0x1D9BA },
	{ 0xE595A8, 0x3B4D9 },
	{ 0xE595AA, 0x1D9B9 },
	{ 0xE595AB, 0x3E4D7 },
	{ 0xE595B1, 0x3E4D6 },
	{ 0xE595B2, 0x3E7A2 },
	{ 0xE595B3, 0x3E4D5 },
	{ 0xE595B5, 0x2B3F4 },
	{ 0xE595B6, 0x2B3F5 },
	{ 0xE595B7, 0x2BACE },
	{ 0xE595BA, 0x3BABC },
	{ 0xE595BB, 0x1DEBD },
	{ 0xE595BC, 0x1DEC0 },
	{ 0xE595BD, 0x2BAD9 },
	{ 0xE595BE, 0x1DED4 },
	{ 0xE595BF, 0x2BADC },
	{ 0xE59680, 0x1DEBE },
	{ 0xE59681, 0x2BAD5 },
	{ 0xE59682, 0x1DEC4 },
	{ 0xE59683, 0x1DECA },
	{ 0xE59684, 0x1E1C3 },
	{ 0xE59685, 0x3BAB1 },
	{ 0xE59686, 0x3BAB8 },
	{ 0xE59687, 0x1DEC8 },
	{ 0xE59688, 0x2BAD2 },
	{ 0xE59689, 0x1DED5 },
	{ 0xE5968A, 0x1DEC1 },
	{ 0xE5968B, 0x1DEC9 },
	{ 0xE5968C, 0x2BADA },
	{ 0xE5968D, 0x2C1FC },
	{ 0xE5968E, 0x2BADF },
	{ 0xE5968F, 0x2BAD3 },
	{ 0xE59690, 0x4B6DC },
	{ 0xE59691, 0x2BACA },
	{ 0xE59692, 0x2BAD7 },
	{ 0xE59693, 0x2BAD1 },
	{ 0xE59694, 0x1DEC7 },
	{ 0xE59695, 0x2BADD },
	{ 0xE59696, 0x3BAAE },
	{ 0xE59697, 0x3BAAA },
	{ 0xE59698, 0x1DEC3 },
	{ 0xE59699, 0x1DED7 },
	{ 0xE5969A, 0x1DED0 },
	{ 0xE5969B, 0x3BAB3 },
	{ 0xE5969C, 0x1DEC5 },
	{ 0xE5969D, 0x1DEC2 },
	{ 0xE5969E, 0x3BAC0 },
	{ 0xE5969F, 0x1DECD },
	{ 0xE596A0, 0x3BAB4 },
	{ 0xE596A1, 0x2BADE },
	{ 0xE596A2, 0x2BAD0 },
	{ 0xE596A3, 0x2BAD6 },
	{ 0xE596A4, 0x2BAD8 },
	{ 0xE596A5, 0x2BACC },
	{ 0xE596A6, 0x2BADB },
	{ 0xE596A7, 0x1DEBF },
	{ 0xE596A8, 0x2BACB },
	{ 0xE596A9, 0x3BAC2 },
	{ 0xE596AA, 0x1DEC6 },
	{ 0xE596AB, 0x1DED6 },
	{ 0xE596AC, 0x1DED2 },
	{ 0xE596AD, 0x2BACD },
	{ 0xE596AE, 0x1DECC },
	{ 0xE596AF, 0x3BABB },
	{ 0xE596B0, 0xFB9F1 },
	{ 0xE596B1, 0x1DED3 },
	{ 0xE596B2, 0x1DECF },
	{ 0xE596B3, 0x1DECB },
	{ 0xE596B4, 0x3BAAF },
	{ 0xE596B5, 0x2BAD4 },
	{ 0xE596B6, 0x6C7A9 },
	{ 0xE596BA, 0x3E7A3 },
	{ 0xE596BB, 0x1DED1 },
	{ 0xE596BF, 0x2C1FA },
	{ 0xE59780, 0x2C1F6 },
	{ 0xE59781, 0x3C0D1 },
	{ 0xE59782, 0x2C2A7 },
	{ 0xE59783, 0x2C1EF },
	{ 0xE59784, 0x2C1F8 },
	{ 0xE59785, 0x1E3CC },
	{ 0xE59786, 0x1E3CD },
	{ 0xE59787, 0x1E3C5 },
	{ 0xE59788, 0x2C2A3 },
	{ 0xE59789, 0x1E3CF },
	{ 0xE5978A, 0x2C1F4 },
	{ 0xE5978B, 0x2C1F3 },
	{ 0xE5978C, 0x2C1F1 },
	{ 0xE5978D, 0x2C2A5 },
	{ 0xE5978E, 0x1E3C3 },
	{ 0xE5978F, 0x2C1FD },
	{ 0xE59790, 0x2C1F2 },
	{ 0xE59791, 0x1E3C6 },
	{ 0xE59792, 0x2C1FB },
	{ 0xE59793, 0x1E3C1 },
	{ 0xE59794, 0x2C1F7 },
	{ 0xE59795, 0x2C1FE },
	{ 0xE59796, 0x2C2A2 },
	{ 0xE59797, 0x3C0CE },
	{ 0xE59798, 0x4BCCB },
	{ 0xE59799, 0x2C2A6 },
	{ 0xE5979A, 0x1E3CA },
	{ 0xE5979B, 0x2C1F0 },
	{ 0xE5979C, 0x1E3C4 },
	{ 0xE5979D, 0x2C1F5 },
	{ 0xE5979E, 0x3BAAB },
	{ 0xE5979F, 0x1E3BF },
	{ 0xE597A0, 0x6D1C3 },
	{ 0xE597A1, 0x1E3CB },
	{ 0xE597A2, 0x2C2A1 },
	{ 0xE597A3, 0x1E3C7 },
	{ 0xE597A4, 0x1E3C8 },
	{ 0xE597A5, 0x1E3CE },
	{ 0xE597A6, 0x1E3C2 },
	{ 0xE597A7, 0x1A3A1 },
	{ 0xE597A8, 0x1E3C0 },
	{ 0xE597A9, 0x2C1F9 },
	{ 0xE597AA, 0x3C0CC },
	{ 0xE597AE, 0x3E7A5 },
	{ 0xE597AF, 0x1E3C9 },
	{ 0xE597B0, 0x3E7A4 },
	{ 0xE597B1, 0xFC0E2 },
	{ 0xE597B2, 0x2C2A4 },
	{ 0xE597B4, 0x3E4D8 },
	{ 0xE597B6, 0x1E8B5 },
	{ 0xE597B7, 0x1E8B0 },
	{ 0xE597B8, 0x3C6AE },
	{ 0xE597B9, 0x2C9BC },
	{ 0xE597BA, 0x2C9B8 },
	{ 0xE597BB, 0x3C6A8 },
	{ 0xE597BC, 0x2C9B2 },
	{ 0xE597BD, 0x1E8AA },
	{ 0xE597BE, 0x1E8A6 },
	{ 0xE597BF, 0x2C9BB },
	{ 0xE59880, 0x1E8A7 },
	{ 0xE59881, 0x2C9B5 },
	{ 0xE59882, 0x2C9B7 },
	{ 0xE59883, 0x3C6A9 },
	{ 0xE59884, 0x2C9BA },
	{ 0xE59885, 0x3C6B6 },
	{ 0xE59886, 0x1E8AC },
	{ 0xE59887, 0x3C6AC },
	{ 0xE59888, 0x1E8B3 },
	{ 0xE59889, 0x1E8AD },
	{ 0xE5988A, 0x4C2D7 },
	{ 0xE5988B, 0x3C6AA },
	{ 0xE5988C, 0x2C9B0 },
	{ 0xE5988D, 0x1E8AE },
	{ 0xE5988E, 0x1E8AF },
	{ 0xE5988F, 0x2C9B3 },
	{ 0xE59890, 0x1E8B4 },
	{ 0xE59891, 0x3C6B4 },
	{ 0xE59892, 0x2C9B1 },
	{ 0xE59893, 0x2C9B6 },
	{ 0xE59894, 0x1E8AB },
	{ 0xE59895, 0x2C9AF },
	{ 0xE59896, 0x1E8B1 },
	{ 0xE59897, 0x1E8A9 },
	{ 0xE59898, 0x3C6B3 },
	{ 0xE59899, 0x4C2CB },
	{ 0xE5989B, 0x1E8A8 },
	{ 0xE5989C, 0x2C9B4 },
	{ 0xE5989D, 0x2C9B9 },
	{ 0xE5989E, 0x3C6B1 },
	{ 0xE5989F, 0x1E8B2 },
	{ 0xE598A0, 0x3E4DA },
	{ 0xE598A2, 0x3E4D9 },
	{ 0xE598A6, 0x3C6D0 },
	{ 0xE598A7, 0x2C9AE },
	{ 0xE598A8, 0x3C6B0 },
	{ 0xE598A9, 0x1ECB7 },
	{ 0xE598AA, 0x2CFEE },
	{ 0xE598AB, 0x3CBC1 },
	{ 0xE598AC, 0x2CFEB },
	{ 0xE598AD, 0x3CBB8 },
	{ 0xE598AE, 0x1ECB1 },
	{ 0xE598AF, 0x1ECBD },
	{ 0xE598B0, 0x1ECBE },
	{ 0xE598B1, 0x3CBBD },
	{ 0xE598B2, 0x1ECB4 },
	{ 0xE598B3, 0x2CFE9 },
	{ 0xE598B4, 0x1ECB6 },
	{ 0xE598B5, 0x2CFE1 },
	{ 0xE598B6, 0x1ECBC },
	{ 0xE598B7, 0x3CBC4 },
	{ 0xE598B8, 0x2CFED },
	{ 0xE598B9, 0x1ECB3 },
	{ 0xE598BA, 0x2CFEF },
	{ 0xE598BB, 0x1ECB2 },
	{ 0xE598BC, 0x4C9B1 },
	{ 0xE598BD, 0x2CFEA },
	{ 0xE598BE, 0x2CFEC },
	{ 0xE598BF, 0x1ECB5 },
	{ 0xE59980, 0x2CFE8 },
	{ 0xE59981, 0x2CFE2 },
	{ 0xE59982, 0x2CFDF },
	{ 0xE59983, 0x4C9AE },
	{ 0xE59984, 0x3CBBE },
	{ 0xE59985, 0x2BACF },
	{ 0xE59986, 0x2CFE5 },
	{ 0xE59987, 0x3CBB7 },
	{ 0xE59988, 0x2CFDE },
	{ 0xE59989, 0x2CFE4 },
	{ 0xE5998A, 0x2CFE3 },
	{ 0xE5998B, 0x3CBBB },
	{ 0xE5998C, 0x2CFE0 },
	{ 0xE5998D, 0x3CBC3 },
	{ 0xE5998E, 0x1ECB9 },
	{ 0xE5998F, 0x3CBC5 },
	{ 0xE59990, 0x3CBC0 },
	{ 0xE59991, 0x3C6B5 },
	{ 0xE59992, 0x3CBBC },
	{ 0xE59993, 0x1ECB8 },
	{ 0xE59994, 0x3CBB9 },
	{ 0xE59995, 0x7A1E3 },
	{ 0xE59996, 0x3CBBF },
	{ 0xE59997, 0x1ECBA },
	{ 0xE59998, 0x2CFE6 },
	{ 0xE59999, 0x1F0BB },
	{ 0xE5999A, 0x2CFE7 },
	{ 0xE5999E, 0x2D6CF },
	{ 0xE5999F, 0x3D0BF },
	{ 0xE599A0, 0x2D6C8 },
	{ 0xE599A1, 0x3D0C0 },
	{ 0xE599A2, 0x1F0C7 },
	{ 0xE599A3, 0x2D6CC },
	{ 0xE599A4, 0x1F0BF },
	{ 0xE599A5, 0x1F0C3 },
	{ 0xE599A6, 0x2D6CB },
	{ 0xE599A7, 0x3D0BB },
	{ 0xE599A8, 0x1F0C2 },
	{ 0xE599A9, 0x1F0BE },
	{ 0xE599AA, 0x1F0C1 },
	{ 0xE599AB, 0x1F0BC },
	{ 0xE599AC, 0x1F0C6 },
	{ 0xE599AD, 0x2D6CD },
	{ 0xE599AE, 0x2D6C9 },
	{ 0xE599AF, 0x1F0C5 },
	{ 0xE599B0, 0x2D6C7 },
	{ 0xE599B1, 0x1F0C4 },
	{ 0xE599B2, 0x2D6CE },
	{ 0xE599B3, 0x2D6CA },
	{ 0xE599B4, 0x1ECBB },
	{ 0xE599B5, 0x4CFF1 },
	{ 0xE599B6, 0x1F0C8 },
	{ 0xE599B7, 0x2D6D0 },
	{ 0xE599B8, 0x1F0C0 },
	{ 0xE599B9, 0x1F0BD },
	{ 0xE599BA, 0xFD3DD },
	{ 0xE599BB, 0x3D0BD },
	{ 0xE599BD, 0x3D4C8 },
	{ 0xE599BE, 0x2DCD2 },
	{ 0xE599BF, 0x2DCD4 },
	{ 0xE59A80, 0x1F3C6 },
	{ 0xE59A81, 0x2DCD5 },
	{ 0xE59A82, 0x2DCD3 },
	{ 0xE59A83, 0x2DCD1 },
	{ 0xE59A84, 0x2DCD0 },
	{ 0xE59A85, 0x1F3C8 },
	{ 0xE59A86, 0x2DCCF },
	{ 0xE59A87, 0x1F3C9 },
	{ 0xE59A88, 0x4D5F4 },
	{ 0xE59A89, 0x3D4C9 },
	{ 0xE59A8A, 0x3D4C7 },
	{ 0xE59A8B, 0x4D5F8 },
	{ 0xE59A8C, 0x2DCCD },
	{ 0xE59A8D, 0x2DCCE },
	{ 0xE59A8E, 0x1F3C5 },
	{ 0xE59A8F, 0x1F3CA },
	{ 0xE59A90, 0x1F3C7 },
	{ 0xE59A91, 0x3E4DD },
	{ 0xE59A92, 0x3E4DB },
	{ 0xE59A93, 0x2DCCC },
	{ 0xE59A94, 0x3D7DB },
	{ 0xE59A95, 0x1F6BC },
	{ 0xE59A96, 0x3D7DA },
	{ 0xE59A97, 0x2E1C8 },
	{ 0xE59A98, 0x2E1C6 },
	{ 0xE59A99, 0x2E1CB },
	{ 0xE59A9A, 0x2E1C9 },
	{ 0xE59A9B, 0x3D7D8 },
	{ 0xE59A9C, 0x2E1C7 },
	{ 0xE59A9D, 0x2E1CA },
	{ 0xE59A9E, 0x3D7D9 },
	{ 0xE59A9F, 0x3D7D7 },
	{ 0xE59AA0, 0x3D7DC },
	{ 0xE59AA5, 0x1F8AC },
	{ 0xE59AA6, 0x2E5BE },
	{ 0xE59AA7, 0x2E5BF },
	{ 0xE59AA8, 0x1F8AD },
	{ 0xE59AA9, 0x4DFCD },
	{ 0xE59AAA, 0x2E5C0 },
	{ 0xE59AAB, 0x2E5BC },
	{ 0xE59AAC, 0x2E5C1 },
	{ 0xE59AAD, 0x2E5BD },
	{ 0xE59AAE, 0x1F6BD },
	{ 0xE59AAF, 0x3DAAD },
	{ 0xE59AB0, 0x3E4DE },
	{ 0xE59AB1, 0x4E3B1 },
	{ 0xE59AB2, 0x2E8EB },
	{ 0xE59AB3, 0x2E8ED },
	{ 0xE59AB4, 0x1F9E4 },
	{ 0xE59AB5, 0x2E8EC },
	{ 0xE59AB6, 0x1F9E3 },
	{ 0xE59AB7, 0x1F9E2 },
	{ 0xE59AB8, 0x3E7A6 },
	{ 0xE59AB9, 0x3E7A7 },
	{ 0xE59ABA, 0x3E4DC },
	{ 0xE59ABB, 0x3DEA6 },
	{ 0xE59ABC, 0x1F9E5 },
	{ 0xE59ABD, 0x2EBD3 },
	{ 0xE59ABE, 0x2EBD4 },
	{ 0xE59ABF, 0x4E6B4 },
	{ 0xE59B80, 0x1FAE5 },
	{ 0xE59B81, 0x1FAE4 },
	{ 0xE59B82, 0x1FAE6 },
	{ 0xE59B83, 0x2EBD2 },
	{ 0xE59B84, 0x3E7A8 },
	{ 0xE59B85, 0x2EDC6 },
	{ 0xE59B86, 0x2EDC5 },
	{ 0xE59B87, 0x3DFC0 },
	{ 0xE59B88, 0x1FBD9 },
	{ 0xE59B89, 0x1FBDB },
	{ 0xE59B8A, 0x1FBDA },
	{ 0xE59B8B, 0x2EDC7 },
	{ 0xE59B8C, 0x1FCB4 },
	{ 0xE59B8D, 0x2F0B4 },
	{ 0xE59B8F, 0x4EAC4 },
	{ 0xE59B90, 0x4EAC3 },
	{ 0xE59B91, 0x1FCDD },
	{ 0xE59B92, 0x3E0F1 },
	{ 0xE59B93, 0x2F0B3 },
	{ 0xE59B94, 0x2F0FC },
	{ 0xE59B97, 0x2A1AA },
	{ 0xE59B98, 0x3A1F7 },
	{ 0xE59B99, 0x4A1EF },
	{ 0xE59B9A, 0x1C6BF },
	{ 0xE59B9B, 0x1C6BE },
	{ 0xE59B9C, 0x4A1ED },
	{ 0xE59B9D, 0x1C7E0 },
	{ 0xE59B9E, 0x1C7DF },
	{ 0xE59B9F, 0x2A2A7 },
	{ 0xE59BA0, 0x1C7DE },
	{ 0xE59BA1, 0x2A2A6 },
	{ 0xE59BA3, 0x3A3BE },
	{ 0xE59BA4, 0x1C9DB },
	{ 0xE59BA5, 0x2A3C9 },
	{ 0xE59BA6, 0x3A5AC },
	{ 0xE59BA7, 0x2A3C8 },
	{ 0xE59BA8, 0xFA3D0 },
	{ 0xE59BA9, 0x3A5A6 },
	{ 0xE59BAA, 0x1C9D9 },
	{ 0xE59BAB, 0x1C9DC },
	{ 0xE59BAC, 0x3A5AB },
	{ 0xE59BAD, 0x3A5AA },
	{ 0xE59BAE, 0x2A3C7 },
	{ 0xE59BAF, 0x3A5A9 },
	{ 0xE59BB0, 0x1C9DA },
	{ 0xE59BB1, 0x3A5C8 },
	{ 0xE59BB2, 0x3A5A7 },
	{ 0xE59BB3, 0x3A5A8 },
	{ 0xE59BB6, 0x3A8A2 },
	{ 0xE59BB7, 0x2A5F0 },
	{ 0xE59BB8, 0x3A7FD },
	{ 0xE59BB9, 0x2A5F1 },
	{ 0xE59BBA, 0x1CCD6 },
	{ 0xE59BBB, 0x3A7FC },
	{ 0xE59BBC, 0x3A8A1 },
	{ 0xE59BBD, 0x3A7FB },
	{ 0xE59BBF, 0x1D0CC },
	{ 0xE59C80, 0x3ABE5 },
	{ 0xE59C81, 0x2AECA },
	{ 0xE59C82, 0x2AECB },
	{ 0xE59C83, 0x1D4E7 },
	{ 0xE59C84, 0x1D4E8 },
	{ 0xE59C85, 0x3B0A7 },
	{ 0xE59C87, 0x2B4AF },
	{ 0xE59C88, 0x1D9CE },
	{ 0xE59C89, 0x1D9D0 },
	{ 0xE59C8A, 0x2B4AE },
	{ 0xE59C8B, 0x1D9CF },
	{ 0xE59C8C, 0x2BAE0 },
	{ 0xE59C8D, 0x1DED8 },
	{ 0xE59C8E, 0x3BAC4 },
	{ 0xE59C8F, 0x3BAC3 },
	{ 0xE59C90, 0x4B6E8 },
	{ 0xE59C91, 0x4BCD2 },
	{ 0xE59C92, 0x1E3D0 },
	{ 0xE59C93, 0x1E3D1 },
	{ 0xE59C94, 0x2C2A8 },
	{ 0xE59C95, 0x3C0D2 },
	{ 0xE59C96, 0x1E8B7 },
	{ 0xE59C97, 0x3C6B7 },
	{ 0xE59C98, 0x1E8B6 },
	{ 0xE59C9A, 0x2CFF0 },
	{ 0xE59C9B, 0x2D6D2 },
	{ 0xE59C9C, 0x2D6D1 },
	{ 0xE59C9D, 0x3DFC1 },
	{ 0xE59C9E, 0x2F1DA },
	{ 0xE59C9F, 0x1C4C8 },
	{ 0xE59CA0, 0x2A1B9 },
	{ 0xE59CA1, 0x3A1E1 },
	{ 0xE59CA2, 0x2A1CF },
	{ 0xE59CA3, 0x2A1D0 },
	{ 0xE59CA4, 0x3A2B4 },
	{ 0xE59CA5, 0x4A1F0 },
	{ 0xE59CA7, 0x4A1F1 },
	{ 0xE59CA8, 0x1C7E3 },
	{ 0xE59CA9, 0x1C7E7 },
	{ 0xE59CAA, 0x2A2A9 },
	{ 0xE59CAB, 0x4A2D1 },
	{ 0xE59CAC, 0x1C7E5 },
	{ 0xE59CAD, 0x1C7E4 },
	{ 0xE59CAE, 0x2A2A8 },
	{ 0xE59CAF, 0x1C7E6 },
	{ 0xE59CB0, 0x1C7E2 },
	{ 0xE59CB1, 0x3A3C1 },
	{ 0xE59CB2, 0x3A3C2 },
	{ 0xE59CB3, 0x1C7E1 },
	{ 0xE59CB4, 0x2A2AA },
	{ 0xE59CB5, 0x3A3BF },
	{ 0xE59CB6, 0x3A3C0 },
	{ 0xE59CBB, 0x1C9E6 },
	{ 0xE59CBC, 0x3A5B1 },
	{ 0xE59CBD, 0x3A5BE },
	{ 0xE59CBE, 0x1C9E3 },
	{ 0xE59CBF, 0x3A5B0 },
	{ 0xE59D80, 0x1C9DF },
	{ 0xE59D81, 0x2A3CA },
	{ 0xE59D82, 0x3A5C0 },
	{ 0xE59D83, 0x3A5B6 },
	{ 0xE59D84, 0x3A5AF },
	{ 0xE59D85, 0x2A3CB },
	{ 0xE59D86, 0x3A5BC },
	{ 0xE59D87, 0x1C9E1 },
	{ 0xE59D88, 0x3A5AD },
	{ 0xE59D89, 0x2A3CD },
	{ 0xE59D8A, 0x1C9DD },
	{ 0xE59D8B, 0x2A3CE },
	{ 0xE59D8C, 0x2A3CC },
	{ 0xE59D8D, 0x1C9E0 },
	{ 0xE59D8E, 0x1C9E2 },
	{ 0xE59D8F, 0x1C9E5 },
	{ 0xE59D90, 0x1C9E4 },
	{ 0xE59D91, 0x1C9DE },
	{ 0xE59D92, 0x2A3CF },
	{ 0xE59D93, 0x3A5B2 },
	{ 0xE59D94, 0x3A5C1 },
	{ 0xE59D95, 0x3A5C2 },
	{ 0xE59D96, 0x3A5B3 },
	{ 0xE59D97, 0x3A5B8 },
	{ 0xE59D98, 0x3A5B7 },
	{ 0xE59D99, 0x3E4DF },
	{ 0xE59D9B, 0xFA3D2 },
	{ 0xE59D9F, 0x3A5B5 },
	{ 0xE59DA1, 0x1CCDB },
	{ 0xE59DA2, 0x2A5FE },
	{ 0xE59DA3, 0x3A8A5 },
	{ 0xE59DA4, 0x1CCDD },
	{ 0xE59DA5, 0x3A8A3 },
	{ 0xE59DA6, 0x1CCDC },
	{ 0xE59DA7, 0x3A8A6 },
	{ 0xE59DA8, 0x2A6A1 },
	{ 0xE59DA9, 0x1CCDA },
	{ 0xE59DAA, 0x1CCD9 },
	{ 0xE59DAB, 0x2A5F5 },
	{ 0xE59DAC, 0x4A5E9 },
	{ 0xE59DAD, 0x2A5F4 },
	{ 0xE59DAE, 0x3A8A8 },
	{ 0xE59DAF, 0x2A5F2 },
	{ 0xE59DB0, 0x2A5F7 },
	{ 0xE59DB1, 0x2A5F6 },
	{ 0xE59DB2, 0x2A5F3 },
	{ 0xE59DB3, 0x2A5FC },
	{ 0xE59DB4, 0x2A5FD },
	{ 0xE59DB5, 0x2A5FA },
	{ 0xE59DB6, 0x2A5F8 },
	{ 0xE59DB7, 0x1CCD8 },
	{ 0xE59DB8, 0x3A8A9 },
	{ 0xE59DB9, 0x4A5E6 },
	{ 0xE59DBA, 0x4A5E8 },
	{ 0xE59DBB, 0x2A5FB },
	{ 0xE59DBC, 0x1CCDE },
	{ 0xE59DBD, 0x2A6A2 },
	{ 0xE59DBE, 0x4A5E5 },
	{ 0xE59DBF, 0x3A8AA },
	{ 0xE59E80, 0x2A5F9 },
	{ 0xE59E81, 0x3A8A4 },
	{ 0xE59E82, 0x1D0CD },
	{ 0xE59E83, 0x1CCD7 },
	{ 0xE59E87, 0x4A5EE },
	{ 0xE59E88, 0xFA6B3 },
	{ 0xE59E8A, 0x3E4E0 },
	{ 0xE59E8B, 0x1D0CE },
	{ 0xE59E8C, 0x2A9D5 },
	{ 0xE59E8D, 0x3ABE9 },
	{ 0xE59E8E, 0x3ABE8 },
	{ 0xE59E8F, 0x2A9DB },
	{ 0xE59E90, 0x3ABEC },
	{ 0xE59E91, 0x3ABE7 },
	{ 0xE59E92, 0x3ABEA },
	{ 0xE59E93, 0x1D0D4 },
	{ 0xE59E94, 0x2A9D9 },
	{ 0xE59E95, 0x2A9DF },
	{ 0xE59E96, 0x3ABF1 },
	{ 0xE59E97, 0x2A9D6 },
	{ 0xE59E98, 0x2A9DA },
	{ 0xE59E99, 0x2A9DC },
	{ 0xE59E9A, 0x2A9DE },
	{ 0xE59E9B, 0x2A9D8 },
	{ 0xE59E9C, 0x3ABF0 },
	{ 0xE59E9D, 0x2A9D7 },
	{ 0xE59E9E, 0x2A9D2 },
	{ 0xE59E9F, 0x2A9D3 },
	{ 0xE59EA0, 0x1D0CF },
	{ 0xE59EA1, 0x3ABEB },
	{ 0xE59EA2, 0x1D0D1 },
	{ 0xE59EA3, 0x1D0D0 },
	{ 0xE59EA4, 0x2A9D4 },
	{ 0xE59EA5, 0x2A9DD },
	{ 0xE59EA6, 0x3ABED },
	{ 0xE59EA7, 0x3ABF2 },
	{ 0xE59EA8, 0x3ABEE },
	{ 0xE59EA9, 0x4A8E0 },
	{ 0xE59EAA, 0xFA9EA },
	{ 0xE59EAB, 0xFA9F1 },
	{ 0xE59EAC, 0x3ABE6 },
	{ 0xE59EAE, 0x1D0D3 },
	{ 0xE59EB4, 0x4A8DE },
	{ 0xE59EB5, 0x2A9D1 },
	{ 0xE59EB6, 0x2AED5 },
	{ 0xE59EB7, 0x3B0AA },
	{ 0xE59EB8, 0x2AED4 },
	{ 0xE59EB9, 0x2AED9 },
	{ 0xE59EBA, 0x2AED0 },
	{ 0xE59EBB, 0x3B0B0 },
	{ 0xE59EBC, 0x2AED3 },
	{ 0xE59EBD, 0x2AED2 },
	{ 0xE59EBE, 0x3B0AF },
	{ 0xE59EBF, 0x2AED6 },
	{ 0xE59F80, 0x3B0B8 },
	{ 0xE59F81, 0x2AEDA },
	{ 0xE59F82, 0x1D4E9 },
	{ 0xE59F83, 0x1D4EC },
	{ 0xE59F84, 0x3B0B4 },
	{ 0xE59F85, 0x3B0B5 },
	{ 0xE59F86, 0x2AED1 },
	{ 0xE59F87, 0x2AED7 },
	{ 0xE59F88, 0x3B0B3 },
	{ 0xE59F89, 0x3B0A8 },
	{ 0xE59F8A, 0x3B0B7 },
	{ 0xE59F8B, 0x1D4EB },
	{ 0xE59F8C, 0x2AECC },
	{ 0xE59F8D, 0x3B0AB },
	{ 0xE59F8E, 0x1D0D2 },
	{ 0xE59F8F, 0x2B4BD },
	{ 0xE59F90, 0x2AED8 },
	{ 0xE59F91, 0x3B0B6 },
	{ 0xE59F92, 0x2AECF },
	{ 0xE59F93, 0x4ACB3 },
	{ 0xE59F94, 0x1D4EA },
	{ 0xE59F95, 0x2AECE },
	{ 0xE59F97, 0xFAEDC },
	{ 0xE59F9B, 0x3B0B2 },
	{ 0xE59F9C, 0x2B4B4 },
	{ 0xE59F9D, 0x3B4EE },
	{ 0xE59F9E, 0x3B4F1 },
	{ 0xE59F9F, 0x1D9D1 },
	{ 0xE59FA0, 0x1D9D5 },
	{ 0xE59FA1, 0x2B4C4 },
	{ 0xE59FA2, 0x2B4B2 },
	{ 0xE59FA3, 0x2B4C0 },
	{ 0xE59FA4, 0x1D9D6 },
	{ 0xE59FA5, 0x2B4C2 },
	{ 0xE59FA6, 0x3B4F2 },
	{ 0xE59FA7, 0x2B4C8 },
	{ 0xE59FA8, 0x3B4F4 },
	{ 0xE59FA9, 0x2B4CC },
	{ 0xE59FAA, 0x3B4E9 },
	{ 0xE59FAB, 0x4B0FB },
	{ 0xE59FAC, 0x2B4C3 },
	{ 0xE59FAD, 0x2B4B7 },
	{ 0xE59FAE, 0x2B4BF },
	{ 0xE59FAF, 0x3B4EB },
	{ 0xE59FB0, 0x2B4CD },
	{ 0xE59FB1, 0x2B4CB },
	{ 0xE59FB2, 0x2B4C1 },
	{ 0xE59FB3, 0x2B4BC },
	{ 0xE59FB4, 0x2B4B5 },
	{ 0xE59FB5, 0x2BAE8 },
	{ 0xE59FB6, 0x2B4B3 },
	{ 0xE59FB7, 0x1D9DA },
	{ 0xE59FB8, 0x2B4BA },
	{ 0xE59FB9, 0x1D9DB },
	{ 0xE59FBA, 0x1D9D7 },
	{ 0xE59FBB, 0x2B4B0 },
	{ 0xE59FBC, 0x2B4C6 },
	{ 0xE59FBD, 0x2B4B8 },
	{ 0xE59FBE, 0x3B4EF },
	{ 0xE59FBF, 0x3B4F5 },
	{ 0xE5A080, 0x2B4B6 },
	{ 0xE5A081, 0x2B4C9 },
	{ 0xE5A082, 0x1D9D8 },
	{ 0xE5A083, 0x3B4F6 },
	{ 0xE5A084, 0x2B4CF },
	{ 0xE5A085, 0x1D9D2 },
	{ 0xE5A086, 0x1D9D4 },
	{ 0xE5A087, 0x2B4BE },
	{ 0xE5A088, 0x2B4B9 },
	{ 0xE5A089, 0x1D4ED },
	{ 0xE5A08A, 0x1D9D3 },
	{ 0xE5A08B, 0x2B4BB },
	{ 0xE5A08C, 0x2B4CA },
	{ 0xE5A08D, 0x2B4CE },
	{ 0xE5A08E, 0x2B4C5 },
	{ 0xE5A08F, 0x3E4E1 },
	{ 0xE5A090, 0x2B4C7 },
	{ 0xE5A092, 0x3E4E2 },
	{ 0xE5A093, 0x3E4E3 },
	{ 0xE5A094, 0x2B4B1 },
	{ 0xE5A097, 0x4B6E9 },
	{ 0xE5A098, 0x3BACA },
	{ 0xE5A099, 0x2BAE3 },
	{ 0xE5A09A, 0x3BAC5 },
	{ 0xE5A09B, 0x2BAEC },
	{ 0xE5A09C, 0x2BAEB },
	{ 0xE5A09D, 0x1DEE0 },
	{ 0xE5A09E, 0x2BAE4 },
	{ 0xE5A09F, 0x3BAC7 },
	{ 0xE5A0A0, 0x1DEE1 },
	{ 0xE5A0A1, 0x1DEDF },
	{ 0xE5A0A2, 0x3BAD0 },
	{ 0xE5A0A3, 0x2BAE6 },
	{ 0xE5A0A4, 0x1DEDC },
	{ 0xE5A0A5, 0x2BAEA },
	{ 0xE5A0A6, 0x3BACC },
	{ 0xE5A0A7, 0x2BAE5 },
	{ 0xE5A0A8, 0x2BAE7 },
	{ 0xE5A0A9, 0x2BAE1 },
	{ 0xE5A0AA, 0x1DEDA },
	{ 0xE5A0AB, 0x4B6EF },
	{ 0xE5A0AC, 0x2BAF4 },
	{ 0xE5A0AD, 0x2BAF3 },
	{ 0xE5A0AE, 0x2BAF0 },
	{ 0xE5A0AF, 0x1DED9 },
	{ 0xE5A0B0, 0x1DEDD },
	{ 0xE5A0B1, 0x1DEDE },
	{ 0xE5A0B2, 0x2AECD },
	{ 0xE5A0B3, 0x2BAED },
	{ 0xE5A0B4, 0x1DEDB },
	{ 0xE5A0B5, 0x1D9D9 },
	{ 0xE5A0B6, 0x2BAEF },
	{ 0xE5A0B7, 0x2BAE2 },
	{ 0xE5A0B8, 0x2BAF2 },
	{ 0xE5A0B9, 0x2BAF1 },
	{ 0xE5A0BA, 0x3BACE },
	{ 0xE5A0BB, 0x2BAF5 },
	{ 0xE5A0BC, 0x3BAC9 },
	{ 0xE5A0BD, 0x2C2B6 },
	{ 0xE5A0BE, 0x3BACB },
	{ 0xE5A0BF, 0x2BAEE },
	{ 0xE5A180, 0xFB9FD },
	{ 0xE5A182, 0xFB9FE },
	{ 0xE5A183, 0x4BCD7 },
	{ 0xE5A184, 0x4B6ED },
	{ 0xE5A185, 0x4B6F1 },
	{ 0xE5A187, 0x3E4E4 },
	{ 0xE5A188, 0x2BAE9 },
	{ 0xE5A189, 0x2C2AE },
	{ 0xE5A18A, 0x1E3DB },
	{ 0xE5A18B, 0x1E3DE },
	{ 0xE5A18C, 0x1E3D9 },
	{ 0xE5A18D, 0x2C2AD },
	{ 0xE5A18E, 0x2C2B1 },
	{ 0xE5A18F, 0x2C2AC },
	{ 0xE5A190, 0x3C0D7 },
	{ 0xE5A191, 0x1E3D3 },
	{ 0xE5A192, 0x1E3DD },
	{ 0xE5A193, 0x2C2A9 },
	{ 0xE5A194, 0x1E3D7 },
	{ 0xE5A195, 0x2C2B0 },
	{ 0xE5A196, 0x3C0DB },
	{ 0xE5A197, 0x1E3D5 },
	{ 0xE5A198, 0x1E3D4 },
	{ 0xE5A199, 0x2C2B3 },
	{ 0xE5A19A, 0x1E3D6 },
	{ 0xE5A19B, 0x2C2B5 },
	{ 0xE5A19C, 0x3C0D6 },
	{ 0xE5A19D, 0x2C2B2 },
	{ 0xE5A19E, 0x1E3D2 },
	{ 0xE5A19F, 0x3C0DE },
	{ 0xE5A1A0, 0x3C0DC },
	{ 0xE5A1A1, 0x3C0D8 },
	{ 0xE5A1A2, 0x1E3DC },
	{ 0xE5A1A3, 0x2C2B7 },
	{ 0xE5A1A4, 0x2C2AB },
	{ 0xE5A1A5, 0x2C2B4 },
	{ 0xE5A1A6, 0x3C0DD },
	{ 0xE5A1A7, 0x4BCD3 },
	{ 0xE5A1A8, 0x2C2AA },
	{ 0xE5A1A9, 0x3C0DA },
	{ 0xE5A1AA, 0x3C0D9 },
	{ 0xE5A1AB, 0x1E3D8 },
	{ 0xE5A1AC, 0x3C0D4 },
	{ 0xE5A1AD, 0x1E3DA },
	{ 0xE5A1AF, 0x2C2AF },
	{ 0xE5A1B1, 0x2C2B8 },
	{ 0xE5A1B2, 0x3C6C3 },
	{ 0xE5A1B3, 0x3C6BE },
	{ 0xE5A1B4, 0x2C9C4 },
	{ 0xE5A1B5, 0x1E8B8 },
	{ 0xE5A1B6, 0x2C9CA },
	{ 0xE5A1B7, 0x3C6C2 },
	{ 0xE5A1B8, 0x3C6BC },
	{ 0xE5A1B9, 0x1E8BD },
	{ 0xE5A1BA, 0x2C9C6 },
	{ 0xE5A1BB, 0x2C9CD },
	{ 0xE5A1BC, 0x2C9BE },
	{ 0xE5A1BD, 0x1E8BF },
	{ 0xE5A1BE, 0x1E8B9 },
	{ 0xE5A1BF, 0x2C9C3 },
	{ 0xE5A280, 0x1ECBF },
	{ 0xE5A281, 0x2C9C2 },
	{ 0xE5A282, 0x2C9CB },
	{ 0xE5A283, 0x1E8BA },
	{ 0xE5A284, 0x3C6BD },
	{ 0xE5A285, 0x1E8BE },
	{ 0xE5A286, 0x2C9C1 },
	{ 0xE5A287, 0x2C9C7 },
	{ 0xE5A288, 0x2C9CC },
	{ 0xE5A289, 0x2C9BD },
	{ 0xE5A28A, 0x1E8BC },
	{ 0xE5A28B, 0x2C9C5 },
	{ 0xE5A28C, 0x3C6BA },
	{ 0xE5A28D, 0x3C6C5 },
	{ 0xE5A28E, 0x2C9C9 },
	{ 0xE5A28F, 0x2C9CF },
	{ 0xE5A290, 0x2C9BF },
	{ 0xE5A291, 0x2C9C8 },
	{ 0xE5A292, 0x3C6B8 },
	{ 0xE5A293, 0x1E8BB },
	{ 0xE5A294, 0x2C9CE },
	{ 0xE5A295, 0x3C6C1 },
	{ 0xE5A296, 0x3C6C4 },
	{ 0xE5A297, 0x3C6C0 },
	{ 0xE5A298, 0x2C9C0 },
	{ 0xE5A29A, 0x4C2D9 },
	{ 0xE5A29B, 0x3E4E5 },
	{ 0xE5A29C, 0x1ECC3 },
	{ 0xE5A29D, 0x2CFF2 },
	{ 0xE5A29E, 0x1ECC1 },
	{ 0xE5A29F, 0x1ECC0 },
	{ 0xE5A2A0, 0x2CFF4 },
	{ 0xE5A2A1, 0x2CFF9 },
	{ 0xE5A2A2, 0x3CBC6 },
	{ 0xE5A2A3, 0x2CFF5 },
	{ 0xE5A2A4, 0x3CBD0 },
	{ 0xE5A2A5, 0x2CFF8 },
	{ 0xE5A2A6, 0x1ECC6 },
	{ 0xE5A2A7, 0x3CBD1 },
	{ 0xE5A2A8, 0x1F0AE },
	{ 0xE5A2A9, 0x1ECC5 },
	{ 0xE5A2AA, 0x3CBCB },
	{ 0xE5A2AB, 0x2CFF1 },
	{ 0xE5A2AC, 0x2CFF7 },
	{ 0xE5A2AD, 0x3C6BF },
	{ 0xE5A2AE, 0x1ECC4 },
	{ 0xE5A2AF, 0x2CFF6 },
	{ 0xE5A2B0, 0x3CBCD },
	{ 0xE5A2B1, 0x2CFF3 },
	{ 0xE5A2B2, 0x3CBC9 },
	{ 0xE5A2B3, 0x1ECC2 },
	{ 0xE5A2B4, 0x3CBCF },
	{ 0xE5A2B5, 0x3CBCC },
	{ 0xE5A2B7, 0x3CBC7 },
	{ 0xE5A2BA, 0x2D6D7 },
	{ 0xE5A2BB, 0x3D0CA },
	{ 0xE5A2BC, 0x2D6D9 },
	{ 0xE5A2BD, 0x2D6D4 },
	{ 0xE5A2BE, 0x1F0CA },
	{ 0xE5A2BF, 0x2D6D6 },
	{ 0xE5A380, 0x3D0CB },
	{ 0xE5A381, 0x1F0C9 },
	{ 0xE5A382, 0x2D6D8 },
	{ 0xE5A383, 0x3D0C8 },
	{ 0xE5A384, 0x3D0CC },
	{ 0xE5A385, 0x1F0CC },
	{ 0xE5A386, 0x2D6DA },
	{ 0xE5A387, 0x1F0CB },
	{ 0xE5A388, 0x2D6D3 },
	{ 0xE5A389, 0x2D6D5 },
	{ 0xE5A38A, 0x3D0C9 },
	{ 0xE5A38D, 0x3D4CB },
	{ 0xE5A38E, 0x1F3CE },
	{ 0xE5A38F, 0x2DCD8 },
	{ 0xE5A390, 0x3D4CC },
	{ 0xE5A391, 0x1F3CD },
	{ 0xE5A392, 0x2DCD9 },
	{ 0xE5A393, 0x1F3CC },
	{ 0xE5A394, 0x2DCD7 },
	{ 0xE5A395, 0x1F3CB },
	{ 0xE5A396, 0x2DCD6 },
	{ 0xE5A398, 0x1F6BF },
	{ 0xE5A399, 0x1F6BE },
	{ 0xE5A39A, 0x2E5C2 },
	{ 0xE5A39B, 0x2E5C4 },
	{ 0xE5A39C, 0x3DAAF },
	{ 0xE5A39D, 0x2E5C3 },
	{ 0xE5A39E, 0x1F8AE },
	{ 0xE5A39F, 0x1F8AF },
	{ 0xE5A3A0, 0x3DAAE },
	{ 0xE5A3A1, 0x7C6C5 },
	{ 0xE5A3A2, 0x1F8B0 },
	{ 0xE5A3A3, 0x2E8EE },
	{ 0xE5A3A4, 0x1F9E6 },
	{ 0xE5A3A6, 0x3DEA8 },
	{ 0xE5A3A7, 0x2EFA2 },
	{ 0xE5A3A8, 0x2EFA1 },
	{ 0xE5A3A9, 0x1FCDE },
	{ 0xE5A3AB, 0x1C4C9 },
	{ 0xE5A3AC, 0x1C5B1 },
	{ 0xE5A3AE, 0x3A3C3 },
	{ 0xE5A3AF, 0x1C9E7 },
	{ 0xE5A3B0, 0x3A5C5 },
	{ 0xE5A3B1, 0x3A5C3 },
	{ 0xE5A3B2, 0x3A5C4 },
	{ 0xE5A3B3, 0x3A8AD },
	{ 0xE5A3B4, 0x2A9E0 },
	{ 0xE5A3B5, 0x3ABF7 },
	{ 0xE5A3B7, 0x3B4F7 },
	{ 0xE5A3B9, 0x1DEE2 },
	{ 0xE5A3BA, 0x1DEE3 },
	{ 0xE5A3BB, 0x3BAD2 },
	{ 0xE5A3BC, 0x2C2B9 },
	{ 0xE5A3BD, 0x1E8C0 },
	{ 0xE5A3BE, 0x2C9D0 },
	{ 0xE5A3BF, 0x2CFFA },
	{ 0xE5A480, 0x3E4E6 },
	{ 0xE5A481, 0x3D0CD },
	{ 0xE5A482, 0x3A1B9 },
	{ 0xE5A483, 0x2A1BA },
	{ 0xE5A484, 0x3A2B5 },
	{ 0xE5A485, 0x3A3C4 },
	{ 0xE5A486, 0x2A3D0 },
	{ 0xE5A488, 0x3ABFA },
	{ 0xE5A489, 0x3ABF9 },
	{ 0xE5A48A, 0x3A1BA },
	{ 0xE5A48B, 0x3A5C6 },
	{ 0xE5A48C, 0x2A6A3 },
	{ 0xE5A48D, 0x2A9E1 },
	{ 0xE5A48E, 0x2AEDB },
	{ 0xE5A48F, 0x1D4EE },
	{ 0xE5A490, 0x3C6C6 },
	{ 0xE5A491, 0x3E5E0 },
	{ 0xE5A492, 0x2E5C5 },
	{ 0xE5A493, 0x4DFD2 },
	{ 0xE5A494, 0x1FAE7 },
	{ 0xE5A495, 0x1C4CA },
	{ 0xE5A496, 0x1C6C0 },
	{ 0xE5A497, 0x2A1D1 },
	{ 0xE5A498, 0x3A2B6 },
	{ 0xE5A499, 0x1C7E8 },
	{ 0xE5A49A, 0x1C7E9 },
	{ 0xE5A49B, 0x4A2D2 },
	{ 0xE5A49C, 0x1CCDF },
	{ 0xE5A49D, 0x4A5F0 },
	{ 0xE5A49F, 0x3B4F9 },
	{ 0xE5A4A0, 0x1D9DC },
	{ 0xE5A4A1, 0x5B7BD },
	{ 0xE5A4A2, 0x1E8C2 },
	{ 0xE5A4A3, 0x3C0DF },
	{ 0xE5A4A4, 0x1E8C3 },
	{ 0xE5A4A5, 0x1E8C1 },
	{ 0xE5A4A6, 0x3CBD3 },
	{ 0xE5A4A7, 0x1C4CB },
	{ 0xE5A4A8, 0x4A1C9 },
	{ 0xE5A4A9, 0x1C5B2 },
	{ 0xE5A4AA, 0x1C5B4 },
	{ 0xE5A4AB, 0x1C5B3 },
	{ 0xE5A4AC, 0x2A1BB },
	{ 0xE5A4AD, 0x1C5B5 },
	{ 0xE5A4AE, 0x1C6C1 },
	{ 0xE5A4AF, 0x2A1D2 },
	{ 0xE5A4B0, 0x3A2B8 },
	{ 0xE5A4B1, 0x1C6C2 },
	{ 0xE5A4B2, 0x3A2B7 },
	{ 0xE5A4B3, 0x4A1F2 },
	{ 0xE5A4B4, 0x3A2B9 },
	{ 0xE5A4B5, 0x4A2D3 },
	{ 0xE5A4B6, 0x3A3C7 },
	{ 0xE5A4B7, 0x1C7EA },
	{ 0xE5A4B8, 0x1C7EB },
	{ 0xE5A4BC, 0x2A2AB },
	{ 0xE5A4BD, 0x3A5C9 },
	{ 0xE5A4BE, 0x1C9E8 },
	{ 0xE5A4BF, 0x4A3E2 },
	{ 0xE5A580, 0x2A3D1 },
	{ 0xE5A583, 0x4A5F5 },
	{ 0xE5A584, 0x1CCE3 },
	{ 0xE5A585, 0x2A6A4 },
	{ 0xE5A586, 0x4A5F2 },
	{ 0xE5A587, 0x1CCE1 },
	{ 0xE5A588, 0x1CCE2 },
	{ 0xE5A589, 0x1CCE0 },
	{ 0xE5A58A, 0x2AEDC },
	{ 0xE5A58B, 0x3A8AE },
	{ 0xE5A58C, 0x3A8AF },
	{ 0xE5A58D, 0x3E4E7 },
	{ 0xE5A58E, 0x1D0D8 },
	{ 0xE5A58F, 0x1D0D7 },
	{ 0xE5A590, 0x1D0D9 },
	{ 0xE5A591, 0x1D0D6 },
	{ 0xE5A592, 0x3ABFC },
	{ 0xE5A593, 0x2A9E2 },
	{ 0xE5A594, 0x1CCE4 },
	{ 0xE5A595, 0x1D0D5 },
	{ 0xE5A597, 0x1D4EF },
	{ 0xE5A598, 0x1D4F0 },
	{ 0xE5A599, 0x4ACB8 },
	{ 0xE5A59A, 0x1D4F1 },
	{ 0xE5A59B, 0x3B4FB },
	{ 0xE5A59C, 0x2B4D0 },
	{ 0xE5A59D, 0x3B4FC },
	{ 0xE5A59E, 0x3B4FD },
	{ 0xE5A59F, 0x4B1A6 },
	{ 0xE5A5A0, 0x1DEE4 },
	{ 0xE5A5A1, 0x2BAF6 },
	{ 0xE5A5A2, 0x1D9DD },
	{ 0xE5A5A3, 0x3BAD3 },
	{ 0xE5A5A4, 0x3BAD4 },
	{ 0xE5A5A5, 0x4B6F9 },
	{ 0xE5A5A6, 0x3C0E0 },
	{ 0xE5A5A7, 0x1E3DF },
	{ 0xE5A5A8, 0x3C0E1 },
	{ 0xE5A5A9, 0x1E8C5 },
	{ 0xE5A5AA, 0x1E8C4 },
	{ 0xE5A5AB, 0x2C9D1 },
	{ 0xE5A5AC, 0x3C6C8 },
	{ 0xE5A5AD, 0x1ECC7 },
	{ 0xE5A5AE, 0x1F0CD },
	{ 0xE5A5AF, 0x4CFFB },
	{ 0xE5A5B0, 0x2E1CC },
	{ 0xE5A5B1, 0x2EDC8 },
	{ 0xE5A5B2, 0x2EFA3 },
	{ 0xE5A5B3, 0x1C4CC },
	{ 0xE5A5B4, 0x1C6C3 },
	{ 0xE5A5B5, 0x3A2BB },
	{ 0xE5A5B6, 0x1C6C4 },
	{ 0xE5A5B7, 0x2A2B1 },
	{ 0xE5A5B8, 0x1C7ED },
	{ 0xE5A5B9, 0x1C7F0 },
	{ 0xE5A5BA, 0x3A3CB },
	{ 0xE5A5BB, 0x2A2AF },
	{ 0xE5A5BC, 0x2A2AD },
	{ 0xE5A5BD, 0x1C7EF },
	{ 0xE5A5BE, 0x2A2B0 },
	{ 0xE5A5BF, 0x2A2B2 },
	{ 0xE5A680, 0x2A2AC },
	{ 0xE5A681, 0x1C7F2 },
	{ 0xE5A682, 0x1C7F1 },
	{ 0xE5A683, 0x1C7EE },
	{ 0xE5A684, 0x1C7EC },
	{ 0xE5A685, 0x2A2AE },
	{ 0xE5A686, 0x3A3CD },
	{ 0xE5A689, 0x3A5D5 },
	{ 0xE5A68A, 0x1C9F3 },
	{ 0xE5A68B, 0x4A3E7 },
	{ 0xE5A68C, 0x3A5CC },
	{ 0xE5A68D, 0x1C9F0 },
	{ 0xE5A68E, 0x2A3D6 },
	{ 0xE5A68F, 0x2A3D9 },
	{ 0xE5A690, 0x2A3D8 },
	{ 0xE5A691, 0x4A3E9 },
	{ 0xE5A692, 0x1C9EA },
	{ 0xE5A693, 0x1C9F2 },
	{ 0xE5A694, 0x3A5CB },
	{ 0xE5A695, 0x4A3EA },
	{ 0xE5A696, 0x1C9EF },
	{ 0xE5A697, 0x2A3D5 },
	{ 0xE5A698, 0x2A3D3 },
	{ 0xE5A699, 0x1C9EE },
	{ 0xE5A69A, 0x3A5D6 },
	{ 0xE5A69B, 0x3A5D3 },
	{ 0xE5A69C, 0x3A5CE },
	{ 0xE5A69D, 0x1C9E9 },
	{ 0xE5A69E, 0x1C9EC },
	{ 0xE5A69F, 0x3A5D1 },
	{ 0xE5A6A0, 0x2A3D4 },
	{ 0xE5A6A1, 0x2A3DB },
	{ 0xE5A6A2, 0x2A3D7 },
	{ 0xE5A6A3, 0x1C9ED },
	{ 0xE5A6A4, 0x1C9F1 },
	{ 0xE5A6A5, 0x1C9F4 },
	{ 0xE5A6A6, 0x2A3D2 },
	{ 0xE5A6A7, 0x2A3DA },
	{ 0xE5A6A8, 0x1C9EB },
	{ 0xE5A6AC, 0x3A8C1 },
	{ 0xE5A6AD, 0x3A8B3 },
	{ 0xE5A6AE, 0x1CCE9 },
	{ 0xE5A6AF, 0x1CCF1 },
	{ 0xE5A6B0, 0x3A8B8 },
	{ 0xE5A6B1, 0x2A6B0 },
	{ 0xE5A6B2, 0x2A6A9 },
	{ 0xE5A6B3, 0x1CCF2 },
	{ 0xE5A6B4, 0x2A6B4 },
	{ 0xE5A6B5, 0x2A6A5 },
	{ 0xE5A6B6, 0x2A6AC },
	{ 0xE5A6B7, 0x3A8C5 },
	{ 0xE5A6B8, 0x3A8C0 },
	{ 0xE5A6B9, 0x1CCE8 },
	{ 0xE5A6BA, 0x2A6A6 },
	{ 0xE5A6BB, 0x1CCE6 },
	{ 0xE5A6BC, 0x2A6AD },
	{ 0xE5A6BD, 0x2A6B1 },
	{ 0xE5A6BE, 0x1CCE5 },
	{ 0xE5A6BF, 0x3A8BD },
	{ 0xE5A780, 0x2A6B2 },
	{ 0xE5A781, 0x2A6AB },
	{ 0xE5A782, 0x3A8B7 },
	{ 0xE5A783, 0x2A6AE },
	{ 0xE5A784, 0x3A8B5 },
	{ 0xE5A785, 0x1CCF4 },
	{ 0xE5A786, 0x1CCEB },
	{ 0xE5A787, 0x2A6B5 },
	{ 0xE5A788, 0x2A6B3 },
	{ 0xE5A789, 0x3A8BF },
	{ 0xE5A78A, 0x1CCF0 },
	{ 0xE5A78B, 0x1CCEE },
	{ 0xE5A78C, 0x2A6AA },
	{ 0xE5A78D, 0x1CCED },
	{ 0xE5A78E, 0x2A6A8 },
	{ 0xE5A78F, 0x2A6A7 },
	{ 0xE5A790, 0x1CCEC },
	{ 0xE5A791, 0x1CCEA },
	{ 0xE5A792, 0x1CCF3 },
	{ 0xE5A793, 0x1CCEF },
	{ 0xE5A794, 0x1CCE7 },
	{ 0xE5A795, 0x3ACA6 },
	{ 0xE5A796, 0x2A6AF },
	{ 0xE5A797, 0x3A8C6 },
	{ 0xE5A798, 0x1D0DB },
	{ 0xE5A799, 0x3ACAD },
	{ 0xE5A79A, 0x1D0E2 },
	{ 0xE5A79B, 0x2A9F0 },
	{ 0xE5A79C, 0x1D0DA },
	{ 0xE5A79D, 0x2A9E8 },
	{ 0xE5A79E, 0x2A9E4 },
	{ 0xE5A79F, 0x3ACA1 },
	{ 0xE5A7A0, 0x2A9F4 },
	{ 0xE5A7A1, 0x2A9E3 },
	{ 0xE5A7A2, 0x3ACAC },
	{ 0xE5A7A3, 0x1D0DD },
	{ 0xE5A7A4, 0x2A9ED },
	{ 0xE5A7A5, 0x1D0E0 },
	{ 0xE5A7A6, 0x1D0E3 },
	{ 0xE5A7A7, 0x3ACAE },
	{ 0xE5A7A8, 0x1D0DE },
	{ 0xE5A7A9, 0x2A9F1 },
	{ 0xE5A7AA, 0x1D0E1 },
	{ 0xE5A7AB, 0x3ACA3 },
	{ 0xE5A7AC, 0x1D4F8 },
	{ 0xE5A7AD, 0x2A9F7 },
	{ 0xE5A7AE, 0x2A9E5 },
	{ 0xE5A7AF, 0x3ACA4 },
	{ 0xE5A7B0, 0x3ACA5 },
	{ 0xE5A7B1, 0x2A9E7 },
	{ 0xE5A7B2, 0x2A9EE },
	{ 0xE5A7B3, 0x2A9F2 },
	{ 0xE5A7B4, 0x2A9F6 },
	{ 0xE5A7B5, 0x2A9F3 },
	{ 0xE5A7B6, 0x2A9EC },
	{ 0xE5A7B7, 0x2A9EF },
	{ 0xE5A7B8, 0x3ACAB },
	{ 0xE5A7B9, 0x3ACA9 },
	{ 0xE5A7BA, 0x2A9E9 },
	{ 0xE5A7BB, 0x1D0E5 },
	{ 0xE5A7BC, 0x2A9EB },
	{ 0xE5A7BD, 0x2A9EA },
	{ 0xE5A7BE, 0x2A9F5 },
	{ 0xE5A7BF, 0x1D0DC },
	{ 0xE5A880, 0x2A9E6 },
	{ 0xE5A881, 0x1D0E4 },
	{ 0xE5A882, 0x3ACAA },
	{ 0xE5A883, 0x1D0DF },
	{ 0xE5A884, 0x3ACA8 },
	{ 0xE5A889, 0x1D4FE },
	{ 0xE5A88A, 0x2AEE4 },
	{ 0xE5A88B, 0x3B0C0 },
	{ 0xE5A88C, 0x1D4FD },
	{ 0xE5A88D, 0x3ACA7 },
	{ 0xE5A88E, 0x4ACC0 },
	{ 0xE5A88F, 0x2AEE2 },
	{ 0xE5A890, 0x4ACBE },
	{ 0xE5A891, 0x1D4F2 },
	{ 0xE5A892, 0x3B0CF },
	{ 0xE5A893, 0x1D4F7 },
	{ 0xE5A894, 0x3B0CA },
	{ 0xE5A895, 0x2AEE1 },
	{ 0xE5A896, 0x2AEDE },
	{ 0xE5A897, 0x2AEE3 },
	{ 0xE5A898, 0x1D4F3 },
	{ 0xE5A899, 0x2AEDD },
	{ 0xE5A89A, 0x3B0CE },
	{ 0xE5A89B, 0x1D4F6 },
	{ 0xE5A89C, 0x1D4F4 },
	{ 0xE5A89D, 0x3B0BE },
	{ 0xE5A89E, 0x2AEE5 },
	{ 0xE5A89F, 0x1D4F5 },
	{ 0xE5A8A0, 0x1D4F9 },
	{ 0xE5A8A1, 0x3B0BB },
	{ 0xE5A8A2, 0x3B0C5 },
	{ 0xE5A8A3, 0x1D4FA },
	{ 0xE5A8A4, 0x3B0C8 },
	{ 0xE5A8A5, 0x1D4FC },
	{ 0xE5A8A6, 0x3B0D2 },
	{ 0xE5A8A7, 0x4ACB9 },
	{ 0xE5A8A8, 0x4ACBD },
	{ 0xE5A8A9, 0x1D4FB },
	{ 0xE5A8AA, 0x3B0BC },
	{ 0xE5A8AB, 0x3B5A2 },
	{ 0xE5A8AC, 0x3B5B8 },
	{ 0xE5A8AD, 0x2AEDF },
	{ 0xE5A8AE, 0x2AEE0 },
	{ 0xE5A8AF, 0x3B0CD },
	{ 0xE5A8B0, 0x6B6D7 },
	{ 0xE5A8B1, 0x3B0CB },
	{ 0xE5A8B3, 0x2AEE6 },
	{ 0xE5A8B5, 0x2B4D7 },
	{ 0xE5A8B6, 0x1D9DE },
	{ 0xE5A8B7, 0x2BBA6 },
	{ 0xE5A8B8, 0x2B4D6 },
	{ 0xE5A8B9, 0x2B4E9 },
	{ 0xE5A8BA, 0x3B5A8 },
	{ 0xE5A8BB, 0x3B5A4 },
	{ 0xE5A8BC, 0x1D9E4 },
	{ 0xE5A8BD, 0x3B5B1 },
	{ 0xE5A8BE, 0x2B4E7 },
	{ 0xE5A8BF, 0x3B5B3 },
	{ 0xE5A980, 0x1D9E3 },
	{ 0xE5A981, 0x1D9DF },
	{ 0xE5A982, 0x2B4F0 },
	{ 0xE5A983, 0x2B4E0 },
	{ 0xE5A984, 0x2B4E3 },
	{ 0xE5A985, 0x3B5AE },
	{ 0xE5A986, 0x1D9E7 },
	{ 0xE5A987, 0x2B4ED },
	{ 0xE5A988, 0x2B4E5 },
	{ 0xE5A989, 0x1D9E0 },
	{ 0xE5A98A, 0x1D9E8 },
	{ 0xE5A98B, 0x3B5AA },
	{ 0xE5A98C, 0x2B4EA },
	{ 0xE5A98D, 0x2B4E8 },
	{ 0xE5A98E, 0x3B5AF },
	{ 0xE5A98F, 0x3B5BB },
	{ 0xE5A990, 0x2B4D9 },
	{ 0xE5A991, 0x2B4EE },
	{ 0xE5A992, 0x2B4E2 },
	{ 0xE5A993, 0x2B4DD },
	{ 0xE5A994, 0x3B5BA },
	{ 0xE5A995, 0x2B4D3 },
	{ 0xE5A996, 0x2B4EF },
	{ 0xE5A997, 0x2B4DF },
	{ 0xE5A998, 0x2B4D2 },
	{ 0xE5A999, 0x3B5B9 },
	{ 0xE5A99A, 0x1D9E6 },
	{ 0xE5A99B, 0x2B4E4 },
	{ 0xE5A99C, 0x2B4F1 },
	{ 0xE5A99D, 0x2B4E1 },
	{ 0xE5A99E, 0x2B4D5 },
	{ 0xE5A99F, 0x2B4DA },
	{ 0xE5A9A0, 0x2B4D1 },
	{ 0xE5A9A1, 0x3B5A7 },
	{ 0xE5A9A2, 0x1D9E5 },
	{ 0xE5A9A3, 0x3B5BC },
	{ 0xE5A9A4, 0x2B4DE },
	{ 0xE5A9A5, 0x2B4DB },
	{ 0xE5A9A6, 0x1D9E1 },
	{ 0xE5A9A7, 0x2B4D4 },
	{ 0xE5A9A8, 0x3B5B0 },
	{ 0xE5A9A9, 0x2B4EC },
	{ 0xE5A9AA, 0x1D9E2 },
	{ 0xE5A9AB, 0x3B5AB },
	{ 0xE5A9AC, 0x2B4DC },
	{ 0xE5A9AD, 0x2B4D8 },
	{ 0xE5A9AE, 0x3B5A9 },
	{ 0xE5A9AF, 0x3B5B4 },
	{ 0xE5A9B0, 0x2B4EB },
	{ 0xE5A9B1, 0x3B5B2 },
	{ 0xE5A9B2, 0xFB3F3 },
	{ 0xE5A9B3, 0x3B5B7 },
	{ 0xE5A9B5, 0x3B5B5 },
	{ 0xE5A9B7, 0x1DEE5 },
	{ 0xE5A9B8, 0x2BAFD },
	{ 0xE5A9B9, 0x3BAF5 },
	{ 0xE5A9BA, 0x2BAFA },
	{ 0xE5A9BB, 0x2BBAD },
	{ 0xE5A9BC, 0x2BBA1 },
	{ 0xE5A9BD, 0x2BBAE },
	{ 0xE5A9BE, 0x3BAFC },
	{ 0xE5A9BF, 0x1DEE7 },
	{ 0xE5AA80, 0x3BAE3 },
	{ 0xE5AA81, 0x3BAE1 },
	{ 0xE5AA82, 0x3BAD8 },
	{ 0xE5AA83, 0x2BBAA },
	{ 0xE5AA84, 0x2BBA7 },
	{ 0xE5AA85, 0x3BADB },
	{ 0xE5AA86, 0x3BAF7 },
	{ 0xE5AA87, 0x3BAF2 },
	{ 0xE5AA88, 0x3BAD9 },
	{ 0xE5AA89, 0x3BAE0 },
	{ 0xE5AA8A, 0x2BBA8 },
	{ 0xE5AA8B, 0x2BBAB },
	{ 0xE5AA8C, 0x2BBAF },
	{ 0xE5AA8D, 0x3BAFB },
	{ 0xE5AA8E, 0x2B4E6 },
	{ 0xE5AA8F, 0x2BBB1 },
	{ 0xE5AA90, 0x2C2CD },
	{ 0xE5AA91, 0x3BAE6 },
	{ 0xE5AA92, 0x1DEE8 },
	{ 0xE5AA93, 0x2BBB2 },
	{ 0xE5AA94, 0x2BAF8 },
	{ 0xE5AA95, 0x2BBA4 },
	{ 0xE5AA96, 0x3BAE2 },
	{ 0xE5AA97, 0x2BBA9 },
	{ 0xE5AA98, 0x3BADC },
	{ 0xE5AA99, 0x3BADE },
	{ 0xE5AA9A, 0x1DEE6 },
	{ 0xE5AA9B, 0x1DEE9 },
	{ 0xE5AA9C, 0x2BBB0 },
	{ 0xE5AA9D, 0x2BBB3 },
	{ 0xE5AA9E, 0x2BAFC },
	{ 0xE5AA9F, 0x2BAF9 },
	{ 0xE5AAA0, 0x3BAF3 },
	{ 0xE5AAA1, 0x3BADA },
	{ 0xE5AAA2, 0x2BAFB },
	{ 0xE5AAA3, 0x3BAD7 },
	{ 0xE5AAA4, 0x3BAFA },
	{ 0xE5AAA5, 0x2BBA2 },
	{ 0xE5AAA6, 0x2BAFE },
	{ 0xE5AAA7, 0x1DEEA },
	{ 0xE5AAA8, 0x3BAD6 },
	{ 0xE5AAA9, 0x2BBAC },
	{ 0xE5AAAA, 0x3BAF9 },
	{ 0xE5AAAB, 0x3BAF8 },
	{ 0xE5AAAC, 0x2BBA3 },
	{ 0xE5AAAE, 0x2BBA5 },
	{ 0xE5AAAF, 0x2BAF7 },
	{ 0xE5AAB0, 0x2C2C1 },
	{ 0xE5AAB1, 0x2C2BF },
	{ 0xE5AAB2, 0x1E3E8 },
	{ 0xE5AAB3, 0x1E3E6 },
	{ 0xE5AAB4, 0x2C2C9 },
	{ 0xE5AAB5, 0x2C2C0 },
	{ 0xE5AAB6, 0x2C2CA },
	{ 0xE5AAB7, 0x2C2C6 },
	{ 0xE5AAB8, 0x2C2BE },
	{ 0xE5AAB9, 0x2C2CC },
	{ 0xE5AABA, 0x2C2BD },
	{ 0xE5AABB, 0x2C2C4 },
	{ 0xE5AABC, 0x1E3E5 },
	{ 0xE5AABD, 0x1E3E4 },
	{ 0xE5AABE, 0x1E3E3 },
	{ 0xE5AABF, 0x2C2C2 },
	{ 0xE5AB80, 0x2C2C7 },
	{ 0xE5AB81, 0x1E3E0 },
	{ 0xE5AB82, 0x1E3E7 },
	{ 0xE5AB83, 0x3C0E7 },
	{ 0xE5AB84, 0x2C2BB },
	{ 0xE5AB85, 0x3C0E6 },
	{ 0xE5AB86, 0x2C2C5 },
	{ 0xE5AB87, 0x2C2BA },
	{ 0xE5AB88, 0x2C2C3 },
	{ 0xE5AB89, 0x1E3E1 },
	{ 0xE5AB8A, 0x2C2C8 },
	{ 0xE5AB8B, 0x2C2BC },
	{ 0xE5AB8C, 0x1E3E2 },
	{ 0xE5AB8D, 0x2C2CB },
	{ 0xE5AB8E, 0x3C0E4 },
	{ 0xE5AB8F, 0x3BAEB },
	{ 0xE5AB90, 0x3C0EA },
	{ 0xE5AB91, 0x3E4E8 },
	{ 0xE5AB93, 0x3E4E9 },
	{ 0xE5AB95, 0x2C9D5 },
	{ 0xE5AB96, 0x1E8CA },
	{ 0xE5AB97, 0x1E8C9 },
	{ 0xE5AB98, 0x1E8CB },
	{ 0xE5AB99, 0x2C9E1 },
	{ 0xE5AB9A, 0x2C9D7 },
	{ 0xE5AB9B, 0x2C9DD },
	{ 0xE5AB9C, 0x2C9D2 },
	{ 0xE5AB9D, 0x2C9E0 },
	{ 0xE5AB9E, 0x2C9DF },
	{ 0xE5AB9F, 0x2C9E3 },
	{ 0xE5ABA0, 0x2C9DC },
	{ 0xE5ABA1, 0x1E8C6 },
	{ 0xE5ABA2, 0x2C9DB },
	{ 0xE5ABA3, 0x1E8CC },
	{ 0xE5ABA4, 0x3C6CC },
	{ 0xE5ABA5, 0x2C9D4 },
	{ 0xE5ABA6, 0x1E8C7 },
	{ 0xE5ABA7, 0x3C6CA },
	{ 0xE5ABA8, 0x2C9E2 },
	{ 0xE5ABA9, 0x1E8C8 },
	{ 0xE5ABAA, 0x2C9D6 },
	{ 0xE5ABAB, 0x2C9D9 },
	{ 0xE5ABAC, 0x2C9DE },
	{ 0xE5ABAD, 0x2C9D8 },
	{ 0xE5ABAE, 0x2C9D3 },
	{ 0xE5ABAF, 0x3C6CF },
	{ 0xE5ABB0, 0x3C6D3 },
	{ 0xE5ABB3, 0x2C9DA },
	{ 0xE5ABB4, 0x2CFFC },
	{ 0xE5ABB5, 0x1ECCB },
	{ 0xE5ABB6, 0x2D0A1 },
	{ 0xE5ABB7, 0x2CFFE },
	{ 0xE5ABB8, 0x2D0A3 },
	{ 0xE5ABB9, 0x2D0A5 },
	{ 0xE5ABBA, 0x3CBDC },
	{ 0xE5ABBB, 0x1ECC9 },
	{ 0xE5ABBC, 0x3CBD8 },
	{ 0xE5ABBD, 0x2CFFD },
	{ 0xE5ABBE, 0x3CBD4 },
	{ 0xE5ABBF, 0x2CFFB },
	{ 0xE5AC80, 0x3CBDE },
	{ 0xE5AC81, 0x2D0A6 },
	{ 0xE5AC82, 0x2D0A4 },
	{ 0xE5AC83, 0x2D0A2 },
	{ 0xE5AC84, 0x3CBD6 },
	{ 0xE5AC85, 0x2D0A8 },
	{ 0xE5AC86, 0x3CBDA },
	{ 0xE5AC87, 0x2D0A7 },
	{ 0xE5AC88, 0x1ECCD },
	{ 0xE5AC89, 0x1ECC8 },
	{ 0xE5AC8A, 0x3CBDB },
	{ 0xE5AC8B, 0x1ECCA },
	{ 0xE5AC8C, 0x1ECCC },
	{ 0xE5AC8D, 0x3CBDD },
	{ 0xE5AC8E, 0x3CBDF },
	{ 0xE5AC8F, 0x2D0A9 },
	{ 0xE5AC90, 0x2D6E1 },
	{ 0xE5AC91, 0x3D0D0 },
	{ 0xE5AC92, 0x3D0D3 },
	{ 0xE5AC93, 0x2D6E0 },
	{ 0xE5AC94, 0x2D6DF },
	{ 0xE5AC95, 0x3D0D1 },
	{ 0xE5AC96, 0x2D6E2 },
	{ 0xE5AC97, 0x2D6DB },
	{ 0xE5AC98, 0x3D0CF },
	{ 0xE5AC99, 0x2D6DC },
	{ 0xE5AC9A, 0x2D6E4 },
	{ 0xE5AC9B, 0x2D6DD },
	{ 0xE5AC9C, 0x3D0D4 },
	{ 0xE5AC9D, 0x1F0CE },
	{ 0xE5AC9E, 0x2D6E6 },
	{ 0xE5AC9F, 0x3D0CE },
	{ 0xE5ACA0, 0x2D6E5 },
	{ 0xE5ACA1, 0x2D6DE },
	{ 0xE5ACA2, 0x3D0D6 },
	{ 0xE5ACA3, 0x2DCDD },
	{ 0xE5ACA4, 0x1F3D1 },
	{ 0xE5ACA5, 0x2DCDB },
	{ 0xE5ACA6, 0x2DCE0 },
	{ 0xE5ACA7, 0x2DCDF },
	{ 0xE5ACA8, 0x2D6E3 },
	{ 0xE5ACA9, 0x3D4D0 },
	{ 0xE5ACAA, 0x1F3D0 },
	{ 0xE5ACAB, 0x3D4CE },
	{ 0xE5ACAC, 0x2DCDE },
	{ 0xE5ACAD, 0x2DCDA },
	{ 0xE5ACAE, 0x2DCE2 },
	{ 0xE5ACAF, 0x2DCE1 },
	{ 0xE5ACB0, 0x1F3CF },
	{ 0xE5ACB1, 0x3D4D2 },
	{ 0xE5ACB2, 0x2DCDC },
	{ 0xE5ACB3, 0x3D4CF },
	{ 0xE5ACB4, 0x1F0CF },
	{ 0xE5ACB5, 0x3D4D1 },
	{ 0xE5ACB7, 0x3D4D3 },
	{ 0xE5ACB8, 0x1F6C0 },
	{ 0xE5ACB9, 0x3DAB1 },
	{ 0xE5ACBA, 0x3D7E1 },
	{ 0xE5ACBB, 0x3D7DE },
	{ 0xE5ACBC, 0x2E1CD },
	{ 0xE5ACBD, 0x2E5C6 },
	{ 0xE5ACBE, 0x2E5C7 },
	{ 0xE5ACBF, 0x2E5C8 },
	{ 0xE5AD80, 0x1F9E7 },
	{ 0xE5AD81, 0x4E3B4 },
	{ 0xE5AD82, 0x3DCB6 },
	{ 0xE5AD83, 0x1F9E8 },
	{ 0xE5AD84, 0x3DCB9 },
	{ 0xE5AD85, 0x2E8EF },
	{ 0xE5AD86, 0x3DCBA },
	{ 0xE5AD87, 0x2EBD6 },
	{ 0xE5AD88, 0x2EBD5 },
	{ 0xE5AD89, 0x3DEA9 },
	{ 0xE5AD8A, 0x3DFC2 },
	{ 0xE5AD8B, 0x2EDC9 },
	{ 0xE5AD8C, 0x2EDCA },
	{ 0xE5AD8D, 0x2EFA4 },
	{ 0xE5AD8E, 0x2F0B5 },
	{ 0xE5AD8F, 0x3E0F3 },
	{ 0xE5AD90, 0x1C4CD },
	{ 0xE5AD91, 0x1C4CE },
	{ 0xE5AD92, 0x4A1B2 },
	{ 0xE5AD93, 0x1C4CF },
	{ 0xE5AD94, 0x1C5B6 },
	{ 0xE5AD95, 0x1C6C5 },
	{ 0xE5AD96, 0x2A2B3 },
	{ 0xE5AD97, 0x1C7F3 },
	{ 0xE5AD98, 0x1C7F4 },
	{ 0xE5AD9A, 0x1C9F7 },
	{ 0xE5AD9B, 0x1C9F8 },
	{ 0xE5AD9C, 0x1C9F6 },
	{ 0xE5AD9D, 0x1C9F5 },
	{ 0xE5AD9F, 0x1CCF5 },
	{ 0xE5ADA0, 0x3A8C8 },
	{ 0xE5ADA1, 0x4A6A2 },
	{ 0xE5ADA2, 0x2A6B6 },
	{ 0xE5ADA3, 0x1CCF7 },
	{ 0xE5ADA4, 0x1CCF6 },
	{ 0xE5ADA5, 0x2A6B7 },
	{ 0xE5ADA6, 0x4A6A3 },
	{ 0xE5ADA7, 0x3E4EA },
	{ 0xE5ADA8, 0x4A8EE },
	{ 0xE5ADA9, 0x1D0E6 },
	{ 0xE5ADAA, 0x3ACAF },
	{ 0xE5ADAB, 0x1D5A1 },
	{ 0xE5ADAC, 0x2AEE7 },
	{ 0xE5ADAE, 0x2B4F3 },
	{ 0xE5ADAF, 0x4B1AC },
	{ 0xE5ADB0, 0x1D9E9 },
	{ 0xE5ADB1, 0x1DEEC },
	{ 0xE5ADB2, 0x2B4F2 },
	{ 0xE5ADB3, 0x1DEEB },
	{ 0xE5ADB4, 0x3C0F1 },
	{ 0xE5ADB5, 0x1E8CD },
	{ 0xE5ADB6, 0x3C0F2 },
	{ 0xE5ADB7, 0x2C9E4 },
	{ 0xE5ADB8, 0x1F0D0 },
	{ 0xE5ADB9, 0x3D0D7 },
	{ 0xE5ADBA, 0x1F3D2 },
	{ 0xE5ADBB, 0x2DCE3 },
	{ 0xE5ADBC, 0x3DAB4 },
	{ 0xE5ADBD, 0x1F9E9 },
	{ 0xE5ADBE, 0x3DCBB },
	{ 0xE5ADBF, 0x1FBDC },
	{ 0xE5AE80, 0x3A1BB },
	{ 0xE5AE81, 0x2A1D3 },
	{ 0xE5AE82, 0x3A2BD },
	{ 0xE5AE83, 0x1C6C6 },
	{ 0xE5AE84, 0x2A1D4 },
	{ 0xE5AE85, 0x1C7F7 },
	{ 0xE5AE86, 0x3A3D0 },
	{ 0xE5AE87, 0x1C7F5 },
	{ 0xE5AE88, 0x1C7F6 },
	{ 0xE5AE89, 0x1C7F8 },
	{ 0xE5AE8A, 0x4A3EF },
	{ 0xE5AE8B, 0x1C9FA },
	{ 0xE5AE8C, 0x1C9F9 },
	{ 0xE5AE8D, 0x3A5DA },
	{ 0xE5AE8E, 0x2A3DC },
	{ 0xE5AE8F, 0x1C9FB },
	{ 0xE5AE90, 0x4A6A5 },
	{ 0xE5AE92, 0x2A3DD },
	{ 0xE5AE93, 0x2A6B8 },
	{ 0xE5AE94, 0x3A8CC },
	{ 0xE5AE95, 0x2A6B9 },
	{ 0xE5AE96, 0x3A8CA },
	{ 0xE5AE97, 0x1CCF8 },
	{ 0xE5AE98, 0x1CCFA },
	{ 0xE5AE99, 0x1CCFC },
	{ 0xE5AE9A, 0x1CCF9 },
	{ 0xE5AE9B, 0x1CCFD },
	{ 0xE5AE9C, 0x1CCFB },
	{ 0xE5AE9D, 0x3A8CE },
	{ 0xE5AE9E, 0x3A8CB },
	{ 0xE5AE9F, 0x3A8CD },
	{ 0xE5AEA2, 0x1D0EA },
	{ 0xE5AEA3, 0x1D0E7 },
	{ 0xE5AEA4, 0x1D0E9 },
	{ 0xE5AEA5, 0x1D0EB },
	{ 0xE5AEA6, 0x1D0E8 },
	{ 0xE5AEA7, 0x2AEE8 },
	{ 0xE5AEA8, 0x2A9F8 },
	{ 0xE5AEA9, 0xFAAB9 },
	{ 0xE5AEAB, 0x3ACB2 },
	{ 0xE5AEAC, 0x2AEEA },
	{ 0xE5AEAD, 0x2AEE9 },
	{ 0xE5AEAE, 0x1D5A7 },
	{ 0xE5AEAF, 0x4ACC6 },
	{ 0xE5AEB0, 0x1D5A3 },
	{ 0xE5AEB1, 0x4ACC9 },
	{ 0xE5AEB2, 0x6B6E6 },
	{ 0xE5AEB3, 0x1D5A4 },
	{ 0xE5AEB4, 0x1D5A6 },
	{ 0xE5AEB5, 0x1D5A8 },
	{ 0xE5AEB6, 0x1D5A5 },
	{ 0xE5AEB7, 0x3B0D7 },
	{ 0xE5AEB8, 0x1D5AA },
	{ 0xE5AEB9, 0x1D5A9 },
	{ 0xE5AEBA, 0x4ACC8 },
	{ 0xE5AEBB, 0x3B0D6 },
	{ 0xE5AEBC, 0x3B0D5 },
	{ 0xE5AEBE, 0xFAEFE },
	{ 0xE5AEBF, 0x1D9EE },
	{ 0xE5AF80, 0x2B4F5 },
	{ 0xE5AF81, 0x2B4F4 },
	{ 0xE5AF82, 0x1D9ED },
	{ 0xE5AF83, 0x3B5C1 },
	{ 0xE5AF84, 0x1D9EC },
	{ 0xE5AF85, 0x1D9EB },
	{ 0xE5AF86, 0x1D9EF },
	{ 0xE5AF87, 0x1D9EA },
	{ 0xE5AF88, 0x3B5BF },
	{ 0xE5AF8A, 0x2BBB9 },
	{ 0xE5AF8B, 0x2BBB6 },
	{ 0xE5AF8C, 0x1DEEE },
	{ 0xE5AF8D, 0x2BBB5 },
	{ 0xE5AF8E, 0x2BBBA },
	{ 0xE5AF8F, 0x4B7A4 },
	{ 0xE5AF90, 0x1DEF0 },
	{ 0xE5AF91, 0x2BBB8 },
	{ 0xE5AF92, 0x1DEED },
	{ 0xE5AF93, 0x1DEEF },
	{ 0xE5AF94, 0x2BBB7 },
	{ 0xE5AF95, 0x3BAFE },
	{ 0xE5AF96, 0x2C2CE },
	{ 0xE5AF97, 0x3C0F4 },
	{ 0xE5AF98, 0x2C2CF },
	{ 0xE5AF99, 0x2C2D0 },
	{ 0xE5AF9A, 0x3C0F5 },
	{ 0xE5AF9B, 0x3C0F6 },
	{ 0xE5AF9C, 0x3C0F3 },
	{ 0xE5AF9D, 0x4BCEE },
	{ 0xE5AF9E, 0x1E8CE },
	{ 0xE5AF9F, 0x1E8D6 },
	{ 0xE5AFA0, 0x2C9E5 },
	{ 0xE5AFA1, 0x1E8D0 },
	{ 0xE5AFA2, 0x1E8D4 },
	{ 0xE5AFA3, 0x2C9E6 },
	{ 0xE5AFA4, 0x1E8D5 },
	{ 0xE5AFA5, 0x1E8D1 },
	{ 0xE5AFA6, 0x1E8D2 },
	{ 0xE5AFA7, 0x1E8CF },
	{ 0xE5AFA8, 0x1E8D3 },
	{ 0xE5AFA9, 0x1ECD0 },
	{ 0xE5AFAA, 0x2BBB4 },
	{ 0xE5AFAB, 0x1ECD1 },
	{ 0xE5AFAC, 0x1ECCF },
	{ 0xE5AFAD, 0x4C9C4 },
	{ 0xE5AFAE, 0x1ECCE },
	{ 0xE5AFAF, 0x2D6E7 },
	{ 0xE5AFB0, 0x1F0D1 },
	{ 0xE5AFB1, 0x2DCE4 },
	{ 0xE5AFB2, 0x2DCE5 },
	{ 0xE5AFB3, 0x3DAB5 },
	{ 0xE5AFB4, 0x4DFD5 },
	{ 0xE5AFB5, 0x1F8B1 },
	{ 0xE5AFB6, 0x1F9EA },
	{ 0xE5AFB7, 0x3DEAA },
	{ 0xE5AFB8, 0x1C4D0 },
	{ 0xE5AFB9, 0x3A2BE },
	{ 0xE5AFBA, 0x1C7F9 },
	{ 0xE5AFBD, 0x3A5DE },
	{ 0xE5AFBE, 0x3A5DC },
	{ 0xE5AFBF, 0x3A5DD },
	{ 0xE5B080, 0x3A8D0 },
	{ 0xE5B081, 0x1D0EC },
	{ 0xE5B083, 0x2AEEB },
	{ 0xE5B084, 0x1D5AB },
	{ 0xE5B085, 0x3B0D8 },
	{ 0xE5B086, 0x3B0D9 },
	{ 0xE5B087, 0x1D9F2 },
	{ 0xE5B088, 0x1D9F1 },
	{ 0xE5B089, 0x1D9F0 },
	{ 0xE5B08A, 0x1DEF1 },
	{ 0xE5B08B, 0x1DEF2 },
	{ 0xE5B08C, 0x2BBBB },
	{ 0xE5B08D, 0x1E8D7 },
	{ 0xE5B08E, 0x1F0D2 },
	{ 0xE5B08F, 0x1C4D1 },
	{ 0xE5B090, 0x2A1BC },
	{ 0xE5B091, 0x1C5B7 },
	{ 0xE5B092, 0x2A1D5 },
	{ 0xE5B093, 0x4A1F3 },
	{ 0xE5B094, 0x3A2BF },
	{ 0xE5B095, 0x2A2B4 },
	{ 0xE5B096, 0x1C7FA },
	{ 0xE5B097, 0x4A2DC },
	{ 0xE5B098, 0x3A3D2 },
	{ 0xE5B099, 0x3A8D1 },
	{ 0xE5B09A, 0x1CCFE },
	{ 0xE5B09B, 0x3ACB4 },
	{ 0xE5B09E, 0x3BBA4 },
	{ 0xE5B09F, 0x2C2D1 },
	{ 0xE5B0A0, 0x3C0F8 },
	{ 0xE5B0A1, 0x3E5A5 },
	{ 0xE5B0A2, 0x1C4D2 },
	{ 0xE5B0A3, 0x4A1CB },
	{ 0xE5B0A4, 0x1C5B8 },
	{ 0xE5B0A5, 0x2A2B5 },
	{ 0xE5B0A8, 0x2A3DE },
	{ 0xE5B0A9, 0x4A6A9 },
	{ 0xE5B0AA, 0x2A3DF },
	{ 0xE5B0AB, 0x3A5DF },
	{ 0xE5B0AC, 0x1C9FC },
	{ 0xE5B0AD, 0xFA5D4 },
	{ 0xE5B0AF, 0x3ACB5 },
	{ 0xE5B0B0, 0x2BBBC },
	{ 0xE5B0B1, 0x1DEF3 },
	{ 0xE5B0B3, 0x2C2D2 },
	{ 0xE5B0B5, 0x4C9C9 },
	{ 0xE5B0B6, 0x3D4D4 },
	{ 0xE5B0B7, 0x1F3D3 },
	{ 0xE5B0B8, 0x1C4D3 },
	{ 0xE5B0B9, 0x1C4E7 },
	{ 0xE5B0BA, 0x1C5B9 },
	{ 0xE5B0BB, 0x2A1D6 },
	{ 0xE5B0BC, 0x1C6C7 },
	{ 0xE5B0BD, 0x3A3D4 },
	{ 0xE5B0BE, 0x1CAA2 },
	{ 0xE5B0BF, 0x1CAA1 },
	{ 0xE5B180, 0x1C9FD },
	{ 0xE5B181, 0x1C9FE },
	{ 0xE5B184, 0x2A6BA },
	{ 0xE5B185, 0x1CDA2 },
	{ 0xE5B186, 0x1CDA3 },
	{ 0xE5B187, 0x2A6BB },
	{ 0xE5B188, 0x1CDA1 },
	{ 0xE5B189, 0x3A8D4 },
	{ 0xE5B18A, 0x3A8D5 },
	{ 0xE5B18B, 0x1D0F0 },
	{ 0xE5B18C, 0x2A9F9 },
	{ 0xE5B18D, 0x1D0EF },
	{ 0xE5B18E, 0x1D0ED },
	{ 0xE5B18F, 0x1D0EE },
	{ 0xE5B190, 0x1D5AE },
	{ 0xE5B191, 0x1D5AC },
	{ 0xE5B192, 0x3B0DA },
	{ 0xE5B193, 0x3B0DB },
	{ 0xE5B194, 0x2AEED },
	{ 0xE5B195, 0x1D5AD },
	{ 0xE5B196, 0x2AEEC },
	{ 0xE5B197, 0x3E4EB },
	{ 0xE5B198, 0x1D5A2 },
	{ 0xE5B199, 0x2B4F6 },
	{ 0xE5B19A, 0x4B1B5 },
	{ 0xE5B19B, 0x3B5C3 },
	{ 0xE5B19C, 0x1D9F4 },
	{ 0xE5B19D, 0x1D9F5 },
	{ 0xE5B19E, 0x3BBA6 },
	{ 0xE5B19F, 0x3BBA5 },
	{ 0xE5B1A0, 0x1D9F3 },
	{ 0xE5B1A1, 0x3B5C4 },
	{ 0xE5B1A2, 0x1E8D8 },
	{ 0xE5B1A3, 0x2C9E7 },
	{ 0xE5B1A4, 0x1ECD2 },
	{ 0xE5B1A5, 0x1ECD3 },
	{ 0xE5B1A7, 0x2D0AA },
	{ 0xE5B1A8, 0x1F3D4 },
	{ 0xE5B1A9, 0x2E1CE },
	{ 0xE5B1AA, 0x2E1CF },
	{ 0xE5B1AB, 0x3DAB8 },
	{ 0xE5B1AC, 0x1FAE8 },
	{ 0xE5B1AD, 0x2F0B6 },
	{ 0xE5B1AE, 0x2A1AB },
	{ 0xE5B1AF, 0x1C5BA },
	{ 0xE5B1B0, 0x4A2DF },
	{ 0xE5B1B1, 0x1C4D4 },
	{ 0xE5B1B3, 0x2A1D8 },
	{ 0xE5B1B4, 0x2A1D7 },
	{ 0xE5B1B5, 0x4A1F6 },
	{ 0xE5B1B7, 0x3E4EC },
	{ 0xE5B1B8, 0x3A3D5 },
	{ 0xE5B1B9, 0x1C7FB },
	{ 0xE5B1BA, 0x2A2B7 },
	{ 0xE5B1BB, 0x2A2B8 },
	{ 0xE5B1BC, 0x2A2B6 },
	{ 0xE5B1BD, 0x4A2E0 },
	{ 0xE5B1BE, 0x2A2B9 },
	{ 0xE5B280, 0x3A3DA },
	{ 0xE5B281, 0xFA2C7 },
	{ 0xE5B284, 0x3A5E1 },
	{ 0xE5B285, 0x3A5E6 },
	{ 0xE5B286, 0x2A3E7 },
	{ 0xE5B287, 0x4A3FA },
	{ 0xE5B288, 0x2A3E2 },
	{ 0xE5B289, 0x2A3E4 },
	{ 0xE5B28A, 0x2A3E6 },
	{ 0xE5B28B, 0x2A3E3 },
	{ 0xE5B28C, 0x1CAA6 },
	{ 0xE5B28D, 0x2A3E0 },
	{ 0xE5B28E, 0x3A5E2 },
	{ 0xE5B28F, 0x2A3E1 },
	{ 0xE5B290, 0x1CAA3 },
	{ 0xE5B291, 0x1CAA4 },
	{ 0xE5B292, 0x2A3E5 },
	{ 0xE5B293, 0x2A3E8 },
	{ 0xE5B294, 0x1CAA5 },
	{ 0xE5B295, 0x2A3E9 },
	{ 0xE5B297, 0xFA3FC },
	{ 0xE5B299, 0xFA3F8 },
	{ 0xE5B29C, 0x3A5E3 },
	{ 0xE5B29D, 0x2A6C9 },
	{ 0xE5B29E, 0x3A8DD },
	{ 0xE5B29F, 0x2A6C3 },
	{ 0xE5B2A0, 0x2A6BE },
	{ 0xE5B2A1, 0x1CDA5 },
	{ 0xE5B2A2, 0x2A6C6 },
	{ 0xE5B2A3, 0x2A6C4 },
	{ 0xE5B2A4, 0x2A6BD },
	{ 0xE5B2A5, 0x2A6CA },
	{ 0xE5B2A6, 0x2A6CD },
	{ 0xE5B2A7, 0x2A6C8 },
	{ 0xE5B2A8, 0x2A6C1 },
	{ 0xE5B2A9, 0x1CDA7 },
	{ 0xE5B2AA, 0x2A6C7 },
	{ 0xE5B2AB, 0x1CDA8 },
	{ 0xE5B2AC, 0x2A6C2 },
	{ 0xE5B2AD, 0x2A6C5 },
	{ 0xE5B2AE, 0x2A6BC },
	{ 0xE5B2AF, 0x2A6C0 },
	{ 0xE5B2B0, 0x2A6CC },
	{ 0xE5B2B1, 0x1CDA9 },
	{ 0xE5B2B2, 0x4A6AF },
	{ 0xE5B2B3, 0x1CDAA },
	{ 0xE5B2B4, 0x3A8DE },
	{ 0xE5B2B5, 0x2A6BF },
	{ 0xE5B2B6, 0x2A6CB },
	{ 0xE5B2B7, 0x1CDA4 },
	{ 0xE5B2B8, 0x1CDA6 },
	{ 0xE5B2B9, 0x3A8DC },
	{ 0xE5B2BA, 0x3A8DF },
	{ 0xE5B2BB, 0x3A8D7 },
	{ 0xE5B380, 0x4A6B4 },
	{ 0xE5B381, 0x3A8D8 },
	{ 0xE5B386, 0x2AAAC },
	{ 0xE5B387, 0x2AAA5 },
	{ 0xE5B388, 0x2AAAB },
	{ 0xE5B389, 0x2AAA4 },
	{ 0xE5B38A, 0x2AAA6 },
	{ 0xE5B38B, 0x2A9FE },
	{ 0xE5B38C, 0x2A9FC },
	{ 0xE5B38D, 0x3ACBF },
	{ 0xE5B38E, 0x2AAAD },
	{ 0xE5B38F, 0x2AAAA },
	{ 0xE5B390, 0x2A9FA },
	{ 0xE5B391, 0x3ACBB },
	{ 0xE5B392, 0x1D0F2 },
	{ 0xE5B393, 0x2AAA8 },
	{ 0xE5B394, 0x2AAA9 },
	{ 0xE5B395, 0x3E4ED },
	{ 0xE5B396, 0x2AAA7 },
	{ 0xE5B397, 0x2A9FD },
	{ 0xE5B398, 0x2A9FB },
	{ 0xE5B399, 0x1D0F1 },
	{ 0xE5B39A, 0x2AAA3 },
	{ 0xE5B39B, 0x2AAA1 },
	{ 0xE5B39C, 0x3ACBC },
	{ 0xE5B39D, 0x3ACC2 },
	{ 0xE5B39E, 0x2AAA2 },
	{ 0xE5B39F, 0x2AAAE },
	{ 0xE5B3A1, 0x3ACBE },
	{ 0xE5B3A2, 0x3ACC1 },
	{ 0xE5B3A5, 0x3ACC3 },
	{ 0xE5B3A6, 0x3ACBD },
	{ 0xE5B3A8, 0x1D5B3 },
	{ 0xE5B3A9, 0x3B0E3 },
	{ 0xE5B3AA, 0x1D5B2 },
	{ 0xE5B3AB, 0x3B0DF },
	{ 0xE5B3AC, 0x2AEEE },
	{ 0xE5B3AD, 0x1D5AF },
	{ 0xE5B3AE, 0x2AEF0 },
	{ 0xE5B3AF, 0x3B0E4 },
	{ 0xE5B3B0, 0x1D5B4 },
	{ 0xE5B3B1, 0x2AEF1 },
	{ 0xE5B3B2, 0x4ACE0 },
	{ 0xE5B3B3, 0x3B0E1 },
	{ 0xE5B3B4, 0x1D5B7 },
	{ 0xE5B3B5, 0x3B0E2 },
	{ 0xE5B3B6, 0x1D5B5 },
	{ 0xE5B3B7, 0x2AEF2 },
	{ 0xE5B3B8, 0x2AAAF },
	{ 0xE5B3B9, 0x2AEF4 },
	{ 0xE5B3BA, 0x3B0DE },
	{ 0xE5B3BB, 0x1D5B1 },
	{ 0xE5B3BC, 0x4ACDC },
	{ 0xE5B3BD, 0x1D5B0 },
	{ 0xE5B3BE, 0x4ACE1 },
	{ 0xE5B3BF, 0x2AEEF },
	{ 0xE5B480, 0x2AEF3 },
	{ 0xE5B481, 0x1D5B6 },
	{ 0xE5B486, 0x1D9F7 },
	{ 0xE5B487, 0x1D9F6 },
	{ 0xE5B488, 0x3B5CB },
	{ 0xE5B489, 0x3B5C8 },
	{ 0xE5B48A, 0x3B5C7 },
	{ 0xE5B48B, 0x2B4F8 },
	{ 0xE5B48C, 0x2B4FC },
	{ 0xE5B48D, 0x2B4FE },
	{ 0xE5B48E, 0x1D9F8 },
	{ 0xE5B48F, 0x2B5A3 },
	{ 0xE5B490, 0x3B5D1 },
	{ 0xE5B491, 0x1D9FC },
	{ 0xE5B492, 0x2B5A5 },
	{ 0xE5B493, 0x3B5D2 },
	{ 0xE5B494, 0x1D9FE },
	{ 0xE5B495, 0x3B5CF },
	{ 0xE5B496, 0x1D9FA },
	{ 0xE5B497, 0x1DAA4 },
	{ 0xE5B498, 0x3B5D5 },
	{ 0xE5B499, 0x1DAA1 },
	{ 0xE5B49A, 0x2B4FA },
	{ 0xE5B49B, 0x1D9F9 },
	{ 0xE5B49C, 0x3BBAB },
	{ 0xE5B49D, 0x2B4F9 },
	{ 0xE5B49E, 0x2B4F7 },
	{ 0xE5B49F, 0x2B5A7 },
	{ 0xE5B4A0, 0x2B4FB },
	{ 0xE5B4A1, 0x3B5C6 },
	{ 0xE5B4A2, 0x1D9FB },
	{ 0xE5B4A3, 0x2B5A6 },
	{ 0xE5B4A4, 0x1DAA2 },
	{ 0xE5B4A5, 0x2B5A2 },
	{ 0xE5B4A6, 0x2B5A1 },
	{ 0xE5B4A7, 0x1DAA3 },
	{ 0xE5B4A8, 0x2B4FD },
	{ 0xE5B4A9, 0x1D9FD },
	{ 0xE5B4AA, 0x3B5CE },
	{ 0xE5B4AB, 0x6BEF6 },
	{ 0xE5B4AC, 0x3B5CA },
	{ 0xE5B4AE, 0x2B5A8 },
	{ 0xE5B4AF, 0x3B5D4 },
	{ 0xE5B4B0, 0x2B5A4 },
	{ 0xE5B4B1, 0x2BBCB },
	{ 0xE5B4B2, 0x2BBD2 },
	{ 0xE5B4B3, 0x2BBC7 },
	{ 0xE5B4B4, 0x1DEF6 },
	{ 0xE5B4B5, 0x2BBC3 },
	{ 0xE5B4B6, 0x2BBD3 },
	{ 0xE5B4B7, 0x2BBBD },
	{ 0xE5B4B8, 0x2BBD0 },
	{ 0xE5B4B9, 0x2BBCE },
	{ 0xE5B4BA, 0x2BBC8 },
	{ 0xE5B4BB, 0x3BBB6 },
	{ 0xE5B4BC, 0x2BBD1 },
	{ 0xE5B4BD, 0x2BBCA },
	{ 0xE5B4BE, 0x3BBA8 },
	{ 0xE5B4BF, 0x2BBC2 },
	{ 0xE5B580, 0x2BBD4 },
	{ 0xE5B581, 0x2BBC0 },
	{ 0xE5B582, 0x2BBCD },
	{ 0xE5B583, 0x2BBBE },
	{ 0xE5B584, 0x3BBA7 },
	{ 0xE5B585, 0x2BBD5 },
	{ 0xE5B586, 0x3BBB7 },
	{ 0xE5B587, 0x1DEF7 },
	{ 0xE5B588, 0x3BBAA },
	{ 0xE5B589, 0x2BBCF },
	{ 0xE5B58A, 0x2C2D5 },
	{ 0xE5B58B, 0x2BBC1 },
	{ 0xE5B58C, 0x1DEF4 },
	{ 0xE5B58D, 0x3BBAE },
	{ 0xE5B58E, 0x2BBC5 },
	{ 0xE5B58F, 0x3BBB4 },
	{ 0xE5B590, 0x1DEF5 },
	{ 0xE5B591, 0x2BBC4 },
	{ 0xE5B592, 0x2BBC9 },
	{ 0xE5B593, 0x3BBB3 },
	{ 0xE5B594, 0x4B7B5 },
	{ 0xE5B595, 0x2BBC6 },
	{ 0xE5B596, 0x4B7AF },
	{ 0xE5B597, 0x3BBB1 },
	{ 0xE5B599, 0x2BBCC },
	{ 0xE5B59B, 0x3BBAD },
	{ 0xE5B59E, 0x2C2D9 },
	{ 0xE5B59F, 0x4BCF9 },
	{ 0xE5B5A0, 0x3C1A1 },
	{ 0xE5B5A1, 0x4BCFB },
	{ 0xE5B5A2, 0x2C2DC },
	{ 0xE5B5A3, 0x2C2D4 },
	{ 0xE5B5A4, 0x3C0FC },
	{ 0xE5B5A5, 0x2C2D6 },
	{ 0xE5B5A6, 0x3C0FA },
	{ 0xE5B5A7, 0x2C2DB },
	{ 0xE5B5A8, 0x2C2DA },
	{ 0xE5B5A9, 0x1E3E9 },
	{ 0xE5B5AA, 0x4BCF5 },
	{ 0xE5B5AB, 0x2BBBF },
	{ 0xE5B5AC, 0x2C2D8 },
	{ 0xE5B5AD, 0x3C0F9 },
	{ 0xE5B5AE, 0x3C0FD },
	{ 0xE5B5AF, 0x1E3EA },
	{ 0xE5B5B0, 0x4BCF4 },
	{ 0xE5B5B1, 0x2C2D3 },
	{ 0xE5B5B2, 0x2C2D7 },
	{ 0xE5B5B3, 0x4BCFC },
	{ 0xE5B5B4, 0x4BCF8 },
	{ 0xE5B5B5, 0x3E4EE },
	{ 0xE5B5B7, 0x2C9EE },
	{ 0xE5B5B8, 0x3C6DC },
	{ 0xE5B5B9, 0x2C9F5 },
	{ 0xE5B5BA, 0x2C9EC },
	{ 0xE5B5BB, 0x3C6D4 },
	{ 0xE5B5BC, 0x2C9F3 },
	{ 0xE5B5BD, 0x2C9EA },
	{ 0xE5B5BE, 0x2C9F2 },
	{ 0xE5B5BF, 0x2C9F6 },
	{ 0xE5B680, 0x2C9E9 },
	{ 0xE5B681, 0x2C9ED },
	{ 0xE5B682, 0x2C9E8 },
	{ 0xE5B683, 0x3C6D6 },
	{ 0xE5B684, 0x1E8D9 },
	{ 0xE5B685, 0x4C3AC },
	{ 0xE5B686, 0x2C9EB },
	{ 0xE5B687, 0x1E8DA },
	{ 0xE5B688, 0x2C9F1 },
	{ 0xE5B689, 0x2C9F0 },
	{ 0xE5B68A, 0x2C9EF },
	{ 0xE5B68B, 0x3C6D9 },
	{ 0xE5B68C, 0x3C6DA },
	{ 0xE5B68D, 0x2C9F4 },
	{ 0xE5B68E, 0x3E4EF },
	{ 0xE5B68F, 0x3CBE5 },
	{ 0xE5B690, 0x3CBE6 },
	{ 0xE5B691, 0x3CBE3 },
	{ 0xE5B692, 0x2D0AE },
	{ 0xE5B693, 0x2D0B0 },
	{ 0xE5B694, 0x1ECD5 },
	{ 0xE5B695, 0x2D0B1 },
	{ 0xE5B696, 0x3CBEB },
	{ 0xE5B697, 0x2D0AC },
	{ 0xE5B698, 0x3CBE7 },
	{ 0xE5B699, 0x2D0AB },
	{ 0xE5B69A, 0x2D0B5 },
	{ 0xE5B69B, 0x3CBE9 },
	{ 0xE5B69C, 0x2D0B3 },
	{ 0xE5B69D, 0x1ECD4 },
	{ 0xE5B69E, 0x2D0B6 },
	{ 0xE5B69F, 0x2D0AD },
	{ 0xE5B6A0, 0x2D0B2 },
	{ 0xE5B6A1, 0x2D0B4 },
	{ 0xE5B6A2, 0x2D0AF },
	{ 0xE5B6A3, 0x3CBEA },
	{ 0xE5B6A4, 0x3CBE8 },
	{ 0xE5B6A5, 0x3E4F0 },
	{ 0xE5B6A6, 0x3D0D8 },
	{ 0xE5B6A7, 0x2D6EB },
	{ 0xE5B6A8, 0x2D6F0 },
	{ 0xE5B6A9, 0x2D6EA },
	{ 0xE5B6AA, 0x2D6EF },
	{ 0xE5B6AB, 0x3D0DB },
	{ 0xE5B6AC, 0x2D6E8 },
	{ 0xE5B6AD, 0x2D6F2 },
	{ 0xE5B6AE, 0x2D6EE },
	{ 0xE5B6AF, 0x2D6F3 },
	{ 0xE5B6B0, 0x2D6ED },
	{ 0xE5B6B1, 0x2D6E9 },
	{ 0xE5B6B2, 0x2D6F1 },
	{ 0xE5B6B3, 0x3D0DA },
	{ 0xE5B6B4, 0x2D6F4 },
	{ 0xE5B6B5, 0x2D6EC },
	{ 0xE5B6B6, 0x3E4F1 },
	{ 0xE5B6B7, 0x2DCE6 },
	{ 0xE5B6B8, 0x1F3D8 },
	{ 0xE5B6B9, 0x3D4D7 },
	{ 0xE5B6BA, 0x1F3D6 },
	{ 0xE5B6BB, 0x3D4D9 },
	{ 0xE5B6BC, 0x1F3D5 },
	{ 0xE5B6BD, 0x1F3D7 },
	{ 0xE5B6BE, 0x3D4D5 },
	{ 0xE5B6BF, 0x3E4F2 },
	{ 0xE5B780, 0x2E1D0 },
	{ 0xE5B781, 0x3D7E2 },
	{ 0xE5B782, 0x2E4BE },
	{ 0xE5B783, 0x2E5C9 },
	{ 0xE5B784, 0x3DAB9 },
	{ 0xE5B786, 0x2E8F0 },
	{ 0xE5B787, 0x2E8F1 },
	{ 0xE5B788, 0x3DCBD },
	{ 0xE5B789, 0x1F9EB },
	{ 0xE5B78A, 0x3DCBC },
	{ 0xE5B78B, 0x2EBD7 },
	{ 0xE5B78C, 0x3DCBE },
	{ 0xE5B78D, 0x1FAE9 },
	{ 0xE5B78E, 0x4E6BB },
	{ 0xE5B78F, 0x2EBD8 },
	{ 0xE5B790, 0x3DEAD },
	{ 0xE5B791, 0x2EDCC },
	{ 0xE5B792, 0x1FBDE },
	{ 0xE5B793, 0x3DFC3 },
	{ 0xE5B794, 0x1FBDD },
	{ 0xE5B795, 0x2EDCB },
	{ 0xE5B796, 0x1FCB5 },
	{ 0xE5B797, 0x3E0B0 },
	{ 0xE5B798, 0x2EFA5 },
	{ 0xE5B799, 0x4EBE8 },
	{ 0xE5B79A, 0x4EAC6 },
	{ 0xE5B79B, 0x3A1BC },
	{ 0xE5B79C, 0x4A1AC },
	{ 0xE5B79D, 0x1C4D5 },
	{ 0xE5B79E, 0x1C7FC },
	{ 0xE5B79F, 0x2A2BA },
	{ 0xE5B7A0, 0x2A3EA },
	{ 0xE5B7A1, 0x1CBD6 },
	{ 0xE5B7A2, 0x1DAA5 },
	{ 0xE5B7A3, 0x3B5D7 },
	{ 0xE5B7A4, 0x3CBEC },
	{ 0xE5B7A5, 0x1C4D6 },
	{ 0xE5B7A6, 0x1C6CA },
	{ 0xE5B7A7, 0x1C6C9 },
	{ 0xE5B7A8, 0x1C6C8 },
	{ 0xE5B7A9, 0x4A2E3 },
	{ 0xE5B7AB, 0x1CAA7 },
	{ 0xE5B7AE, 0x1D5B8 },
	{ 0xE5B7B0, 0x2C2DD },
	{ 0xE5B7B1, 0x1C4D7 },
	{ 0xE5B7B2, 0x1C4D8 },
	{ 0xE5B7B3, 0x1C4D9 },
	{ 0xE5B7B4, 0x1C5BB },
	{ 0xE5B7B5, 0x3A5E7 },
	{ 0xE5B7B6, 0x3A8E0 },
	{ 0xE5B7B7, 0x1D0F3 },
	{ 0xE5B7B8, 0x4ACE4 },
	{ 0xE5B7B9, 0x2AAB0 },
	{ 0xE5B7BA, 0x3ACC5 },
	{ 0xE5B7BB, 0x3ACC4 },
	{ 0xE5B7BD, 0x1DEF8 },
	{ 0xE5B7BE, 0x1C4DA },
	{ 0xE5B7BF, 0x2A1BD },
	{ 0xE5B880, 0x3A1E3 },
	{ 0xE5B881, 0x4A1CC },
	{ 0xE5B882, 0x1C6CB },
	{ 0xE5B883, 0x1C6CC },
	{ 0xE5B884, 0x2A1D9 },
	{ 0xE5B886, 0x1C7FD },
	{ 0xE5B887, 0x5A2DC },
	{ 0xE5B888, 0x3A3DC },
	{ 0xE5B889, 0x3A5E8 },
	{ 0xE5B88A, 0x2A3EB },
	{ 0xE5B88B, 0x3A5EB },
	{ 0xE5B88C, 0x1CAA8 },
	{ 0xE5B88D, 0x4A4A3 },
	{ 0xE5B88E, 0x2A3EC },
	{ 0xE5B891, 0x1CDB0 },
	{ 0xE5B892, 0x3A8E2 },
	{ 0xE5B893, 0x3A8E1 },
	{ 0xE5B894, 0x2A6CF },
	{ 0xE5B895, 0x1CDAE },
	{ 0xE5B896, 0x1CDAD },
	{ 0xE5B897, 0x2A6CE },
	{ 0xE5B898, 0x1CDAB },
	{ 0xE5B899, 0x2A6D0 },
	{ 0xE5B89A, 0x1CDAC },
	{ 0xE5B89B, 0x1CDAF },
	{ 0xE5B89D, 0x1D0F4 },
	{ 0xE5B89E, 0x3ACC6 },
	{ 0xE5B89F, 0x1D0F6 },
	{ 0xE5B8A0, 0x2AAB4 },
	{ 0xE5B8A1, 0x2AAB1 },
	{ 0xE5B8A2, 0x2AAB2 },
	{ 0xE5B8A3, 0x2AAB3 },
	{ 0xE5B8A4, 0x2AAB5 },
	{ 0xE5B8A5, 0x1D0F5 },
	{ 0xE5B8A8, 0x2AEF6 },
	{ 0xE5B8A9, 0x2AEF5 },
	{ 0xE5B8AA, 0x3B0E6 },
	{ 0xE5B8AB, 0x1D5BA },
	{ 0xE5B8AC, 0x3B0E9 },
	{ 0xE5B8AD, 0x1D5B9 },
	{ 0xE5B8AE, 0x3B0E8 },
	{ 0xE5B8AF, 0x3B0EA },
	{ 0xE5B8B0, 0x3B0E7 },
	{ 0xE5B8B2, 0x3B5DB },
	{ 0xE5B8B3, 0x1DAA8 },
	{ 0xE5B8B4, 0x2B5AA },
	{ 0xE5B8B5, 0x3B5D9 },
	{ 0xE5B8B6, 0x1DAA7 },
	{ 0xE5B8B7, 0x1DAA9 },
	{ 0xE5B8B8, 0x1DAA6 },
	{ 0xE5B8B9, 0x3B5D8 },
	{ 0xE5B8BA, 0x3B5DA },
	{ 0xE5B8BD, 0x1DEFA },
	{ 0xE5B8BE, 0x2B5A9 },
	{ 0xE5B8BF, 0x5B7FC },
	{ 0xE5B980, 0x1DEFB },
	{ 0xE5B981, 0x2BBD7 },
	{ 0xE5B982, 0x3B9F9 },
	{ 0xE5B983, 0x1DEFC },
	{ 0xE5B984, 0x2BBD6 },
	{ 0xE5B985, 0x1DEF9 },
	{ 0xE5B986, 0x3BBBA },
	{ 0xE5B987, 0x3BBBB },
	{ 0xE5B988, 0x3BBBD },
	{ 0xE5B98A, 0x2C2E0 },
	{ 0xE5B98B, 0x2C2E2 },
	{ 0xE5B98C, 0x1E3EB },
	{ 0xE5B98D, 0x2C2E1 },
	{ 0xE5B98E, 0x2C2DF },
	{ 0xE5B98F, 0x2C2DE },
	{ 0xE5B990, 0x4BDAA },
	{ 0xE5B991, 0x4C3B5 },
	{ 0xE5B992, 0x3C6DD },
	{ 0xE5B993, 0x2C9F9 },
	{ 0xE5B994, 0x1E8DF },
	{ 0xE5B995, 0x1E8DD },
	{ 0xE5B996, 0x4C3B0 },
	{ 0xE5B997, 0x1E8DE },
	{ 0xE5B998, 0x2C9F7 },
	{ 0xE5B999, 0x2C9F8 },
	{ 0xE5B99A, 0x3CBED },
	{ 0xE5B99B, 0x1E8DB },
	{ 0xE5B99C, 0x2D0BA },
	{ 0xE5B99D, 0x2D0B8 },
	{ 0xE5B99E, 0x3CBF0 },
	{ 0xE5B99F, 0x1ECD7 },
	{ 0xE5B9A0, 0x2D0B9 },
	{ 0xE5B9A1, 0x1ECD8 },
	{ 0xE5B9A2, 0x1ECD6 },
	{ 0xE5B9A3, 0x1E8DC },
	{ 0xE5B9A4, 0xFCEDE },
	{ 0xE5B9A5, 0x3E4F3 },
	{ 0xE5B9A6, 0x2D6F7 },
	{ 0xE5B9A7, 0x2D6F5 },
	{ 0xE5B9A8, 0x2D6F6 },
	{ 0xE5B9A9, 0x2D0B7 },
	{ 0xE5B9AA, 0x2DCE8 },
	{ 0xE5B9AB, 0x1F3D9 },
	{ 0xE5B9AC, 0x2DCE7 },
	{ 0xE5B9AD, 0x2E1D1 },
	{ 0xE5B9AE, 0x2E1D2 },
	{ 0xE5B9AF, 0x2D6F8 },
	{ 0xE5B9B0, 0x2E5CA },
	{ 0xE5B9B1, 0x3E6F7 },
	{ 0xE5B9B2, 0x1C4DB },
	{ 0xE5B9B3, 0x1C6CD },
	{ 0xE5B9B4, 0x1C8A1 },
	{ 0xE5B9B5, 0x2A2BB },
	{ 0xE5B9B6, 0x1C7FE },
	{ 0xE5B9B7, 0x3A8E3 },
	{ 0xE5B9B8, 0x1CDB1 },
	{ 0xE5B9B9, 0x1E3EC },
	{ 0xE5B9BA, 0x3A1BD },
	{ 0xE5B9BB, 0x1C5BC },
	{ 0xE5B9BC, 0x1C6CE },
	{ 0xE5B9BD, 0x1D0F7 },
	{ 0xE5B9BE, 0x1DEFD },
	{ 0xE5B9BF, 0x3A1BE },
	{ 0xE5BA80, 0x2A1DA },
	{ 0xE5BA81, 0x3A2C7 },
	{ 0xE5BA82, 0x2A1DB },
	{ 0xE5BA83, 0x3A2C8 },
	{ 0xE5BA84, 0x2A2BC },
	{ 0xE5BA85, 0x3E6F8 },
	{ 0xE5BA87, 0x1CAAA },
	{ 0xE5BA88, 0x2A3F0 },
	{ 0xE5BA89, 0x2A3EE },
	{ 0xE5BA8A, 0x1CAAB },
	{ 0xE5BA8B, 0x2A3ED },
	{ 0xE5BA8C, 0x2A3EF },
	{ 0xE5BA8D, 0x2A3F1 },
	{ 0xE5BA8E, 0x4A4A8 },
	{ 0xE5BA8F, 0x1CAA9 },
	{ 0xE5BA90, 0x3A5EE },
	{ 0xE5BA92, 0x3A5ED },
	{ 0xE5BA95, 0x1CDB5 },
	{ 0xE5BA96, 0x1CDB6 },
	{ 0xE5BA97, 0x1CDB3 },
	{ 0xE5BA98, 0x3A8E5 },
	{ 0xE5BA99, 0x3A8E7 },
	{ 0xE5BA9A, 0x1CDB2 },
	{ 0xE5BA9B, 0x2AAB9 },
	{ 0xE5BA9C, 0x1CDB4 },
	{ 0xE5BA9D, 0x3A8E8 },
	{ 0xE5BAA0, 0x1D0F8 },
	{ 0xE5BAA1, 0x3ACC8 },
	{ 0xE5BAA2, 0x2AAB8 },
	{ 0xE5BAA3, 0x2AABA },
	{ 0xE5BAA4, 0x2AAB7 },
	{ 0xE5BAA5, 0x2AABB },
	{ 0xE5BAA6, 0x1D0F9 },
	{ 0xE5BAA7, 0x1D5BD },
	{ 0xE5BAA8, 0x2AEF7 },
	{ 0xE5BAA9, 0x3B0EC },
	{ 0xE5BAAA, 0x2AEF9 },
	{ 0xE5BAAB, 0x1D5BB },
	{ 0xE5BAAC, 0x2AEFA },
	{ 0xE5BAAD, 0x1D5BC },
	{ 0xE5BAAE, 0x2AEF8 },
	{ 0xE5BAAF, 0x3B0EB },
	{ 0xE5BAB0, 0x2AAB6 },
	{ 0xE5BAB1, 0x2B5AB },
	{ 0xE5BAB2, 0x2B5AE },
	{ 0xE5BAB3, 0x2B5AF },
	{ 0xE5BAB4, 0x2B5AC },
	{ 0xE5BAB5, 0x1DAAD },
	{ 0xE5BAB6, 0x1DAAC },
	{ 0xE5BAB7, 0x1DAAA },
	{ 0xE5BAB8, 0x1DAAB },
	{ 0xE5BAB9, 0x2B5AD },
	{ 0xE5BABA, 0x3B5E1 },
	{ 0xE5BABB, 0x3B5E0 },
	{ 0xE5BABD, 0x3BBBF },
	{ 0xE5BABE, 0x1DAAE },
	{ 0xE5BABF, 0x3BBC0 },
	{ 0xE5BB80, 0x3BBBE },
	{ 0xE5BB81, 0x1DFA1 },
	{ 0xE5BB82, 0x1DFA2 },
	{ 0xE5BB83, 0x6C8C5 },
	{ 0xE5BB84, 0x1DFA3 },
	{ 0xE5BB85, 0x2C2E3 },
	{ 0xE5BB86, 0x2C2E5 },
	{ 0xE5BB87, 0x2C2E7 },
	{ 0xE5BB88, 0x1E3EE },
	{ 0xE5BB89, 0x1E3ED },
	{ 0xE5BB8A, 0x1DEFE },
	{ 0xE5BB8B, 0x2C2E6 },
	{ 0xE5BB8C, 0x2C2E4 },
	{ 0xE5BB8D, 0x3E4F4 },
	{ 0xE5BB8E, 0x2C9FD },
	{ 0xE5BB8F, 0x3C6E1 },
	{ 0xE5BB90, 0x3C6E0 },
	{ 0xE5BB91, 0x2C9FB },
	{ 0xE5BB92, 0x2CAA3 },
	{ 0xE5BB93, 0x1E8E0 },
	{ 0xE5BB94, 0x2CAA4 },
	{ 0xE5BB95, 0x2CAA1 },
	{ 0xE5BB96, 0x1E8E1 },
	{ 0xE5BB97, 0x2C9FC },
	{ 0xE5BB98, 0x2C9FA },
	{ 0xE5BB99, 0x2CAA2 },
	{ 0xE5BB9A, 0x1ECDA },
	{ 0xE5BB9B, 0x2D0BC },
	{ 0xE5BB9C, 0x2C9FE },
	{ 0xE5BB9D, 0x1ECDC },
	{ 0xE5BB9E, 0x2D0BD },
	{ 0xE5BB9F, 0x1ECDB },
	{ 0xE5BBA0, 0x1ECDE },
	{ 0xE5BBA1, 0x2D0BE },
	{ 0xE5BBA2, 0x1ECD9 },
	{ 0xE5BBA3, 0x1ECDD },
	{ 0xE5BBA5, 0x2D6FD },
	{ 0xE5BBA6, 0x2D6FB },
	{ 0xE5BBA7, 0x2D6FA },
	{ 0xE5BBA8, 0x2D6FC },
	{ 0xE5BBA9, 0x2D6F9 },
	{ 0xE5BBAA, 0x3D0DC },
	{ 0xE5BBAB, 0x4DBA1 },
	{ 0xE5BBAC, 0x1F8B3 },
	{ 0xE5BBAD, 0x3E4F5 },
	{ 0xE5BBAE, 0x2E8F2 },
	{ 0xE5BBAF, 0x2E8F3 },
	{ 0xE5BBB0, 0x3DCBF },
	{ 0xE5BBB1, 0x2EBD9 },
	{ 0xE5BBB2, 0x2EDCD },
	{ 0xE5BBB3, 0x1FDA2 },
	{ 0xE5BBB4, 0x3A1BF },
	{ 0xE5BBB5, 0x3A3E1 },
	{ 0xE5BBB6, 0x1CDB7 },
	{ 0xE5BBB7, 0x1CAAC },
	{ 0xE5BBB8, 0x3A8E9 },
	{ 0xE5BBB9, 0x3A8EB },
	{ 0xE5BBBA, 0x1D0FA },
	{ 0xE5BBBB, 0x3ACCC },
	{ 0xE5BBBC, 0x3ACCB },
	{ 0xE5BBBD, 0x3B0EE },
	{ 0xE5BBBE, 0x1C4DC },
	{ 0xE5BBBF, 0x1C5BD },
	{ 0xE5BC80, 0x4A1CD },
	{ 0xE5BC81, 0x1C6CF },
	{ 0xE5BC82, 0x2A2BD },
	{ 0xE5BC83, 0x3A5EF },
	{ 0xE5BC84, 0x1CAAD },
	{ 0xE5BC85, 0x2A3F2 },
	{ 0xE5BC86, 0x3A8ED },
	{ 0xE5BC87, 0x2AABC },
	{ 0xE5BC88, 0x1D0FB },
	{ 0xE5BC8A, 0x1E8E2 },
	{ 0xE5BC8B, 0x1C4DD },
	{ 0xE5BC8C, 0x3A1E4 },
	{ 0xE5BC8D, 0x3A2C9 },
	{ 0xE5BC8E, 0x3A3E2 },
	{ 0xE5BC8F, 0x1C8A2 },
	{ 0xE5BC90, 0xFA2CE },
	{ 0xE5BC91, 0x3BBC2 },
	{ 0xE5BC92, 0x1E3EF },
	{ 0xE5BC93, 0x1C4DE },
	{ 0xE5BC94, 0x1C5BE },
	{ 0xE5BC95, 0x1C5BF },
	{ 0xE5BC97, 0x1C6D1 },
	{ 0xE5BC98, 0x1C6D0 },
	{ 0xE5BC99, 0x4A2EB },
	{ 0xE5BC9A, 0x2A2BE },
	{ 0xE5BC9B, 0x1C8A3 },
	{ 0xE5BC9C, 0x4A2EC },
	{ 0xE5BC9D, 0x2A3F3 },
	{ 0xE5BC9E, 0x3A5F1 },
	{ 0xE5BC9F, 0x1CAAE },
	{ 0xE5BCA1, 0x3A8EE },
	{ 0xE5BCA2, 0x2A6D2 },
	{ 0xE5BCA3, 0x2A6D3 },
	{ 0xE5BCA4, 0x2A6D4 },
	{ 0xE5BCA5, 0x3A8F0 },
	{ 0xE5BCA6, 0x1CDB8 },
	{ 0xE5BCA7, 0x1CDB9 },
	{ 0xE5BCA8, 0x2A6D1 },
	{ 0xE5BCA9, 0x1CDBA },
	{ 0xE5BCAB, 0x4A9AC },
	{ 0xE5BCAC, 0x4ACF0 },
	{ 0xE5BCAD, 0x1D0FC },
	{ 0xE5BCAE, 0x2AABD },
	{ 0xE5BCAF, 0x3ACCD },
	{ 0xE5BCB0, 0x2AEFC },
	{ 0xE5BCB1, 0x1D5BE },
	{ 0xE5BCB2, 0x3B0EF },
	{ 0xE5BCB3, 0x2AEFB },
	{ 0xE5BCB4, 0x3B5E2 },
	{ 0xE5BCB5, 0x1DAAF },
	{ 0xE5BCB6, 0x2B5B0 },
	{ 0xE5BCB7, 0x1DAB0 },
	{ 0xE5BCB8, 0x2B5B1 },
	{ 0xE5BCB9, 0x3B5E3 },
	{ 0xE5BCBA, 0x3BBC7 },
	{ 0xE5BCBB, 0x3BBC5 },
	{ 0xE5BCBC, 0x1DFA4 },
	{ 0xE5BCBD, 0x4B7C5 },
	{ 0xE5BCBE, 0x3BBC4 },
	{ 0xE5BCBF, 0x4BDB0 },
	{ 0xE5BD80, 0x2C2E8 },
	{ 0xE5BD81, 0xFC1BF },
	{ 0xE5BD82, 0x3C1A2 },
	{ 0xE5BD83, 0x2CAA6 },
	{ 0xE5BD84, 0x2CAA5 },
	{ 0xE5BD86, 0x1E8E3 },
	{ 0xE5BD87, 0x4C9DE },
	{ 0xE5BD88, 0x1ECDF },
	{ 0xE5BD89, 0x2D0BF },
	{ 0xE5BD8A, 0x1F0D3 },
	{ 0xE5BD8B, 0x2D6FE },
	{ 0xE5BD8C, 0x1F3DA },
	{ 0xE5BD8D, 0x3D7E3 },
	{ 0xE5BD8E, 0x1FBDF },
	{ 0xE5BD8F, 0x2EFA7 },
	{ 0xE5BD90, 0x3A1C0 },
	{ 0xE5BD91, 0x3A1C1 },
	{ 0xE5BD92, 0x3A2CA },
	{ 0xE5BD93, 0x3A3D1 },
	{ 0xE5BD94, 0x2A6D5 },
	{ 0xE5BD95, 0x3A8F1 },
	{ 0xE5BD96, 0x2AABE },
	{ 0xE5BD97, 0x1DAB1 },
	{ 0xE5BD98, 0x2BBD8 },
	{ 0xE5BD99, 0x1E3F0 },
	{ 0xE5BD9A, 0x3C1A3 },
	{ 0xE5BD9B, 0x3D0DE },
	{ 0xE5BD9C, 0xFD4C3 },
	{ 0xE5BD9D, 0x3D7E4 },
	{ 0xE5BD9E, 0x1F6C1 },
	{ 0xE5BDA0, 0x3E1E4 },
	{ 0xE5BDA1, 0x3A1C2 },
	{ 0xE5BDA2, 0x1CAB0 },
	{ 0xE5BDA3, 0x3A5F2 },
	{ 0xE5BDA4, 0x1CAAF },
	{ 0xE5BDA5, 0x1D0FD },
	{ 0xE5BDA6, 0x3ACD0 },
	{ 0xE5BDA7, 0x2AEFD },
	{ 0xE5BDA9, 0x1DAB3 },
	{ 0xE5BDAA, 0x1DDA9 },
	{ 0xE5BDAB, 0x1DAB4 },
	{ 0xE5BDAC, 0x1DAB2 },
	{ 0xE5BDAD, 0x1DFA5 },
	{ 0xE5BDAE, 0x3C1A4 },
	{ 0xE5BDAF, 0x2CAA7 },
	{ 0xE5BDB0, 0x1E8E4 },
	{ 0xE5BDB1, 0x1ECE0 },
	{ 0xE5BDB2, 0x3DFC5 },
	{ 0xE5BDB3, 0x2A1AC },
	{ 0xE5BDB4, 0x2A2BF },
	{ 0xE5BDB5, 0x4A2ED },
	{ 0xE5BDB6, 0x2A3F5 },
	{ 0xE5BDB7, 0x1CAB1 },
	{ 0xE5BDB8, 0x2A3F4 },
	{ 0xE5BDB9, 0x1CAB2 },
	{ 0xE5BDBA, 0x4A4AC },
	{ 0xE5BDBC, 0x1CDBE },
	{ 0xE5BDBD, 0x2A6D8 },
	{ 0xE5BDBE, 0x2A6D7 },
	{ 0xE5BDBF, 0x1CDBD },
	{ 0xE5BE80, 0x1CDBB },
	{ 0xE5BE81, 0x1CDBC },
	{ 0xE5BE82, 0x2A6D6 },
	{ 0xE5BE83, 0x3A8F6 },
	{ 0xE5BE84, 0x3A8F5 },
	{ 0xE5BE85, 0x1D1A1 },
	{ 0xE5BE86, 0x2AABF },
	{ 0xE5BE87, 0x1D1A4 },
	{ 0xE5BE88, 0x1D0FE },
	{ 0xE5BE89, 0x1D1A6 },
	{ 0xE5BE8A, 0x1D1A2 },
	{ 0xE5BE8B, 0x1D1A3 },
	{ 0xE5BE8C, 0x1D1A5 },
	{ 0xE5BE8D, 0x4A9B1 },
	{ 0xE5BE8E, 0x3B0F0 },
	{ 0xE5BE8F, 0x3B0F2 },
	{ 0xE5BE90, 0x1D5C1 },
	{ 0xE5BE91, 0x1D5C0 },
	{ 0xE5BE92, 0x1D5BF },
	{ 0xE5BE93, 0x3B0F1 },
	{ 0xE5BE94, 0x3E4F6 },
	{ 0xE5BE96, 0x2B5B3 },
	{ 0xE5BE97, 0x1DAB5 },
	{ 0xE5BE98, 0x1DAB8 },
	{ 0xE5BE99, 0x1DAB6 },
	{ 0xE5BE9A, 0x3E4F7 },
	{ 0xE5BE9B, 0x2B5B2 },
	{ 0xE5BE9C, 0x1DABB },
	{ 0xE5BE9D, 0x4B1D3 },
	{ 0xE5BE9E, 0x1DAB7 },
	{ 0xE5BE9F, 0x2B5B4 },
	{ 0xE5BEA0, 0x1DABA },
	{ 0xE5BEA1, 0x1DAB9 },
	{ 0xE5BEA2, 0x4B1D2 },
	{ 0xE5BEA3, 0x4B1D7 },
	{ 0xE5BEA4, 0x4B7CA },
	{ 0xE5BEA5, 0x2BBDA },
	{ 0xE5BEA6, 0x2BBD9 },
	{ 0xE5BEA7, 0x3BBCB },
	{ 0xE5BEA8, 0x1DFA8 },
	{ 0xE5BEA9, 0x1DFA6 },
	{ 0xE5BEAA, 0x1DFA7 },
	{ 0xE5BEAB, 0x2BBDB },
	{ 0xE5BEAC, 0x1E3F1 },
	{ 0xE5BEAD, 0x2C2EA },
	{ 0xE5BEAE, 0x1E3F2 },
	{ 0xE5BEAF, 0x2C2E9 },
	{ 0xE5BEB0, 0x4BDB4 },
	{ 0xE5BEB1, 0x4C3BF },
	{ 0xE5BEB2, 0x2D0C0 },
	{ 0xE5BEB3, 0x3C6E3 },
	{ 0xE5BEB4, 0x3C6E4 },
	{ 0xE5BEB5, 0x1ECE2 },
	{ 0xE5BEB6, 0x2CAA8 },
	{ 0xE5BEB7, 0x1ECE1 },
	{ 0xE5BEB8, 0x3CBF2 },
	{ 0xE5BEB9, 0x1E8E5 },
	{ 0xE5BEBA, 0x3E4F8 },
	{ 0xE5BEBB, 0x2D7A2 },
	{ 0xE5BEBC, 0x2D7A1 },
	{ 0xE5BEBD, 0x1F3DB },
	{ 0xE5BEBE, 0x2DCE9 },
	{ 0xE5BEBF, 0x2E5CB },
	{ 0xE5BF80, 0x2E8F4 },
	{ 0xE5BF81, 0x2E8F5 },
	{ 0xE5BF82, 0x3DEAF },
	{ 0xE5BF83, 0x1C5C0 },
	{ 0xE5BF84, 0x4A1B6 },
	{ 0xE5BF85, 0x1C6D2 },
	{ 0xE5BF87, 0x3A2CD },
	{ 0xE5BF88, 0x4A2F1 },
	{ 0xE5BF89, 0x2A1DC },
	{ 0xE5BF8A, 0x3A2CC },
	{ 0xE5BF8B, 0x5A2E6 },
	{ 0xE5BF8C, 0x1CAB4 },
	{ 0xE5BF8D, 0x1CAB6 },
	{ 0xE5BF8E, 0x3A5F8 },
	{ 0xE5BF8F, 0x2A2C2 },
	{ 0xE5BF90, 0x2A3F8 },
	{ 0xE5BF91, 0x2A3F7 },
	{ 0xE5BF92, 0x2A3F6 },
	{ 0xE5BF93, 0x3A3E6 },
	{ 0xE5BF94, 0x2A2C1 },
	{ 0xE5BF95, 0x2A2C0 },
	{ 0xE5BF96, 0x1C8A5 },
	{ 0xE5BF97, 0x1CAB5 },
	{ 0xE5BF98, 0x1CAB3 },
	{ 0xE5BF99, 0x1C8A4 },
	{ 0xE5BF9A, 0x3A3E7 },
	{ 0xE5BF9B, 0x3A3E9 },
	{ 0xE5BF9C, 0x3A5F7 },
	{ 0xE5BF9D, 0x1CDBF },
	{ 0xE5BF9E, 0x2A6D9 },
	{ 0xE5BF9F, 0x3A5FB },
	{ 0xE5BFA0, 0x1CDC0 },
	{ 0xE5BFA1, 0x2A3FD },
	{ 0xE5BFA2, 0x4A6D0 },
	{ 0xE5BFA3, 0x2A4A1 },
	{ 0xE5BFA4, 0x2A3FE },
	{ 0xE5BFA5, 0x2A6DA },
	{ 0xE5BFA6, 0x3A5F6 },
	{ 0xE5BFA7, 0x3A5F4 },
	{ 0xE5BFA8, 0x2A3FA },
	{ 0xE5BFA9, 0x3A8FE },
	{ 0xE5BFAA, 0x1CABA },
	{ 0xE5BFAB, 0x1CAB8 },
	{ 0xE5BFAC, 0x3A5FC },
	{ 0xE5BFAD, 0x2A3F9 },
	{ 0xE5BFAE, 0x2A3FB },
	{ 0xE5BFAF, 0x2A4A3 },
	{ 0xE5BFB0, 0x3A6A2 },
	{ 0xE5BFB1, 0x1CAB7 },
	{ 0xE5BFB2, 0x3A6A1 },
	{ 0xE5BFB3, 0x2A3FC },
	{ 0xE5BFB4, 0x2A4A7 },
	{ 0xE5BFB5, 0x1CDC2 },
	{ 0xE5BFB6, 0x3A5FD },
	{ 0xE5BFB7, 0x2A4A4 },
	{ 0xE5BFB8, 0x1CAB9 },
	{ 0xE5BFB9, 0x3A6A3 },
	{ 0xE5BFBA, 0x2A4A2 },
	{ 0xE5BFBB, 0x2A4A5 },
	{ 0xE5BFBC, 0x3A5FA },
	{ 0xE5BFBD, 0x1CDC1 },
	{ 0xE5BFBE, 0x3A5F5 },
	{ 0xE5BFBF, 0x1CDC3 },
	{ 0xE68080, 0x2A4A6 },
	{ 0xE68087, 0x3A8F8 },
	{ 0xE68088, 0x3A9A2 },
	{ 0xE68089, 0x2A6EE },
	{ 0xE6808A, 0x2A6E1 },
	{ 0xE6808B, 0x2A6DF },
	{ 0xE6808C, 0x2A6ED },
	{ 0xE6808D, 0x2A6E8 },
	{ 0xE6808E, 0x1D1AB },
	{ 0xE6808F, 0x1CDC4 },
	{ 0xE68090, 0x2A6E9 },
	{ 0xE68091, 0x2A6EC },
	{ 0xE68092, 0x1D1A7 },
	{ 0xE68093, 0x2A6EB },
	{ 0xE68094, 0x1CDC5 },
	{ 0xE68095, 0x1CDCA },
	{ 0xE68096, 0x1CDC8 },
	{ 0xE68097, 0x2A6E2 },
	{ 0xE68098, 0x4A9B6 },
	{ 0xE68099, 0x2A6DD },
	{ 0xE6809A, 0x2A6E4 },
	{ 0xE6809B, 0x1CDCF },
	{ 0xE6809C, 0x2A6EF },
	{ 0xE6809D, 0x1D1A8 },
	{ 0xE6809E, 0x2A6E5 },
	{ 0xE6809F, 0x4A6CF },
	{ 0xE680A0, 0x1D1A9 },
	{ 0xE680A1, 0x1CDCB },
	{ 0xE680A2, 0x2A6E7 },
	{ 0xE680A3, 0x3ACDA },
	{ 0xE680A4, 0x2AACE },
	{ 0xE680A5, 0x1D1AA },
	{ 0xE680A6, 0x2A6DC },
	{ 0xE680A7, 0x1CDCC },
	{ 0xE680A8, 0x1D1AC },
	{ 0xE680A9, 0x1CDCD },
	{ 0xE680AA, 0x1CDC9 },
	{ 0xE680AB, 0x1CDCE },
	{ 0xE680AC, 0x2A6E6 },
	{ 0xE680AD, 0x2A6DB },
	{ 0xE680AE, 0x2A6EA },
	{ 0xE680AF, 0x1CDC6 },
	{ 0xE680B0, 0x3A8F7 },
	{ 0xE680B1, 0x3ACDB },
	{ 0xE680B2, 0x2A6DE },
	{ 0xE680B3, 0x2A6E3 },
	{ 0xE680B4, 0x2A6E0 },
	{ 0xE680B5, 0x1CDC7 },
	{ 0xE680B6, 0x3A8FA },
	{ 0xE680B7, 0x2AAC0 },
	{ 0xE680B8, 0x4A9C5 },
	{ 0xE680B9, 0x2AAC1 },
	{ 0xE680BD, 0x3A9A1 },
	{ 0xE68180, 0x2AACB },
	{ 0xE68181, 0x2AFA3 },
	{ 0xE68182, 0x2AACC },
	{ 0xE68183, 0x1D1B2 },
	{ 0xE68184, 0x2AACF },
	{ 0xE68185, 0x2AAC5 },
	{ 0xE68186, 0x1D1B1 },
	{ 0xE68187, 0x2AAC7 },
	{ 0xE68188, 0x4A9BF },
	{ 0xE68189, 0x2AAC8 },
	{ 0xE6818A, 0x3ACE0 },
	{ 0xE6818B, 0x3B0F9 },
	{ 0xE6818C, 0x2AACA },
	{ 0xE6818D, 0x1D1AD },
	{ 0xE6818E, 0x3ACD6 },
	{ 0xE6818F, 0x3B0F3 },
	{ 0xE68190, 0x1D5C5 },
	{ 0xE68191, 0x3ACD7 },
	{ 0xE68192, 0x3ACDD },
	{ 0xE68193, 0x2AAC6 },
	{ 0xE68194, 0x2AAC2 },
	{ 0xE68195, 0x1D5C6 },
	{ 0xE68196, 0x3B0FE },
	{ 0xE68197, 0x4A9BE },
	{ 0xE68198, 0x2AAD0 },
	{ 0xE68199, 0x1D5C2 },
	{ 0xE6819A, 0x2AFA1 },
	{ 0xE6819B, 0x2AAC9 },
	{ 0xE6819C, 0x3ACD4 },
	{ 0xE6819D, 0x2AEFE },
	{ 0xE6819E, 0x2AAC4 },
	{ 0xE6819F, 0x2AACD },
	{ 0xE681A0, 0x3ACDF },
	{ 0xE681A1, 0x3ACE1 },
	{ 0xE681A2, 0x1D1B0 },
	{ 0xE681A3, 0x1D5C3 },
	{ 0xE681A4, 0x1D1B6 },
	{ 0xE681A5, 0x1D5C4 },
	{ 0xE681A6, 0x2AAD1 },
	{ 0xE681A7, 0x2AFA2 },
	{ 0xE681A8, 0x1D1AF },
	{ 0xE681A9, 0x1D5C8 },
	{ 0xE681AA, 0x1D1B5 },
	{ 0xE681AB, 0x1D1B4 },
	{ 0xE681AC, 0x1D1B3 },
	{ 0xE681AD, 0x1D5C7 },
	{ 0xE681AE, 0x2AAD2 },
	{ 0xE681AF, 0x1D5C9 },
	{ 0xE681B0, 0x1D1AE },
	{ 0xE681B1, 0x4A9CB },
	{ 0xE681B2, 0x2AAC3 },
	{ 0xE681B3, 0x3B0FA },
	{ 0xE681B4, 0x3B0F8 },
	{ 0xE681B5, 0x3B0FB },
	{ 0xE681BC, 0x3ACDC },
	{ 0xE681BE, 0x3B0F6 },
	{ 0xE681BF, 0x1DABC },
	{ 0xE68280, 0x2AFA6 },
	{ 0xE68281, 0x2AFA8 },
	{ 0xE68282, 0x4ADA5 },
	{ 0xE68283, 0x2AFAA },
	{ 0xE68284, 0x1D5CA },
	{ 0xE68285, 0x1D5D0 },
	{ 0xE68286, 0x2B5B7 },
	{ 0xE68287, 0x2AFAE },
	{ 0xE68288, 0x2AFA5 },
	{ 0xE68289, 0x1DABE },
	{ 0xE6828A, 0x2B5B5 },
	{ 0xE6828B, 0x3B1A2 },
	{ 0xE6828C, 0x1D5CF },
	{ 0xE6828D, 0x1D5CD },
	{ 0xE6828E, 0x2AFB0 },
	{ 0xE6828F, 0x4ADAD },
	{ 0xE68290, 0x2B5B6 },
	{ 0xE68291, 0x4ADAC },
	{ 0xE68292, 0x2AFA7 },
	{ 0xE68293, 0x3B1A5 },
	{ 0xE68294, 0x1D5CE },
	{ 0xE68295, 0x2AFAB },
	{ 0xE68296, 0x1D5D1 },
	{ 0xE68297, 0x2AFAD },
	{ 0xE68298, 0x3B5E8 },
	{ 0xE68299, 0x3B0F4 },
	{ 0xE6829A, 0x1D5CC },
	{ 0xE6829B, 0x2AFAC },
	{ 0xE6829C, 0x2AFAF },
	{ 0xE6829D, 0x2AFA9 },
	{ 0xE6829E, 0x3B1A7 },
	{ 0xE6829F, 0x1D5CB },
	{ 0xE682A0, 0x1DABF },
	{ 0xE682A1, 0x3B5F1 },
	{ 0xE682A2, 0x2AFA4 },
	{ 0xE682A3, 0x1DABD },
	{ 0xE682A4, 0x3B5F2 },
	{ 0xE682A5, 0x4B1EB },
	{ 0xE682A6, 0x3B1A3 },
	{ 0xE682A7, 0x3B1A8 },
	{ 0xE682A8, 0x1DAC0 },
	{ 0xE682A9, 0x3B1A1 },
	{ 0xE682AA, 0x3B5EF },
	{ 0xE682AE, 0x3B1A6 },
	{ 0xE682B0, 0x2B5B9 },
	{ 0xE682B1, 0x2B5C2 },
	{ 0xE682B2, 0x1DFAB },
	{ 0xE682B3, 0x3BBD4 },
	{ 0xE682B4, 0x1DAC2 },
	{ 0xE682B5, 0x1DAC7 },
	{ 0xE682B6, 0x1DFAC },
	{ 0xE682B7, 0x2B5C4 },
	{ 0xE682B8, 0x1DACE },
	{ 0xE682B9, 0x2BBDD },
	{ 0xE682BA, 0x2B5BA },
	{ 0xE682BB, 0x1DAC6 },
	{ 0xE682BC, 0x1DAC9 },
	{ 0xE682BD, 0x1DAC4 },
	{ 0xE682BE, 0x2B5B8 },
	{ 0xE682BF, 0x2B5C6 },
	{ 0xE68380, 0x2B5C9 },
	{ 0xE68381, 0x2BBEC },
	{ 0xE68382, 0x4B1E8 },
	{ 0xE68383, 0x2B5C7 },
	{ 0xE68384, 0x2BBE1 },
	{ 0xE68385, 0x1DAC5 },
	{ 0xE68386, 0x1DACC },
	{ 0xE68387, 0x1DAD0 },
	{ 0xE68388, 0x2B5C1 },
	{ 0xE68389, 0x2BBDC },
	{ 0xE6838A, 0x2B5C5 },
	{ 0xE6838B, 0x1DAC1 },
	{ 0xE6838C, 0x2BBDE },
	{ 0xE6838D, 0x2B5C8 },
	{ 0xE6838E, 0x2BBE0 },
	{ 0xE6838F, 0x2B5BD },
	{ 0xE68390, 0x3B5EA },
	{ 0xE68391, 0x1DFA9 },
	{ 0xE68392, 0x3BBD6 },
	{ 0xE68393, 0x2B5BB },
	{ 0xE68394, 0x2B5BC },
	{ 0xE68395, 0x1DACB },
	{ 0xE68396, 0x3BBD5 },
	{ 0xE68397, 0x3B5EE },
	{ 0xE68398, 0x1DACA },
	{ 0xE68399, 0x2B5BF },
	{ 0xE6839A, 0x1DACF },
	{ 0xE6839B, 0x2B5C3 },
	{ 0xE6839C, 0x1DAC8 },
	{ 0xE6839D, 0x2B5C0 },
	{ 0xE6839E, 0x3B5F9 },
	{ 0xE6839F, 0x1DACD },
	{ 0xE683A0, 0x1DFAD },
	{ 0xE683A1, 0x1DFAA },
	{ 0xE683A2, 0x2BBDF },
	{ 0xE683A3, 0x3BBD8 },
	{ 0xE683A4, 0x2B5BE },
	{ 0xE683A5, 0x3BBD9 },
	{ 0xE683A6, 0x1DAC3 },
	{ 0xE683A7, 0x3B5F6 },
	{ 0xE683A8, 0x3B5F8 },
	{ 0xE683A9, 0x3BBDA },
	{ 0xE683AA, 0x3BBCD },
	{ 0xE683AE, 0x3B5F4 },
	{ 0xE683B0, 0x1DFB2 },
	{ 0xE683B1, 0x1DFB6 },
	{ 0xE683B2, 0x2BBE3 },
	{ 0xE683B3, 0x1E3F7 },
	{ 0xE683B4, 0x1DFB4 },
	{ 0xE683B5, 0x2BBE7 },
	{ 0xE683B6, 0x1DFB8 },
	{ 0xE683B7, 0x2C2EB },
	{ 0xE683B8, 0x2BBE9 },
	{ 0xE683B9, 0x1E3F9 },
	{ 0xE683BA, 0x1DFB0 },
	{ 0xE683BB, 0x1DFB3 },
	{ 0xE683BC, 0x2BBEA },
	{ 0xE683BD, 0x3BBDE },
	{ 0xE683BE, 0x2BBEB },
	{ 0xE683BF, 0x2BBF1 },
	{ 0xE68480, 0x1DFBA },
	{ 0xE68481, 0x1E3FA },
	{ 0xE68482, 0x4BDBD },
	{ 0xE68483, 0x2BBED },
	{ 0xE68484, 0x2BBF2 },
	{ 0xE68485, 0x2BBE6 },
	{ 0xE68486, 0x1E4A6 },
	{ 0xE68487, 0x3BBCF },
	{ 0xE68488, 0x1E3FB },
	{ 0xE68489, 0x1DFB9 },
	{ 0xE6848A, 0x2BBE4 },
	{ 0xE6848B, 0x2BBF3 },
	{ 0xE6848C, 0x3BBD1 },
	{ 0xE6848D, 0x1E4A5 },
	{ 0xE6848E, 0x1DFB7 },
	{ 0xE6848F, 0x1E3F4 },
	{ 0xE68490, 0x2BBF0 },
	{ 0xE68491, 0x3BBDD },
	{ 0xE68492, 0x1DFBB },
	{ 0xE68493, 0x2BBE8 },
	{ 0xE68494, 0x2BBE2 },
	{ 0xE68495, 0x1DFB1 },
	{ 0xE68496, 0x2BBE5 },
	{ 0xE68497, 0x5BFB0 },
	{ 0xE68498, 0x2BBEE },
	{ 0xE68499, 0x3C1AB },
	{ 0xE6849A, 0x1E3F3 },
	{ 0xE6849B, 0x1E3F8 },
	{ 0xE6849C, 0x1DFAE },
	{ 0xE6849D, 0x2BBEF },
	{ 0xE6849E, 0x3BBE1 },
	{ 0xE6849F, 0x1E3F6 },
	{ 0xE684A0, 0x3BBE2 },
	{ 0xE684A1, 0x3BBE3 },
	{ 0xE684A2, 0x3BBD0 },
	{ 0xE684A3, 0x1DFAF },
	{ 0xE684A5, 0x3E4F9 },
	{ 0xE684A7, 0x1E4A4 },
	{ 0xE684A8, 0x2CAAA },
	{ 0xE684A9, 0x2C2F6 },
	{ 0xE684AA, 0x3C1A9 },
	{ 0xE684AB, 0x2C2EE },
	{ 0xE684AC, 0x2CAA9 },
	{ 0xE684AD, 0x4BDB9 },
	{ 0xE684AE, 0x2C2F2 },
	{ 0xE684AF, 0x2C2F4 },
	{ 0xE684B0, 0x3C1A7 },
	{ 0xE684B1, 0x3C1AC },
	{ 0xE684B2, 0x2C2F1 },
	{ 0xE684B3, 0x3C6EF },
	{ 0xE684B4, 0x1E4A3 },
	{ 0xE684B5, 0x4BDB8 },
	{ 0xE684B6, 0x2C2F0 },
	{ 0xE684B7, 0x1E4A7 },
	{ 0xE684B8, 0x3C6EE },
	{ 0xE684B9, 0x6D2E4 },
	{ 0xE684BA, 0x3C1A8 },
	{ 0xE684BB, 0x2CAB9 },
	{ 0xE684BC, 0x3C6EC },
	{ 0xE684BD, 0x3C1AE },
	{ 0xE684BE, 0x1E4A2 },
	{ 0xE684BF, 0x1E8E7 },
	{ 0xE68580, 0x2C2F7 },
	{ 0xE68581, 0x2CAAB },
	{ 0xE68582, 0x3C6ED },
	{ 0xE68583, 0x3C1AA },
	{ 0xE68584, 0x1E3FE },
	{ 0xE68585, 0x2C2EF },
	{ 0xE68586, 0x2C2F3 },
	{ 0xE68587, 0x1E8E6 },
	{ 0xE68588, 0x1E3F5 },
	{ 0xE68589, 0x2C2EC },
	{ 0xE6858A, 0x2C2ED },
	{ 0xE6858B, 0x1E8E8 },
	{ 0xE6858C, 0x1E3FD },
	{ 0xE6858D, 0x1E4A1 },
	{ 0xE6858E, 0x1E3FC },
	{ 0xE6858F, 0x2C2F5 },
	{ 0xE68590, 0x3E4FA },
	{ 0xE68592, 0x2CAAF },
	{ 0xE68593, 0x2CAB0 },
	{ 0xE68594, 0x2CAB5 },
	{ 0xE68595, 0x1ECE7 },
	{ 0xE68596, 0x2CABC },
	{ 0xE68597, 0x3CBF3 },
	{ 0xE68598, 0x1E8EE },
	{ 0xE68599, 0x3CBFE },
	{ 0xE6859A, 0x1E8ED },
	{ 0xE6859B, 0x2CAB7 },
	{ 0xE6859C, 0x3CBF4 },
	{ 0xE6859D, 0x1ECE6 },
	{ 0xE6859E, 0x2CAAC },
	{ 0xE6859F, 0x1E8EC },
	{ 0xE685A0, 0x3C6F1 },
	{ 0xE685A1, 0x2CABB },
	{ 0xE685A2, 0x1E8EA },
	{ 0xE685A3, 0x1E8EB },
	{ 0xE685A4, 0x3CBFC },
	{ 0xE685A5, 0x2CAB8 },
	{ 0xE685A6, 0x2D0D1 },
	{ 0xE685A7, 0x1ECE4 },
	{ 0xE685A8, 0x1DFB5 },
	{ 0xE685A9, 0x3C6F2 },
	{ 0xE685AA, 0x2CABA },
	{ 0xE685AB, 0x1ECEB },
	{ 0xE685AC, 0x2CAB2 },
	{ 0xE685AD, 0x4C9EF },
	{ 0xE685AE, 0x1ECE5 },
	{ 0xE685AF, 0x3C6EA },
	{ 0xE685B0, 0x1ECEA },
	{ 0xE685B1, 0x2CAAD },
	{ 0xE685B2, 0x2CAB1 },
	{ 0xE685B3, 0x2CAAE },
	{ 0xE685B4, 0x2CAB4 },
	{ 0xE685B5, 0x1E8EF },
	{ 0xE685B6, 0x1ECE3 },
	{ 0xE685B7, 0x1E8E9 },
	{ 0xE685B8, 0x3CCA1 },
	{ 0xE685B9, 0x2D0C3 },
	{ 0xE685BA, 0x2CAB6 },
	{ 0xE685BB, 0x3C6E8 },
	{ 0xE685BC, 0x1ECE9 },
	{ 0xE685BD, 0x3C6F3 },
	{ 0xE685BE, 0x1ECEC },
	{ 0xE685BF, 0x7A2F1 },
	{ 0xE68680, 0x2CAB3 },
	{ 0xE68681, 0x3C6EB },
	{ 0xE68682, 0x1ECE8 },
	{ 0xE68683, 0x2D0C2 },
	{ 0xE68684, 0x5CDAA },
	{ 0xE68685, 0x3CCA3 },
	{ 0xE68686, 0x3C6F4 },
	{ 0xE68687, 0x3CCA4 },
	{ 0xE68688, 0x3CBF7 },
	{ 0xE68689, 0x2D0C7 },
	{ 0xE6868A, 0x1F0D7 },
	{ 0xE6868B, 0x2D0C1 },
	{ 0xE6868C, 0x2D7AE },
	{ 0xE6868D, 0x2D0D0 },
	{ 0xE6868E, 0x1ECF0 },
	{ 0xE6868F, 0x3CBFA },
	{ 0xE68690, 0x1ECEE },
	{ 0xE68691, 0x1F0D5 },
	{ 0xE68692, 0x2D0CD },
	{ 0xE68693, 0x2D0C9 },
	{ 0xE68694, 0x1ECF4 },
	{ 0xE68695, 0x3CBF6 },
	{ 0xE68696, 0x2D7A5 },
	{ 0xE68697, 0x3D0E8 },
	{ 0xE68698, 0x3CCA8 },
	{ 0xE68699, 0x3D0E7 },
	{ 0xE6869A, 0x1ECF2 },
	{ 0xE6869B, 0x2D0C8 },
	{ 0xE6869C, 0x3CCA9 },
	{ 0xE6869D, 0x2D7A3 },
	{ 0xE6869E, 0x3CCA5 },
	{ 0xE6869F, 0x2D0CC },
	{ 0xE686A0, 0x4D0BB },
	{ 0xE686A1, 0x2D0CF },
	{ 0xE686A2, 0x2D0C6 },
	{ 0xE686A3, 0x3CBF9 },
	{ 0xE686A4, 0x1ECF3 },
	{ 0xE686A5, 0x4D0B7 },
	{ 0xE686A6, 0x3CBF5 },
	{ 0xE686A7, 0x1ECED },
	{ 0xE686A8, 0x2D7A4 },
	{ 0xE686A9, 0x1F0D6 },
	{ 0xE686AA, 0x2D0CE },
	{ 0xE686AB, 0x1ECEF },
	{ 0xE686AC, 0x1ECF1 },
	{ 0xE686AD, 0x2D0CB },
	{ 0xE686AE, 0x1ECF5 },
	{ 0xE686AF, 0x2D0CA },
	{ 0xE686B0, 0x2D0C5 },
	{ 0xE686B1, 0x2D0C4 },
	{ 0xE686B2, 0x1F0D4 },
	{ 0xE686B3, 0x2D0D2 },
	{ 0xE686B4, 0x2D7A7 },
	{ 0xE686B5, 0x2DCEB },
	{ 0xE686B6, 0x1F0D9 },
	{ 0xE686B7, 0x3D0E1 },
	{ 0xE686B8, 0x2D7AD },
	{ 0xE686B9, 0x3D0E3 },
	{ 0xE686BA, 0x2D7AB },
	{ 0xE686BB, 0x3D0EA },
	{ 0xE686BC, 0x2DCEC },
	{ 0xE686BD, 0x3D0E4 },
	{ 0xE686BE, 0x1F0DA },
	{ 0xE686BF, 0x2D7AC },
	{ 0xE68780, 0x3D0E6 },
	{ 0xE68781, 0x2D7A9 },
	{ 0xE68782, 0x1F3DD },
	{ 0xE68783, 0x2DCEA },
	{ 0xE68784, 0x3D0EC },
	{ 0xE68785, 0x2D7A6 },
	{ 0xE68786, 0x2D7A8 },
	{ 0xE68787, 0x1F3DE },
	{ 0xE68788, 0x1F0DC },
	{ 0xE68789, 0x1F3DC },
	{ 0xE6878A, 0x1F0DB },
	{ 0xE6878B, 0x1F3E0 },
	{ 0xE6878C, 0x2D7AA },
	{ 0xE6878D, 0x1F0D8 },
	{ 0xE6878E, 0x3D0E2 },
	{ 0xE6878F, 0x3D0E5 },
	{ 0xE68790, 0x3D0EB },
	{ 0xE68793, 0x3E6F9 },
	{ 0xE68795, 0x4DBAB },
	{ 0xE68796, 0x2E1DB },
	{ 0xE68797, 0x4D6B3 },
	{ 0xE68798, 0x2E1D3 },
	{ 0xE68799, 0x3D4E1 },
	{ 0xE6879A, 0x3D4DF },
	{ 0xE6879B, 0x3D4DC },
	{ 0xE6879C, 0x3D4DE },
	{ 0xE6879D, 0x3D4DD },
	{ 0xE6879E, 0x2DCF2 },
	{ 0xE6879F, 0x2E1D4 },
	{ 0xE687A0, 0x2DCEE },
	{ 0xE687A1, 0x4D6B2 },
	{ 0xE687A2, 0x3D4DB },
	{ 0xE687A3, 0x1F6C2 },
	{ 0xE687A4, 0x2DCF0 },
	{ 0xE687A5, 0x2DCEF },
	{ 0xE687A6, 0x1F3DF },
	{ 0xE687A7, 0x2DCED },
	{ 0xE687A8, 0x2DCF1 },
	{ 0xE687A9, 0x2E1DC },
	{ 0xE687AA, 0x2E1D8 },
	{ 0xE687AB, 0x2E1DA },
	{ 0xE687AC, 0x4DFE0 },
	{ 0xE687AD, 0x2E1D5 },
	{ 0xE687AE, 0x2E1D6 },
	{ 0xE687AF, 0x4DFE1 },
	{ 0xE687B0, 0x2E1D9 },
	{ 0xE687B1, 0x2E1D7 },
	{ 0xE687B2, 0x1F8B4 },
	{ 0xE687B3, 0x3D7E5 },
	{ 0xE687B5, 0x1F8B7 },
	{ 0xE687B6, 0x1F8B6 },
	{ 0xE687B7, 0x1F8B5 },
	{ 0xE687B8, 0x1F9EC },
	{ 0xE687B9, 0x2E8F6 },
	{ 0xE687BA, 0x1F9ED },
	{ 0xE687BB, 0x2E5CC },
	{ 0xE687BC, 0x1FAEA },
	{ 0xE687BD, 0x2EBDA },
	{ 0xE687BE, 0x1FAEB },
	{ 0xE687BF, 0x1FBE0 },
	{ 0xE68880, 0x1FCB6 },
	{ 0xE68881, 0x2EFA8 },
	{ 0xE68882, 0x3DFC6 },
	{ 0xE68883, 0x2EFA9 },
	{ 0xE68884, 0x2EFAA },
	{ 0xE68885, 0x3E1BE },
	{ 0xE68887, 0x2F2AA },
	{ 0xE68888, 0x1C5C1 },
	{ 0xE68889, 0x2A1DD },
	{ 0xE6888A, 0x1C6D3 },
	{ 0xE6888C, 0x1C8A7 },
	{ 0xE6888D, 0x1C8A8 },
	{ 0xE6888E, 0x1C8A6 },
	{ 0xE6888F, 0x3A3EB },
	{ 0xE68890, 0x1C8A9 },
	{ 0xE68891, 0x1CABC },
	{ 0xE68892, 0x1CABB },
	{ 0xE68893, 0x3A6A5 },
	{ 0xE68894, 0x2A6F0 },
	{ 0xE68895, 0x1CDD1 },
	{ 0xE68896, 0x1CDD0 },
	{ 0xE68898, 0x3ACE3 },
	{ 0xE68899, 0x2AFB1 },
	{ 0xE6889A, 0x1DAD1 },
	{ 0xE6889B, 0x1DAD2 },
	{ 0xE6889C, 0x4B1EE },
	{ 0xE6889D, 0x4B1F0 },
	{ 0xE6889E, 0x3BBE4 },
	{ 0xE6889F, 0x1DFBC },
	{ 0xE688A0, 0x2C2F8 },
	{ 0xE688A1, 0x1E4A8 },
	{ 0xE688A2, 0x1E4A9 },
	{ 0xE688A3, 0x2C2FA },
	{ 0xE688A4, 0x2C2FC },
	{ 0xE688A5, 0x2C2FB },
	{ 0xE688A6, 0x4BDC3 },
	{ 0xE688A7, 0x2CABE },
	{ 0xE688A8, 0x3C6F6 },
	{ 0xE688A9, 0x2CABD },
	{ 0xE688AA, 0x1E8F0 },
	{ 0xE688AB, 0x2CABF },
	{ 0xE688AC, 0x3C6F5 },
	{ 0xE688AD, 0x2D0D3 },
	{ 0xE688AE, 0x1ECF6 },
	{ 0xE688AF, 0x3CCAC },
	{ 0xE688B0, 0x1F0DD },
	{ 0xE688B1, 0x3D0ED },
	{ 0xE688B2, 0x1F3E1 },
	{ 0xE688B3, 0x1F6C3 },
	{ 0xE688B4, 0x1F3E2 },
	{ 0xE688B5, 0x3DFC8 },
	{ 0xE688B6, 0x1C5C2 },
	{ 0xE688B7, 0x3A1E5 },
	{ 0xE688B8, 0x3A1E6 },
	{ 0xE688B9, 0x3A2CE },
	{ 0xE688BA, 0x2A4A8 },
	{ 0xE688BB, 0x3A6A8 },
	{ 0xE688BC, 0x3A6A9 },
	{ 0xE688BD, 0x2A6F1 },
	{ 0xE688BE, 0x1CDD3 },
	{ 0xE688BF, 0x1CDD2 },
	{ 0xE68980, 0x1CDD4 },
	{ 0xE68981, 0x1D1B7 },
	{ 0xE68982, 0x2AAD3 },
	{ 0xE68983, 0x2AAD4 },
	{ 0xE68985, 0x3B1A9 },
	{ 0xE68986, 0x2AFB2 },
	{ 0xE68987, 0x1D5D2 },
	{ 0xE68988, 0x1DAD3 },
	{ 0xE68989, 0x1DFBD },
	{ 0xE6898A, 0x2BBF4 },
	{ 0xE6898B, 0x1C5C3 },
	{ 0xE6898C, 0x4A1B7 },
	{ 0xE6898D, 0x1C4DF },
	{ 0xE6898E, 0x1C5C4 },
	{ 0xE6898F, 0x3A2D0 },
	{ 0xE68990, 0x2A1DE },
	{ 0xE68991, 0x1C6D7 },
	{ 0xE68992, 0x1C6D6 },
	{ 0xE68993, 0x1C6D4 },
	{ 0xE68994, 0x1C6D5 },
	{ 0xE68997, 0x3A3EF },
	{ 0xE68998, 0x1C8AC },
	{ 0xE68999, 0x2A2C9 },
	{ 0xE6899A, 0x2A2CB },
	{ 0xE6899B, 0x1C8AB },
	{ 0xE6899C, 0x2A2C3 },
	{ 0xE6899D, 0x3A3EC },
	{ 0xE6899E, 0x2A2C4 },
	{ 0xE6899F, 0x3A3ED },
	{ 0xE689A0, 0x2A2CA },
	{ 0xE689A1, 0x2A2C6 },
	{ 0xE689A2, 0x2A2C8 },
	{ 0xE689A3, 0x1C8AA },
	{ 0xE689A4, 0x2A2C5 },
	{ 0xE689A5, 0x2A2CC },
	{ 0xE689A6, 0x2A2C7 },
	{ 0xE689A7, 0x3A3EE },
	{ 0xE689A8, 0xFA2D1 },
	{ 0xE689AD, 0x1CAC3 },
	{ 0xE689AE, 0x1CACC },
	{ 0xE689AF, 0x1CACA },
	{ 0xE689B0, 0x2A4B2 },
	{ 0xE689B1, 0x2A4AF },
	{ 0xE689B2, 0x2A4B7 },
	{ 0xE689B3, 0x1CAC8 },
	{ 0xE689B4, 0x2A4B8 },
	{ 0xE689B5, 0x3A6B9 },
	{ 0xE689B6, 0x1CAC1 },
	{ 0xE689B7, 0x2A4B5 },
	{ 0xE689B8, 0x3A6AE },
	{ 0xE689B9, 0x1CAC7 },
	{ 0xE689BA, 0x2A4B1 },
	{ 0xE689BB, 0x2A4B0 },
	{ 0xE689BC, 0x1CAC5 },
	{ 0xE689BD, 0x2A4B6 },
	{ 0xE689BE, 0x1CAC6 },
	{ 0xE689BF, 0x1CDD5 },
	{ 0xE68A80, 0x1CAC0 },
	{ 0xE68A81, 0x2A4B3 },
	{ 0xE68A82, 0x3A6AA },
	{ 0xE68A83, 0x2A4A9 },
	{ 0xE68A84, 0x1CABD },
	{ 0xE68A85, 0x3A6B7 },
	{ 0xE68A86, 0x1CAD0 },
	{ 0xE68A87, 0x2A4AE },
	{ 0xE68A88, 0x2A4B4 },
	{ 0xE68A89, 0x1CAC2 },
	{ 0xE68A8A, 0x1CAC4 },
	{ 0xE68A8B, 0x3A6AF },
	{ 0xE68A8C, 0x2A4AA },
	{ 0xE68A8D, 0x3A6B6 },
	{ 0xE68A8E, 0x2A4AB },
	{ 0xE68A8F, 0x2A4AC },
	{ 0xE68A90, 0x4A4B9 },
	{ 0xE68A91, 0x1CACF },
	{ 0xE68A92, 0x1CAC9 },
	{ 0xE68A93, 0x1CACE },
	{ 0xE68A94, 0x2A4AD },
	{ 0xE68A95, 0x1CACD },
	{ 0xE68A96, 0x1CABF },
	{ 0xE68A97, 0x1CABE },
	{ 0xE68A98, 0x1CACB },
	{ 0xE68A99, 0x3A6B5 },
	{ 0xE68A9A, 0x4A4BC },
	{ 0xE68A9B, 0x3A6B3 },
	{ 0xE68A9C, 0x3A6B4 },
	{ 0xE68A9D, 0x3A6B8 },
	{ 0xE68A9E, 0x3A6B1 },
	{ 0xE68AA3, 0x3E4FB },
	{ 0xE68AA4, 0xFA4B9 },
	{ 0xE68AA5, 0x3A6B2 },
	{ 0xE68AA6, 0x3A9B1 },
	{ 0xE68AA7, 0x3A9AA },
	{ 0xE68AA8, 0x1CDE3 },
	{ 0xE68AA9, 0x2A6FD },
	{ 0xE68AAA, 0x2A6F6 },
	{ 0xE68AAB, 0x1CDDE },
	{ 0xE68AAC, 0x1CDF1 },
	{ 0xE68AAD, 0x2A6F2 },
	{ 0xE68AAE, 0x2A6F9 },
	{ 0xE68AAF, 0x2A6FB },
	{ 0xE68AB0, 0x2A6FE },
	{ 0xE68AB1, 0x1CDEC },
	{ 0xE68AB2, 0x3A9A6 },
	{ 0xE68AB3, 0x2A6FA },
	{ 0xE68AB4, 0x2A6F3 },
	{ 0xE68AB5, 0x1CDEA },
	{ 0xE68AB6, 0x2A6F7 },
	{ 0xE68AB7, 0x3A9A8 },
	{ 0xE68AB8, 0x2A7A1 },
	{ 0xE68AB9, 0x1CDDB },
	{ 0xE68ABA, 0x3A9A5 },
	{ 0xE68ABB, 0x2A6FC },
	{ 0xE68ABC, 0x1CDE5 },
	{ 0xE68ABD, 0x1CDE4 },
	{ 0xE68ABE, 0x2A6F5 },
	{ 0xE68ABF, 0x1CDD9 },
	{ 0xE68B80, 0x3A9B4 },
	{ 0xE68B81, 0x3A9B2 },
	{ 0xE68B82, 0x1CDDA },
	{ 0xE68B83, 0xFA7B0 },
	{ 0xE68B84, 0x1CDD8 },
	{ 0xE68B85, 0x3A9B3 },
	{ 0xE68B86, 0x1CDF0 },
	{ 0xE68B87, 0x1CDE8 },
	{ 0xE68B88, 0x1CDE2 },
	{ 0xE68B89, 0x1CDD6 },
	{ 0xE68B8A, 0x2A6F8 },
	{ 0xE68B8B, 0x1CDE1 },
	{ 0xE68B8C, 0x1CDD7 },
	{ 0xE68B8D, 0x1CDE9 },
	{ 0xE68B8E, 0x1CDF2 },
	{ 0xE68B8F, 0x2AAD5 },
	{ 0xE68B90, 0x1CDE6 },
	{ 0xE68B91, 0x2A6F4 },
	{ 0xE68B92, 0x1CDDC },
	{ 0xE68B93, 0x1CDDF },
	{ 0xE68B94, 0x1CDE0 },
	{ 0xE68B95, 0x3A9AE },
	{ 0xE68B96, 0x1CDEE },
	{ 0xE68B97, 0x1CDEF },
	{ 0xE68B98, 0x1CDED },
	{ 0xE68B99, 0x1CDE7 },
	{ 0xE68B9A, 0x1CDEB },
	{ 0xE68B9B, 0x1CDDD },
	{ 0xE68B9C, 0x1D1B8 },
	{ 0xE68B9D, 0x3A9B0 },
	{ 0xE68B9E, 0x3A9B7 },
	{ 0xE68B9F, 0x3A9B5 },
	{ 0xE68BA0, 0x3A9B6 },
	{ 0xE68BA1, 0x3A9AF },
	{ 0xE68BA4, 0x3A9A9 },
	{ 0xE68BAA, 0x3ACED },
	{ 0xE68BAB, 0x2AADB },
	{ 0xE68BAC, 0x1D1C4 },
	{ 0xE68BAD, 0x1D1BC },
	{ 0xE68BAE, 0x1D1BE },
	{ 0xE68BAF, 0x1D1C3 },
	{ 0xE68BB0, 0x2AAE7 },
	{ 0xE68BB1, 0x1D1C1 },
	{ 0xE68BB2, 0x2AFB3 },
	{ 0xE68BB3, 0x1D5D3 },
	{ 0xE68BB4, 0x1D1C6 },
	{ 0xE68BB5, 0x2AAD8 },
	{ 0xE68BB6, 0x2AAE0 },
	{ 0xE68BB7, 0x1D1C2 },
	{ 0xE68BB8, 0x2AADF },
	{ 0xE68BB9, 0x2AADC },
	{ 0xE68BBA, 0x2AAE4 },
	{ 0xE68BBB, 0x2AAE6 },
	{ 0xE68BBC, 0x1D1BB },
	{ 0xE68BBD, 0x1D1BF },
	{ 0xE68BBE, 0x1D1C5 },
	{ 0xE68BBF, 0x1D5D5 },
	{ 0xE68C80, 0x2AAE1 },
	{ 0xE68C81, 0x1D1BD },
	{ 0xE68C82, 0x1D1C8 },
	{ 0xE68C83, 0x2AADA },
	{ 0xE68C84, 0x3ACEF },
	{ 0xE68C85, 0x3ACF0 },
	{ 0xE68C86, 0x5A9C5 },
	{ 0xE68C87, 0x1D1C0 },
	{ 0xE68C88, 0x1D5D4 },
	{ 0xE68C89, 0x1D1BA },
	{ 0xE68C8A, 0x4A9D9 },
	{ 0xE68C8B, 0x2AAD7 },
	{ 0xE68C8C, 0x2AADE },
	{ 0xE68C8D, 0x2AAD6 },
	{ 0xE68C8E, 0x2AAD9 },
	{ 0xE68C8F, 0x2AADD },
	{ 0xE68C90, 0x2AFB4 },
	{ 0xE68C91, 0x1D1C7 },
	{ 0xE68C92, 0x4A9D1 },
	{ 0xE68C93, 0x2AAE2 },
	{ 0xE68C94, 0x2AAE3 },
	{ 0xE68C95, 0x2AAE5 },
	{ 0xE68C96, 0x1D1B9 },
	{ 0xE68C97, 0x3ACEC },
	{ 0xE68C99, 0x3B1B2 },
	{ 0xE68C9B, 0x3B1B3 },
	{ 0xE68C9F, 0x3ACEB },
	{ 0xE68CA1, 0x3ACEE },
	{ 0xE68CA3, 0x4A9DB },
	{ 0xE68CA8, 0x1D5E3 },
	{ 0xE68CA9, 0x2AFC0 },
	{ 0xE68CAA, 0x1D5E1 },
	{ 0xE68CAB, 0x1D5E2 },
	{ 0xE68CAC, 0x2AFB6 },
	{ 0xE68CAD, 0x2AFC6 },
	{ 0xE68CAE, 0x3B1AC },
	{ 0xE68CAF, 0x1D5D8 },
	{ 0xE68CB0, 0x3B1AF },
	{ 0xE68CB1, 0x3B1B5 },
	{ 0xE68CB2, 0x2B5CA },
	{ 0xE68CB3, 0x2AFC8 },
	{ 0xE68CB4, 0x2AFC2 },
	{ 0xE68CB5, 0x3B1B8 },
	{ 0xE68CB6, 0x2AFB9 },
	{ 0xE68CB7, 0x3B1B7 },
	{ 0xE68CB8, 0x2AFCB },
	{ 0xE68CB9, 0x2AFBC },
	{ 0xE68CBA, 0x1D5DE },
	{ 0xE68CBB, 0x2B5E1 },
	{ 0xE68CBC, 0x2AFBF },
	{ 0xE68CBD, 0x1D5E0 },
	{ 0xE68CBE, 0x1D5D7 },
	{ 0xE68CBF, 0x3B1BC },
	{ 0xE68D80, 0x2AFCD },
	{ 0xE68D81, 0x2AFC1 },
	{ 0xE68D82, 0x1D5DA },
	{ 0xE68D83, 0x2AFBA },
	{ 0xE68D84, 0x2AFB7 },
	{ 0xE68D85, 0x2AFB8 },
	{ 0xE68D86, 0x1D5DB },
	{ 0xE68D87, 0x2AFC7 },
	{ 0xE68D88, 0x2AFCE },
	{ 0xE68D89, 0x1D5DD },
	{ 0xE68D8A, 0x2AFBE },
	{ 0xE68D8B, 0x2AFBD },
	{ 0xE68D8C, 0x1D5E5 },
	{ 0xE68D8D, 0x1D5E4 },
	{ 0xE68D8E, 0x1D5D6 },
	{ 0xE68D8F, 0x1D5DC },
	{ 0xE68D90, 0x1D5DF },
	{ 0xE68D91, 0x2AFCA },
	{ 0xE68D92, 0x3B1AE },
	{ 0xE68D93, 0x3B1B9 },
	{ 0xE68D94, 0x2AFC4 },
	{ 0xE68D95, 0x1D5D9 },
	{ 0xE68D96, 0x2AFB5 },
	{ 0xE68D97, 0x2AFCC },
	{ 0xE68D98, 0x2AFC3 },
	{ 0xE68D99, 0x2AFC5 },
	{ 0xE68D9A, 0x2AFC9 },
	{ 0xE68D9B, 0x3B1B0 },
	{ 0xE68D9C, 0x3B1BB },
	{ 0xE68D9D, 0x3B1B6 },
	{ 0xE68DA0, 0x3E4FC },
	{ 0xE68DA4, 0x3E4FD },
	{ 0xE68DA5, 0x2B5CB },
	{ 0xE68DA6, 0x3B6B1 },
	{ 0xE68DA7, 0x1DADB },
	{ 0xE68DA8, 0x1DAEF },
	{ 0xE68DA9, 0x1DAEE },
	{ 0xE68DAA, 0x3B6A7 },
	{ 0xE68DAB, 0x1DAE3 },
	{ 0xE68DAC, 0x3B6A9 },
	{ 0xE68DAD, 0x2B5DD },
	{ 0xE68DAE, 0x2B5D9 },
	{ 0xE68DAF, 0x2B5D6 },
	{ 0xE68DB0, 0x2B5E8 },
	{ 0xE68DB1, 0x1DADE },
	{ 0xE68DB2, 0x1DAD6 },
	{ 0xE68DB3, 0x3B6A6 },
	{ 0xE68DB4, 0x3B6B2 },
	{ 0xE68DB5, 0x2B5DB },
	{ 0xE68DB6, 0x1DFCD },
	{ 0xE68DB7, 0x1DADA },
	{ 0xE68DB8, 0x2B5E3 },
	{ 0xE68DB9, 0x3B6A2 },
	{ 0xE68DBA, 0x1DAF0 },
	{ 0xE68DBB, 0x1DAED },
	{ 0xE68DBC, 0x2B5DF },
	{ 0xE68DBD, 0x2B5CE },
	{ 0xE68DBE, 0x3B5FC },
	{ 0xE68DBF, 0x3B6AB },
	{ 0xE68E80, 0x1DAEC },
	{ 0xE68E81, 0x2B5E5 },
	{ 0xE68E82, 0x2B5CD },
	{ 0xE68E83, 0x1DAE1 },
	{ 0xE68E84, 0x1DAE5 },
	{ 0xE68E85, 0x2B5E4 },
	{ 0xE68E86, 0x3B6A3 },
	{ 0xE68E87, 0x2B5D7 },
	{ 0xE68E88, 0x1DAE6 },
	{ 0xE68E89, 0x1DAE0 },
	{ 0xE68E8A, 0x2B5CC },
	{ 0xE68E8B, 0x3B5FD },
	{ 0xE68E8C, 0x1DFBF },
	{ 0xE68E8D, 0x2B5E7 },
	{ 0xE68E8E, 0x2B5D5 },
	{ 0xE68E8F, 0x1DAEB },
	{ 0xE68E90, 0x2B5D8 },
	{ 0xE68E91, 0x2B5E6 },
	{ 0xE68E92, 0x1DAEA },
	{ 0xE68E93, 0x3B6A4 },
	{ 0xE68E94, 0x2BBF5 },
	{ 0xE68E95, 0x4B1F7 },
	{ 0xE68E96, 0x1DAD7 },
	{ 0xE68E97, 0x2B5D3 },
	{ 0xE68E98, 0x1DADC },
	{ 0xE68E99, 0x1DAE7 },
	{ 0xE68E9A, 0x4B1F8 },
	{ 0xE68E9B, 0x1DAE2 },
	{ 0xE68E9C, 0x2B5DC },
	{ 0xE68E9D, 0x2B5D2 },
	{ 0xE68E9E, 0x2B5D0 },
	{ 0xE68E9F, 0x2B5E2 },
	{ 0xE68EA0, 0x1DAD4 },
	{ 0xE68EA1, 0x1DAE8 },
	{ 0xE68EA2, 0x1DAD8 },
	{ 0xE68EA3, 0x1DFBE },
	{ 0xE68EA4, 0x2B5E0 },
	{ 0xE68EA5, 0x1DAD9 },
	{ 0xE68EA6, 0x4B2A3 },
	{ 0xE68EA7, 0x1DAD5 },
	{ 0xE68EA8, 0x1DAE4 },
	{ 0xE68EA9, 0x1DADF },
	{ 0xE68EAA, 0x1DADD },
	{ 0xE68EAB, 0x2B5D4 },
	{ 0xE68EAC, 0x1DAE9 },
	{ 0xE68EAD, 0x2B5D1 },
	{ 0xE68EAE, 0x2B5DE },
	{ 0xE68EAF, 0x2B5DA },
	{ 0xE68EB0, 0x2BBF7 },
	{ 0xE68EB1, 0x2BBF6 },
	{ 0xE68EB2, 0x3B6AD },
	{ 0xE68EB6, 0x3E4FE },
	{ 0xE68EBA, 0x3B6AE },
	{ 0xE68EBD, 0x2B5CF },
	{ 0xE68EBE, 0x2BCA9 },
	{ 0xE68EBF, 0x3BBF1 },
	{ 0xE68F80, 0x1DFC1 },
	{ 0xE68F81, 0x3BBF0 },
	{ 0xE68F82, 0x2BCAF },
	{ 0xE68F83, 0x2BBFC },
	{ 0xE68F84, 0x2BCAC },
	{ 0xE68F85, 0x2C2FD },
	{ 0xE68F86, 0x1DFC4 },
	{ 0xE68F87, 0x2BCB0 },
	{ 0xE68F88, 0x2BCB3 },
	{ 0xE68F89, 0x1DFC3 },
	{ 0xE68F8A, 0x2BCA1 },
	{ 0xE68F8B, 0x2BCB2 },
	{ 0xE68F8C, 0x2BCB1 },
	{ 0xE68F8D, 0x1DFC5 },
	{ 0xE68F8E, 0x2BBF8 },
	{ 0xE68F8F, 0x1DFC0 },
	{ 0xE68F90, 0x1DFC8 },
	{ 0xE68F91, 0x3BBF3 },
	{ 0xE68F92, 0x1DFC6 },
	{ 0xE68F93, 0x2BCAE },
	{ 0xE68F94, 0x4B7F1 },
	{ 0xE68F95, 0x2BCA4 },
	{ 0xE68F96, 0x1DFCA },
	{ 0xE68F97, 0x2BCB5 },
	{ 0xE68F98, 0x2BCAD },
	{ 0xE68F99, 0x2BCB6 },
	{ 0xE68F9A, 0x1DFD2 },
	{ 0xE68F9B, 0x1DFD0 },
	{ 0xE68F9C, 0x2BCAB },
	{ 0xE68F9D, 0x2BCAA },
	{ 0xE68F9E, 0x3BBE7 },
	{ 0xE68F9F, 0x2BCA8 },
	{ 0xE68FA0, 0x2BCA2 },
	{ 0xE68FA1, 0x1DFC9 },
	{ 0xE68FA2, 0x3BBE6 },
	{ 0xE68FA3, 0x1DFC7 },
	{ 0xE68FA4, 0x2AFBB },
	{ 0xE68FA5, 0x2BBF9 },
	{ 0xE68FA6, 0x3BBE8 },
	{ 0xE68FA7, 0x2C3BD },
	{ 0xE68FA8, 0x2BBFA },
	{ 0xE68FA9, 0x1DFC2 },
	{ 0xE68FAA, 0x1DFCF },
	{ 0xE68FAB, 0x2C3A1 },
	{ 0xE68FAC, 0x4B7E0 },
	{ 0xE68FAD, 0x1DFCB },
	{ 0xE68FAE, 0x1DFCC },
	{ 0xE68FAF, 0x2BBFB },
	{ 0xE68FB0, 0x2BCB4 },
	{ 0xE68FB1, 0x2C2FE },
	{ 0xE68FB2, 0x2BCA5 },
	{ 0xE68FB3, 0x2BBFE },
	{ 0xE68FB4, 0x1DFCE },
	{ 0xE68FB5, 0x2BCA6 },
	{ 0xE68FB6, 0x2BCA3 },
	{ 0xE68FB7, 0x3BBF2 },
	{ 0xE68FB8, 0x3BBED },
	{ 0xE68FB9, 0x1DFD3 },
	{ 0xE68FBA, 0x4B7EF },
	{ 0xE68FBE, 0x3BBEF },
	{ 0xE69083, 0x3E5A1 },
	{ 0xE69086, 0x1E4B8 },
	{ 0xE69087, 0x3C1C9 },
	{ 0xE69088, 0x3C1B2 },
	{ 0xE69089, 0x2C3A4 },
	{ 0xE6908A, 0x2C3B7 },
	{ 0xE6908B, 0x2C3BC },
	{ 0xE6908C, 0x2C3B0 },
	{ 0xE6908D, 0x1E4B4 },
	{ 0xE6908E, 0x2C3C1 },
	{ 0xE6908F, 0x1E4B1 },
	{ 0xE69090, 0x2C3A2 },
	{ 0xE69091, 0x3C1BA },
	{ 0xE69092, 0x2C3A3 },
	{ 0xE69093, 0x1E4AA },
	{ 0xE69094, 0x1E4B3 },
	{ 0xE69095, 0x2C3AA },
	{ 0xE69096, 0x1E4B6 },
	{ 0xE69097, 0x1E4B7 },
	{ 0xE69098, 0x2C3AB },
	{ 0xE69099, 0x3C1B8 },
	{ 0xE6909A, 0x2C3B8 },
	{ 0xE6909B, 0x2C3BE },
	{ 0xE6909C, 0x1E4B2 },
	{ 0xE6909D, 0x3C1BE },
	{ 0xE6909E, 0x1E4AC },
	{ 0xE6909F, 0x2C3A9 },
	{ 0xE690A0, 0x2C3A5 },
	{ 0xE690A1, 0x2C3C0 },
	{ 0xE690A2, 0x2C3AE },
	{ 0xE690A3, 0x2C3AF },
	{ 0xE690A4, 0x2C3A6 },
	{ 0xE690A5, 0x2C3BA },
	{ 0xE690A6, 0x2C3B1 },
	{ 0xE690A7, 0x2C3BB },
	{ 0xE690A8, 0x2C3B3 },
	{ 0xE690A9, 0x3C1BD },
	{ 0xE690AA, 0x1E4AD },
	{ 0xE690AB, 0x2CAC0 },
	{ 0xE690AC, 0x1E4B0 },
	{ 0xE690AD, 0x1E4AE },
	{ 0xE690AE, 0x2C3BF },
	{ 0xE690AF, 0x2C3B6 },
	{ 0xE690B0, 0x2C3B2 },
	{ 0xE690B1, 0x3C1B6 },
	{ 0xE690B2, 0x3C1B3 },
	{ 0xE690B3, 0x2C3A7 },
	{ 0xE690B4, 0x1E8FA },
	{ 0xE690B5, 0x2C3B5 },
	{ 0xE690B6, 0x1E4B5 },
	{ 0xE690B7, 0x2C3AD },
	{ 0xE690B8, 0x3C1B4 },
	{ 0xE690B9, 0x2C3AC },
	{ 0xE690BA, 0x3C1C8 },
	{ 0xE690BB, 0x3C7A5 },
	{ 0xE690BC, 0x3C1C2 },
	{ 0xE690BD, 0x1E4AF },
	{ 0xE690BE, 0x1E4AB },
	{ 0xE690BF, 0x2CAD5 },
	{ 0xE69180, 0x2C3B9 },
	{ 0xE69181, 0x2C3B4 },
	{ 0xE69183, 0x2C3A8 },
	{ 0xE69186, 0x3C1C4 },
	{ 0xE69187, 0x3C1C5 },
	{ 0xE69189, 0x3E6F6 },
	{ 0xE6918B, 0x2CAD0 },
	{ 0xE6918C, 0x3C6F8 },
	{ 0xE6918D, 0x2CAC1 },
	{ 0xE6918E, 0x2CACC },
	{ 0xE6918F, 0x3C7A8 },
	{ 0xE69190, 0x2CAD3 },
	{ 0xE69191, 0x1E8F8 },
	{ 0xE69192, 0x1DFD1 },
	{ 0xE69193, 0x2CAD1 },
	{ 0xE69194, 0x1E8F3 },
	{ 0xE69195, 0x3C6FE },
	{ 0xE69196, 0x3C7A4 },
	{ 0xE69197, 0x3C6FA },
	{ 0xE69198, 0x1E8F2 },
	{ 0xE69199, 0x2CAD8 },
	{ 0xE6919A, 0x4C3DD },
	{ 0xE6919B, 0x2CAC2 },
	{ 0xE6919C, 0x2CACF },
	{ 0xE6919D, 0x2CAC3 },
	{ 0xE6919E, 0x2CACE },
	{ 0xE6919F, 0x1E8F6 },
	{ 0xE691A0, 0x2CAD2 },
	{ 0xE691A1, 0x2BCA7 },
	{ 0xE691A2, 0x3C7A1 },
	{ 0xE691A3, 0x4C3DE },
	{ 0xE691A4, 0x3C7AA },
	{ 0xE691A5, 0x2CAD9 },
	{ 0xE691A6, 0x2CACA },
	{ 0xE691A7, 0x1E8F9 },
	{ 0xE691A8, 0x2D0E1 },
	{ 0xE691A9, 0x1ECF7 },
	{ 0xE691AA, 0x3C7A3 },
	{ 0xE691AB, 0x2CAD7 },
	{ 0xE691AC, 0x2CAD6 },
	{ 0xE691AD, 0x1E8FB },
	{ 0xE691AE, 0x2D0D4 },
	{ 0xE691AF, 0x1ECF8 },
	{ 0xE691B0, 0x2D0D5 },
	{ 0xE691B1, 0x3C7A2 },
	{ 0xE691B2, 0x2CAC6 },
	{ 0xE691B3, 0x2CAC7 },
	{ 0xE691B4, 0x2CAC4 },
	{ 0xE691B5, 0x2CAC9 },
	{ 0xE691B6, 0x2CAC5 },
	{ 0xE691B7, 0x2CADA },
	{ 0xE691B8, 0x1E8F5 },
	{ 0xE691B9, 0x1ECF9 },
	{ 0xE691BA, 0x1E8F7 },
	{ 0xE691BB, 0x1E8FC },
	{ 0xE691BC, 0x3C6FB },
	{ 0xE691BD, 0x2CAC8 },
	{ 0xE691BE, 0x3C7A9 },
	{ 0xE691BF, 0x2CAD4 },
	{ 0xE69280, 0x3CCAD },
	{ 0xE69281, 0x3C7A6 },
	{ 0xE69282, 0x2CACD },
	{ 0xE69283, 0x3CCB5 },
	{ 0xE69285, 0x2D0D8 },
	{ 0xE69286, 0x3CCB8 },
	{ 0xE69287, 0x1E8F1 },
	{ 0xE69288, 0x1ECFC },
	{ 0xE69289, 0x2D7B5 },
	{ 0xE6928A, 0x2D0DD },
	{ 0xE6928B, 0x2D0DC },
	{ 0xE6928C, 0x2D0DE },
	{ 0xE6928D, 0x3CCB0 },
	{ 0xE6928E, 0x3CCAF },
	{ 0xE6928F, 0x2D0DB },
	{ 0xE69290, 0x1ECFD },
	{ 0xE69291, 0x3CCBB },
	{ 0xE69292, 0x1EDA5 },
	{ 0xE69293, 0x1EDA2 },
	{ 0xE69294, 0x3CCB1 },
	{ 0xE69295, 0x1EDA3 },
	{ 0xE69296, 0x2D0D6 },
	{ 0xE69297, 0x2D0D9 },
	{ 0xE69298, 0x2D0E3 },
	{ 0xE69299, 0x1EDAB },
	{ 0xE6929A, 0x1EDA9 },
	{ 0xE6929B, 0x3CCAE },
	{ 0xE6929C, 0x2D0DA },
	{ 0xE6929D, 0x2BBFD },
	{ 0xE6929E, 0x1ECFA },
	{ 0xE6929F, 0x2D0E0 },
	{ 0xE692A0, 0x2D0D7 },
	{ 0xE692A1, 0x3CCBE },
	{ 0xE692A2, 0x1EDAC },
	{ 0xE692A3, 0x2D0DF },
	{ 0xE692A4, 0x1E8F4 },
	{ 0xE692A5, 0x1EDA1 },
	{ 0xE692A6, 0x2CACB },
	{ 0xE692A7, 0x3CCBF },
	{ 0xE692A8, 0x3CCB4 },
	{ 0xE692A9, 0x1EDA4 },
	{ 0xE692AA, 0x3CCBD },
	{ 0xE692AB, 0x1EDA8 },
	{ 0xE692AC, 0x1EDAA },
	{ 0xE692AD, 0x1EDA7 },
	{ 0xE692AE, 0x1EDA6 },
	{ 0xE692AF, 0x3CCBA },
	{ 0xE692B0, 0x1ECFE },
	{ 0xE692B1, 0x2D0E2 },
	{ 0xE692B2, 0x1ECFB },
	{ 0xE692B3, 0x1EDAD },
	{ 0xE692B4, 0x3CCB9 },
	{ 0xE692B6, 0x3E5A2 },
	{ 0xE692B9, 0x3CCB7 },
	{ 0xE692BB, 0x1F0E1 },
	{ 0xE692BC, 0x1F0E2 },
	{ 0xE692BD, 0x2D7B4 },
	{ 0xE692BE, 0x1F0EB },
	{ 0xE692BF, 0x1F0E8 },
	{ 0xE69380, 0x3D0F0 },
	{ 0xE69381, 0x1F0DF },
	{ 0xE69382, 0x1F0E6 },
	{ 0xE69383, 0x2D7B6 },
	{ 0xE69384, 0x1F0E4 },
	{ 0xE69385, 0x1F0DE },
	{ 0xE69386, 0x3CCB2 },
	{ 0xE69387, 0x1F0E5 },
	{ 0xE69388, 0x3D0F7 },
	{ 0xE69389, 0x2D7B3 },
	{ 0xE6938A, 0x1F3E4 },
	{ 0xE6938B, 0x1F0E0 },
	{ 0xE6938C, 0x5D4DE },
	{ 0xE6938D, 0x1F0E7 },
	{ 0xE6938E, 0x1F3E3 },
	{ 0xE6938F, 0x2D7B2 },
	{ 0xE69390, 0x2D7B1 },
	{ 0xE69391, 0x3D0F6 },
	{ 0xE69392, 0x1F0E9 },
	{ 0xE69393, 0x3D0EF },
	{ 0xE69394, 0x1F0EA },
	{ 0xE69395, 0x3D0F9 },
	{ 0xE69396, 0x2D7B0 },
	{ 0xE69397, 0x2D7AF },
	{ 0xE69398, 0x1F3E5 },
	{ 0xE69399, 0x2D7B9 },
	{ 0xE6939A, 0x1F0E3 },
	{ 0xE6939B, 0x2D7B7 },
	{ 0xE6939C, 0x3D0F5 },
	{ 0xE6939F, 0x3D4E4 },
	{ 0xE693A0, 0x1F3E6 },
	{ 0xE693A1, 0x3D4E7 },
	{ 0xE693A2, 0x1F3EB },
	{ 0xE693A3, 0x2DCF5 },
	{ 0xE693A4, 0x2DCF7 },
	{ 0xE693A5, 0x3D7EB },
	{ 0xE693A6, 0x1F3E8 },
	{ 0xE693A7, 0x3D7ED },
	{ 0xE693A8, 0x2DCF8 },
	{ 0xE693A9, 0x2DCF4 },
	{ 0xE693AA, 0x3D7EC },
	{ 0xE693AB, 0x2DCF6 },
	{ 0xE693AC, 0x1F3E9 },
	{ 0xE693AD, 0x1F3EC },
	{ 0xE693AE, 0x3D4E9 },
	{ 0xE693AF, 0x2DCF3 },
	{ 0xE693B0, 0x1F3E7 },
	{ 0xE693B1, 0x1F3EA },
	{ 0xE693B2, 0x1F6C5 },
	{ 0xE693B3, 0x2D7B8 },
	{ 0xE693B4, 0x1F6C4 },
	{ 0xE693B5, 0x7BFE2 },
	{ 0xE693B6, 0x3D7EA },
	{ 0xE693B7, 0x1F6CA },
	{ 0xE693B8, 0x2E1E0 },
	{ 0xE693B9, 0x3D7F0 },
	{ 0xE693BA, 0x1F6C8 },
	{ 0xE693BB, 0x1F6C9 },
	{ 0xE693BC, 0x2E1E3 },
	{ 0xE693BD, 0x2E1DF },
	{ 0xE693BE, 0x1F6C6 },
	{ 0xE693BF, 0x2E1DD },
	{ 0xE69480, 0x1F8B8 },
	{ 0xE69481, 0x2E1E1 },
	{ 0xE69482, 0x4DBB6 },
	{ 0xE69483, 0x2E1E2 },
	{ 0xE69484, 0x2E1DE },
	{ 0xE69485, 0x3D7EE },
	{ 0xE69486, 0x1F6C7 },
	{ 0xE69487, 0x2E5CD },
	{ 0xE69488, 0x3DABB },
	{ 0xE69489, 0x2E5D0 },
	{ 0xE6948A, 0x3DABC },
	{ 0xE6948B, 0x3DABA },
	{ 0xE6948C, 0x2E5D1 },
	{ 0xE6948D, 0x2E5CF },
	{ 0xE6948E, 0x2E5D2 },
	{ 0xE6948F, 0x1F8B9 },
	{ 0xE69490, 0x2E5CE },
	{ 0xE69491, 0x3DEB1 },
	{ 0xE69493, 0x2E8FA },
	{ 0xE69494, 0x1F9EF },
	{ 0xE69495, 0x2E8F9 },
	{ 0xE69496, 0x2E8F8 },
	{ 0xE69497, 0x2E8F7 },
	{ 0xE69498, 0x1F9EE },
	{ 0xE69499, 0x1F9F0 },
	{ 0xE6949A, 0x3E5A3 },
	{ 0xE6949B, 0x2EBDB },
	{ 0xE6949C, 0x1FAED },
	{ 0xE6949D, 0x1FAEC },
	{ 0xE6949E, 0x3DFCA },
	{ 0xE6949F, 0x3DFCB },
	{ 0xE694A0, 0x2EDCF },
	{ 0xE694A1, 0x2EDCE },
	{ 0xE694A2, 0x2EDD1 },
	{ 0xE694A3, 0x1FCB7 },
	{ 0xE694A4, 0x1FBE1 },
	{ 0xE694A5, 0x2EFAC },
	{ 0xE694A6, 0x2EDD0 },
	{ 0xE694A7, 0x3DFC9 },
	{ 0xE694A8, 0x3E0B2 },
	{ 0xE694A9, 0x2EFAB },
	{ 0xE694AA, 0x1FCB9 },
	{ 0xE694AB, 0x1FCB8 },
	{ 0xE694AC, 0x1FCDF },
	{ 0xE694AD, 0x2F0B7 },
	{ 0xE694AE, 0x2F0FD },
	{ 0xE694AF, 0x1C5C5 },
	{ 0xE694B0, 0x6A3EC },
	{ 0xE694B1, 0x3ACF2 },
	{ 0xE694B2, 0x2BCB7 },
	{ 0xE694B3, 0x2D7BA },
	{ 0xE694B4, 0x3A1E7 },
	{ 0xE694B5, 0x3A1E8 },
	{ 0xE694B6, 0x1C8AD },
	{ 0xE694B7, 0x2A2CD },
	{ 0xE694B8, 0x1CAD3 },
	{ 0xE694B9, 0x1CAD1 },
	{ 0xE694BA, 0x4A4BF },
	{ 0xE694BB, 0x1CAD2 },
	{ 0xE694BC, 0x4A4BE },
	{ 0xE694BD, 0x2A7A2 },
	{ 0xE694BE, 0x1CDF3 },
	{ 0xE694BF, 0x1D1C9 },
	{ 0xE69580, 0x3ACF4 },
	{ 0xE69581, 0x2AAE8 },
	{ 0xE69582, 0x3ACF6 },
	{ 0xE69583, 0x2AAE9 },
	{ 0xE69584, 0x3ACF3 },
	{ 0xE69585, 0x1D1CA },
	{ 0xE69586, 0x2AFD0 },
	{ 0xE69587, 0x4ADC3 },
	{ 0xE69588, 0x1D5E6 },
	{ 0xE69589, 0x1D5E7 },
	{ 0xE6958A, 0x2AFCF },
	{ 0xE6958B, 0x3B1BD },
	{ 0xE6958C, 0x4ADC4 },
	{ 0xE6958D, 0x3B6B7 },
	{ 0xE6958E, 0x3B6B6 },
	{ 0xE6958F, 0x1DAF7 },
	{ 0xE69590, 0x4B2AB },
	{ 0xE69591, 0x1DAF3 },
	{ 0xE69592, 0x4B2AF },
	{ 0xE69593, 0x2B5E9 },
	{ 0xE69594, 0x1DAFA },
	{ 0xE69595, 0x1DAF9 },
	{ 0xE69596, 0x1DAF2 },
	{ 0xE69597, 0x1DAF5 },
	{ 0xE69598, 0x1DAF8 },
	{ 0xE69599, 0x1DAF4 },
	{ 0xE6959A, 0x3B6B4 },
	{ 0xE6959C, 0x2BCBB },
	{ 0xE6959D, 0x1DAF1 },
	{ 0xE6959E, 0x1DFD4 },
	{ 0xE6959F, 0x3BBF4 },
	{ 0xE695A0, 0x3BBF5 },
	{ 0xE695A1, 0x3BBF6 },
	{ 0xE695A2, 0x1DFD6 },
	{ 0xE695A3, 0x1DFD7 },
	{ 0xE695A4, 0x2BCBA },
	{ 0xE695A5, 0x2BCBD },
	{ 0xE695A6, 0x1DFD5 },
	{ 0xE695A7, 0x2BCB8 },
	{ 0xE695A8, 0x2BCBC },
	{ 0xE695AA, 0x2BCB9 },
	{ 0xE695AB, 0x3C1CB },
	{ 0xE695AC, 0x1E4B9 },
	{ 0xE695AD, 0x3C1CE },
	{ 0xE695AE, 0x4BDDD },
	{ 0xE695AF, 0x2C3C2 },
	{ 0xE695B0, 0x3C1CD },
	{ 0xE695B1, 0x3C7B0 },
	{ 0xE695B2, 0x1E8FD },
	{ 0xE695B3, 0x2CADB },
	{ 0xE695B4, 0x1F0EC },
	{ 0xE695B5, 0x1EDAE },
	{ 0xE695B6, 0x2D0E4 },
	{ 0xE695B7, 0x1EDAF },
	{ 0xE695B8, 0x1EDB0 },
	{ 0xE695B9, 0x2D0E6 },
	{ 0xE695BA, 0x2D0E5 },
	{ 0xE695BB, 0x2D0E7 },
	{ 0xE695BC, 0x2D7BC },
	{ 0xE695BF, 0x2D7BB },
	{ 0xE69680, 0x2DCFA },
	{ 0xE69681, 0x2DCF9 },
	{ 0xE69682, 0x1F3ED },
	{ 0xE69683, 0x1F3EE },
	{ 0xE69684, 0x2E5D3 },
	{ 0xE69685, 0x3DCC1 },
	{ 0xE69687, 0x1C5C6 },
	{ 0xE69688, 0x3A5D8 },
	{ 0xE69689, 0x3A9B9 },
	{ 0xE6968A, 0x4ADC7 },
	{ 0xE6968B, 0x3B1C0 },
	{ 0xE6968C, 0x2BCBE },
	{ 0xE6968D, 0x3B6B8 },
	{ 0xE6968E, 0x3B6B9 },
	{ 0xE69690, 0x1DFD9 },
	{ 0xE69691, 0x1DFD8 },
	{ 0xE69692, 0x2C3C3 },
	{ 0xE69694, 0x2E1E4 },
	{ 0xE69695, 0x1FAEE },
	{ 0xE69696, 0x2EFAD },
	{ 0xE69697, 0x1C5C7 },
	{ 0xE69698, 0x4A4C1 },
	{ 0xE69699, 0x1D5E8 },
	{ 0xE6969A, 0x3B1C2 },
	{ 0xE6969B, 0x1DAFC },
	{ 0xE6969C, 0x1DAFB },
	{ 0xE6969D, 0x2BCBF },
	{ 0xE6969E, 0x2BCC0 },
	{ 0xE6969F, 0x1E4BA },
	{ 0xE696A0, 0x2CADC },
	{ 0xE696A1, 0x1E8FE },
	{ 0xE696A2, 0x2D7BD },
	{ 0xE696A3, 0x4D6BF },
	{ 0xE696A4, 0x1C5C8 },
	{ 0xE696A5, 0x1C6D8 },
	{ 0xE696A6, 0x3A9BB },
	{ 0xE696A7, 0x1CDF4 },
	{ 0xE696A8, 0x2A7A3 },
	{ 0xE696AA, 0x2AAEA },
	{ 0xE696AB, 0x1D1CB },
	{ 0xE696AC, 0x1DAFD },
	{ 0xE696AD, 0x3B6BA },
	{ 0xE696AE, 0x2BCC1 },
	{ 0xE696AF, 0x1DFDA },
	{ 0xE696B0, 0x1E4BB },
	{ 0xE696B1, 0x4BDE3 },
	{ 0xE696B2, 0x2D0E8 },
	{ 0xE696B3, 0x2D0E9 },
	{ 0xE696B4, 0x4D0CE },
	{ 0xE696B5, 0x3D4EB },
	{ 0xE696B6, 0x2DCFB },
	{ 0xE696B7, 0x1F6CB },
	{ 0xE696B8, 0x2F0FE },
	{ 0xE696B9, 0x1C5C9 },
	{ 0xE696BA, 0x3A9BC },
	{ 0xE696BB, 0x2A7A4 },
	{ 0xE696BC, 0x1CDF5 },
	{ 0xE696BD, 0x1D1CC },
	{ 0xE696BE, 0x3ACF7 },
	{ 0xE696BF, 0x2AAEB },
	{ 0xE69781, 0x1D5E9 },
	{ 0xE69782, 0x2AFD4 },
	{ 0xE69783, 0x2AFD2 },
	{ 0xE69784, 0x2AFD3 },
	{ 0xE69785, 0x1D5EA },
	{ 0xE69786, 0x2AFD1 },
	{ 0xE69787, 0x3B6BC },
	{ 0xE69788, 0x4B2B4 },
	{ 0xE69789, 0x3B6BF },
	{ 0xE6978A, 0x3B6BD },
	{ 0xE6978B, 0x1DBA1 },
	{ 0xE6978C, 0x1DBA2 },
	{ 0xE6978D, 0x2B5EA },
	{ 0xE6978E, 0x1DBA3 },
	{ 0xE6978F, 0x1DAFE },
	{ 0xE69790, 0x2BCC2 },
	{ 0xE69791, 0x3BBF9 },
	{ 0xE69792, 0x2BCC3 },
	{ 0xE69793, 0x2C3C4 },
	{ 0xE69794, 0x4BDE4 },
	{ 0xE69796, 0x1E9A2 },
	{ 0xE69797, 0x1E9A1 },
	{ 0xE69798, 0x4D0CF },
	{ 0xE69799, 0xFD4E4 },
	{ 0xE6979A, 0x2DCFC },
	{ 0xE6979B, 0x2E1E5 },
	{ 0xE6979C, 0x3DABF },
	{ 0xE6979D, 0x2E5D5 },
	{ 0xE6979E, 0x2E5D4 },
	{ 0xE6979F, 0x2E8FB },
	{ 0xE697A0, 0x3A1E9 },
	{ 0xE697A1, 0x2A1BE },
	{ 0xE697A2, 0x1D1CD },
	{ 0xE697A3, 0x3B6C1 },
	{ 0xE697A4, 0x3C1D0 },
	{ 0xE697A5, 0x1C5CA },
	{ 0xE697A6, 0x1C6D9 },
	{ 0xE697A7, 0x3A2D1 },
	{ 0xE697A8, 0x1C8AF },
	{ 0xE697A9, 0x1C8AE },
	{ 0xE697AA, 0x3A3F3 },
	{ 0xE697AB, 0x3A3F2 },
	{ 0xE697AC, 0x1C8B0 },
	{ 0xE697AD, 0x1C8B1 },
	{ 0xE697AE, 0x2A2CF },
	{ 0xE697AF, 0x2A2CE },
	{ 0xE697B0, 0x2A4B9 },
	{ 0xE697B1, 0x1CAD4 },
	{ 0xE697B2, 0x2A4BC },
	{ 0xE697B3, 0x2A4BB },
	{ 0xE697B4, 0x2A4BA },
	{ 0xE697B5, 0x2A4BD },
	{ 0xE697B6, 0x3A6BD },
	{ 0xE697B9, 0x4A6E2 },
	{ 0xE697BA, 0x1CDF6 },
	{ 0xE697BB, 0x2A7AA },
	{ 0xE697BC, 0x2A7A6 },
	{ 0xE697BD, 0x2A7AF },
	{ 0xE697BE, 0x3A9C3 },
	{ 0xE697BF, 0x3A9BE },
	{ 0xE69880, 0x1CDFD },
	{ 0xE69881, 0x3A9C2 },
	{ 0xE69882, 0x1CDFB },
	{ 0xE69883, 0x2A7AB },
	{ 0xE69884, 0x2A7A7 },
	{ 0xE69885, 0x2A7AE },
	{ 0xE69886, 0x1CDFA },
	{ 0xE69887, 0x1CEA3 },
	{ 0xE69888, 0x2A7A9 },
	{ 0xE69889, 0x2A7A5 },
	{ 0xE6988A, 0x1CEA2 },
	{ 0xE6988B, 0x2A7AC },
	{ 0xE6988C, 0x1CDF9 },
	{ 0xE6988D, 0x2A7AD },
	{ 0xE6988E, 0x1CDFC },
	{ 0xE6988F, 0x1CDFE },
	{ 0xE69890, 0x2A7B1 },
	{ 0xE69891, 0x2A7B0 },
	{ 0xE69892, 0x2A7A8 },
	{ 0xE69893, 0x1CDF8 },
	{ 0xE69894, 0x1CDF7 },
	{ 0xE69895, 0x1CEA1 },
	{ 0xE69896, 0x4A6E1 },
	{ 0xE69897, 0x3A9C0 },
	{ 0xE69898, 0x3A9C1 },
	{ 0xE69899, 0xFA7BE },
	{ 0xE6989A, 0x3ACFE },
	{ 0xE6989B, 0x3ACFA },
	{ 0xE6989C, 0x2AAF0 },
	{ 0xE6989D, 0x2AAF6 },
	{ 0xE6989E, 0x3ADA3 },
	{ 0xE6989F, 0x1D1D3 },
	{ 0xE698A0, 0x1D1D0 },
	{ 0xE698A1, 0x2AAED },
	{ 0xE698A2, 0x2AAF2 },
	{ 0xE698A3, 0x3ACFC },
	{ 0xE698A4, 0x1D1D6 },
	{ 0xE698A5, 0x1D1CE },
	{ 0xE698A6, 0x2AAF1 },
	{ 0xE698A7, 0x1D1D1 },
	{ 0xE698A8, 0x1D1D4 },
	{ 0xE698A9, 0x3ACF9 },
	{ 0xE698AA, 0x4A9E7 },
	{ 0xE698AB, 0x2AAF4 },
	{ 0xE698AC, 0x3ACFD },
	{ 0xE698AD, 0x1D1CF },
	{ 0xE698AE, 0x2AAF9 },
	{ 0xE698AF, 0x1D1D2 },
	{ 0xE698B0, 0x3ADA1 },
	{ 0xE698B1, 0x1D1D5 },
	{ 0xE698B2, 0x2AAEE },
	{ 0xE698B3, 0x2AAF3 },
	{ 0xE698B4, 0x2AAF7 },
	{ 0xE698B5, 0x2AAEF },
	{ 0xE698B6, 0x2AAEC },
	{ 0xE698B7, 0x3ADA4 },
	{ 0xE698B8, 0x3ADA5 },
	{ 0xE698B9, 0x2AAF8 },
	{ 0xE698BA, 0x2AAF5 },
	{ 0xE698BB, 0x3ADA2 },
	{ 0xE698BC, 0x3ACB7 },
	{ 0xE69980, 0x3B1C6 },
	{ 0xE69981, 0x1D5F2 },
	{ 0xE69982, 0x1D5EB },
	{ 0xE69983, 0x1D5EE },
	{ 0xE69984, 0x3B1CC },
	{ 0xE69985, 0x1D5F1 },
	{ 0xE69986, 0x3B1C4 },
	{ 0xE69987, 0x2AFD7 },
	{ 0xE69988, 0x3B1C9 },
	{ 0xE69989, 0x1D5EC },
	{ 0xE6998A, 0x2AFD5 },
	{ 0xE6998B, 0x3B1C8 },
	{ 0xE6998C, 0x1D5F0 },
	{ 0xE6998D, 0x3B1CD },
	{ 0xE6998E, 0x3B1C5 },
	{ 0xE6998F, 0x1D5ED },
	{ 0xE69990, 0x3B1C3 },
	{ 0xE69991, 0x2AFD8 },
	{ 0xE69992, 0x1D5EF },
	{ 0xE69997, 0x3B6C2 },
	{ 0xE69998, 0x4B2B9 },
	{ 0xE69999, 0x2B5EE },
	{ 0xE6999A, 0x1DBA5 },
	{ 0xE6999B, 0x2B5ED },
	{ 0xE6999C, 0x2B5EF },
	{ 0xE6999D, 0x1DBA4 },
	{ 0xE6999E, 0x1DBA9 },
	{ 0xE6999F, 0x2AFD6 },
	{ 0xE699A0, 0x3B1CB },
	{ 0xE699A1, 0x2B5EC },
	{ 0xE699A2, 0x2B5F0 },
	{ 0xE699A3, 0x3B6C4 },
	{ 0xE699A4, 0x1DBA6 },
	{ 0xE699A5, 0x2B5EB },
	{ 0xE699A6, 0x1DBA8 },
	{ 0xE699A7, 0x3B6C5 },
	{ 0xE699A8, 0x1DBA7 },
	{ 0xE699A9, 0x3BCA6 },
	{ 0xE699AA, 0x2BCCA },
	{ 0xE699AB, 0x3BBFD },
	{ 0xE699AC, 0x2BCC5 },
	{ 0xE699AD, 0x3BCA5 },
	{ 0xE699AE, 0x1DFDB },
	{ 0xE699AF, 0x1DFDF },
	{ 0xE699B0, 0x1DFDC },
	{ 0xE699B1, 0x2BCC8 },
	{ 0xE699B2, 0x2BCCB },
	{ 0xE699B3, 0x3BCA3 },
	{ 0xE699B4, 0x1DFDD },
	{ 0xE699B5, 0x4B8A4 },
	{ 0xE699B6, 0x1DFDE },
	{ 0xE699B7, 0x1DFE3 },
	{ 0xE699B8, 0x2C3CD },
	{ 0xE699B9, 0x2BCC9 },
	{ 0xE699BA, 0x1DFE1 },
	{ 0xE699BB, 0x2BCC6 },
	{ 0xE699BC, 0x2BCC4 },
	{ 0xE699BD, 0x3BBFC },
	{ 0xE699BE, 0x1DFE2 },
	{ 0xE699BF, 0x3BBFE },
	{ 0xE69A80, 0x2BCC7 },
	{ 0xE69A81, 0x3BCA4 },
	{ 0xE69A84, 0x1E4C1 },
	{ 0xE69A85, 0x4BDE9 },
	{ 0xE69A86, 0x2C3C5 },
	{ 0xE69A87, 0x1E4BE },
	{ 0xE69A88, 0x1E4BF },
	{ 0xE69A89, 0x1E4BD },
	{ 0xE69A8A, 0x2C3CA },
	{ 0xE69A8B, 0x2C3C9 },
	{ 0xE69A8C, 0x2C3C6 },
	{ 0xE69A8D, 0x1E4C3 },
	{ 0xE69A8E, 0x3C1DB },
	{ 0xE69A8F, 0x3C1D6 },
	{ 0xE69A90, 0x2C3C8 },
	{ 0xE69A91, 0x1DFE0 },
	{ 0xE69A92, 0x3C1D9 },
	{ 0xE69A93, 0x3C1D1 },
	{ 0xE69A94, 0x2C3CC },
	{ 0xE69A95, 0x2C3C7 },
	{ 0xE69A96, 0x1E4C0 },
	{ 0xE69A97, 0x1E4BC },
	{ 0xE69A98, 0x1E4C2 },
	{ 0xE69A99, 0x2C3CB },
	{ 0xE69A9A, 0x3C7B4 },
	{ 0xE69A9B, 0x4C3EB },
	{ 0xE69A9C, 0x3C7B5 },
	{ 0xE69A9D, 0x1E9A5 },
	{ 0xE69A9E, 0x4C3EF },
	{ 0xE69A9F, 0x2CADF },
	{ 0xE69AA0, 0x2CADE },
	{ 0xE69AA1, 0x2CADD },
	{ 0xE69AA2, 0x1E9A3 },
	{ 0xE69AA3, 0x4C3ED },
	{ 0xE69AA4, 0x3C7B9 },
	{ 0xE69AA5, 0x3C7B3 },
	{ 0xE69AA6, 0x3C7B7 },
	{ 0xE69AA8, 0x1E9A4 },
	{ 0xE69AA9, 0x2D0EC },
	{ 0xE69AAA, 0x2D0EF },
	{ 0xE69AAB, 0x1EDB2 },
	{ 0xE69AAC, 0x3CCC4 },
	{ 0xE69AAD, 0x3CCC6 },
	{ 0xE69AAE, 0x1EDB1 },
	{ 0xE69AAF, 0x2D0F0 },
	{ 0xE69AB0, 0x2D0EB },
	{ 0xE69AB1, 0x1EDB4 },
	{ 0xE69AB2, 0x2D0ED },
	{ 0xE69AB3, 0x3CCC1 },
	{ 0xE69AB4, 0x1EDB3 },
	{ 0xE69AB5, 0x2D0EA },
	{ 0xE69AB6, 0x3CCC0 },
	{ 0xE69AB7, 0x2D0EE },
	{ 0xE69AB8, 0x1F0F2 },
	{ 0xE69AB9, 0x1F0EF },
	{ 0xE69ABA, 0x2D7C6 },
	{ 0xE69ABB, 0x2D7C5 },
	{ 0xE69ABC, 0x3CCC3 },
	{ 0xE69ABD, 0x2D7C4 },
	{ 0xE69ABE, 0x2D7BF },
	{ 0xE69ABF, 0x3D0FD },
	{ 0xE69B80, 0x2D7C0 },
	{ 0xE69B81, 0x3D1A3 },
	{ 0xE69B82, 0x4D0D0 },
	{ 0xE69B83, 0x3D0FA },
	{ 0xE69B84, 0x1F0F0 },
	{ 0xE69B85, 0x3D0FE },
	{ 0xE69B86, 0x1F0ED },
	{ 0xE69B87, 0x1F0F1 },
	{ 0xE69B88, 0x2D7BE },
	{ 0xE69B89, 0x1F0EE },
	{ 0xE69B8A, 0x2D7C1 },
	{ 0xE69B8B, 0x2D7C2 },
	{ 0xE69B8C, 0x2D7C7 },
	{ 0xE69B8D, 0x3D1A2 },
	{ 0xE69B8E, 0x3D4F1 },
	{ 0xE69B8F, 0x2D7C3 },
	{ 0xE69B90, 0x3D4EF },
	{ 0xE69B91, 0x3D4F0 },
	{ 0xE69B92, 0x2DCFD },
	{ 0xE69B93, 0x4D6C1 },
	{ 0xE69B94, 0x3D4EC },
	{ 0xE69B95, 0x3D4ED },
	{ 0xE69B96, 0x1F3F0 },
	{ 0xE69B97, 0x3D4F2 },
	{ 0xE69B98, 0x2E1E8 },
	{ 0xE69B99, 0x1F3EF },
	{ 0xE69B9A, 0x2E1E6 },
	{ 0xE69B9B, 0x2E1E7 },
	{ 0xE69B9C, 0x1F6CC },
	{ 0xE69B9D, 0x1F8BB },
	{ 0xE69B9E, 0x2E5D6 },
	{ 0xE69B9F, 0x3DAC3 },
	{ 0xE69BA0, 0x1F8BA },
	{ 0xE69BA1, 0x3DAC2 },
	{ 0xE69BA2, 0x3E5A6 },
	{ 0xE69BA3, 0x2E8FD },
	{ 0xE69BA4, 0x2E8FE },
	{ 0xE69BA5, 0x3DCC2 },
	{ 0xE69BA6, 0x1F9F1 },
	{ 0xE69BA7, 0x3DCC3 },
	{ 0xE69BA8, 0x2E8FC },
	{ 0xE69BA9, 0x1FAEF },
	{ 0xE69BAA, 0x4EACC },
	{ 0xE69BAB, 0x2EFAE },
	{ 0xE69BAC, 0x1FCBA },
	{ 0xE69BAD, 0x2F0B8 },
	{ 0xE69BAE, 0x2F0B9 },
	{ 0xE69BAF, 0x3E1BF },
	{ 0xE69BB0, 0x1C5CB },
	{ 0xE69BB1, 0x4A1FC },
	{ 0xE69BB2, 0x1C8B2 },
	{ 0xE69BB3, 0x1C8B3 },
	{ 0xE69BB4, 0x1CAD5 },
	{ 0xE69BB5, 0x3A6C1 },
	{ 0xE69BB6, 0x2A7B2 },
	{ 0xE69BB7, 0x1D1D7 },
	{ 0xE69BB8, 0x1D5F3 },
	{ 0xE69BB9, 0x1DBAA },
	{ 0xE69BBA, 0xFB2F3 },
	{ 0xE69BBC, 0x1D9B7 },
	{ 0xE69BBE, 0x1DFE4 },
	{ 0xE69BBF, 0x1DFE5 },
	{ 0xE69C80, 0x1DEB2 },
	{ 0xE69C81, 0x2BCCC },
	{ 0xE69C82, 0x3E5A7 },
	{ 0xE69C83, 0x1E4C4 },
	{ 0xE69C84, 0x2CAE1 },
	{ 0xE69C85, 0x2CAE0 },
	{ 0xE69C86, 0x3D1A4 },
	{ 0xE69C87, 0x7D3C7 },
	{ 0xE69C88, 0x1C5CC },
	{ 0xE69C89, 0x1C8B4 },
	{ 0xE69C8A, 0x2A7B3 },
	{ 0xE69C8B, 0x1CEA5 },
	{ 0xE69C8C, 0x3A9C5 },
	{ 0xE69C8D, 0x1CEA4 },
	{ 0xE69C8E, 0x3ADA7 },
	{ 0xE69C8F, 0x2AAFA },
	{ 0xE69C90, 0x2AAFB },
	{ 0xE69C91, 0x3E6B2 },
	{ 0xE69C92, 0x2AFD9 },
	{ 0xE69C93, 0x2AFDA },
	{ 0xE69C94, 0x1D5F4 },
	{ 0xE69C95, 0x1D5F5 },
	{ 0xE69C96, 0x3B6C8 },
	{ 0xE69C97, 0x1D5F6 },
	{ 0xE69C98, 0x2B5F1 },
	{ 0xE69C99, 0x3B6C7 },
	{ 0xE69C9A, 0x3B6C6 },
	{ 0xE69C9B, 0x1DBAC },
	{ 0xE69C9C, 0x4B8A9 },
	{ 0xE69C9D, 0x1DFE7 },
	{ 0xE69C9E, 0x3BCA9 },
	{ 0xE69C9F, 0x1DFE6 },
	{ 0xE69CA0, 0x2C3CE },
	{ 0xE69CA1, 0x2C6C1 },
	{ 0xE69CA2, 0x2CAE2 },
	{ 0xE69CA3, 0x2D7C8 },
	{ 0xE69CA4, 0x3D1A6 },
	{ 0xE69CA5, 0x3E6B3 },
	{ 0xE69CA6, 0x1F6CD },
	{ 0xE69CA7, 0x1F9F2 },
	{ 0xE69CA8, 0x1C5CD },
	{ 0xE69CAA, 0x1C6DC },
	{ 0xE69CAB, 0x1C6DD },
	{ 0xE69CAC, 0x1C6DB },
	{ 0xE69CAD, 0x1C6DE },
	{ 0xE69CAE, 0x1C6DA },
	{ 0xE69CAF, 0x3A2D2 },
	{ 0xE69CB1, 0x1C8B7 },
	{ 0xE69CB2, 0x3A3F7 },
	{ 0xE69CB3, 0x2A2D7 },
	{ 0xE69CB4, 0x1C8B6 },
	{ 0xE69CB5, 0x1C8B8 },
	{ 0xE69CB6, 0x3A3F8 },
	{ 0xE69CB7, 0x3A3F5 },
	{ 0xE69CB8, 0x2A2D2 },
	{ 0xE69CB9, 0x2A2D1 },
	{ 0xE69CBA, 0x2A2D4 },
	{ 0xE69CBB, 0x2A2D3 },
	{ 0xE69CBC, 0x2A2D6 },
	{ 0xE69CBD, 0x1C8B5 },
	{ 0xE69CBE, 0x2A2D0 },
	{ 0xE69CBF, 0x2A2D5 },
	{ 0xE69D80, 0xFA2D8 },
	{ 0xE69D82, 0xFA2D7 },
	{ 0xE69D84, 0x3A6C8 },
	{ 0xE69D85, 0x2A4BE },
	{ 0xE69D86, 0x1CADF },
	{ 0xE69D87, 0x2A4BF },
	{ 0xE69D88, 0x2A4C3 },
	{ 0xE69D89, 0x1CADE },
	{ 0xE69D8A, 0x3A6C9 },
	{ 0xE69D8B, 0x2A4C7 },
	{ 0xE69D8C, 0x2A4C2 },
	{ 0xE69D8D, 0x2A4C5 },
	{ 0xE69D8E, 0x1CAD7 },
	{ 0xE69D8F, 0x1CAD8 },
	{ 0xE69D90, 0x1CAD9 },
	{ 0xE69D91, 0x1CADA },
	{ 0xE69D92, 0x3A6C5 },
	{ 0xE69D93, 0x1CAE1 },
	{ 0xE69D94, 0x3A6C4 },
	{ 0xE69D95, 0x2A4C1 },
	{ 0xE69D96, 0x1CADC },
	{ 0xE69D97, 0x1CAE2 },
	{ 0xE69D98, 0x3A6C7 },
	{ 0xE69D99, 0x2A4C0 },
	{ 0xE69D9A, 0x2A4C6 },
	{ 0xE69D9B, 0x3A6C2 },
	{ 0xE69D9C, 0x1CADB },
	{ 0xE69D9D, 0x2A4C4 },
	{ 0xE69D9E, 0x1CADD },
	{ 0xE69D9F, 0x1CAD6 },
	{ 0xE69DA0, 0x1CAE0 },
	{ 0xE69DA1, 0x3A6CA },
	{ 0xE69DA2, 0xFA4A2 },
	{ 0xE69DA5, 0x4A4C6 },
	{ 0xE69DA6, 0xFA4D3 },
	{ 0xE69DAA, 0x1CEBA },
	{ 0xE69DAB, 0x3A9C7 },
	{ 0xE69DAC, 0x2A7B5 },
	{ 0xE69DAD, 0x1CEA6 },
	{ 0xE69DAE, 0x4A6E9 },
	{ 0xE69DAF, 0x1CEB0 },
	{ 0xE69DB0, 0x1CEB1 },
	{ 0xE69DB1, 0x1CEA9 },
	{ 0xE69DB2, 0x1CEBB },
	{ 0xE69DB3, 0x1CEAB },
	{ 0xE69DB4, 0x2A7BD },
	{ 0xE69DB5, 0x1CEB6 },
	{ 0xE69DB6, 0x2A7B8 },
	{ 0xE69DB7, 0x1CEAC },
	{ 0xE69DB8, 0x2A7C7 },
	{ 0xE69DB9, 0x2A7C8 },
	{ 0xE69DBA, 0x2A7C0 },
	{ 0xE69DBB, 0x2A7B9 },
	{ 0xE69DBC, 0x1CEB9 },
	{ 0xE69DBD, 0x2A7C5 },
	{ 0xE69DBE, 0x1CEB4 },
	{ 0xE69DBF, 0x1CEB2 },
	{ 0xE69E80, 0x3A9D2 },
	{ 0xE69E81, 0x2A7C6 },
	{ 0xE69E82, 0x3A9C9 },
	{ 0xE69E83, 0x2A7C4 },
	{ 0xE69E84, 0x2A7BC },
	{ 0xE69E85, 0x2A7B4 },
	{ 0xE69E86, 0x2A7BB },
	{ 0xE69E87, 0x1CEAD },
	{ 0xE69E88, 0x4A6E5 },
	{ 0xE69E89, 0x1CEB3 },
	{ 0xE69E8A, 0x3A9CA },
	{ 0xE69E8B, 0x1CEA7 },
	{ 0xE69E8C, 0x2A7BF },
	{ 0xE69E8D, 0x2A7BE },
	{ 0xE69E8E, 0x2A7B6 },
	{ 0xE69E8F, 0x3A9CF },
	{ 0xE69E90, 0x1CEB5 },
	{ 0xE69E91, 0x2A7C2 },
	{ 0xE69E92, 0x2A7B7 },
	{ 0xE69E93, 0x1CEB8 },
	{ 0xE69E94, 0x2A7C9 },
	{ 0xE69E95, 0x1CEA8 },
	{ 0xE69E96, 0x3A9C8 },
	{ 0xE69E97, 0x1CEAF },
	{ 0xE69E98, 0x2A7BA },
	{ 0xE69E99, 0x2A7C3 },
	{ 0xE69E9A, 0x1CEB7 },
	{ 0xE69E9B, 0x4A6E7 },
	{ 0xE69E9C, 0x1CEAA },
	{ 0xE69E9D, 0x1CEAE },
	{ 0xE69E9E, 0x4A6EA },
	{ 0xE69E9F, 0x2A7C1 },
	{ 0xE69EA1, 0xFA7CE },
	{ 0xE69EA2, 0x3A9CE },
	{ 0xE69EA3, 0x3A9CC },
	{ 0xE69EA4, 0x3E5A8 },
	{ 0xE69EA6, 0xFA7D0 },
	{ 0xE69EAC, 0x3E5A9 },
	{ 0xE69EAE, 0x2ABBD },
	{ 0xE69EAF, 0x1D1DF },
	{ 0xE69EB0, 0x1D1EC },
	{ 0xE69EB1, 0x3ADB6 },
	{ 0xE69EB2, 0x2ABB8 },
	{ 0xE69EB3, 0x2ABAE },
	{ 0xE69EB4, 0x1D1E5 },
	{ 0xE69EB5, 0x2ABAC },
	{ 0xE69EB6, 0x1D1DE },
	{ 0xE69EB7, 0x2ABA7 },
	{ 0xE69EB8, 0x1D1E8 },
	{ 0xE69EB9, 0x2ABB4 },
	{ 0xE69EBA, 0x2ABA1 },
	{ 0xE69EBB, 0x2ABA3 },
	{ 0xE69EBC, 0x3ADAE },
	{ 0xE69EBD, 0x4ADD9 },
	{ 0xE69EBE, 0x4A9EE },
	{ 0xE69EBF, 0x3ADB0 },
	{ 0xE69F80, 0x2ABA6 },
	{ 0xE69F81, 0x2AAFC },
	{ 0xE69F82, 0x2ABB3 },
	{ 0xE69F83, 0x2ABC3 },
	{ 0xE69F84, 0x1D1E3 },
	{ 0xE69F85, 0x2ABA8 },
	{ 0xE69F86, 0x2ABBA },
	{ 0xE69F87, 0x3ADAD },
	{ 0xE69F88, 0x2AAFE },
	{ 0xE69F89, 0x2ABC1 },
	{ 0xE69F8A, 0x2ABC2 },
	{ 0xE69F8B, 0x2ABC5 },
	{ 0xE69F8C, 0x2ABBC },
	{ 0xE69F8D, 0x2ABAD },
	{ 0xE69F8E, 0x2ABB5 },
	{ 0xE69F8F, 0x1D1E9 },
	{ 0xE69F90, 0x1D1DC },
	{ 0xE69F91, 0x1D1E4 },
	{ 0xE69F92, 0x1D1F0 },
	{ 0xE69F93, 0x1D1D9 },
	{ 0xE69F94, 0x1D1DB },
	{ 0xE69F95, 0x3ADB1 },
	{ 0xE69F96, 0x3ADAB },
	{ 0xE69F97, 0x3ADBA },
	{ 0xE69F98, 0x2ABA5 },
	{ 0xE69F99, 0x1D1ED },
	{ 0xE69F9A, 0x1D1E6 },
	{ 0xE69F9B, 0x2ABBF },
	{ 0xE69F9C, 0x2ABA2 },
	{ 0xE69F9D, 0x1D1EF },
	{ 0xE69F9E, 0x1D1EA },
	{ 0xE69F9F, 0x2ABAB },
	{ 0xE69FA0, 0x4A9ED },
	{ 0xE69FA1, 0x4ADCE },
	{ 0xE69FA2, 0x1D1EE },
	{ 0xE69FA3, 0x2ABB2 },
	{ 0xE69FA4, 0x2ABAA },
	{ 0xE69FA5, 0x1D1E7 },
	{ 0xE69FA6, 0x2ABBE },
	{ 0xE69FA7, 0x2ABB6 },
	{ 0xE69FA8, 0x3ADAA },
	{ 0xE69FA9, 0x1D1E1 },
	{ 0xE69FAA, 0x2ABC4 },
	{ 0xE69FAB, 0x2ABA9 },
	{ 0xE69FAC, 0x1D1DD },
	{ 0xE69FAD, 0x2ABBB },
	{ 0xE69FAE, 0x2ABB1 },
	{ 0xE69FAF, 0x1D1E2 },
	{ 0xE69FB0, 0x2ABB7 },
	{ 0xE69FB1, 0x1D1DA },
	{ 0xE69FB2, 0x2AAFD },
	{ 0xE69FB3, 0x1D1EB },
	{ 0xE69FB4, 0x1D6A7 },
	{ 0xE69FB5, 0x1D1E0 },
	{ 0xE69FB6, 0x2ABB0 },
	{ 0xE69FB7, 0x2ABAF },
	{ 0xE69FB8, 0x2ABA4 },
	{ 0xE69FB9, 0x3A9D1 },
	{ 0xE69FBA, 0x2ABC0 },
	{ 0xE69FBB, 0x3ADB4 },
	{ 0xE69FBC, 0x2ABB9 },
	{ 0xE69FBE, 0x3ADB2 },
	{ 0xE69FBF, 0x1D1D8 },
	{ 0xE6A080, 0x3ADB9 },
	{ 0xE6A081, 0x3ADB7 },
	{ 0xE6A084, 0x6B1F2 },
	{ 0xE6A085, 0x3ADB8 },
	{ 0xE6A086, 0x3E5AB },
	{ 0xE6A090, 0x3E5AA },
	{ 0xE6A091, 0xFABC8 },
	{ 0xE6A092, 0x2AFEE },
	{ 0xE6A093, 0x1D6AE },
	{ 0xE6A094, 0x2AFEF },
	{ 0xE6A095, 0x3B1DD },
	{ 0xE6A096, 0x2AFE3 },
	{ 0xE6A097, 0x1D6A3 },
	{ 0xE6A098, 0x1D6AF },
	{ 0xE6A099, 0x3B1D7 },
	{ 0xE6A09A, 0x2AFDC },
	{ 0xE6A09B, 0x3B1D3 },
	{ 0xE6A09C, 0x2AFE5 },
	{ 0xE6A09D, 0x2AFED },
	{ 0xE6A09E, 0x3B1DB },
	{ 0xE6A09F, 0x2AFDB },
	{ 0xE6A0A0, 0x2AFF6 },
	{ 0xE6A0A1, 0x1D5F7 },
	{ 0xE6A0A2, 0x3B1DE },
	{ 0xE6A0A3, 0x3B1E4 },
	{ 0xE6A0A4, 0x3B1D0 },
	{ 0xE6A0A5, 0x2AFF5 },
	{ 0xE6A0A6, 0x2AFF0 },
	{ 0xE6A0A7, 0x3B1DF },
	{ 0xE6A0A8, 0x2AFF1 },
	{ 0xE6A0A9, 0x1D6A1 },
	{ 0xE6A0AA, 0x1D6AC },
	{ 0xE6A0AB, 0x2AFE7 },
	{ 0xE6A0AC, 0x3B1D6 },
	{ 0xE6A0AD, 0x2AFE8 },
	{ 0xE6A0AE, 0x2AFF2 },
	{ 0xE6A0AF, 0x2AFE9 },
	{ 0xE6A0B0, 0x3B1E3 },
	{ 0xE6A0B1, 0x2AFE4 },
	{ 0xE6A0B2, 0x2AFDE },
	{ 0xE6A0B3, 0x2AFDF },
	{ 0xE6A0B4, 0x2AFEC },
	{ 0xE6A0B5, 0x2AFE6 },
	{ 0xE6A0B6, 0x3B1D4 },
	{ 0xE6A0B7, 0x3B1CF },
	{ 0xE6A0B8, 0x1D5F8 },
	{ 0xE6A0B9, 0x1D5FC },
	{ 0xE6A0BA, 0x2AFF4 },
	{ 0xE6A0BB, 0x2AFE0 },
	{ 0xE6A0BC, 0x1D6AA },
	{ 0xE6A0BD, 0x1D6A6 },
	{ 0xE6A0BE, 0x3B1DA },
	{ 0xE6A0BF, 0x4ADD5 },
	{ 0xE6A180, 0x1D6A9 },
	{ 0xE6A181, 0x1D6B0 },
	{ 0xE6A182, 0x1D5FD },
	{ 0xE6A183, 0x1D6AB },
	{ 0xE6A184, 0x2AFEB },
	{ 0xE6A185, 0x1D6AD },
	{ 0xE6A186, 0x1D5FA },
	{ 0xE6A187, 0x3B1D9 },
	{ 0xE6A188, 0x1D5F9 },
	{ 0xE6A189, 0x2AFDD },
	{ 0xE6A18A, 0x4ADCF },
	{ 0xE6A18B, 0x2AFE1 },
	{ 0xE6A18C, 0x1D6A4 },
	{ 0xE6A18D, 0x2AFF3 },
	{ 0xE6A18E, 0x2AFEA },
	{ 0xE6A18F, 0x2AFE2 },
	{ 0xE6A190, 0x1D6A8 },
	{ 0xE6A191, 0x1D6A5 },
	{ 0xE6A192, 0x3ADAF },
	{ 0xE6A193, 0x1D5FB },
	{ 0xE6A194, 0x1D5FE },
	{ 0xE6A195, 0x3B1E2 },
	{ 0xE6A196, 0x3B1D8 },
	{ 0xE6A197, 0xFB0A4 },
	{ 0xE6A198, 0x3B1E1 },
	{ 0xE6A199, 0x3B1E0 },
	{ 0xE6A19A, 0x3E5AD },
	{ 0xE6A19E, 0x3E5AC },
	{ 0xE6A1AB, 0x2B6A8 },
	{ 0xE6A1AC, 0x3B6D5 },
	{ 0xE6A1AD, 0x2B5F6 },
	{ 0xE6A1AE, 0x2B5F7 },
	{ 0xE6A1AF, 0x2B5FB },
	{ 0xE6A1B0, 0x3B6E0 },
	{ 0xE6A1B1, 0x2B6AC },
	{ 0xE6A1B2, 0x2B6A9 },
	{ 0xE6A1B3, 0x3B6CE },
	{ 0xE6A1B4, 0x2B6A2 },
	{ 0xE6A1B5, 0x2B6A1 },
	{ 0xE6A1B6, 0x1DBB3 },
	{ 0xE6A1B7, 0x2B6A5 },
	{ 0xE6A1B8, 0x2B6B4 },
	{ 0xE6A1B9, 0x2B5F2 },
	{ 0xE6A1BA, 0x3B6DB },
	{ 0xE6A1BB, 0x2B6B5 },
	{ 0xE6A1BC, 0x2B6A7 },
	{ 0xE6A1BD, 0x2B6B9 },
	{ 0xE6A1BE, 0x2B6AD },
	{ 0xE6A1BF, 0x1DBB2 },
	{ 0xE6A280, 0x2B6AB },
	{ 0xE6A281, 0x1DBAD },
	{ 0xE6A282, 0x1DBC2 },
	{ 0xE6A283, 0x1DBB8 },
	{ 0xE6A284, 0x3B6D7 },
	{ 0xE6A285, 0x1DBBC },
	{ 0xE6A286, 0x1DBBB },
	{ 0xE6A287, 0x2B5F3 },
	{ 0xE6A288, 0x4B2BF },
	{ 0xE6A289, 0x2B6B2 },
	{ 0xE6A28A, 0x2B6B8 },
	{ 0xE6A28B, 0x2B6B0 },
	{ 0xE6A28C, 0x2B6B7 },
	{ 0xE6A28E, 0x3B6D1 },
	{ 0xE6A28F, 0x2B6A4 },
	{ 0xE6A290, 0x2B5F4 },
	{ 0xE6A291, 0x2B6B6 },
	{ 0xE6A292, 0x2B6A6 },
	{ 0xE6A293, 0x1DBB0 },
	{ 0xE6A294, 0x1DBBD },
	{ 0xE6A295, 0x3B6DA },
	{ 0xE6A296, 0x2B6AF },
	{ 0xE6A297, 0x1DBB6 },
	{ 0xE6A298, 0x3B6CD },
	{ 0xE6A299, 0x3B6DC },
	{ 0xE6A29A, 0x3B6D0 },
	{ 0xE6A29B, 0x2B6AE },
	{ 0xE6A29C, 0x2B5F5 },
	{ 0xE6A29D, 0x1DBBE },
	{ 0xE6A29E, 0x3B6CB },
	{ 0xE6A29F, 0x1DBC0 },
	{ 0xE6A2A0, 0x2B6B1 },
	{ 0xE6A2A1, 0x1DBC1 },
	{ 0xE6A2A2, 0x1DBAF },
	{ 0xE6A2A3, 0x2B5FC },
	{ 0xE6A2A4, 0x2B6B3 },
	{ 0xE6A2A5, 0x3B6D4 },
	{ 0xE6A2A6, 0x3B4F8 },
	{ 0xE6A2A7, 0x1DBB5 },
	{ 0xE6A2A8, 0x1DBBF },
	{ 0xE6A2A9, 0x2B5FE },
	{ 0xE6A2AA, 0x2B6AA },
	{ 0xE6A2AB, 0x2B5F9 },
	{ 0xE6A2AC, 0x2B5FD },
	{ 0xE6A2AD, 0x1DBBA },
	{ 0xE6A2AE, 0x2B5F8 },
	{ 0xE6A2AF, 0x1DBAE },
	{ 0xE6A2B0, 0x1DBB7 },
	{ 0xE6A2B1, 0x1DBB4 },
	{ 0xE6A2B2, 0x2B6A3 },
	{ 0xE6A2B3, 0x1D6A2 },
	{ 0xE6A2B4, 0x2BCE3 },
	{ 0xE6A2B5, 0x1DBB1 },
	{ 0xE6A2B6, 0x3B6CC },
	{ 0xE6A2B7, 0x3B6D2 },
	{ 0xE6A2B8, 0x3B6DE },
	{ 0xE6A2B9, 0x3B6DF },
	{ 0xE6A2BD, 0xFB5D7 },
	{ 0xE6A381, 0x3B6D6 },
	{ 0xE6A383, 0x3BCC5 },
	{ 0xE6A384, 0x1DBB9 },
	{ 0xE6A385, 0x3BCC1 },
	{ 0xE6A386, 0x2BCE6 },
	{ 0xE6A387, 0x2BCFC },
	{ 0xE6A388, 0x2BCF1 },
	{ 0xE6A389, 0x1DFFB },
	{ 0xE6A38A, 0x3BCB8 },
	{ 0xE6A38B, 0x1DFF6 },
	{ 0xE6A38C, 0x2BCE0 },
	{ 0xE6A38D, 0x1DFF7 },
	{ 0xE6A38E, 0x2BCF0 },
	{ 0xE6A38F, 0x3BCBE },
	{ 0xE6A390, 0x2BCE9 },
	{ 0xE6A391, 0x2BCF6 },
	{ 0xE6A392, 0x1DFF3 },
	{ 0xE6A393, 0x2BCCE },
	{ 0xE6A394, 0x2BCF8 },
	{ 0xE6A395, 0x1DFE9 },
	{ 0xE6A396, 0x2BCD6 },
	{ 0xE6A397, 0x1DFEC },
	{ 0xE6A398, 0x1DFEB },
	{ 0xE6A399, 0x4B8B2 },
	{ 0xE6A39A, 0x1DFFC },
	{ 0xE6A39B, 0x3B6D3 },
	{ 0xE6A39C, 0x2BCD0 },
	{ 0xE6A39D, 0x2BCF2 },
	{ 0xE6A39E, 0x2BCF3 },
	{ 0xE6A39F, 0x1DFEE },
	{ 0xE6A3A0, 0x1DFEA },
	{ 0xE6A3A1, 0x2BCDE },
	{ 0xE6A3A2, 0x3BCBD },
	{ 0xE6A3A3, 0x1DFF5 },
	{ 0xE6A3A4, 0x2BCD9 },
	{ 0xE6A3A5, 0x3BCB2 },
	{ 0xE6A3A6, 0x2BCF4 },
	{ 0xE6A3A7, 0x1DFF1 },
	{ 0xE6A3A8, 0x2BCEC },
	{ 0xE6A3A9, 0x2BCF9 },
	{ 0xE6A3AA, 0x2BCD3 },
	{ 0xE6A3AB, 0x2BCD8 },
	{ 0xE6A3AC, 0x2BCD2 },
	{ 0xE6A3AD, 0x3BCAA },
	{ 0xE6A3AE, 0x1DFF0 },
	{ 0xE6A3AF, 0x2BCE5 },
	{ 0xE6A3B0, 0x2C3E4 },
	{ 0xE6A3B1, 0x2BCD4 },
	{ 0xE6A3B2, 0x1DFF4 },
	{ 0xE6A3B3, 0x2BCDD },
	{ 0xE6A3B4, 0x2BCF5 },
	{ 0xE6A3B5, 0x1DFEF },
	{ 0xE6A3B6, 0x2BCDA },
	{ 0xE6A3B7, 0x2BCD7 },
	{ 0xE6A3B8, 0x2BCE8 },
	{ 0xE6A3B9, 0x1DFF2 },
	{ 0xE6A3BA, 0x1DFE8 },
	{ 0xE6A3BB, 0x1DFFE },
	{ 0xE6A3BC, 0x2BCEB },
	{ 0xE6A3BD, 0x2BCEA },
	{ 0xE6A3BE, 0x3BCB1 },
	{ 0xE6A3BF, 0x3BCC2 },
	{ 0xE6A480, 0x3BCB9 },
	{ 0xE6A481, 0x3BCBB },
	{ 0xE6A482, 0x3BCB4 },
	{ 0xE6A483, 0x3BCAF },
	{ 0xE6A484, 0x2BCCF },
	{ 0xE6A485, 0x1DFED },
	{ 0xE6A486, 0x2BCF7 },
	{ 0xE6A487, 0x2BCDF },
	{ 0xE6A488, 0x2BCE1 },
	{ 0xE6A489, 0x3BCB7 },
	{ 0xE6A48A, 0x2BCEE },
	{ 0xE6A48B, 0x2BCED },
	{ 0xE6A48C, 0x2BCCD },
	{ 0xE6A48D, 0x1DFF8 },
	{ 0xE6A48E, 0x1DFFA },
	{ 0xE6A48F, 0x2BCD5 },
	{ 0xE6A490, 0x2BCDC },
	{ 0xE6A491, 0x2BCE4 },
	{ 0xE6A492, 0x1DFF9 },
	{ 0xE6A493, 0x2BCDB },
	{ 0xE6A494, 0x2BCE7 },
	{ 0xE6A495, 0x2BCFA },
	{ 0xE6A496, 0xFBBF0 },
	{ 0xE6A497, 0x2BCEF },
	{ 0xE6A498, 0x3BCBC },
	{ 0xE6A49B, 0xFBCA1 },
	{ 0xE6A49C, 0x3BCC4 },
	{ 0xE6A49E, 0x3BCB3 },
	{ 0xE6A4A5, 0x2BCFB },
	{ 0xE6A4A7, 0xFBCA9 },
	{ 0xE6A4A9, 0x3E5AF },
	{ 0xE6A4AA, 0x2BCD1 },
	{ 0xE6A4AB, 0xFBBEE },
	{ 0xE6A4AC, 0x3E5AE },
	{ 0xE6A4AE, 0x3BCC0 },
	{ 0xE6A4AF, 0x2C3F8 },
	{ 0xE6A4B0, 0x1E4CC },
	{ 0xE6A4B1, 0x3C1E5 },
	{ 0xE6A4B2, 0x2C3F6 },
	{ 0xE6A4B3, 0x2C3E1 },
	{ 0xE6A4B4, 0x2C3E6 },
	{ 0xE6A4B5, 0x2C3DF },
	{ 0xE6A4B6, 0x3C1F7 },
	{ 0xE6A4B7, 0x2C3F2 },
	{ 0xE6A4B8, 0x2C3D1 },
	{ 0xE6A4B9, 0x2C3D8 },
	{ 0xE6A4BA, 0x4BDF1 },
	{ 0xE6A4BB, 0x2C3F0 },
	{ 0xE6A4BC, 0x2C3FA },
	{ 0xE6A4BD, 0x2C3E2 },
	{ 0xE6A4BE, 0x3C1E8 },
	{ 0xE6A4BF, 0x2C3D5 },
	{ 0xE6A580, 0x2C3E8 },
	{ 0xE6A581, 0x2C3ED },
	{ 0xE6A582, 0x2C3D9 },
	{ 0xE6A583, 0x3C1EB },
	{ 0xE6A584, 0x2C3EA },
	{ 0xE6A585, 0x2C3D6 },
	{ 0xE6A586, 0x3C1DD },
	{ 0xE6A587, 0x3C1F5 },
	{ 0xE6A588, 0x2C3DD },
	{ 0xE6A589, 0x2C3DE },
	{ 0xE6A58A, 0x1E4CE },
	{ 0xE6A58B, 0x2C3F1 },
	{ 0xE6A58C, 0x2C3EF },
	{ 0xE6A58D, 0x3C1F3 },
	{ 0xE6A58E, 0x2C3D2 },
	{ 0xE6A58F, 0x2C3F4 },
	{ 0xE6A590, 0x3C1F4 },
	{ 0xE6A591, 0x2C3F5 },
	{ 0xE6A592, 0x2C3F7 },
	{ 0xE6A593, 0x1E4D2 },
	{ 0xE6A594, 0x1E4CA },
	{ 0xE6A595, 0x3C1EF },
	{ 0xE6A596, 0x2B5FA },
	{ 0xE6A597, 0x2C3DA },
	{ 0xE6A598, 0x2C3EC },
	{ 0xE6A599, 0x2C3DB },
	{ 0xE6A59A, 0x1E4C7 },
	{ 0xE6A59B, 0x1E4D7 },
	{ 0xE6A59C, 0x2C3F3 },
	{ 0xE6A59D, 0x1E4D5 },
	{ 0xE6A59E, 0x1E4D1 },
	{ 0xE6A59F, 0x2C3D0 },
	{ 0xE6A5A0, 0x1E4C9 },
	{ 0xE6A5A1, 0x3C1F9 },
	{ 0xE6A5A2, 0x2C3D3 },
	{ 0xE6A5A3, 0x1E4D6 },
	{ 0xE6A5A4, 0x3C1F8 },
	{ 0xE6A5A5, 0x2C3E3 },
	{ 0xE6A5A6, 0x2C3CF },
	{ 0xE6A5A7, 0x3C1F6 },
	{ 0xE6A5A8, 0x1E4CF },
	{ 0xE6A5A9, 0x2C3E7 },
	{ 0xE6A5AA, 0x2C3D7 },
	{ 0xE6A5AB, 0x1E4D0 },
	{ 0xE6A5AC, 0x2C3E0 },
	{ 0xE6A5AD, 0x1E4C6 },
	{ 0xE6A5AE, 0x1DFFD },
	{ 0xE6A5AF, 0x2C3E9 },
	{ 0xE6A5B0, 0x2BCE2 },
	{ 0xE6A5B1, 0x2C3D4 },
	{ 0xE6A5B2, 0x4BDEC },
	{ 0xE6A5B3, 0x3C1ED },
	{ 0xE6A5B4, 0x2C3EE },
	{ 0xE6A5B5, 0x1E4CB },
	{ 0xE6A5B6, 0x2C3EB },
	{ 0xE6A5B7, 0x1E4C8 },
	{ 0xE6A5B8, 0x2C3E5 },
	{ 0xE6A5B9, 0x1E4D3 },
	{ 0xE6A5BA, 0x2C3DC },
	{ 0xE6A5BB, 0x2C3F9 },
	{ 0xE6A5BC, 0x3C1EA },
	{ 0xE6A5BD, 0x3C1FB },
	{ 0xE6A5BF, 0xFC2C9 },
	{ 0xE6A680, 0xFC2C7 },
	{ 0xE6A682, 0x1E4CD },
	{ 0xE6A683, 0x2C5AC },
	{ 0xE6A685, 0x3C1F2 },
	{ 0xE6A686, 0x1E4D4 },
	{ 0xE6A68A, 0xFC2A8 },
	{ 0xE6A68C, 0xFC2BC },
	{ 0xE6A68D, 0x2CAF0 },
	{ 0xE6A68E, 0x2CAEE },
	{ 0xE6A68F, 0x3C7BA },
	{ 0xE6A690, 0x2CBA6 },
	{ 0xE6A691, 0x2CAEC },
	{ 0xE6A692, 0x3C7BD },
	{ 0xE6A693, 0x2CAFE },
	{ 0xE6A694, 0x1E4C5 },
	{ 0xE6A695, 0x1E9A8 },
	{ 0xE6A696, 0x2CAE8 },
	{ 0xE6A697, 0x2CBA5 },
	{ 0xE6A698, 0x3C7D1 },
	{ 0xE6A699, 0x2CAED },
	{ 0xE6A69A, 0x2CAFB },
	{ 0xE6A69B, 0x1E9AD },
	{ 0xE6A69C, 0x1E9A6 },
	{ 0xE6A69D, 0x3C7CE },
	{ 0xE6A69E, 0x2CBA3 },
	{ 0xE6A69F, 0x3C7C6 },
	{ 0xE6A6A0, 0x2CAE6 },
	{ 0xE6A6A1, 0x2CBA2 },
	{ 0xE6A6A2, 0x3C7C7 },
	{ 0xE6A6A3, 0x1E9B8 },
	{ 0xE6A6A4, 0x2CAF7 },
	{ 0xE6A6A5, 0x2CBA9 },
	{ 0xE6A6A6, 0x1E9B6 },
	{ 0xE6A6A7, 0x2CAEF },
	{ 0xE6A6A8, 0x1E9A7 },
	{ 0xE6A6A9, 0x2CAF1 },
	{ 0xE6A6AA, 0x2CBA1 },
	{ 0xE6A6AB, 0x1E9B0 },
	{ 0xE6A6AC, 0x2CAEA },
	{ 0xE6A6AD, 0x1E9B4 },
	{ 0xE6A6AE, 0x1E9AA },
	{ 0xE6A6AF, 0x2CAF3 },
	{ 0xE6A6B0, 0x2CAE9 },
	{ 0xE6A6B1, 0x2CAE3 },
	{ 0xE6A6B2, 0x3C7BE },
	{ 0xE6A6B3, 0x2CAFD },
	{ 0xE6A6B4, 0x1E9B1 },
	{ 0xE6A6B5, 0x2CBA8 },
	{ 0xE6A6B6, 0x2CAE4 },
	{ 0xE6A6B7, 0x1E9AE },
	{ 0xE6A6B8, 0x4C3F7 },
	{ 0xE6A6B9, 0x2CAF9 },
	{ 0xE6A6BA, 0x4C3F9 },
	{ 0xE6A6BB, 0x1E9AF },
	{ 0xE6A6BC, 0x2CAEB },
	{ 0xE6A6BD, 0x2CAF6 },
	{ 0xE6A6BE, 0x2CAF2 },
	{ 0xE6A6BF, 0x2CAF4 },
	{ 0xE6A780, 0x3C7C3 },
	{ 0xE6A781, 0x1E9A9 },
	{ 0xE6A782, 0x2CBA7 },
	{ 0xE6A783, 0x1E9B7 },
	{ 0xE6A784, 0x2CAF5 },
	{ 0xE6A785, 0x3C7BB },
	{ 0xE6A786, 0x2CBAA },
	{ 0xE6A787, 0x4C4A7 },
	{ 0xE6A788, 0x3C7BC },
	{ 0xE6A789, 0x2CAE5 },
	{ 0xE6A78A, 0x2CAFA },
	{ 0xE6A78B, 0x1E9AC },
	{ 0xE6A78C, 0x1E9B5 },
	{ 0xE6A78D, 0x1E9B3 },
	{ 0xE6A78E, 0x2CAE7 },
	{ 0xE6A78F, 0x2CAFC },
	{ 0xE6A790, 0x1E9B2 },
	{ 0xE6A791, 0x3C7C5 },
	{ 0xE6A792, 0x3C7C8 },
	{ 0xE6A793, 0x1E9AB },
	{ 0xE6A794, 0x2CAF8 },
	{ 0xE6A795, 0x3C7CD },
	{ 0xE6A796, 0x3C7C4 },
	{ 0xE6A797, 0x4C4A8 },
	{ 0xE6A798, 0x3CCD4 },
	{ 0xE6A799, 0x2CBA4 },
	{ 0xE6A7A1, 0x3C7CC },
	{ 0xE6A7A2, 0x2D0FC },
	{ 0xE6A7A3, 0x3C7C2 },
	{ 0xE6A7A4, 0x2D0F8 },
	{ 0xE6A7A5, 0x2D0F4 },
	{ 0xE6A7A6, 0x2D1AA },
	{ 0xE6A7A7, 0x2D1A7 },
	{ 0xE6A7A8, 0x1EDB7 },
	{ 0xE6A7A9, 0x3CCE4 },
	{ 0xE6A7AA, 0x3CCE0 },
	{ 0xE6A7AB, 0x2D1AE },
	{ 0xE6A7AC, 0x2D0FB },
	{ 0xE6A7AD, 0x1EDC2 },
	{ 0xE6A7AE, 0x2D1A4 },
	{ 0xE6A7AF, 0x3CCCF },
	{ 0xE6A7B0, 0x3CCD1 },
	{ 0xE6A7B1, 0x2D0F7 },
	{ 0xE6A7B2, 0x2D1A3 },
	{ 0xE6A7B3, 0x1EDBF },
	{ 0xE6A7B4, 0x2D1B7 },
	{ 0xE6A7B5, 0x4CABD },
	{ 0xE6A7B6, 0x2D1B4 },
	{ 0xE6A7B7, 0x2D1A6 },
	{ 0xE6A7B8, 0x2D0F5 },
	{ 0xE6A7B9, 0x3CCDF },
	{ 0xE6A7BA, 0x3CCD7 },
	{ 0xE6A7BB, 0x2D1AB },
	{ 0xE6A7BC, 0x2D1AD },
	{ 0xE6A7BD, 0x1EDBB },
	{ 0xE6A7BE, 0x2D1A1 },
	{ 0xE6A7BF, 0x2D0FA },
	{ 0xE6A880, 0x2D0F1 },
	{ 0xE6A881, 0x1EDB8 },
	{ 0xE6A882, 0x1EDC0 },
	{ 0xE6A883, 0x4CAC8 },
	{ 0xE6A884, 0x2D1B0 },
	{ 0xE6A885, 0x1EDC1 },
	{ 0xE6A886, 0x2D0F2 },
	{ 0xE6A887, 0x2D1B6 },
	{ 0xE6A888, 0x2D1A9 },
	{ 0xE6A889, 0x2D1AF },
	{ 0xE6A88A, 0x1EDBE },
	{ 0xE6A88B, 0x3CCCD },
	{ 0xE6A88C, 0x3CCD0 },
	{ 0xE6A88D, 0x2D1AC },
	{ 0xE6A88E, 0x3CCC7 },
	{ 0xE6A88F, 0x2D1B3 },
	{ 0xE6A890, 0x3CCDB },
	{ 0xE6A891, 0x1EDC3 },
	{ 0xE6A892, 0x3CCD6 },
	{ 0xE6A893, 0x1EDBD },
	{ 0xE6A894, 0x2D1A5 },
	{ 0xE6A895, 0x2D0F6 },
	{ 0xE6A896, 0x2D1B8 },
	{ 0xE6A897, 0x2D0F3 },
	{ 0xE6A898, 0x2D1B1 },
	{ 0xE6A899, 0x1EDBA },
	{ 0xE6A89A, 0x3CCCA },
	{ 0xE6A89B, 0x2D0FD },
	{ 0xE6A89C, 0x3CCC9 },
	{ 0xE6A89D, 0x2D0FE },
	{ 0xE6A89E, 0x1EDB9 },
	{ 0xE6A89F, 0x1EDB6 },
	{ 0xE6A8A0, 0x2D0F9 },
	{ 0xE6A8A1, 0x1EDBC },
	{ 0xE6A8A2, 0x3CCD2 },
	{ 0xE6A8A3, 0x1EDB5 },
	{ 0xE6A8A4, 0x3CCE2 },
	{ 0xE6A8A5, 0x2D1B2 },
	{ 0xE6A8A6, 0x2D1B5 },
	{ 0xE6A8A7, 0x2D1A2 },
	{ 0xE6A8A8, 0x2D7D5 },
	{ 0xE6A8A9, 0x3CCDE },
	{ 0xE6A8AA, 0x3CCD9 },
	{ 0xE6A8AB, 0xFCFC2 },
	{ 0xE6A8AC, 0x3CCE1 },
	{ 0xE6A8AD, 0x3E5B0 },
	{ 0xE6A8B2, 0x2D7CD },
	{ 0xE6A8B3, 0x3D1AC },
	{ 0xE6A8B4, 0x2D7C9 },
	{ 0xE6A8B5, 0x1F1A1 },
	{ 0xE6A8B6, 0x3D1BC },
	{ 0xE6A8B7, 0x3D1B8 },
	{ 0xE6A8B8, 0x1F0F4 },
	{ 0xE6A8B9, 0x1F0F9 },
	{ 0xE6A8BA, 0x1F0F5 },
	{ 0xE6A8BB, 0x2D7D7 },
	{ 0xE6A8BC, 0x2D7E2 },
	{ 0xE6A8BD, 0x1F0F3 },
	{ 0xE6A8BE, 0x2D7CF },
	{ 0xE6A8BF, 0x2D7D8 },
	{ 0xE6A980, 0x2D1A8 },
	{ 0xE6A981, 0x2D7D9 },
	{ 0xE6A982, 0x3D1A8 },
	{ 0xE6A983, 0x3D1AB },
	{ 0xE6A984, 0x1F0FA },
	{ 0xE6A985, 0x3D1C0 },
	{ 0xE6A986, 0x2D7E8 },
	{ 0xE6A987, 0x1F0FE },
	{ 0xE6A988, 0x1F1A3 },
	{ 0xE6A989, 0x2D7CB },
	{ 0xE6A98A, 0x3D1BB },
	{ 0xE6A98B, 0x1F0FD },
	{ 0xE6A98C, 0x3D1B1 },
	{ 0xE6A98D, 0x2D7E6 },
	{ 0xE6A98E, 0x2D7E7 },
	{ 0xE6A98F, 0x2D7DD },
	{ 0xE6A990, 0x2D7DC },
	{ 0xE6A991, 0x2D7D4 },
	{ 0xE6A992, 0x3D1A9 },
	{ 0xE6A993, 0x3D1BE },
	{ 0xE6A994, 0x2D7DE },
	{ 0xE6A995, 0x2D7E5 },
	{ 0xE6A996, 0x2D7E4 },
	{ 0xE6A997, 0x3D1AF },
	{ 0xE6A998, 0x1F0F8 },
	{ 0xE6A999, 0x1F0F6 },
	{ 0xE6A99A, 0x2D7D6 },
	{ 0xE6A99B, 0x2D7D3 },
	{ 0xE6A99C, 0x3D1C4 },
	{ 0xE6A99D, 0x2D7D0 },
	{ 0xE6A99E, 0x2D7E3 },
	{ 0xE6A99F, 0x1F1A2 },
	{ 0xE6A9A0, 0x2D7E1 },
	{ 0xE6A9A1, 0x1F0FC },
	{ 0xE6A9A2, 0x1F0FB },
	{ 0xE6A9A3, 0x3D1A7 },
	{ 0xE6A9A4, 0x2D7DB },
	{ 0xE6A9A5, 0x4CACB },
	{ 0xE6A9A6, 0x2D7CA },
	{ 0xE6A9A7, 0x2D7CC },
	{ 0xE6A9A8, 0x2D7CE },
	{ 0xE6A9A9, 0x2D7E0 },
	{ 0xE6A9AA, 0x2D7DA },
	{ 0xE6A9AB, 0x1F0F7 },
	{ 0xE6A9AC, 0x3D1AE },
	{ 0xE6A9AD, 0x2D7D1 },
	{ 0xE6A9AE, 0x3D1B2 },
	{ 0xE6A9AF, 0x2D7DF },
	{ 0xE6A9B0, 0x3D1C1 },
	{ 0xE6A9B1, 0x3D1BA },
	{ 0xE6A9B2, 0xFD4FB },
	{ 0xE6A9B6, 0x2D7D2 },
	{ 0xE6A9B7, 0x3E5B1 },
	{ 0xE6A9B8, 0xFD5A9 },
	{ 0xE6A9BA, 0x3E5B2 },
	{ 0xE6A9BD, 0x3D4F5 },
	{ 0xE6A9BE, 0x1F3F8 },
	{ 0xE6A9BF, 0x2DDB1 },
	{ 0xE6AA80, 0x1F3F1 },
	{ 0xE6AA81, 0x2DDA2 },
	{ 0xE6AA82, 0x3D4FB },
	{ 0xE6AA83, 0x2DDAD },
	{ 0xE6AA84, 0x1F3F3 },
	{ 0xE6AA85, 0x2DDB4 },
	{ 0xE6AA86, 0x3D5A1 },
	{ 0xE6AA87, 0x2DDA9 },
	{ 0xE6AA88, 0x3D4FC },
	{ 0xE6AA89, 0x2DDA4 },
	{ 0xE6AA8A, 0x3D4F6 },
	{ 0xE6AA8B, 0x4D6C5 },
	{ 0xE6AA8C, 0x2DDB5 },
	{ 0xE6AA8D, 0x2DCFE },
	{ 0xE6AA8E, 0x2DDAB },
	{ 0xE6AA8F, 0x3D5A7 },
	{ 0xE6AA90, 0x1F3FA },
	{ 0xE6AA91, 0x2DDB0 },
	{ 0xE6AA92, 0x2DDB6 },
	{ 0xE6AA93, 0x2DDAA },
	{ 0xE6AA94, 0x1F3F2 },
	{ 0xE6AA95, 0x2DDAC },
	{ 0xE6AA96, 0x2DDA1 },
	{ 0xE6AA97, 0x1F3F9 },
	{ 0xE6AA98, 0x3D5A3 },
	{ 0xE6AA99, 0x3D4FA },
	{ 0xE6AA9A, 0x2DDB3 },
	{ 0xE6AA9B, 0x2DDA6 },
	{ 0xE6AA9C, 0x1F3F5 },
	{ 0xE6AA9D, 0x3D5A4 },
	{ 0xE6AA9E, 0x2DDA8 },
	{ 0xE6AA9F, 0x2DDA5 },
	{ 0xE6AAA0, 0x1F3FB },
	{ 0xE6AAA1, 0x2DDA7 },
	{ 0xE6AAA2, 0x1F3F4 },
	{ 0xE6AAA3, 0x1F3F7 },
	{ 0xE6AAA4, 0x2DDAF },
	{ 0xE6AAA5, 0x2DDA3 },
	{ 0xE6AAA6, 0x2DDB2 },
	{ 0xE6AAA7, 0x3D4F8 },
	{ 0xE6AAA8, 0x2DDAE },
	{ 0xE6AAAA, 0x3D5A9 },
	{ 0xE6AAAB, 0x3D7F4 },
	{ 0xE6AAAC, 0x1F6CF },
	{ 0xE6AAAD, 0x2E1F3 },
	{ 0xE6AAAE, 0x1F6D4 },
	{ 0xE6AAAF, 0x1F6D5 },
	{ 0xE6AAB0, 0x3D7F7 },
	{ 0xE6AAB1, 0x3D8A1 },
	{ 0xE6AAB2, 0x3D7F6 },
	{ 0xE6AAB3, 0x1F6CE },
	{ 0xE6AAB4, 0x2E1F2 },
	{ 0xE6AAB5, 0x3D7F8 },
	{ 0xE6AAB6, 0x2E1EF },
	{ 0xE6AAB7, 0x2E1F0 },
	{ 0xE6AAB8, 0x1F6D2 },
	{ 0xE6AAB9, 0x2E1EA },
	{ 0xE6AABA, 0x2E1EE },
	{ 0xE6AABB, 0x1F6D1 },
	{ 0xE6AABC, 0x3D7FE },
	{ 0xE6AABD, 0x2E1EB },
	{ 0xE6AABE, 0x3D7F9 },
	{ 0xE6AABF, 0x3D8A3 },
	{ 0xE6AB80, 0x3D7FD },
	{ 0xE6AB81, 0x3D7FA },
	{ 0xE6AB82, 0x1F6D3 },
	{ 0xE6AB83, 0x1F6D0 },
	{ 0xE6AB84, 0x3D8A2 },
	{ 0xE6AB85, 0x2E1E9 },
	{ 0xE6AB86, 0x2E1ED },
	{ 0xE6AB87, 0x2E1F1 },
	{ 0xE6AB88, 0x3D7FB },
	{ 0xE6AB8A, 0x3E5B3 },
	{ 0xE6AB8B, 0x2E5DC },
	{ 0xE6AB8C, 0x2E5D9 },
	{ 0xE6AB8D, 0x2E5E2 },
	{ 0xE6AB8E, 0x3DAC4 },
	{ 0xE6AB8F, 0x2E5E1 },
	{ 0xE6AB90, 0x2E5DF },
	{ 0xE6AB91, 0x2E5DA },
	{ 0xE6AB92, 0x3DACF },
	{ 0xE6AB93, 0x1F8BF },
	{ 0xE6AB94, 0x3DAC5 },
	{ 0xE6AB95, 0x3DACE },
	{ 0xE6AB96, 0x4DFF1 },
	{ 0xE6AB97, 0x3DAC7 },
	{ 0xE6AB98, 0x3DACD },
	{ 0xE6AB99, 0x2E5DB },
	{ 0xE6AB9A, 0x1F8BE },
	{ 0xE6AB9B, 0x1F3F6 },
	{ 0xE6AB9C, 0x2E5DE },
	{ 0xE6AB9D, 0x1F8BD },
	{ 0xE6AB9E, 0x2E5E3 },
	{ 0xE6AB9F, 0x2E5DD },
	{ 0xE6ABA0, 0x2E5D8 },
	{ 0xE6ABA1, 0x2E1EC },
	{ 0xE6ABA2, 0x3DAC8 },
	{ 0xE6ABA3, 0x3DAC6 },
	{ 0xE6ABA5, 0x1F8BC },
	{ 0xE6ABA6, 0x3E5B4 },
	{ 0xE6ABA7, 0x2E5D7 },
	{ 0xE6ABA8, 0x2E9A4 },
	{ 0xE6ABA9, 0x3DCC9 },
	{ 0xE6ABAA, 0x2E9A3 },
	{ 0xE6ABAB, 0x2E5E0 },
	{ 0xE6ABAC, 0x1F9F3 },
	{ 0xE6ABAD, 0x3D7F5 },
	{ 0xE6ABAE, 0x2E9A7 },
	{ 0xE6ABAF, 0x2E9A8 },
	{ 0xE6ABB0, 0x2E9A2 },
	{ 0xE6ABB1, 0x2E9A6 },
	{ 0xE6ABB2, 0x4E3D0 },
	{ 0xE6ABB3, 0x2E9A1 },
	{ 0xE6ABB4, 0x3DCC7 },
	{ 0xE6ABB5, 0x3E5B5 },
	{ 0xE6ABB6, 0x4E3CE },
	{ 0xE6ABB8, 0x2EBDF },
	{ 0xE6ABB9, 0x2E9A5 },
	{ 0xE6ABBA, 0x1FAF2 },
	{ 0xE6ABBB, 0x1FAF0 },
	{ 0xE6ABBC, 0x2EBDD },
	{ 0xE6ABBD, 0x3DEB5 },
	{ 0xE6ABBE, 0x3DEB4 },
	{ 0xE6ABBF, 0x3DEB3 },
	{ 0xE6AC80, 0x2EBE0 },
	{ 0xE6AC81, 0x3DEB7 },
	{ 0xE6AC82, 0x2EBDC },
	{ 0xE6AC83, 0x2EBDE },
	{ 0xE6AC84, 0x1FAF1 },
	{ 0xE6AC86, 0x3DFCF },
	{ 0xE6AC87, 0x3DFCE },
	{ 0xE6AC88, 0x2EDD3 },
	{ 0xE6AC89, 0x2EDD4 },
	{ 0xE6AC8A, 0x1FBE2 },
	{ 0xE6AC8B, 0x2EDD2 },
	{ 0xE6AC8C, 0xFE9CC },
	{ 0xE6AC8D, 0x3E5B6 },
	{ 0xE6AC8E, 0x3E5B7 },
	{ 0xE6AC8F, 0x2EFB1 },
	{ 0xE6AC90, 0x1FCBB },
	{ 0xE6AC91, 0x2EFAF },
	{ 0xE6AC92, 0x2EFB0 },
	{ 0xE6AC93, 0x2F0BA },
	{ 0xE6AC94, 0x3E0F4 },
	{ 0xE6AC95, 0xFEBD1 },
	{ 0xE6AC96, 0x1FDA3 },
	{ 0xE6AC97, 0x2F1A3 },
	{ 0xE6AC98, 0x2F1A1 },
	{ 0xE6AC99, 0x2F1A2 },
	{ 0xE6AC9A, 0x2F1A4 },
	{ 0xE6AC9B, 0x3E1C0 },
	{ 0xE6AC9C, 0x3E1E5 },
	{ 0xE6AC9D, 0x3E1C1 },
	{ 0xE6AC9E, 0x2F2AB },
	{ 0xE6ACA0, 0x1C5CE },
	{ 0xE6ACA1, 0x1C8B9 },
	{ 0xE6ACA2, 0x3A3F9 },
	{ 0xE6ACA3, 0x1CEBC },
	{ 0xE6ACA4, 0x4A6F1 },
	{ 0xE6ACA5, 0x2A7CA },
	{ 0xE6ACA6, 0x3A9D3 },
	{ 0xE6ACA7, 0x3A9D4 },
	{ 0xE6ACA8, 0x2ABC6 },
	{ 0xE6ACA9, 0x4A9F2 },
	{ 0xE6ACAA, 0x3ADBC },
	{ 0xE6ACAB, 0x3B1E6 },
	{ 0xE6ACAC, 0x2AFF7 },
	{ 0xE6ACAD, 0x2AFF9 },
	{ 0xE6ACAE, 0x3B1E5 },
	{ 0xE6ACAF, 0x2AFF8 },
	{ 0xE6ACB0, 0x3B1E7 },
	{ 0xE6ACB1, 0x2AFFA },
	{ 0xE6ACB2, 0x1DBC3 },
	{ 0xE6ACB3, 0x2B6BB },
	{ 0xE6ACB4, 0x2AFFB },
	{ 0xE6ACB5, 0x3B6E2 },
	{ 0xE6ACB6, 0x2B6BA },
	{ 0xE6ACB7, 0x2B6BC },
	{ 0xE6ACB8, 0x2B6BD },
	{ 0xE6ACB9, 0x2BCFD },
	{ 0xE6ACBA, 0x1E0A2 },
	{ 0xE6ACBB, 0x2BCFE },
	{ 0xE6ACBC, 0x2BDA2 },
	{ 0xE6ACBD, 0x1E0A3 },
	{ 0xE6ACBE, 0x1E0A1 },
	{ 0xE6ACBF, 0x2BDA1 },
	{ 0xE6AD80, 0x3C1FD },
	{ 0xE6AD81, 0x2C4A2 },
	{ 0xE6AD82, 0x2C3FE },
	{ 0xE6AD83, 0x2C3FD },
	{ 0xE6AD84, 0x3C1FC },
	{ 0xE6AD85, 0x2C3FC },
	{ 0xE6AD86, 0x2C3FB },
	{ 0xE6AD87, 0x1E4D8 },
	{ 0xE6AD88, 0x2C4A1 },
	{ 0xE6AD89, 0x1E9B9 },
	{ 0xE6AD8A, 0x2CBAB },
	{ 0xE6AD8B, 0x2CBAD },
	{ 0xE6AD8C, 0x1E9BA },
	{ 0xE6AD8D, 0x2CBAC },
	{ 0xE6AD8E, 0x1EDC5 },
	{ 0xE6AD8F, 0x3CCE6 },
	{ 0xE6AD90, 0x1EDC4 },
	{ 0xE6AD91, 0x2D1B9 },
	{ 0xE6AD92, 0x3CCE5 },
	{ 0xE6AD93, 0x3CCE7 },
	{ 0xE6AD94, 0x2D7EA },
	{ 0xE6AD95, 0x2D7E9 },
	{ 0xE6AD96, 0x2D7EB },
	{ 0xE6AD97, 0x3D1C6 },
	{ 0xE6AD98, 0x3D1C5 },
	{ 0xE6AD99, 0x1F1A4 },
	{ 0xE6AD9A, 0xFD5B9 },
	{ 0xE6AD9B, 0x2DDB7 },
	{ 0xE6AD9C, 0x1F3FC },
	{ 0xE6AD9D, 0x3D5AB },
	{ 0xE6AD9E, 0x2E1F4 },
	{ 0xE6AD9F, 0x1F6D6 },
	{ 0xE6ADA0, 0x2E5E4 },
	{ 0xE6ADA1, 0x1FBE3 },
	{ 0xE6ADA2, 0x1C5CF },
	{ 0xE6ADA3, 0x1C6DF },
	{ 0xE6ADA4, 0x1C8BA },
	{ 0xE6ADA5, 0x1CAE3 },
	{ 0xE6ADA6, 0x1CEBD },
	{ 0xE6ADA7, 0x1CEBE },
	{ 0xE6ADA8, 0x3A9D5 },
	{ 0xE6ADA9, 0x3A9D6 },
	{ 0xE6ADAA, 0x1D1F1 },
	{ 0xE6ADAB, 0x3ADBD },
	{ 0xE6ADAC, 0x3B1E8 },
	{ 0xE6ADAD, 0x2AFFC },
	{ 0xE6ADAE, 0x3BCC9 },
	{ 0xE6ADAF, 0x3BCC7 },
	{ 0xE6ADB0, 0x4C4AD },
	{ 0xE6ADB1, 0x3C1FE },
	{ 0xE6ADB2, 0x1E4D9 },
	{ 0xE6ADB3, 0x3C2A1 },
	{ 0xE6ADB4, 0x3C7D3 },
	{ 0xE6ADB5, 0x4CACE },
	{ 0xE6ADB6, 0x2D2D9 },
	{ 0xE6ADB7, 0x1F1A5 },
	{ 0xE6ADB8, 0x1F6D7 },
	{ 0xE6ADB9, 0x1C5D0 },
	{ 0xE6ADBA, 0x3A2D3 },
	{ 0xE6ADBB, 0x1C8BB },
	{ 0xE6ADBD, 0x4A6F6 },
	{ 0xE6ADBE, 0x2A7CC },
	{ 0xE6ADBF, 0x1CEBF },
	{ 0xE6AE80, 0x2A7CB },
	{ 0xE6AE81, 0x3A9D8 },
	{ 0xE6AE82, 0x2ABC7 },
	{ 0xE6AE83, 0x1D1F2 },
	{ 0xE6AE84, 0x2ABC8 },
	{ 0xE6AE85, 0x5A9E9 },
	{ 0xE6AE86, 0x1D1F3 },
	{ 0xE6AE88, 0x2AFFE },
	{ 0xE6AE89, 0x1D6B2 },
	{ 0xE6AE8A, 0x1D6B1 },
	{ 0xE6AE8B, 0x3B1EA },
	{ 0xE6AE8C, 0x2B6C2 },
	{ 0xE6AE8D, 0x2B6C0 },
	{ 0xE6AE8E, 0x2B6C1 },
	{ 0xE6AE8F, 0x2B6BF },
	{ 0xE6AE90, 0x3B6E4 },
	{ 0xE6AE91, 0x2B6BE },
	{ 0xE6AE94, 0x2BDA3 },
	{ 0xE6AE95, 0x2BDA6 },
	{ 0xE6AE96, 0x1E0A5 },
	{ 0xE6AE97, 0x2BDA4 },
	{ 0xE6AE98, 0x1E0A4 },
	{ 0xE6AE99, 0x2BDA5 },
	{ 0xE6AE9B, 0x2C4A3 },
	{ 0xE6AE9C, 0x3C2A2 },
	{ 0xE6AE9D, 0x4C4B1 },
	{ 0xE6AE9E, 0x2CBAE },
	{ 0xE6AE9F, 0x2CBAF },
	{ 0xE6AEA0, 0x2CBB0 },
	{ 0xE6AEA1, 0x3C7D4 },
	{ 0xE6AEA2, 0x2D1BC },
	{ 0xE6AEA3, 0x2D1BB },
	{ 0xE6AEA4, 0x1EDC6 },
	{ 0xE6AEA5, 0x2D1BA },
	{ 0xE6AEA6, 0x2D1BD },
	{ 0xE6AEA7, 0x2D7EC },
	{ 0xE6AEA8, 0x4D0ED },
	{ 0xE6AEA9, 0x5DBF2 },
	{ 0xE6AEAA, 0x2D7ED },
	{ 0xE6AEAB, 0x2D7EE },
	{ 0xE6AEAC, 0x4D6D2 },
	{ 0xE6AEAD, 0x2DDB8 },
	{ 0xE6AEAE, 0x1F3FD },
	{ 0xE6AEAF, 0x1F6D8 },
	{ 0xE6AEB0, 0x2E5E5 },
	{ 0xE6AEB2, 0x1FAF3 },
	{ 0xE6AEB3, 0x2A1BF },
	{ 0xE6AEB4, 0x3A9D9 },
	{ 0xE6AEB5, 0x1D1F4 },
	{ 0xE6AEB6, 0x2ABC9 },
	{ 0xE6AEB7, 0x1D6B3 },
	{ 0xE6AEB8, 0x4B2CE },
	{ 0xE6AEB9, 0x4B2D0 },
	{ 0xE6AEBA, 0x1DBC4 },
	{ 0xE6AEBB, 0x3B6E5 },
	{ 0xE6AEBC, 0x1E0A6 },
	{ 0xE6AEBD, 0x2BDA7 },
	{ 0xE6AEBE, 0x3BCCB },
	{ 0xE6AEBF, 0x1E4DB },
	{ 0xE6AF80, 0x1E4DA },
	{ 0xE6AF81, 0x3C2A6 },
	{ 0xE6AF83, 0x2CBB1 },
	{ 0xE6AF84, 0x2CBB2 },
	{ 0xE6AF85, 0x1EDC7 },
	{ 0xE6AF86, 0x1EDC8 },
	{ 0xE6AF87, 0x2D7F0 },
	{ 0xE6AF88, 0x2D7EF },
	{ 0xE6AF89, 0x2E1F5 },
	{ 0xE6AF8A, 0x2EFB2 },
	{ 0xE6AF8B, 0x1C5D1 },
	{ 0xE6AF8C, 0x2A1C0 },
	{ 0xE6AF8D, 0x1C6E0 },
	{ 0xE6AF8E, 0x3A3FA },
	{ 0xE6AF8F, 0x1CAE4 },
	{ 0xE6AF90, 0x2A4C8 },
	{ 0xE6AF91, 0x3A9DA },
	{ 0xE6AF92, 0x1D1F5 },
	{ 0xE6AF93, 0x1E4DC },
	{ 0xE6AF94, 0x1C5D2 },
	{ 0xE6AF96, 0x2ABCA },
	{ 0xE6AF97, 0x1D1F6 },
	{ 0xE6AF98, 0x2ABCB },
	{ 0xE6AF9A, 0x1F3FE },
	{ 0xE6AF9B, 0x1C5D3 },
	{ 0xE6AF9C, 0x3E5B8 },
	{ 0xE6AF9D, 0x3E5B9 },
	{ 0xE6AF9E, 0x2A7CD },
	{ 0xE6AFA0, 0x2ABCC },
	{ 0xE6AFA1, 0x3ADC2 },
	{ 0xE6AFA2, 0x2B0A5 },
	{ 0xE6AFA3, 0x2B0A4 },
	{ 0xE6AFA4, 0x2B0A2 },
	{ 0xE6AFA5, 0x3B1EE },
	{ 0xE6AFA6, 0x2B0A1 },
	{ 0xE6AFA7, 0x2B0A6 },
	{ 0xE6AFA8, 0x2B0A3 },
	{ 0xE6AFA9, 0x3B1EC },
	{ 0xE6AFAA, 0x3B1ED },
	{ 0xE6AFAB, 0x1DBC5 },
	{ 0xE6AFAC, 0x1DBC6 },
	{ 0xE6AFAD, 0x3B6E6 },
	{ 0xE6AFAF, 0x1E0A7 },
	{ 0xE6AFB0, 0x2BDA8 },
	{ 0xE6AFB1, 0x4B8CE },
	{ 0xE6AFB2, 0x2BDA9 },
	{ 0xE6AFB3, 0x2BDAA },
	{ 0xE6AFB4, 0x3BCCD },
	{ 0xE6AFB5, 0xFBCBC },
	{ 0xE6AFB6, 0x3E5BA },
	{ 0xE6AFB7, 0x2C4A7 },
	{ 0xE6AFB8, 0x2C4A8 },
	{ 0xE6AFB9, 0x2C4A6 },
	{ 0xE6AFBA, 0x3C2A8 },
	{ 0xE6AFBB, 0x2C4A4 },
	{ 0xE6AFBC, 0x2C4A5 },
	{ 0xE6AFBD, 0x1E4DD },
	{ 0xE6AFBE, 0x2CBB3 },
	{ 0xE6AFBF, 0x2D1C0 },
	{ 0xE6B080, 0x2D1BF },
	{ 0xE6B081, 0x2D1BE },
	{ 0xE6B082, 0x2D1C1 },
	{ 0xE6B083, 0x2D7F2 },
	{ 0xE6B084, 0x2D7F1 },
	{ 0xE6B085, 0x1F1A6 },
	{ 0xE6B086, 0x2D7F3 },
	{ 0xE6B088, 0x1F4A1 },
	{ 0xE6B089, 0x2DDB9 },
	{ 0xE6B08A, 0x3D5AD },
	{ 0xE6B08B, 0x2E1F6 },
	{ 0xE6B08C, 0x2E5E6 },
	{ 0xE6B08D, 0x2EDD5 },
	{ 0xE6B08F, 0x1C5D4 },
	{ 0xE6B090, 0x1C6E2 },
	{ 0xE6B091, 0x1C6E1 },
	{ 0xE6B092, 0x4A3A1 },
	{ 0xE6B093, 0x1CEC0 },
	{ 0xE6B094, 0x2A1C1 },
	{ 0xE6B095, 0x2A1DF },
	{ 0xE6B096, 0x1C8BC },
	{ 0xE6B098, 0x2A2D8 },
	{ 0xE6B099, 0x2A4C9 },
	{ 0xE6B09A, 0x2A4CA },
	{ 0xE6B09B, 0x1CEC1 },
	{ 0xE6B09C, 0x3A9DD },
	{ 0xE6B09D, 0x2A7CE },
	{ 0xE6B09E, 0x3E5BB },
	{ 0xE6B09F, 0x1D1F7 },
	{ 0xE6B0A0, 0x2ABCD },
	{ 0xE6B0A1, 0x2ABCE },
	{ 0xE6B0A3, 0x1D6B4 },
	{ 0xE6B0A4, 0x1D6B8 },
	{ 0xE6B0A5, 0x2B0A7 },
	{ 0xE6B0A6, 0x1D6B7 },
	{ 0xE6B0A7, 0x1D6B5 },
	{ 0xE6B0A8, 0x1D6B6 },
	{ 0xE6B0AA, 0x2B6C3 },
	{ 0xE6B0AB, 0x1DBC7 },
	{ 0xE6B0AC, 0x1E0AA },
	{ 0xE6B0AD, 0x3BCCE },
	{ 0xE6B0AE, 0x1E0A8 },
	{ 0xE6B0AF, 0x1E0A9 },
	{ 0xE6B0B0, 0x2BDAB },
	{ 0xE6B0B1, 0x3C2A9 },
	{ 0xE6B0B2, 0x3C2AA },
	{ 0xE6B0B3, 0x1E9BB },
	{ 0xE6B0B4, 0x1C5D5 },
	{ 0xE6B0B6, 0x2A1E0 },
	{ 0xE6B0B7, 0x3A2D7 },
	{ 0xE6B0B8, 0x1C6E3 },
	{ 0xE6B0B9, 0x3A2D4 },
	{ 0xE6B0BB, 0x2A1E3 },
	{ 0xE6B0BC, 0x3A4A1 },
	{ 0xE6B0BE, 0x1C6E6 },
	{ 0xE6B0BF, 0x2A1E2 },
	{ 0xE6B180, 0x1C6E5 },
	{ 0xE6B181, 0x1C6E4 },
	{ 0xE6B182, 0x1CAE5 },
	{ 0xE6B183, 0x2A1E1 },
	{ 0xE6B184, 0x3A2D8 },
	{ 0xE6B185, 0x3A2D9 },
	{ 0xE6B186, 0x2A2D9 },
	{ 0xE6B189, 0xFA1E6 },
	{ 0xE6B18A, 0x2A2DD },
	{ 0xE6B18B, 0x2A2DF },
	{ 0xE6B18C, 0x2A2E0 },
	{ 0xE6B18D, 0x1C8C6 },
	{ 0xE6B18E, 0x1C8C7 },
	{ 0xE6B18F, 0x2A2DC },
	{ 0xE6B190, 0x1C8C2 },
	{ 0xE6B191, 0x3A3FD },
	{ 0xE6B192, 0x2A2DA },
	{ 0xE6B193, 0x3A4A5 },
	{ 0xE6B194, 0x2A2DE },
	{ 0xE6B195, 0x1C8C3 },
	{ 0xE6B196, 0x3A6D5 },
	{ 0xE6B197, 0x1C8BE },
	{ 0xE6B198, 0x3A3FC },
	{ 0xE6B199, 0x1C8BF },
	{ 0xE6B19A, 0x3A4A3 },
	{ 0xE6B19B, 0x1C8C5 },
	{ 0xE6B19C, 0x2A2DB },
	{ 0xE6B19D, 0x1C8BD },
	{ 0xE6B19E, 0x1CAE6 },
	{ 0xE6B19F, 0x1C8C0 },
	{ 0xE6B1A0, 0x1C8C1 },
	{ 0xE6B1A1, 0x1C8C4 },
	{ 0xE6B1A2, 0xFA2DD },
	{ 0xE6B1A3, 0x3E5BC },
	{ 0xE6B1A5, 0x2A4DB },
	{ 0xE6B1A6, 0x2A4D9 },
	{ 0xE6B1A7, 0x2A4CC },
	{ 0xE6B1A8, 0x1CAF2 },
	{ 0xE6B1A9, 0x2A4D3 },
	{ 0xE6B1AA, 0x1CAED },
	{ 0xE6B1AB, 0x2A4CD },
	{ 0xE6B1AC, 0x3A9E4 },
	{ 0xE6B1AD, 0x2A4D5 },
	{ 0xE6B1AE, 0x3A6D0 },
	{ 0xE6B1AF, 0x2A4D2 },
	{ 0xE6B1B0, 0x1CAF0 },
	{ 0xE6B1B1, 0x2A4D1 },
	{ 0xE6B1B2, 0x1CAF7 },
	{ 0xE6B1B3, 0x2A4DA },
	{ 0xE6B1B4, 0x1CAF9 },
	{ 0xE6B1B5, 0x3A6D3 },
	{ 0xE6B1B6, 0x1CAFB },
	{ 0xE6B1B7, 0x3A3FE },
	{ 0xE6B1B8, 0x2A4CB },
	{ 0xE6B1B9, 0x3A6D7 },
	{ 0xE6B1BA, 0x1CAEE },
	{ 0xE6B1BB, 0x2A4DC },
	{ 0xE6B1BC, 0x3A6D1 },
	{ 0xE6B1BD, 0x1CAF5 },
	{ 0xE6B1BE, 0x1CAF8 },
	{ 0xE6B1BF, 0x3A6CC },
	{ 0xE6B280, 0x2A7E5 },
	{ 0xE6B281, 0x1CAE8 },
	{ 0xE6B282, 0x1CBA1 },
	{ 0xE6B283, 0x1CAF6 },
	{ 0xE6B284, 0x2A4CE },
	{ 0xE6B285, 0x1CAEB },
	{ 0xE6B286, 0x1CAFA },
	{ 0xE6B287, 0x2A4D6 },
	{ 0xE6B288, 0x1CAE9 },
	{ 0xE6B289, 0x1CAEA },
	{ 0xE6B28A, 0x2A7E3 },
	{ 0xE6B28B, 0x2A4CF },
	{ 0xE6B28C, 0x1CAF1 },
	{ 0xE6B28D, 0x1CAFC },
	{ 0xE6B28E, 0x2A4DD },
	{ 0xE6B28F, 0x2A4D0 },
	{ 0xE6B290, 0x1CAEF },
	{ 0xE6B291, 0x3A6CD },
	{ 0xE6B292, 0x1CAF4 },
	{ 0xE6B293, 0x2A7CF },
	{ 0xE6B294, 0x1CAFD },
	{ 0xE6B295, 0x2A4D7 },
	{ 0xE6B296, 0x1CAF3 },
	{ 0xE6B297, 0x3A9E3 },
	{ 0xE6B298, 0x1CAFE },
	{ 0xE6B299, 0x1CAE7 },
	{ 0xE6B29A, 0x2A4D4 },
	{ 0xE6B29B, 0x1CAEC },
	{ 0xE6B29C, 0x2A4D8 },
	{ 0xE6B29D, 0x2A7E4 },
	{ 0xE6B29E, 0x3A6CE },
	{ 0xE6B29F, 0x3A6D2 },
	{ 0xE6B2A0, 0x3A6DC },
	{ 0xE6B2A1, 0x3A6D9 },
	{ 0xE6B2A2, 0x3A6D6 },
	{ 0xE6B2A3, 0xFA4E8 },
	{ 0xE6B2AA, 0x3A6DB },
	{ 0xE6B2AB, 0x1CECD },
	{ 0xE6B2AC, 0x1CEDD },
	{ 0xE6B2AD, 0x2A7D6 },
	{ 0xE6B2AE, 0x1CED4 },
	{ 0xE6B2AF, 0x3ADCE },
	{ 0xE6B2B0, 0x2A7EB },
	{ 0xE6B2B1, 0x1CEC5 },
	{ 0xE6B2B2, 0x3A9EB },
	{ 0xE6B2B3, 0x1CEC8 },
	{ 0xE6B2B4, 0x2A7E2 },
	{ 0xE6B2B5, 0x4A7A6 },
	{ 0xE6B2B6, 0x2A7D4 },
	{ 0xE6B2B7, 0x2A7D8 },
	{ 0xE6B2B8, 0x1CED0 },
	{ 0xE6B2B9, 0x1CED2 },
	{ 0xE6B2BA, 0x2A7DB },
	{ 0xE6B2BB, 0x1CED9 },
	{ 0xE6B2BC, 0x1CECB },
	{ 0xE6B2BD, 0x1CEC9 },
	{ 0xE6B2BE, 0x1CECA },
	{ 0xE6B2BF, 0x1CED8 },
	{ 0xE6B380, 0x2A7E7 },
	{ 0xE6B381, 0x1CED3 },
	{ 0xE6B382, 0x2A7DA },
	{ 0xE6B383, 0x2A7DC },
	{ 0xE6B384, 0x1CED1 },
	{ 0xE6B385, 0x1CED6 },
	{ 0xE6B386, 0x2A7DD },
	{ 0xE6B387, 0x2A7EA },
	{ 0xE6B388, 0x3A9ED },
	{ 0xE6B389, 0x1D1F8 },
	{ 0xE6B38A, 0x1CEDC },
	{ 0xE6B38B, 0x4A6FD },
	{ 0xE6B38C, 0x1CEC6 },
	{ 0xE6B38D, 0x2A7E9 },
	{ 0xE6B38E, 0x3A9EC },
	{ 0xE6B38F, 0x2A7ED },
	{ 0xE6B390, 0x2A7D9 },
	{ 0xE6B391, 0x2A7EF },
	{ 0xE6B392, 0x2A7E0 },
	{ 0xE6B393, 0x1CECF },
	{ 0xE6B394, 0x2A7D5 },
	{ 0xE6B395, 0x1CECE },
	{ 0xE6B396, 0x1CEE0 },
	{ 0xE6B397, 0x1CED5 },
	{ 0xE6B398, 0x3A9EA },
	{ 0xE6B399, 0x2A7D3 },
	{ 0xE6B39A, 0x2ABD7 },
	{ 0xE6B39B, 0x1CEDB },
	{ 0xE6B39C, 0x1CEDF },
	{ 0xE6B39D, 0x2A7E1 },
	{ 0xE6B39E, 0x2A7E6 },
	{ 0xE6B39F, 0x3A9E5 },
	{ 0xE6B3A0, 0x1CEE1 },
	{ 0xE6B3A1, 0x1CEDA },
	{ 0xE6B3A2, 0x1CECC },
	{ 0xE6B3A3, 0x1CEC2 },
	{ 0xE6B3A4, 0x3A9E9 },
	{ 0xE6B3A5, 0x1CEC7 },
	{ 0xE6B3A6, 0x4A6FB },
	{ 0xE6B3A7, 0x2A7D7 },
	{ 0xE6B3A8, 0x1CEC3 },
	{ 0xE6B3A9, 0x2A7EE },
	{ 0xE6B3AA, 0x3A9E7 },
	{ 0xE6B3AB, 0x2A7D1 },
	{ 0xE6B3AC, 0x2A7D0 },
	{ 0xE6B3AD, 0x2A7DE },
	{ 0xE6B3AE, 0x2A7D2 },
	{ 0xE6B3AF, 0x1CEDE },
	{ 0xE6B3B0, 0x1D6B9 },
	{ 0xE6B3B1, 0x1CED7 },
	{ 0xE6B3B2, 0x2A7DF },
	{ 0xE6B3B3, 0x1CEC4 },
	{ 0xE6B3B4, 0x3ADCF },
	{ 0xE6B3B5, 0x1D2A9 },
	{ 0xE6B3B9, 0x2A7EC },
	{ 0xE6B3BF, 0x3ADC6 },
	{ 0xE6B480, 0x2ABDE },
	{ 0xE6B481, 0x2ABE1 },
	{ 0xE6B482, 0x3ADD0 },
	{ 0xE6B483, 0x2ABE4 },
	{ 0xE6B484, 0x2ABD9 },
	{ 0xE6B485, 0x3ADC8 },
	{ 0xE6B486, 0x3ADCA },
	{ 0xE6B487, 0x2ABE7 },
	{ 0xE6B488, 0x2ABEA },
	{ 0xE6B489, 0x2ABEC },
	{ 0xE6B48A, 0x2ABD6 },
	{ 0xE6B48B, 0x1D1F9 },
	{ 0xE6B48C, 0x1D1FE },
	{ 0xE6B48D, 0x2B0AC },
	{ 0xE6B48E, 0x1D2B0 },
	{ 0xE6B48F, 0x2ABE5 },
	{ 0xE6B490, 0x2ABED },
	{ 0xE6B491, 0x2ABDD },
	{ 0xE6B492, 0x2ABD5 },
	{ 0xE6B493, 0x3ADC9 },
	{ 0xE6B494, 0x3ADC7 },
	{ 0xE6B495, 0x3ADCD },
	{ 0xE6B496, 0x2B0C7 },
	{ 0xE6B497, 0x1D2A3 },
	{ 0xE6B498, 0x2ABE2 },
	{ 0xE6B499, 0x2ABDA },
	{ 0xE6B49A, 0x2ABDC },
	{ 0xE6B49B, 0x1D2A8 },
	{ 0xE6B49C, 0x3B1FA },
	{ 0xE6B49D, 0x2ABDF },
	{ 0xE6B49E, 0x1D2A2 },
	{ 0xE6B49F, 0x2ABD2 },
	{ 0xE6B4A0, 0x2ABE8 },
	{ 0xE6B4A1, 0x3ADCB },
	{ 0xE6B4A2, 0x2ABEB },
	{ 0xE6B4A3, 0x3ADC5 },
	{ 0xE6B4A4, 0x3ADD7 },
	{ 0xE6B4A5, 0x1D1FD },
	{ 0xE6B4A6, 0x3ADD3 },
	{ 0xE6B4A7, 0x1D2AB },
	{ 0xE6B4A8, 0x2ABCF },
	{ 0xE6B4A9, 0x1D2AD },
	{ 0xE6B4AA, 0x1D1FB },
	{ 0xE6B4AB, 0x1D2B1 },
	{ 0xE6B4AC, 0x2ABE9 },
	{ 0xE6B4AD, 0x2ABD1 },
	{ 0xE6B4AE, 0x1D2AE },
	{ 0xE6B4AF, 0x2B0C1 },
	{ 0xE6B4B0, 0x2A7E8 },
	{ 0xE6B4B1, 0x1D2A1 },
	{ 0xE6B4B2, 0x1D1FA },
	{ 0xE6B4B3, 0x2ABD8 },
	{ 0xE6B4B4, 0x2ABD0 },
	{ 0xE6B4B5, 0x1D2AF },
	{ 0xE6B4B6, 0x1D2A7 },
	{ 0xE6B4B7, 0x2ABE3 },
	{ 0xE6B4B8, 0x1D2AC },
	{ 0xE6B4B9, 0x1D2AA },
	{ 0xE6B4BA, 0x2ABDB },
	{ 0xE6B4BB, 0x1D2A4 },
	{ 0xE6B4BC, 0x2ABD3 },
	{ 0xE6B4BD, 0x1D2A5 },
	{ 0xE6B4BE, 0x1D2A6 },
	{ 0xE6B4BF, 0x2ABD4 },
	{ 0xE6B580, 0x2ABE6 },
	{ 0xE6B581, 0x1D1FC },
	{ 0xE6B582, 0x2ABE0 },
	{ 0xE6B583, 0x4AAA1 },
	{ 0xE6B584, 0x3ADD5 },
	{ 0xE6B585, 0x3ADD1 },
	{ 0xE6B596, 0x3B1F7 },
	{ 0xE6B597, 0x3B1F3 },
	{ 0xE6B598, 0x2B0AF },
	{ 0xE6B599, 0x1D6C1 },
	{ 0xE6B59A, 0x1D6C6 },
	{ 0xE6B59B, 0x3B1F9 },
	{ 0xE6B59C, 0x3B2A6 },
	{ 0xE6B59D, 0x3B1F6 },
	{ 0xE6B59E, 0x2B0B8 },
	{ 0xE6B59F, 0x2B0BE },
	{ 0xE6B5A0, 0x2B0BA },
	{ 0xE6B5A1, 0x2B0AD },
	{ 0xE6B5A2, 0x2B0B0 },
	{ 0xE6B5A3, 0x2B0A9 },
	{ 0xE6B5A4, 0x2B0AA },
	{ 0xE6B5A5, 0x1D6CD },
	{ 0xE6B5A6, 0x1D6BE },
	{ 0xE6B5A7, 0x2B0B9 },
	{ 0xE6B5A8, 0x2B0C2 },
	{ 0xE6B5A9, 0x1D6C8 },
	{ 0xE6B5AA, 0x1D6BA },
	{ 0xE6B5AB, 0x3B1EF },
	{ 0xE6B5AC, 0x1D6C3 },
	{ 0xE6B5AD, 0x2B0B1 },
	{ 0xE6B5AE, 0x1D6C5 },
	{ 0xE6B5AF, 0x2B0B2 },
	{ 0xE6B5B0, 0x2B0BC },
	{ 0xE6B5B1, 0x3B2A2 },
	{ 0xE6B5B2, 0x3B2A5 },
	{ 0xE6B5B3, 0x3B1F2 },
	{ 0xE6B5B4, 0x1D6C7 },
	{ 0xE6B5B5, 0x2B0CB },
	{ 0xE6B5B6, 0x2B0AB },
	{ 0xE6B5B7, 0x1D6C0 },
	{ 0xE6B5B8, 0x1D6BF },
	{ 0xE6B5B9, 0x1D6CB },
	{ 0xE6B5BA, 0x2B0A8 },
	{ 0xE6B5BB, 0x2B0C9 },
	{ 0xE6B5BC, 0x2B0BD },
	{ 0xE6B5BD, 0x2B0CA },
	{ 0xE6B5BE, 0x2B0C4 },
	{ 0xE6B5BF, 0x2B0B6 },
	{ 0xE6B680, 0x2B0C5 },
	{ 0xE6B681, 0x3B2A1 },
	{ 0xE6B682, 0x2B0BF },
	{ 0xE6B683, 0x2B0C8 },
	{ 0xE6B684, 0x2B0C6 },
	{ 0xE6B685, 0x1D6CC },
	{ 0xE6B686, 0x2B0B7 },
	{ 0xE6B687, 0x1D6BD },
	{ 0xE6B688, 0x1D6BC },
	{ 0xE6B689, 0x1D6C4 },
	{ 0xE6B68A, 0x1D6CA },
	{ 0xE6B68B, 0x2B0C3 },
	{ 0xE6B68C, 0x1D6C9 },
	{ 0xE6B68D, 0x2B0B4 },
	{ 0xE6B68E, 0x1DBC8 },
	{ 0xE6B68F, 0x3B1F8 },
	{ 0xE6B690, 0x2B0CC },
	{ 0xE6B691, 0x2B0B3 },
	{ 0xE6B692, 0x2B0AE },
	{ 0xE6B693, 0x1D6C2 },
	{ 0xE6B694, 0x1D6CE },
	{ 0xE6B695, 0x1D6BB },
	{ 0xE6B696, 0x3B2A7 },
	{ 0xE6B697, 0x2B0BB },
	{ 0xE6B698, 0x2B0C0 },
	{ 0xE6B699, 0x3B1FD },
	{ 0xE6B69A, 0x3B1FB },
	{ 0xE6B69B, 0x3B1FC },
	{ 0xE6B6A5, 0x3E5BD },
	{ 0xE6B6AA, 0x1DBEA },
	{ 0xE6B6AB, 0x2B6C5 },
	{ 0xE6B6AC, 0x2B6C9 },
	{ 0xE6B6AD, 0x3B6EF },
	{ 0xE6B6AE, 0x1DBD7 },
	{ 0xE6B6AF, 0x1DBD5 },
	{ 0xE6B6B0, 0x3B6FA },
	{ 0xE6B6B1, 0x3B7A1 },
	{ 0xE6B6B2, 0x1DBCC },
	{ 0xE6B6B3, 0x2B6C7 },
	{ 0xE6B6B4, 0x2B6C6 },
	{ 0xE6B6B5, 0x1DBE0 },
	{ 0xE6B6B6, 0x3BCD0 },
	{ 0xE6B6B7, 0x2B6CC },
	{ 0xE6B6B8, 0x1DBDA },
	{ 0xE6B6B9, 0x3B6F2 },
	{ 0xE6B6BA, 0x2B6DE },
	{ 0xE6B6BB, 0x2B6EA },
	{ 0xE6B6BC, 0x1DBC9 },
	{ 0xE6B6BD, 0x2B6DB },
	{ 0xE6B6BE, 0x2B6D4 },
	{ 0xE6B6BF, 0x1DBEC },
	{ 0xE6B780, 0x2B6C4 },
	{ 0xE6B781, 0x3B6EA },
	{ 0xE6B782, 0x2B6E0 },
	{ 0xE6B783, 0x3B6EB },
	{ 0xE6B784, 0x1DBE9 },
	{ 0xE6B785, 0x1DBDD },
	{ 0xE6B786, 0x1DBE8 },
	{ 0xE6B787, 0x1DBD3 },
	{ 0xE6B788, 0x2B6D0 },
	{ 0xE6B789, 0x2B6E2 },
	{ 0xE6B78A, 0x2B6DA },
	{ 0xE6B78B, 0x1DBD4 },
	{ 0xE6B78C, 0x1DBCE },
	{ 0xE6B78D, 0x2B6E8 },
	{ 0xE6B78E, 0x3B6EC },
	{ 0xE6B78F, 0x2B6E1 },
	{ 0xE6B790, 0x2B6E3 },
	{ 0xE6B791, 0x1DBD6 },
	{ 0xE6B792, 0x1DBDE },
	{ 0xE6B793, 0x2B6E5 },
	{ 0xE6B794, 0x2B6CE },
	{ 0xE6B795, 0x2B6DF },
	{ 0xE6B796, 0x2B6D3 },
	{ 0xE6B797, 0x2B6E7 },
	{ 0xE6B798, 0x1DBE3 },
	{ 0xE6B799, 0x1DBCB },
	{ 0xE6B79A, 0x1DBE1 },
	{ 0xE6B79B, 0x2B6D8 },
	{ 0xE6B79C, 0x2B6D6 },
	{ 0xE6B79D, 0x2B6D7 },
	{ 0xE6B79E, 0x1DBD8 },
	{ 0xE6B79F, 0x2B6D2 },
	{ 0xE6B7A0, 0x2B6D1 },
	{ 0xE6B7A1, 0x1DBCD },
	{ 0xE6B7A2, 0x2B6CB },
	{ 0xE6B7A3, 0x2B6E9 },
	{ 0xE6B7A4, 0x1DBCF },
	{ 0xE6B7A5, 0x2B6D5 },
	{ 0xE6B7A6, 0x1DBED },
	{ 0xE6B7A7, 0x3B6F4 },
	{ 0xE6B7A8, 0x1DBE7 },
	{ 0xE6B7A9, 0x2B6CA },
	{ 0xE6B7AA, 0x1DBE4 },
	{ 0xE6B7AB, 0x1DBE2 },
	{ 0xE6B7AC, 0x1DBEB },
	{ 0xE6B7AD, 0x2B6DC },
	{ 0xE6B7AE, 0x1DBE6 },
	{ 0xE6B7AF, 0x2B0B5 },
	{ 0xE6B7B0, 0x2B6DD },
	{ 0xE6B7B1, 0x1DBE5 },
	{ 0xE6B7B2, 0x2B6E4 },
	{ 0xE6B7B3, 0x1DBCA },
	{ 0xE6B7B4, 0x2B6D9 },
	{ 0xE6B7B5, 0x1DBDC },
	{ 0xE6B7B6, 0x2B6CD },
	{ 0xE6B7B7, 0x1DBDB },
	{ 0xE6B7B8, 0x3B6FC },
	{ 0xE6B7B9, 0x1DBD9 },
	{ 0xE6B7BA, 0x1DBD1 },
	{ 0xE6B7BB, 0x1DBD0 },
	{ 0xE6B7BC, 0x2BDAC },
	{ 0xE6B7BD, 0x2B6E6 },
	{ 0xE6B7BE, 0x3BCDD },
	{ 0xE6B7BF, 0x3B7A8 },
	{ 0xE6B880, 0x2B6CF },
	{ 0xE6B881, 0x3B7A6 },
	{ 0xE6B882, 0x3B7A3 },
	{ 0xE6B883, 0x2BDC1 },
	{ 0xE6B884, 0x3B6F0 },
	{ 0xE6B885, 0x1DBD2 },
	{ 0xE6B886, 0x3B6F7 },
	{ 0xE6B887, 0x3B7A4 },
	{ 0xE6B888, 0x3B6F6 },
	{ 0xE6B889, 0x3B7A5 },
	{ 0xE6B88A, 0x3B6F9 },
	{ 0xE6B88B, 0x4B2ED },
	{ 0xE6B88C, 0x3B6FD },
	{ 0xE6B88F, 0x3E5BE },
	{ 0xE6B892, 0x3B7A9 },
	{ 0xE6B895, 0xFB6A9 },
	{ 0xE6B897, 0x3B7A7 },
	{ 0xE6B898, 0x3BCD4 },
	{ 0xE6B899, 0x1E0C7 },
	{ 0xE6B89A, 0x1DBDF },
	{ 0xE6B89B, 0x1E0B5 },
	{ 0xE6B89C, 0x2BDBB },
	{ 0xE6B89D, 0x1E0C3 },
	{ 0xE6B89E, 0x3BCD2 },
	{ 0xE6B89F, 0x2BDAF },
	{ 0xE6B8A0, 0x1E0B2 },
	{ 0xE6B8A1, 0x1E0AE },
	{ 0xE6B8A2, 0x2BDCD },
	{ 0xE6B8A3, 0x1E0B4 },
	{ 0xE6B8A4, 0x1E0B8 },
	{ 0xE6B8A5, 0x1E0B3 },
	{ 0xE6B8A6, 0x1E0BC },
	{ 0xE6B8A7, 0x2BDD1 },
	{ 0xE6B8A8, 0x2BDC8 },
	{ 0xE6B8A9, 0x3BCEB },
	{ 0xE6B8AA, 0x3BCED },
	{ 0xE6B8AB, 0x2BDB6 },
	{ 0xE6B8AC, 0x1E0C1 },
	{ 0xE6B8AD, 0x1E0BB },
	{ 0xE6B8AE, 0x2BDC2 },
	{ 0xE6B8AF, 0x1E0AB },
	{ 0xE6B8B0, 0x2BDCE },
	{ 0xE6B8B1, 0x2BDC7 },
	{ 0xE6B8B2, 0x1E0AF },
	{ 0xE6B8B3, 0x2BDBC },
	{ 0xE6B8B4, 0x1E0BE },
	{ 0xE6B8B5, 0x2BDD9 },
	{ 0xE6B8B6, 0x2BDDA },
	{ 0xE6B8B7, 0x4B8DB },
	{ 0xE6B8B8, 0x1E0AC },
	{ 0xE6B8B9, 0x2BDCC },
	{ 0xE6B8BA, 0x1E0C0 },
	{ 0xE6B8BB, 0x2BDC0 },
	{ 0xE6B8BC, 0x2BDB2 },
	{ 0xE6B8BD, 0x2BDB3 },
	{ 0xE6B8BE, 0x1E0C4 },
	{ 0xE6B8BF, 0x2BDB7 },
	{ 0xE6B980, 0x2BDBE },
	{ 0xE6B981, 0x2BDB8 },
	{ 0xE6B982, 0x3BCDA },
	{ 0xE6B983, 0x1E0C2 },
	{ 0xE6B984, 0x1E0CA },
	{ 0xE6B985, 0x2BDB4 },
	{ 0xE6B986, 0x2BDAD },
	{ 0xE6B987, 0x2BDAE },
	{ 0xE6B988, 0x3BCD6 },
	{ 0xE6B989, 0x2BDB0 },
	{ 0xE6B98A, 0x1E0B1 },
	{ 0xE6B98B, 0x2BDBD },
	{ 0xE6B98C, 0x3BCEE },
	{ 0xE6B98D, 0x1E0BF },
	{ 0xE6B98E, 0x1E0C8 },
	{ 0xE6B98F, 0x3BCD8 },
	{ 0xE6B990, 0x3BCE9 },
	{ 0xE6B991, 0x2BDBF },
	{ 0xE6B992, 0x2BDD7 },
	{ 0xE6B993, 0x2BDCF },
	{ 0xE6B994, 0x1E0AD },
	{ 0xE6B995, 0x2BDD5 },
	{ 0xE6B996, 0x1E0B9 },
	{ 0xE6B997, 0x3BCE6 },
	{ 0xE6B998, 0x1E0B7 },
	{ 0xE6B999, 0x3BCE4 },
	{ 0xE6B99A, 0x2BDDB },
	{ 0xE6B99B, 0x1E0B6 },
	{ 0xE6B99C, 0x2BDC5 },
	{ 0xE6B99D, 0x2BDB9 },
	{ 0xE6B99E, 0x2BDC3 },
	{ 0xE6B99F, 0x1E0CD },
	{ 0xE6B9A0, 0x2BDC9 },
	{ 0xE6B9A1, 0x2BDC6 },
	{ 0xE6B9A2, 0x2BDB5 },
	{ 0xE6B9A3, 0x1E0C9 },
	{ 0xE6B9A4, 0x2BDD3 },
	{ 0xE6B9A5, 0x2BDD0 },
	{ 0xE6B9A6, 0x2BDD8 },
	{ 0xE6B9A7, 0x1E0B0 },
	{ 0xE6B9A8, 0x2BDC4 },
	{ 0xE6B9A9, 0x1E0CC },
	{ 0xE6B9AA, 0x3BCDB },
	{ 0xE6B9AB, 0x2BDCB },
	{ 0xE6B9AC, 0x3C2BA },
	{ 0xE6B9AD, 0x3BCE0 },
	{ 0xE6B9AE, 0x1E0BA },
	{ 0xE6B9AF, 0x1E0BD },
	{ 0xE6B9B0, 0x3BCDC },
	{ 0xE6B9B1, 0x2BDCA },
	{ 0xE6B9B2, 0x1E0CB },
	{ 0xE6B9B3, 0x2BDBA },
	{ 0xE6B9B4, 0x2B6C8 },
	{ 0xE6B9B5, 0x3BCD1 },
	{ 0xE6B9B6, 0x3BCEC },
	{ 0xE6B9B7, 0x2BDD4 },
	{ 0xE6B9B8, 0x2BDD2 },
	{ 0xE6B9B9, 0x2BDD6 },
	{ 0xE6B9BA, 0xFBCDD },
	{ 0xE6B9BB, 0x3BCE2 },
	{ 0xE6B9BC, 0x3E5C2 },
	{ 0xE6B9BD, 0x4B8DE },
	{ 0xE6B9BE, 0x3BCE3 },
	{ 0xE6BA80, 0x3BCE8 },
	{ 0xE6BA82, 0xFBCC7 },
	{ 0xE6BA84, 0x3E5C0 },
	{ 0xE6BA86, 0x4B8DF },
	{ 0xE6BA88, 0x2BDB1 },
	{ 0xE6BA89, 0x1E0C6 },
	{ 0xE6BA8A, 0x3E5BF },
	{ 0xE6BA8B, 0x3E5C1 },
	{ 0xE6BA8D, 0x2C4C7 },
	{ 0xE6BA8E, 0x2C4C6 },
	{ 0xE6BA8F, 0x2C4AC },
	{ 0xE6BA90, 0x1E4E3 },
	{ 0xE6BA91, 0x3C2B0 },
	{ 0xE6BA92, 0x2C4C5 },
	{ 0xE6BA93, 0x2C4AF },
	{ 0xE6BA94, 0x2C4B0 },
	{ 0xE6BA95, 0x4BEBF },
	{ 0xE6BA96, 0x1E4ED },
	{ 0xE6BA97, 0x2C4CE },
	{ 0xE6BA98, 0x1E4E8 },
	{ 0xE6BA99, 0x2C4C4 },
	{ 0xE6BA9A, 0x3C2B3 },
	{ 0xE6BA9B, 0x2C4A9 },
	{ 0xE6BA9C, 0x1E4EE },
	{ 0xE6BA9D, 0x1E4E4 },
	{ 0xE6BA9E, 0x2C4B8 },
	{ 0xE6BA9F, 0x2C4AE },
	{ 0xE6BAA0, 0x2C4B1 },
	{ 0xE6BAA1, 0x2C4C9 },
	{ 0xE6BAA2, 0x1E4DE },
	{ 0xE6BAA3, 0x2C4D0 },
	{ 0xE6BAA4, 0x2C4C8 },
	{ 0xE6BAA5, 0x1E4E7 },
	{ 0xE6BAA6, 0x2C4BD },
	{ 0xE6BAA7, 0x1E4F2 },
	{ 0xE6BAA8, 0x3C2AE },
	{ 0xE6BAA9, 0x3C2B6 },
	{ 0xE6BAAA, 0x1E4F1 },
	{ 0xE6BAAB, 0x1E4EB },
	{ 0xE6BAAC, 0x3C2C0 },
	{ 0xE6BAAD, 0x4BEB6 },
	{ 0xE6BAAE, 0x2C4CF },
	{ 0xE6BAAF, 0x1E4DF },
	{ 0xE6BAB0, 0x2C4BB },
	{ 0xE6BAB1, 0x2C4B2 },
	{ 0xE6BAB2, 0x2C4BF },
	{ 0xE6BAB3, 0x2C4CB },
	{ 0xE6BAB4, 0x1E4F3 },
	{ 0xE6BAB5, 0x3C2B9 },
	{ 0xE6BAB6, 0x1E4E1 },
	{ 0xE6BAB7, 0x2C4BA },
	{ 0xE6BAB8, 0x3C2AD },
	{ 0xE6BAB9, 0x2C4B3 },
	{ 0xE6BABA, 0x1E4EA },
	{ 0xE6BABB, 0x3C2B1 },
	{ 0xE6BABC, 0x1E4E9 },
	{ 0xE6BABD, 0x2C4B6 },
	{ 0xE6BABE, 0x2C4C0 },
	{ 0xE6BABF, 0x2C4CA },
	{ 0xE6BB80, 0x2C4AD },
	{ 0xE6BB81, 0x2C4B7 },
	{ 0xE6BB82, 0x1E4E2 },
	{ 0xE6BB83, 0x2C4C1 },
	{ 0xE6BB84, 0x1E4EF },
	{ 0xE6BB85, 0x1E4E6 },
	{ 0xE6BB86, 0x2C4B4 },
	{ 0xE6BB87, 0x1E4E5 },
	{ 0xE6BB88, 0x2C4AB },
	{ 0xE6BB89, 0x2C4B9 },
	{ 0xE6BB8A, 0x2C4CD },
	{ 0xE6BB8B, 0x1E0C5 },
	{ 0xE6BB8C, 0x1E9D7 },
	{ 0xE6BB8D, 0x2C4BC },
	{ 0xE6BB8E, 0x2CBB4 },
	{ 0xE6BB8F, 0x2C4BE },
	{ 0xE6BB90, 0x2C4CC },
	{ 0xE6BB91, 0x1E4EC },
	{ 0xE6BB92, 0x2C4B5 },
	{ 0xE6BB93, 0x1E4E0 },
	{ 0xE6BB94, 0x1E4F0 },
	{ 0xE6BB95, 0x1EDDA },
	{ 0xE6BB96, 0x2C4AA },
	{ 0xE6BB97, 0x6D4CE },
	{ 0xE6BB98, 0x2C4C3 },
	{ 0xE6BB99, 0x3C2C4 },
	{ 0xE6BB9A, 0x3C2BE },
	{ 0xE6BB9B, 0x3C2C7 },
	{ 0xE6BB9C, 0x2C4C2 },
	{ 0xE6BB9D, 0x3C2BD },
	{ 0xE6BBA3, 0x3C2C5 },
	{ 0xE6BBA6, 0x3C2BF },
	{ 0xE6BBA8, 0x3C2BB },
	{ 0xE6BBA9, 0x3C2C6 },
	{ 0xE6BBAB, 0x2CBD0 },
	{ 0xE6BBAC, 0x1E9D4 },
	{ 0xE6BBAD, 0x2CBC5 },
	{ 0xE6BBAE, 0x2CBCA },
	{ 0xE6BBAF, 0x1E9C9 },
	{ 0xE6BBB0, 0x3C7D6 },
	{ 0xE6BBB1, 0x2CBB6 },
	{ 0xE6BBB2, 0x1E9D6 },
	{ 0xE6BBB3, 0x3C7D7 },
	{ 0xE6BBB4, 0x1E9C0 },
	{ 0xE6BBB5, 0x2CBB5 },
	{ 0xE6BBB6, 0x2CBD6 },
	{ 0xE6BBB7, 0x1E9D8 },
	{ 0xE6BBB8, 0x2CBB9 },
	{ 0xE6BBB9, 0x2CBC9 },
	{ 0xE6BBBA, 0x3C7E5 },
	{ 0xE6BBBB, 0x2CBBB },
	{ 0xE6BBBC, 0x2CBD9 },
	{ 0xE6BBBD, 0x2CBD5 },
	{ 0xE6BBBE, 0x1E9BE },
	{ 0xE6BBBF, 0x1E9C8 },
	{ 0xE6BC80, 0x2D1DB },
	{ 0xE6BC81, 0x1E9D5 },
	{ 0xE6BC82, 0x1E9C6 },
	{ 0xE6BC83, 0x2CBB7 },
	{ 0xE6BC84, 0x3C7E3 },
	{ 0xE6BC85, 0x2CBD4 },
	{ 0xE6BC86, 0x1E9CA },
	{ 0xE6BC87, 0x2CBD1 },
	{ 0xE6BC88, 0x2CBDE },
	{ 0xE6BC89, 0x2CBBD },
	{ 0xE6BC8A, 0x2CBC6 },
	{ 0xE6BC8B, 0x3CCF8 },
	{ 0xE6BC8C, 0x3C7DB },
	{ 0xE6BC8D, 0x2CBDC },
	{ 0xE6BC8E, 0x2CBD2 },
	{ 0xE6BC8F, 0x1E9C5 },
	{ 0xE6BC90, 0x3CCEA },
	{ 0xE6BC91, 0x3C7E4 },
	{ 0xE6BC92, 0x2CBC4 },
	{ 0xE6BC93, 0x1E9BF },
	{ 0xE6BC94, 0x1E9BD },
	{ 0xE6BC95, 0x1E9CF },
	{ 0xE6BC96, 0x4C4C3 },
	{ 0xE6BC97, 0x3C7DF },
	{ 0xE6BC98, 0x2CBC2 },
	{ 0xE6BC99, 0x2CBBF },
	{ 0xE6BC9A, 0x2CBC0 },
	{ 0xE6BC9B, 0x3C7DA },
	{ 0xE6BC9C, 0x2CBD8 },
	{ 0xE6BC9D, 0x3C7DC },
	{ 0xE6BC9E, 0x2CBDD },
	{ 0xE6BC9F, 0x2CBDB },
	{ 0xE6BCA0, 0x1E9C3 },
	{ 0xE6BCA1, 0x2CBDF },
	{ 0xE6BCA2, 0x1E9C7 },
	{ 0xE6BCA3, 0x1E9CE },
	{ 0xE6BCA4, 0x4C4C4 },
	{ 0xE6BCA5, 0x2CBB8 },
	{ 0xE6BCA6, 0x2D1C3 },
	{ 0xE6BCA7, 0x2CBC1 },
	{ 0xE6BCA8, 0x3C7DE },
	{ 0xE6BCA9, 0x1E9C1 },
	{ 0xE6BCAA, 0x1E9D3 },
	{ 0xE6BCAB, 0x1E9D0 },
	{ 0xE6BCAC, 0x1E9C4 },
	{ 0xE6BCAD, 0x2CBCB },
	{ 0xE6BCAE, 0x2CBBC },
	{ 0xE6BCAF, 0x1E9D1 },
	{ 0xE6BCB0, 0x2CBCD },
	{ 0xE6BCB1, 0x1E9CB },
	{ 0xE6BCB2, 0x1E9CD },
	{ 0xE6BCB3, 0x1E9BC },
	{ 0xE6BCB4, 0x3C7DD },
	{ 0xE6BCB5, 0x2CBCF },
	{ 0xE6BCB6, 0x2CBC7 },
	{ 0xE6BCB7, 0x2CBBA },
	{ 0xE6BCB8, 0x1E9CC },
	{ 0xE6BCB9, 0x2CBD7 },
	{ 0xE6BCBA, 0x2CBDA },
	{ 0xE6BCBB, 0x2CBC3 },
	{ 0xE6BCBC, 0x2CBCE },
	{ 0xE6BCBD, 0x3CCF4 },
	{ 0xE6BCBE, 0x1E9C2 },
	{ 0xE6BCBF, 0x1EDC9 },
	{ 0xE6BD80, 0x2CBCC },
	{ 0xE6BD81, 0x2D1C2 },
	{ 0xE6BD82, 0x3C7E2 },
	{ 0xE6BD83, 0x2CBD3 },
	{ 0xE6BD84, 0x3C7E1 },
	{ 0xE6BD85, 0x4C4D2 },
	{ 0xE6BD86, 0xFCFF9 },
	{ 0xE6BD88, 0x3E5C4 },
	{ 0xE6BD89, 0x3E5C5 },
	{ 0xE6BD8A, 0x3C7E6 },
	{ 0xE6BD8C, 0x3E5C3 },
	{ 0xE6BD8E, 0x2CBBE },
	{ 0xE6BD8F, 0x2D1CC },
	{ 0xE6BD90, 0x2D1D6 },
	{ 0xE6BD91, 0x1EDCC },
	{ 0xE6BD92, 0x2D1D5 },
	{ 0xE6BD93, 0x2D1E1 },
	{ 0xE6BD94, 0x1EDCE },
	{ 0xE6BD95, 0x2D1D3 },
	{ 0xE6BD96, 0x4CAD8 },
	{ 0xE6BD97, 0x2D1D7 },
	{ 0xE6BD98, 0x1EDD9 },
	{ 0xE6BD99, 0x3CCFD },
	{ 0xE6BD9A, 0x2D1CE },
	{ 0xE6BD9B, 0x1EDD1 },
	{ 0xE6BD9C, 0x3CCF3 },
	{ 0xE6BD9D, 0x2D1DA },
	{ 0xE6BD9E, 0x2D7FB },
	{ 0xE6BD9F, 0x1EDDD },
	{ 0xE6BDA0, 0x1EDDC },
	{ 0xE6BDA1, 0x2D1DC },
	{ 0xE6BDA2, 0x2D1CB },
	{ 0xE6BDA3, 0x2D1E6 },
	{ 0xE6BDA4, 0x1EDD7 },
	{ 0xE6BDA5, 0x3CCEB },
	{ 0xE6BDA6, 0x1EDCD },
	{ 0xE6BDA7, 0x2D1DF },
	{ 0xE6BDA8, 0x4CAE9 },
	{ 0xE6BDA9, 0x2D1E3 },
	{ 0xE6BDAA, 0x2D1E8 },
	{ 0xE6BDAB, 0x2D1DD },
	{ 0xE6BDAC, 0x2D1D1 },
	{ 0xE6BDAD, 0x1EDD0 },
	{ 0xE6BDAE, 0x1EDD3 },
	{ 0xE6BDAF, 0x1EDDB },
	{ 0xE6BDB0, 0x1EDD6 },
	{ 0xE6BDB1, 0x3CCF5 },
	{ 0xE6BDB2, 0x2D1D4 },
	{ 0xE6BDB3, 0x2CBC8 },
	{ 0xE6BDB4, 0x3CCFE },
	{ 0xE6BDB5, 0x3CCEC },
	{ 0xE6BDB6, 0x2D1D0 },
	{ 0xE6BDB7, 0x2D1E7 },
	{ 0xE6BDB8, 0x1EDD2 },
	{ 0xE6BDB9, 0x3CCF9 },
	{ 0xE6BDBA, 0x1EDD5 },
	{ 0xE6BDBB, 0x2D1E9 },
	{ 0xE6BDBC, 0x1EDCA },
	{ 0xE6BDBD, 0x2D1DE },
	{ 0xE6BDBE, 0x2D1C4 },
	{ 0xE6BDBF, 0x2D1E4 },
	{ 0xE6BE80, 0x1F4AA },
	{ 0xE6BE81, 0x3CCFA },
	{ 0xE6BE82, 0x2D1D2 },
	{ 0xE6BE83, 0x4D0F5 },
	{ 0xE6BE84, 0x1EDCB },
	{ 0xE6BE85, 0x2D1CD },
	{ 0xE6BE86, 0x1EDCF },
	{ 0xE6BE87, 0x2D1C5 },
	{ 0xE6BE88, 0x1E9D2 },
	{ 0xE6BE89, 0x2D1C9 },
	{ 0xE6BE8A, 0x4CAD7 },
	{ 0xE6BE8B, 0x2D1E2 },
	{ 0xE6BE8C, 0x2D1CA },
	{ 0xE6BE8D, 0x2D1C8 },
	{ 0xE6BE8E, 0x1EDD4 },
	{ 0xE6BE8F, 0x3CCFB },
	{ 0xE6BE90, 0x2D1E0 },
	{ 0xE6BE91, 0x3CCF7 },
	{ 0xE6BE92, 0x2D1C7 },
	{ 0xE6BE93, 0x2D1D9 },
	{ 0xE6BE94, 0x2D1D8 },
	{ 0xE6BE95, 0x2D1E5 },
	{ 0xE6BE96, 0x2D1CF },
	{ 0xE6BE97, 0x1EDD8 },
	{ 0xE6BE98, 0x4CAE4 },
	{ 0xE6BE99, 0x3E5C7 },
	{ 0xE6BE9A, 0xFCFFD },
	{ 0xE6BE9D, 0x3E5C6 },
	{ 0xE6BE9E, 0x2D7FE },
	{ 0xE6BE9F, 0x3D1D6 },
	{ 0xE6BEA0, 0x1F1B3 },
	{ 0xE6BEA1, 0x1F1A9 },
	{ 0xE6BEA2, 0x2D8AC },
	{ 0xE6BEA3, 0x2D7F6 },
	{ 0xE6BEA4, 0x1F1AB },
	{ 0xE6BEA5, 0x2D8A4 },
	{ 0xE6BEA6, 0x1F1B2 },
	{ 0xE6BEA7, 0x1F1AD },
	{ 0xE6BEA8, 0x2D8A2 },
	{ 0xE6BEA9, 0x2DDBB },
	{ 0xE6BEAA, 0x2D8A8 },
	{ 0xE6BEAB, 0x2D8AE },
	{ 0xE6BEAC, 0x2D8A7 },
	{ 0xE6BEAD, 0x2D7F4 },
	{ 0xE6BEAE, 0x2D8A5 },
	{ 0xE6BEAF, 0x2D8B0 },
	{ 0xE6BEB0, 0x2D8B2 },
	{ 0xE6BEB1, 0x1F1A8 },
	{ 0xE6BEB2, 0x2D8B1 },
	{ 0xE6BEB3, 0x1F1AE },
	{ 0xE6BEB4, 0x1F1B4 },
	{ 0xE6BEB5, 0x3D1D4 },
	{ 0xE6BEB6, 0x1F1B1 },
	{ 0xE6BEB7, 0x3D1D8 },
	{ 0xE6BEB8, 0x2D8AB },
	{ 0xE6BEB9, 0x1F1B0 },
	{ 0xE6BEBA, 0x2D8A6 },
	{ 0xE6BEBB, 0x3D1CD },
	{ 0xE6BEBC, 0x2D7F8 },
	{ 0xE6BEBD, 0x2D7FD },
	{ 0xE6BEBE, 0x3D1D0 },
	{ 0xE6BEBF, 0x2D8AA },
	{ 0xE6BF80, 0x1F1AF },
	{ 0xE6BF81, 0x1F1AC },
	{ 0xE6BF82, 0x1F1A7 },
	{ 0xE6BF83, 0x1F1AA },
	{ 0xE6BF84, 0x2D7FC },
	{ 0xE6BF85, 0x4D1A2 },
	{ 0xE6BF86, 0x2D1C6 },
	{ 0xE6BF87, 0x2D7F7 },
	{ 0xE6BF88, 0x2D7FA },
	{ 0xE6BF89, 0x2D8AD },
	{ 0xE6BF8A, 0x2D8A1 },
	{ 0xE6BF8B, 0x2D7F5 },
	{ 0xE6BF8C, 0x2DDBA },
	{ 0xE6BF8D, 0x2D8AF },
	{ 0xE6BF8E, 0x2D7F9 },
	{ 0xE6BF8F, 0x2D8A9 },
	{ 0xE6BF90, 0x3CCF1 },
	{ 0xE6BF93, 0x3D1D5 },
	{ 0xE6BF94, 0x2DDBD },
	{ 0xE6BF95, 0x1F4AE },
	{ 0xE6BF96, 0x3D5B0 },
	{ 0xE6BF97, 0x3D5AF },
	{ 0xE6BF98, 0x1F4A2 },
	{ 0xE6BF99, 0x3D5B5 },
	{ 0xE6BF9A, 0x3D5B6 },
	{ 0xE6BF9B, 0x1F4A6 },
	{ 0xE6BF9C, 0x2DDBF },
	{ 0xE6BF9D, 0x2DDC5 },
	{ 0xE6BF9E, 0x2DDC3 },
	{ 0xE6BF9F, 0x1F4A4 },
	{ 0xE6BFA0, 0x1F4A5 },
	{ 0xE6BFA1, 0x1F4AC },
	{ 0xE6BFA2, 0x2DDC6 },
	{ 0xE6BFA3, 0x2DDBE },
	{ 0xE6BFA4, 0x1F4A7 },
	{ 0xE6BFA5, 0x3D5B1 },
	{ 0xE6BFA6, 0x2DDC2 },
	{ 0xE6BFA7, 0x2DDC1 },
	{ 0xE6BFA8, 0x2DDC7 },
	{ 0xE6BFA9, 0x1F4AD },
	{ 0xE6BFAA, 0x3D5B7 },
	{ 0xE6BFAB, 0x1F4A8 },
	{ 0xE6BFAC, 0x1F4AB },
	{ 0xE6BFAD, 0x2DDC0 },
	{ 0xE6BFAE, 0x1F4AF },
	{ 0xE6BFAF, 0x1F4A9 },
	{ 0xE6BFB0, 0x1F4B0 },
	{ 0xE6BFB1, 0x1F4A3 },
	{ 0xE6BFB2, 0x2DDC4 },
	{ 0xE6BFB3, 0x3DAD5 },
	{ 0xE6BFB4, 0x2DDBC },
	{ 0xE6BFB5, 0x3D1D9 },
	{ 0xE6BFB6, 0x3D5B9 },
	{ 0xE6BFB7, 0x2E2A5 },
	{ 0xE6BFB8, 0x3E5C8 },
	{ 0xE6BFBA, 0x1F6DD },
	{ 0xE6BFBB, 0x2E2A2 },
	{ 0xE6BFBC, 0x2E2A4 },
	{ 0xE6BFBD, 0x3D8A8 },
	{ 0xE6BFBE, 0x1F6DB },
	{ 0xE6BFBF, 0x2E1FE },
	{ 0xE78080, 0x2E2A1 },
	{ 0xE78081, 0x2E1FA },
	{ 0xE78082, 0x3D8AA },
	{ 0xE78083, 0x3D8A7 },
	{ 0xE78084, 0x2D8A3 },
	{ 0xE78085, 0x2E1FB },
	{ 0xE78086, 0x1F6DC },
	{ 0xE78087, 0x2E1F7 },
	{ 0xE78088, 0x3D8A6 },
	{ 0xE78089, 0x1F6D9 },
	{ 0xE7808A, 0x2E2A6 },
	{ 0xE7808B, 0x1F6DA },
	{ 0xE7808C, 0x2E1F8 },
	{ 0xE7808D, 0x2E1F9 },
	{ 0xE7808E, 0x2E1FD },
	{ 0xE7808F, 0x1F6DF },
	{ 0xE78090, 0x3D8A9 },
	{ 0xE78091, 0x1F6DE },
	{ 0xE78092, 0x4DBDE },
	{ 0xE78093, 0x3D8AB },
	{ 0xE78094, 0x2E1FC },
	{ 0xE78095, 0x1F8C5 },
	{ 0xE78096, 0x2E5EA },
	{ 0xE78097, 0x2E5F0 },
	{ 0xE78098, 0x1F8C6 },
	{ 0xE78099, 0x2E5E7 },
	{ 0xE7809A, 0x1F8C3 },
	{ 0xE7809B, 0x1F8C0 },
	{ 0xE7809C, 0x2E5F2 },
	{ 0xE7809D, 0x1F8C4 },
	{ 0xE7809E, 0x3DAD2 },
	{ 0xE7809F, 0x1F8C1 },
	{ 0xE780A0, 0x2E5E9 },
	{ 0xE780A1, 0x2E5EC },
	{ 0xE780A2, 0x2E5ED },
	{ 0xE780A3, 0x2E5EE },
	{ 0xE780A4, 0x2E5F1 },
	{ 0xE780A5, 0x3DAD4 },
	{ 0xE780A6, 0x2E2A3 },
	{ 0xE780A7, 0x2E5E8 },
	{ 0xE780A8, 0x1F8C2 },
	{ 0xE780A9, 0x2E5EF },
	{ 0xE780AA, 0x2E9B4 },
	{ 0xE780AB, 0x2E5EB },
	{ 0xE780AC, 0x3DAD3 },
	{ 0xE780AD, 0x3E5CA },
	{ 0xE780AE, 0x3E5C9 },
	{ 0xE780AF, 0x2E9AB },
	{ 0xE780B0, 0x1F9F5 },
	{ 0xE780B1, 0x2E9AE },
	{ 0xE780B2, 0x1F9F6 },
	{ 0xE780B3, 0x2E9B7 },
	{ 0xE780B4, 0x2E9AD },
	{ 0xE780B5, 0x2E9AA },
	{ 0xE780B6, 0x3DCD1 },
	{ 0xE780B7, 0x2E9AC },
	{ 0xE780B8, 0x2E9B0 },
	{ 0xE780B9, 0x2E9B3 },
	{ 0xE780BA, 0x2E9B2 },
	{ 0xE780BB, 0x2E9B6 },
	{ 0xE780BC, 0x2E9A9 },
	{ 0xE780BD, 0x3DCCF },
	{ 0xE780BE, 0x1F9F4 },
	{ 0xE780BF, 0x2E9B1 },
	{ 0xE78180, 0x2E9B5 },
	{ 0xE78181, 0x2E9B8 },
	{ 0xE78182, 0x2E9AF },
	{ 0xE78183, 0x2EBE1 },
	{ 0xE78184, 0x2EBE2 },
	{ 0xE78185, 0x2EBE6 },
	{ 0xE78186, 0x2EBE7 },
	{ 0xE78187, 0x3DEBC },
	{ 0xE78188, 0x2EBE4 },
	{ 0xE78189, 0x2EBE5 },
	{ 0xE7818A, 0x2EBE3 },
	{ 0xE7818B, 0x3DEBA },
	{ 0xE7818C, 0x1FAF4 },
	{ 0xE7818D, 0x3DEBB },
	{ 0xE78191, 0x1FBE4 },
	{ 0xE78192, 0x2EDD9 },
	{ 0xE78193, 0x3E0B6 },
	{ 0xE78194, 0x3DFD2 },
	{ 0xE78195, 0x2EDD6 },
	{ 0xE78196, 0x2EDD7 },
	{ 0xE78197, 0x2EDD8 },
	{ 0xE78198, 0x1FBE5 },
	{ 0xE78199, 0x3E0B7 },
	{ 0xE7819A, 0x2EFB4 },
	{ 0xE7819B, 0x2EFB3 },
	{ 0xE7819C, 0x3E5CB },
	{ 0xE7819D, 0x2F0BD },
	{ 0xE7819E, 0x1FCE0 },
	{ 0xE7819F, 0x2F0BB },
	{ 0xE781A0, 0x2F0BE },
	{ 0xE781A1, 0x2F0BC },
	{ 0xE781A2, 0x2F1A5 },
	{ 0xE781A3, 0x1FDA4 },
	{ 0xE781A4, 0x1FDB2 },
	{ 0xE781A5, 0x2F1F1 },
	{ 0xE781A6, 0x2F1DB },
	{ 0xE781A7, 0x3E1F9 },
	{ 0xE781A8, 0x2F1F0 },
	{ 0xE781A9, 0x2F2BE },
	{ 0xE781AA, 0x2F2BF },
	{ 0xE781AB, 0x1C5D6 },
	{ 0xE781AC, 0x4A1D0 },
	{ 0xE781AE, 0x3A4A8 },
	{ 0xE781AF, 0x3A4A6 },
	{ 0xE781B0, 0x1C8C8 },
	{ 0xE781B1, 0x2A2E1 },
	{ 0xE781B2, 0x3A4A7 },
	{ 0xE781B3, 0x3A4AB },
	{ 0xE781B4, 0x2A4DE },
	{ 0xE781B5, 0x3A6E2 },
	{ 0xE781B6, 0x1CBA2 },
	{ 0xE781B7, 0x3A6DF },
	{ 0xE781B8, 0x1CBA5 },
	{ 0xE781B9, 0x3A6DE },
	{ 0xE781BA, 0x2A4DF },
	{ 0xE781BB, 0x3A6E3 },
	{ 0xE781BC, 0x1CBA3 },
	{ 0xE781BD, 0x1CBA4 },
	{ 0xE781BE, 0x3A6E0 },
	{ 0xE781BF, 0xFA4F1 },
	{ 0xE78281, 0x3A9F7 },
	{ 0xE78282, 0x2A7F8 },
	{ 0xE78283, 0x2A7FA },
	{ 0xE78284, 0x2A7F5 },
	{ 0xE78285, 0x2A7F2 },
	{ 0xE78286, 0x2A7F4 },
	{ 0xE78287, 0x3A9F4 },
	{ 0xE78288, 0x3A9F0 },
	{ 0xE78289, 0x3A9F5 },
	{ 0xE7828A, 0x1CEE5 },
	{ 0xE7828B, 0x3A9EF },
	{ 0xE7828C, 0x3A9F9 },
	{ 0xE7828D, 0x3A9F6 },
	{ 0xE7828E, 0x1CEE3 },
	{ 0xE7828F, 0x3A9F2 },
	{ 0xE78290, 0x3A9F1 },
	{ 0xE78291, 0x2A7F6 },
	{ 0xE78292, 0x1CEE4 },
	{ 0xE78293, 0x2A7F3 },
	{ 0xE78294, 0x2A7F0 },
	{ 0xE78295, 0x1CEE2 },
	{ 0xE78296, 0x2A7F7 },
	{ 0xE78297, 0x4A7A9 },
	{ 0xE78298, 0x2A7F1 },
	{ 0xE78299, 0x1CEE6 },
	{ 0xE7829A, 0x2A7F9 },
	{ 0xE7829B, 0x4A7AB },
	{ 0xE7829F, 0x2ABEF },
	{ 0xE782A0, 0x3ADDE },
	{ 0xE782A1, 0x2ABF3 },
	{ 0xE782A2, 0x3ADDC },
	{ 0xE782A3, 0x3ADDA },
	{ 0xE782A4, 0x1D2BA },
	{ 0xE782A5, 0x3ADD8 },
	{ 0xE782A6, 0x4AAA6 },
	{ 0xE782A7, 0x3ADE5 },
	{ 0xE782A8, 0x3ADE2 },
	{ 0xE782A9, 0x2ABF6 },
	{ 0xE782AA, 0x3ADDF },
	{ 0xE782AB, 0x1D2B2 },
	{ 0xE782AC, 0x1D2B5 },
	{ 0xE782AD, 0x1D2B7 },
	{ 0xE782AE, 0x1D2B9 },
	{ 0xE782AF, 0x1D2B6 },
	{ 0xE782B0, 0x2ABF2 },
	{ 0xE782B1, 0x2ABF1 },
	{ 0xE782B2, 0x3ADE4 },
	{ 0xE782B3, 0x1D2B4 },
	{ 0xE782B4, 0x2ABF4 },
	{ 0xE782B5, 0x2ABF5 },
	{ 0xE782B6, 0x3ADE3 },
	{ 0xE782B7, 0x2ABEE },
	{ 0xE782B8, 0x1D2B8 },
	{ 0xE782B9, 0x3ADE8 },
	{ 0xE782BA, 0x1D2B3 },
	{ 0xE782BB, 0x3ADDD },
	{ 0xE782BE, 0x2ABF0 },
	{ 0xE782BF, 0x3E5CD },
	{ 0xE78380, 0x4AAA8 },
	{ 0xE78384, 0x3B2A8 },
	{ 0xE78385, 0x2B0DA },
	{ 0xE78386, 0x2B0DB },
	{ 0xE78387, 0x2B0DC },
	{ 0xE78388, 0x1D6D3 },
	{ 0xE78389, 0x4ADF5 },
	{ 0xE7838A, 0x1D6CF },
	{ 0xE7838B, 0x2B0D1 },
	{ 0xE7838C, 0x3B2AA },
	{ 0xE7838D, 0x2B0D9 },
	{ 0xE7838E, 0x2B0DE },
	{ 0xE7838F, 0x1D6D4 },
	{ 0xE78390, 0x3B2AB },
	{ 0xE78391, 0x2B0CF },
	{ 0xE78392, 0x2B0D5 },
	{ 0xE78393, 0x2B0CE },
	{ 0xE78394, 0x2B0D8 },
	{ 0xE78395, 0x3B2B1 },
	{ 0xE78396, 0x3B2AF },
	{ 0xE78397, 0x2B0D4 },
	{ 0xE78398, 0x1D6D0 },
	{ 0xE78399, 0x1D6D2 },
	{ 0xE7839A, 0x2B0DD },
	{ 0xE7839B, 0x3B2A9 },
	{ 0xE7839C, 0x2B0CD },
	{ 0xE7839D, 0x2B0D0 },
	{ 0xE7839E, 0x2B0D6 },
	{ 0xE7839F, 0x3B2AD },
	{ 0xE783A0, 0x2B0D7 },
	{ 0xE783A1, 0x2B0DF },
	{ 0xE783A2, 0x2B0D3 },
	{ 0xE783A3, 0x3B2AC },
	{ 0xE783A4, 0x1D6D1 },
	{ 0xE783A5, 0x3E5CF },
	{ 0xE783AA, 0x3E5CE },
	{ 0xE783AE, 0x3B2B0 },
	{ 0xE783AF, 0x1DBF2 },
	{ 0xE783B0, 0x2B6F1 },
	{ 0xE783B1, 0x3B7B0 },
	{ 0xE783B2, 0x3B7B2 },
	{ 0xE783B3, 0x2B6F3 },
	{ 0xE783B4, 0x2B6EF },
	{ 0xE783B5, 0x3B7AF },
	{ 0xE783B6, 0x2B6FB },
	{ 0xE783B7, 0x2B6ED },
	{ 0xE783B8, 0x2B6FA },
	{ 0xE783B9, 0x1DBEE },
	{ 0xE783BA, 0x2B6EB },
	{ 0xE783BB, 0x2BDDF },
	{ 0xE783BC, 0x2B6F5 },
	{ 0xE783BD, 0x1DBF1 },
	{ 0xE783BE, 0x3B7B5 },
	{ 0xE783BF, 0x2B6F6 },
	{ 0xE78480, 0x2B6F9 },
	{ 0xE78481, 0x3B7AE },
	{ 0xE78482, 0x2B6FD },
	{ 0xE78483, 0x3B7AC },
	{ 0xE78484, 0x2B6F2 },
	{ 0xE78485, 0x4B2F2 },
	{ 0xE78486, 0x2B6F7 },
	{ 0xE78487, 0x3B7AD },
	{ 0xE78488, 0x3B7B1 },
	{ 0xE78489, 0x1DBEF },
	{ 0xE7848A, 0x1DBF0 },
	{ 0xE7848B, 0x2B6FC },
	{ 0xE7848C, 0x2B6F0 },
	{ 0xE7848D, 0x2B6EC },
	{ 0xE7848E, 0x2B6FE },
	{ 0xE7848F, 0x3B7B3 },
	{ 0xE78490, 0x2B6F4 },
	{ 0xE78491, 0x3E5D0 },
	{ 0xE78492, 0x3E5D1 },
	{ 0xE78493, 0x2B6F8 },
	{ 0xE78497, 0x2B6EE },
	{ 0xE78499, 0x1E0CE },
	{ 0xE7849A, 0x1E0CF },
	{ 0xE7849B, 0x2BDE9 },
	{ 0xE7849C, 0x1E0D5 },
	{ 0xE7849D, 0x3BCF4 },
	{ 0xE7849E, 0x2BDDD },
	{ 0xE7849F, 0x2BDE6 },
	{ 0xE784A0, 0x2BDDC },
	{ 0xE784A1, 0x1E0D2 },
	{ 0xE784A2, 0x2BDE4 },
	{ 0xE784A3, 0x2BDE2 },
	{ 0xE784A4, 0x3BCFD },
	{ 0xE784A5, 0x2BDE3 },
	{ 0xE784A6, 0x1E0D0 },
	{ 0xE784A7, 0x3BCFC },
	{ 0xE784A8, 0x2BDE7 },
	{ 0xE784A9, 0xFBCFE },
	{ 0xE784AA, 0x3BCEF },
	{ 0xE784AB, 0x3BCFA },
	{ 0xE784AC, 0x3BCF2 },
	{ 0xE784AD, 0x3BDA1 },
	{ 0xE784AE, 0x2BDE0 },
	{ 0xE784AF, 0x2BDDE },
	{ 0xE784B0, 0x1E0D1 },
	{ 0xE784B1, 0x2BDE1 },
	{ 0xE784B2, 0x2BDE5 },
	{ 0xE784B3, 0x3BCFB },
	{ 0xE784B4, 0x3BCF9 },
	{ 0xE784B5, 0x3BCF1 },
	{ 0xE784B6, 0x1E0D3 },
	{ 0xE784B7, 0x3BCF3 },
	{ 0xE784B8, 0x3BCF7 },
	{ 0xE784B9, 0x3E5D3 },
	{ 0xE784BA, 0x2BDE8 },
	{ 0xE784BB, 0x3E5D4 },
	{ 0xE784BD, 0x3E5D5 },
	{ 0xE784BF, 0x3E5D2 },
	{ 0xE78581, 0x2C4D6 },
	{ 0xE78582, 0x2C4DD },
	{ 0xE78583, 0x2C4DF },
	{ 0xE78584, 0x2C4E5 },
	{ 0xE78585, 0x3C2D7 },
	{ 0xE78586, 0x1E5A2 },
	{ 0xE78587, 0x2C4D1 },
	{ 0xE78588, 0x3C2CC },
	{ 0xE78589, 0x1E4F8 },
	{ 0xE7858A, 0x3C2CE },
	{ 0xE7858B, 0x2C4E0 },
	{ 0xE7858C, 0x1E4FD },
	{ 0xE7858D, 0x2C4E6 },
	{ 0xE7858E, 0x1E4F4 },
	{ 0xE7858F, 0x3C2D1 },
	{ 0xE78590, 0x2C4E3 },
	{ 0xE78591, 0x3C2D8 },
	{ 0xE78592, 0x2C4D3 },
	{ 0xE78593, 0x2C4E4 },
	{ 0xE78594, 0x2C4D2 },
	{ 0xE78596, 0x1E5A4 },
	{ 0xE78597, 0x3C2D2 },
	{ 0xE78598, 0x2C4DE },
	{ 0xE78599, 0x1E4F5 },
	{ 0xE7859A, 0x2C4E7 },
	{ 0xE7859B, 0x3C8BC },
	{ 0xE7859C, 0x1E4FA },
	{ 0xE7859D, 0x2C4D7 },
	{ 0xE7859E, 0x1E5A1 },
	{ 0xE7859F, 0x2C4E2 },
	{ 0xE785A0, 0x2C4D5 },
	{ 0xE785A1, 0x2C4DC },
	{ 0xE785A2, 0x2C4D8 },
	{ 0xE785A3, 0x2C4D4 },
	{ 0xE785A4, 0x1E4F7 },
	{ 0xE785A5, 0x1E4FE },
	{ 0xE785A6, 0x1E4FC },
	{ 0xE785A7, 0x1E4F9 },
	{ 0xE785A8, 0x1E5A3 },
	{ 0xE785A9, 0x1E4F6 },
	{ 0xE785AA, 0x2C4DB },
	{ 0xE785AB, 0x3C2CF },
	{ 0xE785AC, 0x1E4FB },
	{ 0xE785AD, 0x3C2D9 },
	{ 0xE785AE, 0x1E0D4 },
	{ 0xE785AF, 0x3C2C9 },
	{ 0xE785B0, 0x2C4E1 },
	{ 0xE785B1, 0x3E5D9 },
	{ 0xE785B2, 0x2C4D9 },
	{ 0xE785B4, 0x3C2D3 },
	{ 0xE785B5, 0x3E5D7 },
	{ 0xE785B6, 0x3E5D8 },
	{ 0xE785B7, 0x3E5D6 },
	{ 0xE785B8, 0x2C4DA },
	{ 0xE785B9, 0x4C4D7 },
	{ 0xE785BA, 0x4C4DB },
	{ 0xE785BB, 0x2CBE7 },
	{ 0xE785BC, 0x3C7EF },
	{ 0xE785BD, 0x1E9DB },
	{ 0xE785BE, 0x3C7EE },
	{ 0xE785BF, 0x3C7EC },
	{ 0xE78680, 0x2CBE3 },
	{ 0xE78681, 0x2CBE9 },
	{ 0xE78682, 0x2CBE5 },
	{ 0xE78683, 0x3C7F0 },
	{ 0xE78684, 0x1E9DD },
	{ 0xE78685, 0x2CBE4 },
	{ 0xE78686, 0x2CBE8 },
	{ 0xE78687, 0x2CBE0 },
	{ 0xE78688, 0x3C7F2 },
	{ 0xE78689, 0x2CBE2 },
	{ 0xE7868A, 0x1E9DC },
	{ 0xE7868B, 0x3C7EA },
	{ 0xE7868C, 0x3C7ED },
	{ 0xE7868D, 0x3C7EB },
	{ 0xE7868E, 0x3C7E8 },
	{ 0xE7868F, 0x2CBE6 },
	{ 0xE78690, 0x2CBE1 },
	{ 0xE78691, 0x3C7E7 },
	{ 0xE78692, 0x1E9DE },
	{ 0xE78693, 0x3E5DB },
	{ 0xE78694, 0x1E9D9 },
	{ 0xE78695, 0xFC9CB },
	{ 0xE78696, 0x3E5DA },
	{ 0xE78697, 0x2CBEA },
	{ 0xE78698, 0xFC9DF },
	{ 0xE78699, 0x1E9DA },
	{ 0xE7869A, 0x2D1EF },
	{ 0xE7869B, 0x2D1EC },
	{ 0xE7869C, 0x2D1F8 },
	{ 0xE7869D, 0x2D1F2 },
	{ 0xE7869E, 0x2D1F4 },
	{ 0xE7869F, 0x1EDDE },
	{ 0xE786A0, 0x2D1EE },
	{ 0xE786A1, 0x2D1F6 },
	{ 0xE786A2, 0x3CDAA },
	{ 0xE786A3, 0x3CDA4 },
	{ 0xE786A4, 0x2D1F5 },
	{ 0xE786A5, 0x2D1F3 },
	{ 0xE786A6, 0x3CDA9 },
	{ 0xE786A7, 0x2D1F9 },
	{ 0xE786A8, 0x1EDE1 },
	{ 0xE786A9, 0x2D1F0 },
	{ 0xE786AA, 0x2D1F7 },
	{ 0xE786AB, 0x3CDA8 },
	{ 0xE786AC, 0x1EDDF },
	{ 0xE786AD, 0x3CDA5 },
	{ 0xE786AE, 0x3CDA2 },
	{ 0xE786AF, 0x2D1EB },
	{ 0xE786B0, 0x2D1ED },
	{ 0xE786B1, 0x1EDE0 },
	{ 0xE786B2, 0x2D1EA },
	{ 0xE786B3, 0x2D1FA },
	{ 0xE786B4, 0x3E5DC },
	{ 0xE786B5, 0x2D1F1 },
	{ 0xE786B6, 0x3D1E2 },
	{ 0xE786B7, 0x3D1DA },
	{ 0xE786B8, 0x2D8B6 },
	{ 0xE786B9, 0x1F1BB },
	{ 0xE786BA, 0x3D1E0 },
	{ 0xE786BB, 0x3D1DC },
	{ 0xE786BC, 0x2D8C1 },
	{ 0xE786BD, 0x2D8BF },
	{ 0xE786BE, 0x1F1B5 },
	{ 0xE786BF, 0x2D8B5 },
	{ 0xE78780, 0x2D8B8 },
	{ 0xE78781, 0x2D8B9 },
	{ 0xE78782, 0x2D8B4 },
	{ 0xE78783, 0x1F1BF },
	{ 0xE78784, 0x1F1C0 },
	{ 0xE78785, 0x2D8B3 },
	{ 0xE78786, 0x2D8C2 },
	{ 0xE78787, 0x2D8BD },
	{ 0xE78788, 0x1F1B9 },
	{ 0xE78789, 0x1F1B6 },
	{ 0xE7878A, 0x2D8BC },
	{ 0xE7878B, 0x2D8BA },
	{ 0xE7878C, 0x3D1E3 },
	{ 0xE7878D, 0x4D1A3 },
	{ 0xE7878E, 0x1F1BC },
	{ 0xE7878F, 0x2D8BE },
	{ 0xE78790, 0x1F1B7 },
	{ 0xE78791, 0x3D1DE },
	{ 0xE78792, 0x1F1B8 },
	{ 0xE78793, 0x3D1E6 },
	{ 0xE78794, 0x2D8BB },
	{ 0xE78795, 0x1F1BA },
	{ 0xE78796, 0x2D8B7 },
	{ 0xE78797, 0x7AFCF },
	{ 0xE78798, 0x2D8C0 },
	{ 0xE78799, 0x1F1BD },
	{ 0xE7879A, 0x2D8C3 },
	{ 0xE7879B, 0x2D8C4 },
	{ 0xE7879C, 0x1F1BE },
	{ 0xE7879D, 0x3E5DD },
	{ 0xE7879E, 0x3E5DE },
	{ 0xE7879F, 0x1F4B2 },
	{ 0xE787A0, 0x1F4B9 },
	{ 0xE787A1, 0x2DDC8 },
	{ 0xE787A2, 0x2DDCE },
	{ 0xE787A3, 0x3D5BC },
	{ 0xE787A4, 0x2DDCC },
	{ 0xE787A5, 0x1F4B5 },
	{ 0xE787A6, 0x1F4B4 },
	{ 0xE787A7, 0x1F4B1 },
	{ 0xE787A8, 0x2DDCA },
	{ 0xE787A9, 0x3D5BE },
	{ 0xE787AA, 0x3D5C3 },
	{ 0xE787AB, 0x3D5C0 },
	{ 0xE787AC, 0x1F4B7 },
	{ 0xE787AD, 0x1F4B6 },
	{ 0xE787AE, 0x1F4B3 },
	{ 0xE787AF, 0x3D5C1 },
	{ 0xE787B0, 0x2DDCD },
	{ 0xE787B1, 0x2DDC9 },
	{ 0xE787B2, 0x2DDCB },
	{ 0xE787B3, 0x3D5C2 },
	{ 0xE787B4, 0x1F4B8 },
	{ 0xE787B5, 0xFDAF3 },
	{ 0xE787B8, 0x1F6E3 },
	{ 0xE787B9, 0x2E2A9 },
	{ 0xE787BA, 0x3D8AD },
	{ 0xE787BB, 0x1F6E0 },
	{ 0xE787BC, 0x1F6E1 },
	{ 0xE787BD, 0x2E2AB },
	{ 0xE787BE, 0x1F6E2 },
	{ 0xE787BF, 0x2E2A8 },
	{ 0xE78880, 0x3D8AE },
	{ 0xE78881, 0x2E2A7 },
	{ 0xE78882, 0x2E5F6 },
	{ 0xE78883, 0x2E2AA },
	{ 0xE78884, 0x3DAD6 },
	{ 0xE78885, 0x2E5F7 },
	{ 0xE78886, 0x1F8C7 },
	{ 0xE78887, 0x2E5F5 },
	{ 0xE78888, 0x3DAD7 },
	{ 0xE78889, 0x4DFFE },
	{ 0xE7888A, 0x2E5F4 },
	{ 0xE7888B, 0x3DCD9 },
	{ 0xE7888C, 0x2E5F3 },
	{ 0xE7888D, 0x1F8C8 },
	{ 0xE7888E, 0x3E5DF },
	{ 0xE7888F, 0x3DCD6 },
	{ 0xE78890, 0x1F9F7 },
	{ 0xE78891, 0x3DCD8 },
	{ 0xE78892, 0x3DCD5 },
	{ 0xE78893, 0x2E9B9 },
	{ 0xE78894, 0x2E9BA },
	{ 0xE78895, 0x3DAD8 },
	{ 0xE78896, 0x3DCD3 },
	{ 0xE78897, 0x3DCD7 },
	{ 0xE78898, 0x3E5E1 },
	{ 0xE78899, 0x2EBEA },
	{ 0xE7889A, 0x2EBE9 },
	{ 0xE7889B, 0x1FAF5 },
	{ 0xE7889C, 0x3DFD3 },
	{ 0xE7889D, 0x2EBE8 },
	{ 0xE7889E, 0x2EDDA },
	{ 0xE7889F, 0x2EDDB },
	{ 0xE788A0, 0x3DFD4 },
	{ 0xE788A1, 0x3E0B9 },
	{ 0xE788A2, 0x2EFB5 },
	{ 0xE788A3, 0x2F0BF },
	{ 0xE788A4, 0x3E1C3 },
	{ 0xE788A5, 0x3E1C2 },
	{ 0xE788A6, 0x2F1A6 },
	{ 0xE788A7, 0x2F2AC },
	{ 0xE788A8, 0x1FDC6 },
	{ 0xE788A9, 0x2F2C0 },
	{ 0xE788AA, 0x1C5D7 },
	{ 0xE788AB, 0x4A1D1 },
	{ 0xE788AC, 0x1CEE7 },
	{ 0xE788AD, 0x1CEE8 },
	{ 0xE788AE, 0x3ADE9 },
	{ 0xE788AF, 0x4AAAA },
	{ 0xE788B0, 0x1D2BB },
	{ 0xE788B2, 0x3BDA2 },
	{ 0xE788B4, 0x4CAEC },
	{ 0xE788B5, 0x1F4BA },
	{ 0xE788B6, 0x1C5D8 },
	{ 0xE788B8, 0x1CEE9 },
	{ 0xE788B9, 0x1D6D5 },
	{ 0xE788BA, 0x1E5A5 },
	{ 0xE788BB, 0x1C5D9 },
	{ 0xE788BC, 0x3ADEB },
	{ 0xE788BD, 0x1DBF3 },
	{ 0xE788BE, 0x1E9DF },
	{ 0xE788BF, 0x2A1C2 },
	{ 0xE78980, 0x3A9FC },
	{ 0xE78981, 0x2ABF7 },
	{ 0xE78982, 0x2B0E0 },
	{ 0xE78983, 0x4BECC },
	{ 0xE78984, 0x2CBEB },
	{ 0xE78985, 0x4CAED },
	{ 0xE78986, 0x1F4BB },
	{ 0xE78987, 0x1C5DA },
	{ 0xE78988, 0x1CEEA },
	{ 0xE78989, 0x2ABF8 },
	{ 0xE7898A, 0x2ABF9 },
	{ 0xE7898B, 0x2BDEA },
	{ 0xE7898C, 0x1E0D6 },
	{ 0xE7898E, 0x3C2DD },
	{ 0xE7898F, 0x2C4E8 },
	{ 0xE78990, 0x3C2DC },
	{ 0xE78991, 0x3C2DB },
	{ 0xE78992, 0x1E5A6 },
	{ 0xE78993, 0x2CBEC },
	{ 0xE78994, 0x4C4DE },
	{ 0xE78995, 0x3CDAE },
	{ 0xE78996, 0x1EDE2 },
	{ 0xE78997, 0x3CDAD },
	{ 0xE78998, 0x1F8C9 },
	{ 0xE78999, 0x1C5DB },
	{ 0xE7899A, 0x2BDEB },
	{ 0xE7899B, 0x1C5DC },
	{ 0xE7899D, 0x1C8CA },
	{ 0xE7899E, 0x2A2E2 },
	{ 0xE7899F, 0x1C8C9 },
	{ 0xE789A0, 0x1CBA8 },
	{ 0xE789A1, 0x1CBA7 },
	{ 0xE789A2, 0x1CBA6 },
	{ 0xE789A3, 0x2A4E0 },
	{ 0xE789A4, 0x3A6E4 },
	{ 0xE789A5, 0x3AAA1 },
	{ 0xE789A6, 0x3AAA2 },
	{ 0xE789A7, 0x1CEEB },
	{ 0xE789A8, 0x3AAA3 },
	{ 0xE789A9, 0x1CEEC },
	{ 0xE789AA, 0x2A7FB },
	{ 0xE789AB, 0x4A7B1 },
	{ 0xE789AC, 0x2ABFA },
	{ 0xE789AD, 0x3ADED },
	{ 0xE789AE, 0x2ABFD },
	{ 0xE789AF, 0x1D2BD },
	{ 0xE789B0, 0x2ABFB },
	{ 0xE789B1, 0x4AAAF },
	{ 0xE789B2, 0x1D2BC },
	{ 0xE789B3, 0x2ABFC },
	{ 0xE789B4, 0x1D2BE },
	{ 0xE789B6, 0x2B0E3 },
	{ 0xE789B7, 0x2B0E2 },
	{ 0xE789B8, 0x2B0E1 },
	{ 0xE789B9, 0x1D6D6 },
	{ 0xE789BA, 0x3B2B6 },
	{ 0xE789BB, 0x2B7A2 },
	{ 0xE789BC, 0x2B7A3 },
	{ 0xE789BD, 0x1DBF4 },
	{ 0xE789BE, 0x2B7A1 },
	{ 0xE789BF, 0x2B7A4 },
	{ 0xE78A80, 0x1E0D8 },
	{ 0xE78A81, 0x1DBF5 },
	{ 0xE78A82, 0x3BDA4 },
	{ 0xE78A83, 0x3BDA3 },
	{ 0xE78A84, 0x1E0D7 },
	{ 0xE78A85, 0x2BDEF },
	{ 0xE78A86, 0x2BDEE },
	{ 0xE78A87, 0x3BDA5 },
	{ 0xE78A88, 0x2BDEC },
	{ 0xE78A89, 0x2BDED },
	{ 0xE78A8B, 0x2BDF0 },
	{ 0xE78A8C, 0x2C4EA },
	{ 0xE78A8D, 0x2C4E9 },
	{ 0xE78A8E, 0x2C4ED },
	{ 0xE78A8F, 0x4BECF },
	{ 0xE78A90, 0x2C4EC },
	{ 0xE78A91, 0x2C4EB },
	{ 0xE78A92, 0x1E9E0 },
	{ 0xE78A93, 0x2CBEF },
	{ 0xE78A94, 0x3C7F5 },
	{ 0xE78A95, 0x2CBEE },
	{ 0xE78A96, 0x1E9E1 },
	{ 0xE78A97, 0x2CBED },
	{ 0xE78A98, 0x2D1FB },
	{ 0xE78A99, 0x3CDAF },
	{ 0xE78A9A, 0x2D1FC },
	{ 0xE78A9B, 0x1EDE3 },
	{ 0xE78A9C, 0x4D1AD },
	{ 0xE78A9D, 0x2D8C5 },
	{ 0xE78A9E, 0x2D8C6 },
	{ 0xE78A9F, 0x5CEB7 },
	{ 0xE78AA1, 0x2E5FC },
	{ 0xE78AA2, 0x1F8CA },
	{ 0xE78AA3, 0x2E5FB },
	{ 0xE78AA4, 0x2E5FA },
	{ 0xE78AA5, 0x2E5F8 },
	{ 0xE78AA6, 0x2E5F9 },
	{ 0xE78AA7, 0x1FAF6 },
	{ 0xE78AA8, 0x2E9BB },
	{ 0xE78AA9, 0x2EDDC },
	{ 0xE78AAA, 0x2F1A7 },
	{ 0xE78AAB, 0x3E1FB },
	{ 0xE78AAC, 0x1C5DD },
	{ 0xE78AAD, 0x4A1B8 },
	{ 0xE78AAE, 0x2A1E4 },
	{ 0xE78AAF, 0x1C6E7 },
	{ 0xE78AB0, 0x2A1E5 },
	{ 0xE78AB1, 0x3A4AC },
	{ 0xE78AB2, 0x3A4AD },
	{ 0xE78AB3, 0x4A3A7 },
	{ 0xE78AB4, 0x2A2E3 },
	{ 0xE78AB5, 0x2A2E4 },
	{ 0xE78AB6, 0x3A6EB },
	{ 0xE78AB9, 0x3A6E9 },
	{ 0xE78ABA, 0x2A4E6 },
	{ 0xE78ABB, 0x3A6E6 },
	{ 0xE78ABC, 0x3A6E7 },
	{ 0xE78ABD, 0x2A4E2 },
	{ 0xE78ABE, 0x3A6EA },
	{ 0xE78ABF, 0x2A4E1 },
	{ 0xE78B80, 0x1CEED },
	{ 0xE78B81, 0x2A4E5 },
	{ 0xE78B82, 0x1CBAA },
	{ 0xE78B83, 0x2A4E3 },
	{ 0xE78B84, 0x1CBA9 },
	{ 0xE78B85, 0x2A4E7 },
	{ 0xE78B86, 0x2A4E4 },
	{ 0xE78B87, 0x3A6E8 },
	{ 0xE78B89, 0x2A8A1 },
	{ 0xE78B8A, 0x2ABFE },
	{ 0xE78B8B, 0x2A7FD },
	{ 0xE78B8C, 0x2A8A6 },
	{ 0xE78B8D, 0x3AAA6 },
	{ 0xE78B8E, 0x1CEEE },
	{ 0xE78B8F, 0x3AAAA },
	{ 0xE78B90, 0x1CEF1 },
	{ 0xE78B91, 0x2A8A7 },
	{ 0xE78B92, 0x2A8A3 },
	{ 0xE78B93, 0x3AAA7 },
	{ 0xE78B94, 0x2A8A4 },
	{ 0xE78B95, 0x4A7B6 },
	{ 0xE78B96, 0x2A7FC },
	{ 0xE78B97, 0x1CEF0 },
	{ 0xE78B98, 0x2A7FE },
	{ 0xE78B99, 0x1CEEF },
	{ 0xE78B9A, 0x2A8A5 },
	{ 0xE78B9B, 0x3AAA8 },
	{ 0xE78B9C, 0x2A8A2 },
	{ 0xE78B9D, 0x6ACFE },
	{ 0xE78B9F, 0x2ACA4 },
	{ 0xE78BA0, 0x1D2C0 },
	{ 0xE78BA1, 0x1D2C1 },
	{ 0xE78BA2, 0x3ADF5 },
	{ 0xE78BA3, 0x2ACA7 },
	{ 0xE78BA4, 0x2ACA1 },
	{ 0xE78BA5, 0x3ADF4 },
	{ 0xE78BA6, 0x2ACA6 },
	{ 0xE78BA7, 0x3ADF0 },
	{ 0xE78BA8, 0x2ACA2 },
	{ 0xE78BA9, 0x1D2BF },
	{ 0xE78BAA, 0x2ACA5 },
	{ 0xE78BAB, 0x2ACA3 },
	{ 0xE78BAC, 0x3ADF3 },
	{ 0xE78BAD, 0x3ADF1 },
	{ 0xE78BB3, 0x2B0E9 },
	{ 0xE78BB4, 0x2B0E6 },
	{ 0xE78BB5, 0x3B2B8 },
	{ 0xE78BB6, 0x2B0E8 },
	{ 0xE78BB7, 0x1D6DB },
	{ 0xE78BB8, 0x1D6DA },
	{ 0xE78BB9, 0x1D6D8 },
	{ 0xE78BBA, 0x2B0E5 },
	{ 0xE78BBB, 0x2B0EA },
	{ 0xE78BBC, 0x1D6D7 },
	{ 0xE78BBD, 0x1D6D9 },
	{ 0xE78BBE, 0x2B0E7 },
	{ 0xE78BBF, 0x2B7AC },
	{ 0xE78C80, 0x2B0E4 },
	{ 0xE78C81, 0x2B0EB },
	{ 0xE78C82, 0x3B2B9 },
	{ 0xE78C84, 0x4B3A3 },
	{ 0xE78C85, 0x4B3AA },
	{ 0xE78C86, 0x3BDA6 },
	{ 0xE78C87, 0x2B7A7 },
	{ 0xE78C88, 0x2B7AB },
	{ 0xE78C89, 0x5B3D4 },
	{ 0xE78C8A, 0x2B7AA },
	{ 0xE78C8B, 0x2BDF2 },
	{ 0xE78C8C, 0x2BDFD },
	{ 0xE78C8D, 0x4B3AD },
	{ 0xE78C8E, 0x3B7BB },
	{ 0xE78C8F, 0x2B7AD },
	{ 0xE78C90, 0x3B7BA },
	{ 0xE78C91, 0x2B7A8 },
	{ 0xE78C92, 0x2BDF1 },
	{ 0xE78C93, 0x1DBF9 },
	{ 0xE78C94, 0x4B3A2 },
	{ 0xE78C95, 0x4B3AC },
	{ 0xE78C96, 0x1DBF8 },
	{ 0xE78C97, 0x2B7A6 },
	{ 0xE78C98, 0x2B7A9 },
	{ 0xE78C99, 0x1DBFA },
	{ 0xE78C9A, 0x3B7B9 },
	{ 0xE78C9B, 0x1DBF7 },
	{ 0xE78C9C, 0x1DBF6 },
	{ 0xE78C9D, 0x2B7A5 },
	{ 0xE78C9E, 0x2B7AE },
	{ 0xE78CA2, 0x2BDF4 },
	{ 0xE78CA3, 0x2BDFB },
	{ 0xE78CA4, 0x3BDA7 },
	{ 0xE78CA5, 0x1E0DA },
	{ 0xE78CA6, 0x2BDFA },
	{ 0xE78CA7, 0x2BDF7 },
	{ 0xE78CA8, 0x3BDAE },
	{ 0xE78CA9, 0x1E0DC },
	{ 0xE78CAA, 0x3BDA9 },
	{ 0xE78CAB, 0x3BDAB },
	{ 0xE78CAC, 0x3BDAA },
	{ 0xE78CAD, 0x2BDF9 },
	{ 0xE78CAE, 0x3C2E1 },
	{ 0xE78CAF, 0x3BDAD },
	{ 0xE78CB0, 0x2BDF3 },
	{ 0xE78CB1, 0x2BDF5 },
	{ 0xE78CB2, 0x2BDF8 },
	{ 0xE78CB3, 0x2BDF6 },
	{ 0xE78CB4, 0x1E0DB },
	{ 0xE78CB5, 0x2BDFC },
	{ 0xE78CB6, 0x1E0D9 },
	{ 0xE78CB7, 0x1E5A7 },
	{ 0xE78CB8, 0x3BDA8 },
	{ 0xE78CBA, 0x2C4F1 },
	{ 0xE78CBB, 0x2C4F0 },
	{ 0xE78CBC, 0x2C4EE },
	{ 0xE78CBD, 0x6D4FC },
	{ 0xE78CBE, 0x1E5AA },
	{ 0xE78CBF, 0x1E5A9 },
	{ 0xE78D80, 0x2C4F2 },
	{ 0xE78D81, 0x3C2DF },
	{ 0xE78D82, 0x2C4EF },
	{ 0xE78D83, 0x2CBF0 },
	{ 0xE78D84, 0x1E9E2 },
	{ 0xE78D85, 0x1E5A8 },
	{ 0xE78D86, 0x3C2E2 },
	{ 0xE78D87, 0x3E5E2 },
	{ 0xE78D88, 0x3E5E3 },
	{ 0xE78D89, 0x2C4F4 },
	{ 0xE78D8A, 0x2C4F3 },
	{ 0xE78D8B, 0x3CDB0 },
	{ 0xE78D8C, 0x2CBF3 },
	{ 0xE78D8D, 0x2CBF1 },
	{ 0xE78D8E, 0x1EDE4 },
	{ 0xE78D8F, 0x3C7F9 },
	{ 0xE78D90, 0x1E9E3 },
	{ 0xE78D91, 0x2CBF2 },
	{ 0xE78D92, 0x2D1FE },
	{ 0xE78D93, 0x3C7F8 },
	{ 0xE78D94, 0x3C7FA },
	{ 0xE78D95, 0x3C7F7 },
	{ 0xE78D96, 0x4CAF7 },
	{ 0xE78D97, 0x1EDE5 },
	{ 0xE78D98, 0x2D1FD },
	{ 0xE78D99, 0x2D2A8 },
	{ 0xE78D9A, 0x2D2A7 },
	{ 0xE78D9B, 0x2D2A5 },
	{ 0xE78D9C, 0x4CAF5 },
	{ 0xE78D9D, 0x2D2A4 },
	{ 0xE78D9E, 0x2D2A1 },
	{ 0xE78D9F, 0x2D2A2 },
	{ 0xE78DA0, 0x2D2A3 },
	{ 0xE78DA1, 0x2D2A6 },
	{ 0xE78DA2, 0x2D2A9 },
	{ 0xE78DA5, 0x2D8CB },
	{ 0xE78DA6, 0x2D8C8 },
	{ 0xE78DA7, 0x2D8C9 },
	{ 0xE78DA8, 0x1F1C1 },
	{ 0xE78DA9, 0x2D8C7 },
	{ 0xE78DAA, 0x2D8CD },
	{ 0xE78DAB, 0x2D8CC },
	{ 0xE78DAC, 0x2D8CA },
	{ 0xE78DAE, 0x2DDD0 },
	{ 0xE78DAF, 0x2DDD1 },
	{ 0xE78DB0, 0x1F4BC },
	{ 0xE78DB1, 0x3D5C9 },
	{ 0xE78DB2, 0x1F4BD },
	{ 0xE78DB3, 0x2DDCF },
	{ 0xE78DB4, 0x4D6EC },
	{ 0xE78DB5, 0x1F6E5 },
	{ 0xE78DB6, 0x2E2AC },
	{ 0xE78DB7, 0x1F6E4 },
	{ 0xE78DB8, 0x1F8CB },
	{ 0xE78DB9, 0x4E0A5 },
	{ 0xE78DBA, 0x1F8CC },
	{ 0xE78DBB, 0x1F9F8 },
	{ 0xE78DBC, 0x2E9BD },
	{ 0xE78DBD, 0x2E9BC },
	{ 0xE78DBE, 0x2EBEB },
	{ 0xE78DBF, 0x2EDDD },
	{ 0xE78E80, 0x1FBE6 },
	{ 0xE78E81, 0x2EFB7 },
	{ 0xE78E82, 0x2EFB6 },
	{ 0xE78E83, 0x2EFB8 },
	{ 0xE78E84, 0x1C6E8 },
	{ 0xE78E85, 0x2ACA8 },
	{ 0xE78E86, 0x1D6DC },
	{ 0xE78E87, 0x1DBFB },
	{ 0xE78E88, 0x2B7AF },
	{ 0xE78E89, 0x1C6E9 },
	{ 0xE78E8A, 0x2A1E6 },
	{ 0xE78E8B, 0x1C5DE },
	{ 0xE78E8C, 0x3A2DA },
	{ 0xE78E8D, 0x3A1EB },
	{ 0xE78E8E, 0x2A2E5 },
	{ 0xE78E8F, 0x3A4AF },
	{ 0xE78E90, 0x4A3AA },
	{ 0xE78E91, 0xFA2E6 },
	{ 0xE78E92, 0x2A4EC },
	{ 0xE78E93, 0x2A4EA },
	{ 0xE78E94, 0x2A4EB },
	{ 0xE78E95, 0x2A4E8 },
	{ 0xE78E96, 0x1CBAB },
	{ 0xE78E97, 0x2A4E9 },
	{ 0xE78E98, 0x3A6EE },
	{ 0xE78E9C, 0x3AAB3 },
	{ 0xE78E9D, 0x2A8AF },
	{ 0xE78E9E, 0x3AAAD },
	{ 0xE78E9F, 0x1CEF4 },
	{ 0xE78EA0, 0x2A8AD },
	{ 0xE78EA1, 0x2A8A9 },
	{ 0xE78EA2, 0x2A8AC },
	{ 0xE78EA3, 0x3AAAC },
	{ 0xE78EA4, 0x2A8A8 },
	{ 0xE78EA5, 0x1CEF6 },
	{ 0xE78EA6, 0x2A8AB },
	{ 0xE78EA7, 0x3AAAB },
	{ 0xE78EA8, 0x1CEF3 },
	{ 0xE78EA9, 0x1CEF2 },
	{ 0xE78EAA, 0x3AAB2 },
	{ 0xE78EAB, 0x1CEF5 },
	{ 0xE78EAC, 0x2A8AE },
	{ 0xE78EAD, 0x2A8AA },
	{ 0xE78EAF, 0x3AAAF },
	{ 0xE78EB2, 0x1D2C5 },
	{ 0xE78EB3, 0x1D2C8 },
	{ 0xE78EB4, 0x2ACB0 },
	{ 0xE78EB5, 0x2ACAF },
	{ 0xE78EB6, 0x2ACAE },
	{ 0xE78EB7, 0x1D2C2 },
	{ 0xE78EB8, 0x2ACB7 },
	{ 0xE78EB9, 0x2ACAD },
	{ 0xE78EBA, 0x4AEAA },
	{ 0xE78EBB, 0x1D2C4 },
	{ 0xE78EBC, 0x2B0F0 },
	{ 0xE78EBD, 0x3ADF8 },
	{ 0xE78EBE, 0x2ACB4 },
	{ 0xE78EBF, 0x2ACB2 },
	{ 0xE78F80, 0x1D2C7 },
	{ 0xE78F81, 0x3ADFB },
	{ 0xE78F82, 0x2ACAA },
	{ 0xE78F83, 0x2ACB5 },
	{ 0xE78F84, 0x3ADF7 },
	{ 0xE78F85, 0x2ACAC },
	{ 0xE78F86, 0x2ACB6 },
	{ 0xE78F87, 0x2ACB3 },
	{ 0xE78F88, 0x2ACAB },
	{ 0xE78F89, 0x3ADFA },
	{ 0xE78F8A, 0x1D2C3 },
	{ 0xE78F8B, 0x2ACB8 },
	{ 0xE78F8C, 0x2ACA9 },
	{ 0xE78F8D, 0x1D2C6 },
	{ 0xE78F8E, 0x3ADFE },
	{ 0xE78F8F, 0x3ADF9 },
	{ 0xE78F90, 0x3ADFC },
	{ 0xE78F92, 0x2B0F5 },
	{ 0xE78F93, 0x2B0EC },
	{ 0xE78F94, 0x2B0F7 },
	{ 0xE78F95, 0x3B2BE },
	{ 0xE78F96, 0x2B0EF },
	{ 0xE78F97, 0x2B0FA },
	{ 0xE78F98, 0x2B0FB },
	{ 0xE78F99, 0x2B0ED },
	{ 0xE78F9A, 0x2B0F9 },
	{ 0xE78F9B, 0x2B0F6 },
	{ 0xE78F9C, 0x2B0F4 },
	{ 0xE78F9D, 0x2B0F8 },
	{ 0xE78F9E, 0x1D6E2 },
	{ 0xE78F9F, 0x3B2C0 },
	{ 0xE78FA0, 0x1D6E0 },
	{ 0xE78FA1, 0x3B2C7 },
	{ 0xE78FA2, 0x3B2BC },
	{ 0xE78FA3, 0x2B0F2 },
	{ 0xE78FA4, 0x3B2C6 },
	{ 0xE78FA5, 0x2B0EE },
	{ 0xE78FA6, 0x3B2C1 },
	{ 0xE78FA7, 0x2B0F1 },
	{ 0xE78FA8, 0x2B0FC },
	{ 0xE78FA9, 0x2B0F3 },
	{ 0xE78FAA, 0x1D6E1 },
	{ 0xE78FAB, 0x2ACB1 },
	{ 0xE78FAC, 0x3B2BD },
	{ 0xE78FAD, 0x1D6DD },
	{ 0xE78FAE, 0x1D6DF },
	{ 0xE78FAF, 0x3E5E4 },
	{ 0xE78FB3, 0x3B7BD },
	{ 0xE78FB4, 0x2B7BD },
	{ 0xE78FB5, 0x2B7B2 },
	{ 0xE78FB6, 0x2B7B0 },
	{ 0xE78FB7, 0x3BDB8 },
	{ 0xE78FB8, 0x2B7B1 },
	{ 0xE78FB9, 0x3B2BF },
	{ 0xE78FBA, 0x2B7B8 },
	{ 0xE78FBB, 0x3B7C0 },
	{ 0xE78FBC, 0x2B7B9 },
	{ 0xE78FBD, 0x2B7B5 },
	{ 0xE78FBE, 0x1DCA2 },
	{ 0xE78FBF, 0x2B7BA },
	{ 0xE79080, 0x2B7B7 },
	{ 0xE79081, 0x2B7B4 },
	{ 0xE79082, 0x3B7BC },
	{ 0xE79083, 0x1DBFE },
	{ 0xE79084, 0x2B7B3 },
	{ 0xE79085, 0x1DBFC },
	{ 0xE79086, 0x1DCA1 },
	{ 0xE79087, 0x2B7B6 },
	{ 0xE79088, 0x2B7BE },
	{ 0xE79089, 0x1D6DE },
	{ 0xE7908A, 0x1DBFD },
	{ 0xE7908B, 0x2B7BC },
	{ 0xE7908C, 0x2B7BB },
	{ 0xE7908D, 0x1DCA3 },
	{ 0xE79092, 0x3E5E5 },
	{ 0xE79093, 0xFB6D7 },
	{ 0xE79094, 0x3BDB6 },
	{ 0xE79095, 0x3BDBA },
	{ 0xE79096, 0x2BEA4 },
	{ 0xE79097, 0x3BDAF },
	{ 0xE79098, 0x3BDBB },
	{ 0xE79099, 0x3BDB2 },
	{ 0xE7909A, 0x2BEA5 },
	{ 0xE7909B, 0x1E0E6 },
	{ 0xE7909C, 0x3BDB9 },
	{ 0xE7909D, 0x2BEAB },
	{ 0xE7909E, 0x3C2ED },
	{ 0xE7909F, 0x3BDB5 },
	{ 0xE790A0, 0x2BEAD },
	{ 0xE790A1, 0x2BEA6 },
	{ 0xE790A2, 0x1E0E0 },
	{ 0xE790A3, 0x2BEAA },
	{ 0xE790A4, 0x2BEA9 },
	{ 0xE790A5, 0x1E0E1 },
	{ 0xE790A6, 0x1E0E7 },
	{ 0xE790A7, 0x3C2E4 },
	{ 0xE790A8, 0x1E0E8 },
	{ 0xE790A9, 0x2BEAC },
	{ 0xE790AA, 0x1E0DE },
	{ 0xE790AB, 0x2BEA3 },
	{ 0xE790AC, 0x2BEA1 },
	{ 0xE790AD, 0x2BEA7 },
	{ 0xE790AE, 0x2BDFE },
	{ 0xE790AF, 0x1E0E5 },
	{ 0xE790B0, 0x2BEA2 },
	{ 0xE790B1, 0x2BEA8 },
	{ 0xE790B2, 0x2BEAE },
	{ 0xE790B3, 0x1E0DF },
	{ 0xE790B4, 0x1E0E4 },
	{ 0xE790B5, 0x1E0E2 },
	{ 0xE790B6, 0x1E0E3 },
	{ 0xE790B8, 0x3BDB3 },
	{ 0xE790B9, 0x3BDBC },
	{ 0xE790BA, 0x1E0DD },
	{ 0xE790BB, 0x3E5E6 },
	{ 0xE790BC, 0x3BDB7 },
	{ 0xE790BD, 0x3C2E8 },
	{ 0xE790BE, 0x3C2F5 },
	{ 0xE790BF, 0x1E5B1 },
	{ 0xE79180, 0x2C4FB },
	{ 0xE79181, 0x1E5B0 },
	{ 0xE79182, 0x2C5A1 },
	{ 0xE79183, 0x3C2EF },
	{ 0xE79184, 0x2C4F5 },
	{ 0xE79185, 0x3C2F4 },
	{ 0xE79186, 0x2C5A2 },
	{ 0xE79187, 0x3C2EE },
	{ 0xE79188, 0x3C2E6 },
	{ 0xE79189, 0x3C2F1 },
	{ 0xE7918A, 0x2C4F6 },
	{ 0xE7918B, 0x2C4F7 },
	{ 0xE7918C, 0x3C2F3 },
	{ 0xE7918D, 0x2C5A3 },
	{ 0xE7918E, 0x2C4FE },
	{ 0xE7918F, 0x2C4FC },
	{ 0xE79190, 0x2C4FD },
	{ 0xE79191, 0x2C4F9 },
	{ 0xE79192, 0x2C4F8 },
	{ 0xE79193, 0x3C2E7 },
	{ 0xE79194, 0x2C5A4 },
	{ 0xE79195, 0x1E5AD },
	{ 0xE79196, 0x3C2EB },
	{ 0xE79197, 0x2C4FA },
	{ 0xE79198, 0x3C2F0 },
	{ 0xE79199, 0x1E5B2 },
	{ 0xE7919A, 0x1E5AC },
	{ 0xE7919B, 0x1E5B3 },
	{ 0xE7919C, 0x1E5B4 },
	{ 0xE7919D, 0x3C2EA },
	{ 0xE7919E, 0x1E5AF },
	{ 0xE7919F, 0x1E5AE },
	{ 0xE791A0, 0x3C8A5 },
	{ 0xE791A1, 0x3C7FE },
	{ 0xE791A2, 0x2CBF4 },
	{ 0xE791A3, 0x1E9E5 },
	{ 0xE791A4, 0x1E9E4 },
	{ 0xE791A5, 0x3C7FC },
	{ 0xE791A6, 0x3C7FD },
	{ 0xE791A7, 0x2CBF9 },
	{ 0xE791A8, 0x3C8A2 },
	{ 0xE791A9, 0x1EDE6 },
	{ 0xE791AA, 0x1E9E6 },
	{ 0xE791AB, 0x3C8A1 },
	{ 0xE791AC, 0x3C7FB },
	{ 0xE791AD, 0x1E9E8 },
	{ 0xE791AE, 0x2CBFA },
	{ 0xE791AF, 0x1E5AB },
	{ 0xE791B0, 0x1E9E7 },
	{ 0xE791B1, 0x2CBF6 },
	{ 0xE791B2, 0x2CBF8 },
	{ 0xE791B3, 0x2CBF5 },
	{ 0xE791B4, 0x3C8A7 },
	{ 0xE791B5, 0x2CBF7 },
	{ 0xE791B6, 0x3C8A3 },
	{ 0xE791B8, 0xFC9F6 },
	{ 0xE791B9, 0x2D2B3 },
	{ 0xE791BA, 0x3CDB1 },
	{ 0xE791BB, 0x3CDBB },
	{ 0xE791BC, 0x2D2B2 },
	{ 0xE791BD, 0x2D2AF },
	{ 0xE791BE, 0x1EDE9 },
	{ 0xE791BF, 0x2D8CE },
	{ 0xE79280, 0x1EDEA },
	{ 0xE79281, 0x2D2AE },
	{ 0xE79282, 0x3CDB9 },
	{ 0xE79283, 0x1EDE8 },
	{ 0xE79284, 0x3CDB6 },
	{ 0xE79285, 0x2D2B0 },
	{ 0xE79286, 0x2D2AD },
	{ 0xE79287, 0x2D2AA },
	{ 0xE79288, 0x2D2B1 },
	{ 0xE79289, 0x2D2AB },
	{ 0xE7928A, 0x2D2AC },
	{ 0xE7928B, 0x1EDE7 },
	{ 0xE7928C, 0x3CDB5 },
	{ 0xE7928D, 0x3E5E8 },
	{ 0xE7928F, 0x4D1B9 },
	{ 0xE79290, 0x2DDD5 },
	{ 0xE79291, 0x4D1BA },
	{ 0xE79292, 0x2D8D2 },
	{ 0xE79293, 0x3CDBA },
	{ 0xE79294, 0x2D8D1 },
	{ 0xE79295, 0x2D8D3 },
	{ 0xE79296, 0x3D1EA },
	{ 0xE79297, 0x2DDD2 },
	{ 0xE79298, 0x1F1C4 },
	{ 0xE79299, 0x4D1B8 },
	{ 0xE7929A, 0x2D8CF },
	{ 0xE7929B, 0x3D1E7 },
	{ 0xE7929C, 0x1F1C2 },
	{ 0xE7929D, 0x3D1EC },
	{ 0xE7929E, 0x1F1C6 },
	{ 0xE7929F, 0x1F1C5 },
	{ 0xE792A0, 0x2D8D0 },
	{ 0xE792A1, 0x2D8D4 },
	{ 0xE792A2, 0x3D1EB },
	{ 0xE792A3, 0x1F1C3 },
	{ 0xE792A4, 0x3E5E7 },
	{ 0xE792A5, 0x2DDD9 },
	{ 0xE792A6, 0x1F4C0 },
	{ 0xE792A7, 0x1F6E6 },
	{ 0xE792A8, 0x1F4C1 },
	{ 0xE792A9, 0x1F4BE },
	{ 0xE792AA, 0x2DDD6 },
	{ 0xE792AB, 0x2DDD4 },
	{ 0xE792AC, 0x3D5CF },
	{ 0xE792AD, 0x2DDD7 },
	{ 0xE792AE, 0x3D5CB },
	{ 0xE792AF, 0x2DDDA },
	{ 0xE792B0, 0x1F4BF },
	{ 0xE792B1, 0x2DDD8 },
	{ 0xE792B2, 0x2DDD3 },
	{ 0xE792B3, 0x3D5CD },
	{ 0xE792B4, 0x3E5E9 },
	{ 0xE792B5, 0x2E2AF },
	{ 0xE792B6, 0x2E2B2 },
	{ 0xE792B7, 0x2E6A1 },
	{ 0xE792B8, 0x2E2AD },
	{ 0xE792B9, 0x3D8AF },
	{ 0xE792BA, 0x2E9BE },
	{ 0xE792BB, 0x2E2B3 },
	{ 0xE792BC, 0x3D8B0 },
	{ 0xE792BD, 0x1F8CD },
	{ 0xE792BE, 0x2E2B1 },
	{ 0xE792BF, 0x1F6E7 },
	{ 0xE79380, 0x2E2AE },
	{ 0xE79381, 0x2E2B0 },
	{ 0xE79382, 0x2E2B4 },
	{ 0xE79383, 0x2E6A2 },
	{ 0xE79384, 0x3DADA },
	{ 0xE79385, 0x2E5FE },
	{ 0xE79386, 0x4E0A7 },
	{ 0xE79387, 0x3DADC },
	{ 0xE79388, 0x3DADD },
	{ 0xE79389, 0x3DADB },
	{ 0xE7938A, 0x1F8CE },
	{ 0xE7938B, 0x2E5FD },
	{ 0xE7938C, 0x3DCDE },
	{ 0xE7938D, 0x3DCDC },
	{ 0xE7938E, 0x3DCDF },
	{ 0xE7938F, 0x1F9F9 },
	{ 0xE79390, 0x3DCDD },
	{ 0xE79391, 0x3DCE0 },
	{ 0xE79393, 0x3DEBD },
	{ 0xE79394, 0x1FAF8 },
	{ 0xE79395, 0x2EDDF },
	{ 0xE79396, 0x1FAF7 },
	{ 0xE79397, 0x2EDE1 },
	{ 0xE79398, 0x2EDDE },
	{ 0xE79399, 0x2EDE0 },
	{ 0xE7939A, 0x1FCBC },
	{ 0xE7939B, 0x2F0C0 },
	{ 0xE7939C, 0x1C6EA },
	{ 0xE7939D, 0x2A8B0 },
	{ 0xE7939E, 0x2B0FD },
	{ 0xE7939F, 0x2B0FE },
	{ 0xE793A0, 0x1DCA4 },
	{ 0xE793A1, 0x2C5A5 },
	{ 0xE793A2, 0x1F1C7 },
	{ 0xE793A3, 0x1F8CF },
	{ 0xE793A4, 0x1FBE7 },
	{ 0xE793A5, 0x2F0C1 },
	{ 0xE793A6, 0x1C6EB },
	{ 0xE793A8, 0x2A8B1 },
	{ 0xE793A9, 0x1A3A2 },
	{ 0xE793AA, 0x4AABC },
	{ 0xE793AB, 0x3AEA2 },
	{ 0xE793AC, 0x2ACB9 },
	{ 0xE793AD, 0x3AEA1 },
	{ 0xE793AE, 0x2ACBA },
	{ 0xE793AF, 0x3AEA4 },
	{ 0xE793B3, 0x3B2C8 },
	{ 0xE793B4, 0x2B1A1 },
	{ 0xE793B5, 0x2B1A2 },
	{ 0xE793B6, 0x1DCA5 },
	{ 0xE793B7, 0x1DCA6 },
	{ 0xE793B8, 0xFB6E7 },
	{ 0xE793B9, 0x3BDBD },
	{ 0xE793BA, 0x4B9A5 },
	{ 0xE793BB, 0x2BEAF },
	{ 0xE793BD, 0x2C5A8 },
	{ 0xE793BE, 0x2C5A7 },
	{ 0xE793BF, 0x2C5A6 },
	{ 0xE79480, 0x2CBFB },
	{ 0xE79481, 0x3C2F7 },
	{ 0xE79482, 0x2CBFC },
	{ 0xE79483, 0x2CBFD },
	{ 0xE79484, 0x1E9E9 },
	{ 0xE79486, 0x3C8A8 },
	{ 0xE79487, 0x2D2B5 },
	{ 0xE79488, 0x2D2B4 },
	{ 0xE79489, 0x3CDBD },
	{ 0xE7948A, 0x3D1ED },
	{ 0xE7948B, 0x2D8D5 },
	{ 0xE7948C, 0x1F1C8 },
	{ 0xE7948D, 0x1F1C9 },
	{ 0xE7948E, 0x3D1EE },
	{ 0xE7948F, 0x2DDDE },
	{ 0xE79490, 0x2DDDB },
	{ 0xE79491, 0x2DDDC },
	{ 0xE79492, 0x2DDDD },
	{ 0xE79493, 0x2E2B6 },
	{ 0xE79494, 0x2E2B5 },
	{ 0xE79495, 0x1F6E8 },
	{ 0xE79496, 0x2E6A3 },
	{ 0xE79497, 0x2EBEC },
	{ 0xE79498, 0x1C6EC },
	{ 0xE7949A, 0x1D2C9 },
	{ 0xE7949B, 0x3B7C4 },
	{ 0xE7949C, 0x1DCA7 },
	{ 0xE7949D, 0x2C5A9 },
	{ 0xE7949E, 0x3C2F8 },
	{ 0xE7949F, 0x1C6ED },
	{ 0xE794A0, 0x4AAC0 },
	{ 0xE794A1, 0x2B1A3 },
	{ 0xE794A2, 0x1DCA8 },
	{ 0xE794A3, 0x3B7C5 },
	{ 0xE794A4, 0x3BDBE },
	{ 0xE794A5, 0x1E0E9 },
	{ 0xE794A6, 0x1E0EA },
	{ 0xE794A7, 0x5C7C9 },
	{ 0xE794A8, 0x1C6EE },
	{ 0xE794A9, 0x1C6EF },
	{ 0xE794AA, 0x2A2E6 },
	{ 0xE794AB, 0x1CBAD },
	{ 0xE794AC, 0x1CBAC },
	{ 0xE794AD, 0x1D2CA },
	{ 0xE794AE, 0x2ACBB },
	{ 0xE794AF, 0x2BEB0 },
	{ 0xE794B0, 0x1C6F0 },
	{ 0xE794B1, 0x1C6F1 },
	{ 0xE794B2, 0x1C6F2 },
	{ 0xE794B3, 0x1C6F3 },
	{ 0xE794B6, 0x4A3AB },
	{ 0xE794B7, 0x1CBAE },
	{ 0xE794B8, 0x1CBAF },
	{ 0xE794B9, 0x2A4EE },
	{ 0xE794BA, 0x2A4ED },
	{ 0xE794BB, 0x3AAB7 },
	{ 0xE794BD, 0x1CEF7 },
	{ 0xE794BE, 0x2A8B4 },
	{ 0xE794BF, 0x2A8B2 },
	{ 0xE79580, 0x2A8B3 },
	{ 0xE79581, 0x3AAB8 },
	{ 0xE79582, 0x3AAB5 },
	{ 0xE79583, 0x4A7C0 },
	{ 0xE79584, 0x3AAB6 },
	{ 0xE79586, 0x3AEA7 },
	{ 0xE79587, 0x2ACBC },
	{ 0xE79588, 0x2ACBD },
	{ 0xE79589, 0x3AEA5 },
	{ 0xE7958A, 0x3AEA8 },
	{ 0xE7958B, 0x1D2CE },
	{ 0xE7958C, 0x1D2CC },
	{ 0xE7958D, 0x3AEAA },
	{ 0xE7958E, 0x1D2CD },
	{ 0xE7958F, 0x1D2CB },
	{ 0xE79590, 0x3AEA6 },
	{ 0xE79591, 0xFABFA },
	{ 0xE79593, 0xFACCA },
	{ 0xE79594, 0x1D6E3 },
	{ 0xE79595, 0x3B2CE },
	{ 0xE79596, 0x3B2CD },
	{ 0xE79597, 0x3B2D0 },
	{ 0xE79598, 0x3B2CF },
	{ 0xE79599, 0x1D6E7 },
	{ 0xE7959A, 0x1D6E6 },
	{ 0xE7959B, 0x2B1A4 },
	{ 0xE7959C, 0x1D6E5 },
	{ 0xE7959D, 0x1D6E4 },
	{ 0xE7959E, 0x3B2D1 },
	{ 0xE7959F, 0x2B1A5 },
	{ 0xE795A1, 0x3B7C6 },
	{ 0xE795A2, 0x1DCAB },
	{ 0xE795A3, 0x2B7C0 },
	{ 0xE795A4, 0x2B7BF },
	{ 0xE795A5, 0x1DCA9 },
	{ 0xE795A6, 0x1DCAA },
	{ 0xE795A7, 0x3B7C9 },
	{ 0xE795A8, 0x3B7C7 },
	{ 0xE795AA, 0x1E0EC },
	{ 0xE795AB, 0x1E0EB },
	{ 0xE795AC, 0x2BEB2 },
	{ 0xE795AD, 0x3BDC3 },
	{ 0xE795AE, 0x3BDC2 },
	{ 0xE795AF, 0x2BEB1 },
	{ 0xE795B0, 0x1DCAC },
	{ 0xE795B1, 0x3BDC4 },
	{ 0xE795B2, 0x4B9AC },
	{ 0xE795B5, 0x4BEEB },
	{ 0xE795B6, 0x1E5B5 },
	{ 0xE795B7, 0x2C5AB },
	{ 0xE795B8, 0x1E5B6 },
	{ 0xE795B9, 0x2C5AA },
	{ 0xE795BA, 0x3C2FB },
	{ 0xE795BB, 0x4C4FC },
	{ 0xE795BC, 0x4C4FB },
	{ 0xE795BD, 0x2CBFE },
	{ 0xE795BE, 0x2D2B6 },
	{ 0xE795BF, 0x1EDEB },
	{ 0xE79680, 0x2D8D6 },
	{ 0xE79681, 0x3D1F0 },
	{ 0xE79683, 0x3D5D2 },
	{ 0xE79684, 0x2DDDF },
	{ 0xE79685, 0x4DBF4 },
	{ 0xE79686, 0x1F8D1 },
	{ 0xE79687, 0x1F8D0 },
	{ 0xE79688, 0x4E3E8 },
	{ 0xE79689, 0x3DCE2 },
	{ 0xE7968A, 0x1FBE8 },
	{ 0xE7968B, 0x1C6F4 },
	{ 0xE7968C, 0x2A8B5 },
	{ 0xE7968E, 0x3BDC5 },
	{ 0xE7968F, 0x1DCAD },
	{ 0xE79690, 0x2CCA1 },
	{ 0xE79691, 0x1E9EA },
	{ 0xE79692, 0x3A2DB },
	{ 0xE79693, 0x3A6F3 },
	{ 0xE79694, 0x2A4EF },
	{ 0xE79695, 0x2A4F0 },
	{ 0xE79698, 0x2A8B6 },
	{ 0xE79699, 0x1CEF9 },
	{ 0xE7969A, 0x1CEFA },
	{ 0xE7969B, 0x3AABA },
	{ 0xE7969C, 0x4A7C3 },
	{ 0xE7969D, 0x1CEF8 },
	{ 0xE7969E, 0x3AABB },
	{ 0xE796A2, 0x1D2D2 },
	{ 0xE796A3, 0x1D2D3 },
	{ 0xE796A4, 0x1D2D0 },
	{ 0xE796A5, 0x1D2D1 },
	{ 0xE796A6, 0x3AEAB },
	{ 0xE796A7, 0x2ACBE },
	{ 0xE796A8, 0x3AEAF },
	{ 0xE796A9, 0x4AACA },
	{ 0xE796AA, 0x2ACBF },
	{ 0xE796AB, 0x1D2CF },
	{ 0xE796B0, 0x2B1A6 },
	{ 0xE796B1, 0x3B2D7 },
	{ 0xE796B2, 0x1D6EB },
	{ 0xE796B3, 0x1D6EC },
	{ 0xE796B4, 0x3B2D5 },
	{ 0xE796B5, 0x1DCB0 },
	{ 0xE796B6, 0x2B1AC },
	{ 0xE796B7, 0x4AEC0 },
	{ 0xE796B8, 0x1D6F1 },
	{ 0xE796B9, 0x1D6EF },
	{ 0xE796BA, 0x2B1AD },
	{ 0xE796BB, 0x2B1A8 },
	{ 0xE796BC, 0x1D6EE },
	{ 0xE796BD, 0x1D6ED },
	{ 0xE796BE, 0x1D6E8 },
	{ 0xE796BF, 0x2B1AB },
	{ 0xE79780, 0x2B1AA },
	{ 0xE79781, 0x2B1A7 },
	{ 0xE79782, 0x1D6F0 },
	{ 0xE79783, 0x3B2D2 },
	{ 0xE79784, 0x2B1A9 },
	{ 0xE79785, 0x1D6E9 },
	{ 0xE79786, 0x4AEB4 },
	{ 0xE79787, 0x1D6EA },
	{ 0xE7978A, 0x1DCB1 },
	{ 0xE7978B, 0x2B7C4 },
	{ 0xE7978C, 0x2B7C5 },
	{ 0xE7978D, 0x1DCB2 },
	{ 0xE7978E, 0x2B7C1 },
	{ 0xE7978F, 0x2B7C3 },
	{ 0xE79790, 0x2B7C7 },
	{ 0xE79791, 0x2B7C6 },
	{ 0xE79792, 0x2B7C2 },
	{ 0xE79793, 0x3B7CA },
	{ 0xE79794, 0x1DCAE },
	{ 0xE79795, 0x1DCAF },
	{ 0xE79797, 0x2BEBA },
	{ 0xE79798, 0x1E0F1 },
	{ 0xE79799, 0x1E0F0 },
	{ 0xE7979A, 0x2BEB4 },
	{ 0xE7979B, 0x1E0EE },
	{ 0xE7979C, 0x4B9B4 },
	{ 0xE7979D, 0x2BEB7 },
	{ 0xE7979E, 0x1E0F2 },
	{ 0xE7979F, 0x2BEB8 },
	{ 0xE797A0, 0x1E0F3 },
	{ 0xE797A1, 0x2BEB5 },
	{ 0xE797A2, 0x1E0ED },
	{ 0xE797A3, 0x1E0EF },
	{ 0xE797A4, 0x2BEB9 },
	{ 0xE797A5, 0x3BDC7 },
	{ 0xE797A6, 0x2BEB6 },
	{ 0xE797A7, 0x2BEB3 },
	{ 0xE797AC, 0x4BEF7 },
	{ 0xE797AD, 0x2C5B8 },
	{ 0xE797AE, 0x3C2FC },
	{ 0xE797AF, 0x2C5AD },
	{ 0xE797B0, 0x1E5B8 },
	{ 0xE797B1, 0x1E5BB },
	{ 0xE797B2, 0x1E5BA },
	{ 0xE797B3, 0x1E5BF },
	{ 0xE797B4, 0x1E5BE },
	{ 0xE797B5, 0x2C5B9 },
	{ 0xE797B6, 0x2C5B7 },
	{ 0xE797B7, 0x2C5B0 },
	{ 0xE797B8, 0x2C5B4 },
	{ 0xE797B9, 0x2C5B3 },
	{ 0xE797BA, 0x1E5BC },
	{ 0xE797BB, 0x2C5B6 },
	{ 0xE797BC, 0x2C5B2 },
	{ 0xE797BD, 0x2C5BA },
	{ 0xE797BE, 0x2C5B1 },
	{ 0xE797BF, 0x1E5BD },
	{ 0xE79880, 0x1E5B7 },
	{ 0xE79881, 0x1E5B9 },
	{ 0xE79882, 0x3C2FD },
	{ 0xE79883, 0x2C5AF },
	{ 0xE79887, 0x3C8AB },
	{ 0xE79888, 0x2CCA3 },
	{ 0xE79889, 0x1E9EE },
	{ 0xE7988A, 0x2CCA7 },
	{ 0xE7988B, 0x1E9ED },
	{ 0xE7988C, 0x2CCA4 },
	{ 0xE7988D, 0x1E9EC },
	{ 0xE7988E, 0x3C8A9 },
	{ 0xE7988F, 0x2C5AE },
	{ 0xE79890, 0x2C5B5 },
	{ 0xE79891, 0x2CCA6 },
	{ 0xE79892, 0x4C4FE },
	{ 0xE79893, 0x1E9EF },
	{ 0xE79894, 0x2CCA8 },
	{ 0xE79895, 0x2CCA5 },
	{ 0xE79896, 0x2CCA2 },
	{ 0xE79899, 0x2D2B9 },
	{ 0xE7989A, 0x2D2BD },
	{ 0xE7989B, 0x2D2BF },
	{ 0xE7989C, 0x2D2BB },
	{ 0xE7989D, 0x2D2BA },
	{ 0xE7989E, 0x2D2B8 },
	{ 0xE7989F, 0x1EDEE },
	{ 0xE798A0, 0x1EDEC },
	{ 0xE798A1, 0x1EDF1 },
	{ 0xE798A2, 0x1EDF2 },
	{ 0xE798A3, 0x2D2BC },
	{ 0xE798A4, 0x1EDEF },
	{ 0xE798A5, 0x2D2B7 },
	{ 0xE798A6, 0x1EDF0 },
	{ 0xE798A7, 0x1E9EB },
	{ 0xE798A8, 0x2D2BE },
	{ 0xE798A9, 0x1EDED },
	{ 0xE798AC, 0x3D1F1 },
	{ 0xE798AD, 0x2D8D8 },
	{ 0xE798AE, 0x4D1CF },
	{ 0xE798AF, 0x2D8D7 },
	{ 0xE798B0, 0x2D8DF },
	{ 0xE798B1, 0x2D8D9 },
	{ 0xE798B2, 0x2D8DE },
	{ 0xE798B3, 0x2D8DB },
	{ 0xE798B4, 0x1F1CA },
	{ 0xE798B5, 0x2D8DD },
	{ 0xE798B6, 0x3D1F3 },
	{ 0xE798B7, 0x3D1F2 },
	{ 0xE798B8, 0x1F1CB },
	{ 0xE798B9, 0x4D1CD },
	{ 0xE798BA, 0x1F1CC },
	{ 0xE798BB, 0x3D1F4 },
	{ 0xE798BC, 0x2D8DC },
	{ 0xE798BD, 0x2D8DA },
	{ 0xE79980, 0x4D7A1 },
	{ 0xE79981, 0x4D7A4 },
	{ 0xE79982, 0x1F4C3 },
	{ 0xE79983, 0x2DDE0 },
	{ 0xE79984, 0x3D5D5 },
	{ 0xE79985, 0x3D5D3 },
	{ 0xE79986, 0x1F4C2 },
	{ 0xE79987, 0x2DDE3 },
	{ 0xE79988, 0x2DDE1 },
	{ 0xE79989, 0x2DDE2 },
	{ 0xE7998A, 0x5D5E9 },
	{ 0xE7998B, 0x5DCB6 },
	{ 0xE7998C, 0x1F4C4 },
	{ 0xE7998E, 0x3D5D4 },
	{ 0xE7998F, 0x3D8B4 },
	{ 0xE79990, 0x2E2BA },
	{ 0xE79991, 0x3D8B3 },
	{ 0xE79992, 0x1F6EB },
	{ 0xE79993, 0x2E2BB },
	{ 0xE79994, 0x4DBF5 },
	{ 0xE79995, 0x4DBF9 },
	{ 0xE79996, 0x1F6E9 },
	{ 0xE79997, 0x2E2BC },
	{ 0xE79998, 0x1F6EA },
	{ 0xE79999, 0x2E2B9 },
	{ 0xE7999A, 0x2E2BD },
	{ 0xE7999B, 0x3D8B2 },
	{ 0xE7999C, 0x2E2B7 },
	{ 0xE7999F, 0x1F8D2 },
	{ 0xE799A0, 0x2E6A4 },
	{ 0xE799A1, 0x1F8D3 },
	{ 0xE799A2, 0x1F9FA },
	{ 0xE799A4, 0x2E2B8 },
	{ 0xE799A5, 0x1F9FB },
	{ 0xE799A7, 0x3DEBF },
	{ 0xE799A8, 0x3DEBE },
	{ 0xE799A9, 0x1FAF9 },
	{ 0xE799AA, 0x2EBED },
	{ 0xE799AC, 0x1FBEA },
	{ 0xE799AD, 0x2EDE2 },
	{ 0xE799AE, 0x1FBE9 },
	{ 0xE799AF, 0x3E0BB },
	{ 0xE799B0, 0x2EFB9 },
	{ 0xE799B1, 0x1FCE1 },
	{ 0xE799B2, 0x1FCE2 },
	{ 0xE799B3, 0x3E5EA },
	{ 0xE799B4, 0x7E4D2 },
	{ 0xE799B5, 0x2F2BA },
	{ 0xE799B6, 0x3A2DC },
	{ 0xE799B7, 0x3E5EB },
	{ 0xE799B8, 0x1D2D4 },
	{ 0xE799B9, 0x2ACC0 },
	{ 0xE799BB, 0x1E0F4 },
	{ 0xE799BC, 0x1E0F5 },
	{ 0xE799BD, 0x1C6F5 },
	{ 0xE799BE, 0x1C8CB },
	{ 0xE799BF, 0x2A2E7 },
	{ 0xE79A80, 0x3A6F4 },
	{ 0xE79A81, 0x2A4F1 },
	{ 0xE79A82, 0x1CBB0 },
	{ 0xE79A83, 0x3A6F6 },
	{ 0xE79A84, 0x1CEFB },
	{ 0xE79A85, 0x4AACC },
	{ 0xE79A86, 0x1D2D5 },
	{ 0xE79A87, 0x1D2D6 },
	{ 0xE79A88, 0x1D2D7 },
	{ 0xE79A89, 0x2B7C9 },
	{ 0xE79A8A, 0x2B1AE },
	{ 0xE79A8B, 0x1D6F2 },
	{ 0xE79A8C, 0x4AEC1 },
	{ 0xE79A8D, 0x4AEC3 },
	{ 0xE79A8E, 0x1DCB3 },
	{ 0xE79A8F, 0x2B7C8 },
	{ 0xE79A90, 0x3B7CD },
	{ 0xE79A92, 0x2BEBC },
	{ 0xE79A93, 0x1E0F7 },
	{ 0xE79A94, 0x3BDCC },
	{ 0xE79A95, 0x2BEBB },
	{ 0xE79A96, 0x1E0F6 },
	{ 0xE79A97, 0x3C2FE },
	{ 0xE79A98, 0x3C3A1 },
	{ 0xE79A99, 0x2C5BB },
	{ 0xE79A9A, 0x1EDF3 },
	{ 0xE79A9B, 0x2D2C3 },
	{ 0xE79A9C, 0x2D2C0 },
	{ 0xE79A9D, 0x2D2C1 },
	{ 0xE79A9E, 0x2D2C2 },
	{ 0xE79A9F, 0x4D1D4 },
	{ 0xE79AA0, 0x4D1D5 },
	{ 0xE79AA1, 0x3D1F6 },
	{ 0xE79AA2, 0x5DCC3 },
	{ 0xE79AA3, 0x3D5D6 },
	{ 0xE79AA4, 0x2DDE4 },
	{ 0xE79AA5, 0x3D5D7 },
	{ 0xE79AA6, 0x2E2BE },
	{ 0xE79AA7, 0x4DBFC },
	{ 0xE79AA8, 0x4DBFD },
	{ 0xE79AA9, 0x3DADE },
	{ 0xE79AAA, 0x2E9C0 },
	{ 0xE79AAB, 0x2E9BF },
	{ 0xE79AAC, 0x4E6DA },
	{ 0xE79AAD, 0x2EDE3 },
	{ 0xE79AAE, 0x1C6F6 },
	{ 0xE79AAF, 0x2A8B7 },
	{ 0xE79AB0, 0x1D6F3 },
	{ 0xE79AB3, 0x3BDCD },
	{ 0xE79AB4, 0x1E0F8 },
	{ 0xE79AB5, 0x2C5BC },
	{ 0xE79AB6, 0x4C5B4 },
	{ 0xE79AB7, 0x3C8B0 },
	{ 0xE79AB8, 0x2CCA9 },
	{ 0xE79AB9, 0x3C8AE },
	{ 0xE79ABA, 0x1EDF4 },
	{ 0xE79ABB, 0x2D8E0 },
	{ 0xE79ABC, 0x3E5EC },
	{ 0xE79ABD, 0x2E2BF },
	{ 0xE79ABE, 0x2E9C1 },
	{ 0xE79ABF, 0x1C6F7 },
	{ 0xE79B80, 0x3A6F7 },
	{ 0xE79B81, 0x3A6F8 },
	{ 0xE79B82, 0x1CEFC },
	{ 0xE79B83, 0x1D2DA },
	{ 0xE79B84, 0x2ACC1 },
	{ 0xE79B85, 0x1D2DB },
	{ 0xE79B86, 0x1D2D9 },
	{ 0xE79B87, 0x3AEB2 },
	{ 0xE79B88, 0x1D2D8 },
	{ 0xE79B89, 0x2B1AF },
	{ 0xE79B8A, 0x1D6F4 },
	{ 0xE79B8B, 0x3B2DA },
	{ 0xE79B8C, 0x3B2DB },
	{ 0xE79B8D, 0x1D6F5 },
	{ 0xE79B8E, 0x1D6F6 },
	{ 0xE79B92, 0x1DCB5 },
	{ 0xE79B93, 0x2B7CA },
	{ 0xE79B94, 0x1DCB4 },
	{ 0xE79B95, 0x3B7D0 },
	{ 0xE79B96, 0x3B7D2 },
	{ 0xE79B97, 0x3B7D1 },
	{ 0xE79B98, 0xFB7A3 },
	{ 0xE79B99, 0x3BDCF },
	{ 0xE79B9A, 0x2BEBD },
	{ 0xE79B9B, 0x1DCB6 },
	{ 0xE79B9C, 0x1E0F9 },
	{ 0xE79B9D, 0x2C5BD },
	{ 0xE79B9E, 0x1E5C0 },
	{ 0xE79B9F, 0x1E5C1 },
	{ 0xE79BA0, 0x4C5B5 },
	{ 0xE79BA1, 0x1E9F0 },
	{ 0xE79BA2, 0x3C8B1 },
	{ 0xE79BA3, 0x1E9F1 },
	{ 0xE79BA4, 0x1EDF5 },
	{ 0xE79BA5, 0x1F1CE },
	{ 0xE79BA6, 0x2D8E1 },
	{ 0xE79BA7, 0x1F1CD },
	{ 0xE79BA8, 0x4D7AD },
	{ 0xE79BA9, 0x2DDE5 },
	{ 0xE79BAA, 0x1F4C5 },
	{ 0xE79BAB, 0x3D8B5 },
	{ 0xE79BAC, 0x2E2C0 },
	{ 0xE79BAD, 0x2E9C2 },
	{ 0xE79BAE, 0x1C6F8 },
	{ 0xE79BAF, 0x1CBB1 },
	{ 0xE79BB0, 0x2A8BA },
	{ 0xE79BB1, 0x2A8B9 },
	{ 0xE79BB2, 0x1CEFD },
	{ 0xE79BB3, 0x2A8B8 },
	{ 0xE79BB4, 0x1CEFE },
	{ 0xE79BB5, 0x2A8BB },
	{ 0xE79BB6, 0x4AAD5 },
	{ 0xE79BB7, 0x2ACC7 },
	{ 0xE79BB8, 0x1D2DE },
	{ 0xE79BB9, 0x1D2DD },
	{ 0xE79BBA, 0x2ACC9 },
	{ 0xE79BBB, 0x2ACC8 },
	{ 0xE79BBC, 0x1D2E2 },
	{ 0xE79BBD, 0x3AEB5 },
	{ 0xE79BBE, 0x1D2E1 },
	{ 0xE79BBF, 0x3AEB3 },
	{ 0xE79C80, 0x4AAD9 },
	{ 0xE79C81, 0x1D2DC },
	{ 0xE79C82, 0x4AADD },
	{ 0xE79C83, 0x2ACC3 },
	{ 0xE79C84, 0x2ACC4 },
	{ 0xE79C85, 0x2ACC5 },
	{ 0xE79C86, 0x4AAD2 },
	{ 0xE79C87, 0x1D2E3 },
	{ 0xE79C88, 0x2ACC2 },
	{ 0xE79C89, 0x1D2DF },
	{ 0xE79C8A, 0x2ACC6 },
	{ 0xE79C8B, 0x1D2E0 },
	{ 0xE79C8E, 0x3B2E4 },
	{ 0xE79C8F, 0x3B2DF },
	{ 0xE79C90, 0x2B1B2 },
	{ 0xE79C91, 0x2B1B6 },
	{ 0xE79C92, 0x2B1B4 },
	{ 0xE79C93, 0x2B1B3 },
	{ 0xE79C94, 0x4AED5 },
	{ 0xE79C95, 0x2B1B7 },
	{ 0xE79C96, 0x3B2DE },
	{ 0xE79C97, 0x4AECF },
	{ 0xE79C98, 0x3B2E8 },
	{ 0xE79C99, 0x2B1B8 },
	{ 0xE79C9A, 0x2B1B9 },
	{ 0xE79C9B, 0x2B1B1 },
	{ 0xE79C9C, 0x4AED1 },
	{ 0xE79C9D, 0x2B1B0 },
	{ 0xE79C9E, 0x3B7D9 },
	{ 0xE79C9F, 0x1D6F8 },
	{ 0xE79CA0, 0x1D6F9 },
	{ 0xE79CA1, 0x3B2E7 },
	{ 0xE79CA2, 0x2B1BA },
	{ 0xE79CA3, 0x2B1B5 },
	{ 0xE79CA4, 0x3B2E5 },
	{ 0xE79CA5, 0x2B7D3 },
	{ 0xE79CA6, 0x3B7D5 },
	{ 0xE79CA7, 0x2B1BB },
	{ 0xE79CA8, 0x1D6FA },
	{ 0xE79CA9, 0x1D6F7 },
	{ 0xE79CAA, 0x3B2DC },
	{ 0xE79CAB, 0x3B2E3 },
	{ 0xE79CAD, 0x2B7CD },
	{ 0xE79CAE, 0x4B3CF },
	{ 0xE79CAF, 0x2B7CC },
	{ 0xE79CB0, 0x3B7D3 },
	{ 0xE79CB1, 0x2B7CE },
	{ 0xE79CB2, 0x2B7CF },
	{ 0xE79CB3, 0x2B7D1 },
	{ 0xE79CB4, 0x2B7D0 },
	{ 0xE79CB5, 0x2B7D5 },
	{ 0xE79CB6, 0x1DCBA },
	{ 0xE79CB7, 0x1DCB7 },
	{ 0xE79CB8, 0x1DCBB },
	{ 0xE79CB9, 0x2B7CB },
	{ 0xE79CBA, 0x1DCBC },
	{ 0xE79CBB, 0x2B7D4 },
	{ 0xE79CBC, 0x1DCB9 },
	{ 0xE79CBD, 0x2B7D2 },
	{ 0xE79CBE, 0x1DCB8 },
	{ 0xE79CBF, 0x3B2E2 },
	{ 0xE79D80, 0x3B7D7 },
	{ 0xE79D81, 0x4B3D6 },
	{ 0xE79D82, 0x3BDD6 },
	{ 0xE79D83, 0x3BDD3 },
	{ 0xE79D84, 0x2BEC0 },
	{ 0xE79D85, 0x2BEC2 },
	{ 0xE79D86, 0x2BEBE },
	{ 0xE79D87, 0x2BEBF },
	{ 0xE79D88, 0x3BDD1 },
	{ 0xE79D89, 0x3BDD2 },
	{ 0xE79D8A, 0x2BEC3 },
	{ 0xE79D8B, 0x2BEC5 },
	{ 0xE79D8C, 0x2BEC6 },
	{ 0xE79D8D, 0x2BEC1 },
	{ 0xE79D8E, 0x2BEC4 },
	{ 0xE79D8F, 0x1E0FA },
	{ 0xE79D92, 0x2C5C1 },
	{ 0xE79D93, 0x3C3A7 },
	{ 0xE79D94, 0x2C5C6 },
	{ 0xE79D95, 0x2C5BE },
	{ 0xE79D96, 0x2C5C2 },
	{ 0xE79D97, 0x4BFA9 },
	{ 0xE79D98, 0x3C3A8 },
	{ 0xE79D99, 0x2C5C7 },
	{ 0xE79D9A, 0x2C5C3 },
	{ 0xE79D9B, 0x1E5C2 },
	{ 0xE79D9C, 0x1E5CA },
	{ 0xE79D9D, 0x3C3A5 },
	{ 0xE79D9E, 0x1E5C5 },
	{ 0xE79D9F, 0x2C5BF },
	{ 0xE79DA0, 0x2C5C0 },
	{ 0xE79DA1, 0x1E9F5 },
	{ 0xE79DA2, 0x1E5CD },
	{ 0xE79DA3, 0x1E5C6 },
	{ 0xE79DA4, 0x3C3A6 },
	{ 0xE79DA5, 0x1E5CB },
	{ 0xE79DA6, 0x1E5C4 },
	{ 0xE79DA7, 0x2C5C5 },
	{ 0xE79DA8, 0x1E5CC },
	{ 0xE79DA9, 0x2C5C4 },
	{ 0xE79DAA, 0x1E5C8 },
	{ 0xE79DAB, 0x1E5C3 },
	{ 0xE79DAC, 0x1E5C9 },
	{ 0xE79DAD, 0x2C5C8 },
	{ 0xE79DAE, 0x2CCAE },
	{ 0xE79DAF, 0x2CCB0 },
	{ 0xE79DB0, 0x4C5C2 },
	{ 0xE79DB1, 0x3C8B9 },
	{ 0xE79DB2, 0x4C5C0 },
	{ 0xE79DB3, 0x4C5BD },
	{ 0xE79DB4, 0x3C8B3 },
	{ 0xE79DB5, 0x3C8B6 },
	{ 0xE79DB6, 0x3C8B5 },
	{ 0xE79DB7, 0x3C8B4 },
	{ 0xE79DB8, 0x3C8B8 },
	{ 0xE79DB9, 0x1E5C7 },
	{ 0xE79DBA, 0x3C8BB },
	{ 0xE79DBB, 0x3C8BD },
	{ 0xE79DBC, 0x2CCAB },
	{ 0xE79DBD, 0x1E9F3 },
	{ 0xE79DBE, 0x2CCB1 },
	{ 0xE79DBF, 0x1E9F4 },
	{ 0xE79E80, 0x2CCAF },
	{ 0xE79E81, 0x2CCAA },
	{ 0xE79E82, 0x2CCAD },
	{ 0xE79E83, 0x2CCB2 },
	{ 0xE79E84, 0x1E9F2 },
	{ 0xE79E85, 0x2CCAC },
	{ 0xE79E87, 0x1EDF7 },
	{ 0xE79E88, 0x2D2C7 },
	{ 0xE79E89, 0x2D2C6 },
	{ 0xE79E8A, 0x3CDC4 },
	{ 0xE79E8B, 0x1EDFA },
	{ 0xE79E8C, 0x1EDF8 },
	{ 0xE79E8D, 0x2D2C4 },
	{ 0xE79E8E, 0x1EDF6 },
	{ 0xE79E8F, 0x2D2C5 },
	{ 0xE79E90, 0x3CDC6 },
	{ 0xE79E91, 0x1EDF9 },
	{ 0xE79E94, 0x4D1DF },
	{ 0xE79E95, 0x2D8E9 },
	{ 0xE79E96, 0x3D1FB },
	{ 0xE79E97, 0x2D8EB },
	{ 0xE79E98, 0x3D1F9 },
	{ 0xE79E99, 0x2D8EA },
	{ 0xE79E9A, 0x2D8E2 },
	{ 0xE79E9B, 0x2D8E6 },
	{ 0xE79E9C, 0x2D8E5 },
	{ 0xE79E9D, 0x2D8E3 },
	{ 0xE79E9E, 0x1F1D0 },
	{ 0xE79E9F, 0x1F1D1 },
	{ 0xE79EA0, 0x1F1CF },
	{ 0xE79EA1, 0x2D8E4 },
	{ 0xE79EA2, 0x2D8E7 },
	{ 0xE79EA3, 0x2D8E8 },
	{ 0xE79EA4, 0x3D5D9 },
	{ 0xE79EA5, 0x1F1D2 },
	{ 0xE79EA6, 0x3D5D8 },
	{ 0xE79EA7, 0x1F4CA },
	{ 0xE79EA8, 0x2DDED },
	{ 0xE79EA9, 0x3D5DB },
	{ 0xE79EAA, 0x1F4C7 },
	{ 0xE79EAB, 0x2DDE7 },
	{ 0xE79EAC, 0x1F4C9 },
	{ 0xE79EAD, 0x1F4CB },
	{ 0xE79EAE, 0x4D1E1 },
	{ 0xE79EAF, 0x3D5DC },
	{ 0xE79EB0, 0x1F4C8 },
	{ 0xE79EB1, 0x2DDEC },
	{ 0xE79EB2, 0x2DDE8 },
	{ 0xE79EB3, 0x1F4C6 },
	{ 0xE79EB4, 0x2DDEB },
	{ 0xE79EB5, 0x2DDE6 },
	{ 0xE79EB6, 0x2DDEA },
	{ 0xE79EB7, 0x2DDE9 },
	{ 0xE79EB8, 0x3D8B6 },
	{ 0xE79EB9, 0x3D8B8 },
	{ 0xE79EBA, 0x2E2C2 },
	{ 0xE79EBB, 0x1F6EE },
	{ 0xE79EBC, 0x1F6EF },
	{ 0xE79EBD, 0x1F6EC },
	{ 0xE79EBE, 0x3D8BB },
	{ 0xE79EBF, 0x1F6ED },
	{ 0xE79F80, 0x3D8BA },
	{ 0xE79F81, 0x3D8B9 },
	{ 0xE79F82, 0x2E2C1 },
	{ 0xE79F83, 0x4E0B9 },
	{ 0xE79F84, 0x2E6A7 },
	{ 0xE79F85, 0x3DAE0 },
	{ 0xE79F86, 0x3DADF },
	{ 0xE79F87, 0x1F8D4 },
	{ 0xE79F89, 0x2E6A5 },
	{ 0xE79F8A, 0x2E6A6 },
	{ 0xE79F8C, 0x2E9C3 },
	{ 0xE79F8D, 0x2E9C6 },
	{ 0xE79F8E, 0x2E9C4 },
	{ 0xE79F8F, 0x2E9C5 },
	{ 0xE79F90, 0x2EBEE },
	{ 0xE79F91, 0x3DEC2 },
	{ 0xE79F92, 0x4E6DE },
	{ 0xE79F93, 0x1FAFA },
	{ 0xE79F94, 0x2EFBA },
	{ 0xE79F95, 0x2F0C2 },
	{ 0xE79F96, 0x4EBF4 },
	{ 0xE79F97, 0x1FCE3 },
	{ 0xE79F98, 0x2F1A8 },
	{ 0xE79F99, 0x2F1A9 },
	{ 0xE79F9A, 0x1FDB3 },
	{ 0xE79F9B, 0x1C6F9 },
	{ 0xE79F9C, 0x1D2E4 },
	{ 0xE79F9D, 0x3B2E9 },
	{ 0xE79F9E, 0x2BEC7 },
	{ 0xE79F9F, 0x3BDD7 },
	{ 0xE79FA0, 0x2C5C9 },
	{ 0xE79FA1, 0x4ECF6 },
	{ 0xE79FA2, 0x1C6FA },
	{ 0xE79FA3, 0x1CBB2 },
	{ 0xE79FA4, 0x4A7D2 },
	{ 0xE79FA5, 0x1CFA1 },
	{ 0xE79FA6, 0x3AEB6 },
	{ 0xE79FA7, 0x2ACCA },
	{ 0xE79FA8, 0x2ACCB },
	{ 0xE79FA9, 0x1D6FB },
	{ 0xE79FAA, 0x4B3DB },
	{ 0xE79FAC, 0x2BEC8 },
	{ 0xE79FAD, 0x1E0FB },
	{ 0xE79FAE, 0x1E5CE },
	{ 0xE79FAF, 0x1F4CC },
	{ 0xE79FB0, 0x2DDEE },
	{ 0xE79FB1, 0x2E6A8 },
	{ 0xE79FB2, 0x2E9C7 },
	{ 0xE79FB3, 0x1C6FB },
	{ 0xE79FB4, 0x3A6FB },
	{ 0xE79FB5, 0x3A6FC },
	{ 0xE79FB6, 0xFA5A3 },
	{ 0xE79FB7, 0x2A8C1 },
	{ 0xE79FB8, 0x2A8BC },
	{ 0xE79FB9, 0x2A8BE },
	{ 0xE79FBA, 0x2A8C0 },
	{ 0xE79FBB, 0x2A8BF },
	{ 0xE79FBC, 0x2A8BD },
	{ 0xE79FBD, 0x1CFA2 },
	{ 0xE79FBE, 0xFA8B4 },
	{ 0xE7A082, 0x1D2E5 },
	{ 0xE7A083, 0x2ACD4 },
	{ 0xE7A084, 0x3AEB9 },
	{ 0xE7A085, 0x2ACCF },
	{ 0xE7A086, 0x2ACCC },
	{ 0xE7A087, 0x3AEBB },
	{ 0xE7A088, 0x3AEBE },
	{ 0xE7A089, 0x2ACD3 },
	{ 0xE7A08A, 0x3AEB7 },
	{ 0xE7A08B, 0x3AEBA },
	{ 0xE7A08C, 0x1D2E7 },
	{ 0xE7A08D, 0x1D2E8 },
	{ 0xE7A08E, 0x2ACD2 },
	{ 0xE7A08F, 0x2ACD1 },
	{ 0xE7A090, 0x2ACD0 },
	{ 0xE7A091, 0x2ACCD },
	{ 0xE7A092, 0x2ACCE },
	{ 0xE7A093, 0x2ACD5 },
	{ 0xE7A094, 0x1D2E6 },
	{ 0xE7A095, 0x3AEBD },
	{ 0xE7A098, 0xFACDC },
	{ 0xE7A099, 0x3E5ED },
	{ 0xE7A09B, 0x3E5EE },
	{ 0xE7A09D, 0x1D7A1 },
	{ 0xE7A09E, 0x3E6FC },
	{ 0xE7A09F, 0x1D7A7 },
	{ 0xE7A0A0, 0x1D7A6 },
	{ 0xE7A0A1, 0x2B1C4 },
	{ 0xE7A0A2, 0x2B1BE },
	{ 0xE7A0A3, 0x2B1BC },
	{ 0xE7A0A4, 0x3B2EC },
	{ 0xE7A0A5, 0x1D7A4 },
	{ 0xE7A0A6, 0x2B7DC },
	{ 0xE7A0A7, 0x1D6FD },
	{ 0xE7A0A8, 0x2B1C1 },
	{ 0xE7A0A9, 0x2B1C5 },
	{ 0xE7A0AA, 0x2B1C7 },
	{ 0xE7A0AB, 0x2B1C3 },
	{ 0xE7A0AC, 0x2B1BD },
	{ 0xE7A0AD, 0x1D7A5 },
	{ 0xE7A0AE, 0x2B1C2 },
	{ 0xE7A0AF, 0x2B1C0 },
	{ 0xE7A0B0, 0x1D6FC },
	{ 0xE7A0B1, 0x2B1C8 },
	{ 0xE7A0B2, 0x1D7A8 },
	{ 0xE7A0B3, 0x2B1C6 },
	{ 0xE7A0B4, 0x1D7A2 },
	{ 0xE7A0B5, 0x2B1BF },
	{ 0xE7A0B6, 0x3B2ED },
	{ 0xE7A0B7, 0x1D7A3 },
	{ 0xE7A0B8, 0x1D6FE },
	{ 0xE7A0BD, 0x3E5EF },
	{ 0xE7A182, 0x3B7E2 },
	{ 0xE7A183, 0x1DCBE },
	{ 0xE7A184, 0x4B3DD },
	{ 0xE7A185, 0x2B7DD },
	{ 0xE7A186, 0x3B7E3 },
	{ 0xE7A187, 0x3B7DD },
	{ 0xE7A188, 0x2B7D6 },
	{ 0xE7A189, 0x2B7D8 },
	{ 0xE7A18A, 0x2B7DA },
	{ 0xE7A18B, 0x3B7DF },
	{ 0xE7A18C, 0x2B7DB },
	{ 0xE7A18D, 0x2B7D9 },
	{ 0xE7A18E, 0x1DCBF },
	{ 0xE7A18F, 0x3B7E1 },
	{ 0xE7A190, 0x2B7DE },
	{ 0xE7A191, 0x3B7E0 },
	{ 0xE7A192, 0x2B7D7 },
	{ 0xE7A193, 0x3E5F0 },
	{ 0xE7A194, 0x3E5F1 },
	{ 0xE7A198, 0x3E5F2 },
	{ 0xE7A19C, 0x2BECC },
	{ 0xE7A19D, 0x1E0FC },
	{ 0xE7A19E, 0x2BED4 },
	{ 0xE7A19F, 0x3BDDC },
	{ 0xE7A1A0, 0x2BEC9 },
	{ 0xE7A1A1, 0x6CCAF },
	{ 0xE7A1A2, 0x2BED5 },
	{ 0xE7A1A3, 0x3BDD9 },
	{ 0xE7A1A4, 0x2BECA },
	{ 0xE7A1A5, 0x2BECB },
	{ 0xE7A1A6, 0x3BDDD },
	{ 0xE7A1A7, 0x4B9D4 },
	{ 0xE7A1A8, 0x2BED3 },
	{ 0xE7A1A9, 0x2BED2 },
	{ 0xE7A1AA, 0x2BECF },
	{ 0xE7A1AB, 0x1DCBD },
	{ 0xE7A1AC, 0x1E0FD },
	{ 0xE7A1AD, 0x2BECD },
	{ 0xE7A1AE, 0x2BED0 },
	{ 0xE7A1AF, 0x1E0FE },
	{ 0xE7A1B0, 0x2BED1 },
	{ 0xE7A1B1, 0x2BECE },
	{ 0xE7A1B6, 0x3BDDA },
	{ 0xE7A1B8, 0x3C3B1 },
	{ 0xE7A1B9, 0x2C5D4 },
	{ 0xE7A1BA, 0x3C3AD },
	{ 0xE7A1BB, 0x2C5D8 },
	{ 0xE7A1BC, 0x1E5D5 },
	{ 0xE7A1BD, 0x3C3AE },
	{ 0xE7A1BE, 0x2CCB8 },
	{ 0xE7A1BF, 0x1E5D8 },
	{ 0xE7A280, 0x2C5D6 },
	{ 0xE7A281, 0x3C3B7 },
	{ 0xE7A282, 0x3C3A9 },
	{ 0xE7A283, 0x2C5D3 },
	{ 0xE7A284, 0x2C5CE },
	{ 0xE7A285, 0x2C5D0 },
	{ 0xE7A286, 0x2C5D1 },
	{ 0xE7A287, 0x2C5CA },
	{ 0xE7A288, 0x3C3B5 },
	{ 0xE7A289, 0x1E5D4 },
	{ 0xE7A28A, 0x3C3AB },
	{ 0xE7A28B, 0x3C3B0 },
	{ 0xE7A28C, 0x1E5D3 },
	{ 0xE7A28D, 0x3C3B4 },
	{ 0xE7A28E, 0x1E5CF },
	{ 0xE7A28F, 0x2C5CD },
	{ 0xE7A290, 0x3C3AA },
	{ 0xE7A291, 0x1E5D6 },
	{ 0xE7A292, 0x3C3B6 },
	{ 0xE7A293, 0x1E5D7 },
	{ 0xE7A294, 0x2C5CC },
	{ 0xE7A295, 0x2C5CF },
	{ 0xE7A296, 0x2C5D7 },
	{ 0xE7A297, 0x1E5D1 },
	{ 0xE7A298, 0x1E5D2 },
	{ 0xE7A299, 0x2C5D5 },
	{ 0xE7A29A, 0x2C5CB },
	{ 0xE7A29C, 0xFC4A5 },
	{ 0xE7A29D, 0x4C5D3 },
	{ 0xE7A29E, 0x2CCBA },
	{ 0xE7A29F, 0x1E9F7 },
	{ 0xE7A2A0, 0x2CCBC },
	{ 0xE7A2A1, 0x2C5D2 },
	{ 0xE7A2A2, 0x2CCBE },
	{ 0xE7A2A3, 0x1E9FB },
	{ 0xE7A2A4, 0x2CCBF },
	{ 0xE7A2A5, 0x2CCBB },
	{ 0xE7A2A6, 0x3C8BE },
	{ 0xE7A2A7, 0x1E9F8 },
	{ 0xE7A2A8, 0x2CCB7 },
	{ 0xE7A2A9, 0x1E9FA },
	{ 0xE7A2AA, 0x2CCB4 },
	{ 0xE7A2AB, 0x2CCB9 },
	{ 0xE7A2AC, 0x2CCBD },
	{ 0xE7A2AD, 0x2CCB6 },
	{ 0xE7A2AE, 0x3C8BF },
	{ 0xE7A2AF, 0x3C8C5 },
	{ 0xE7A2B0, 0x1E5D0 },
	{ 0xE7A2B1, 0x3C8C4 },
	{ 0xE7A2B2, 0x2CCB3 },
	{ 0xE7A2B3, 0x1E9F9 },
	{ 0xE7A2B4, 0x2CCB5 },
	{ 0xE7A2B7, 0x3E5F3 },
	{ 0xE7A2B8, 0x3C8C0 },
	{ 0xE7A2B9, 0xFCABF },
	{ 0xE7A2BA, 0x1EDFD },
	{ 0xE7A2BB, 0x2D2C9 },
	{ 0xE7A2BC, 0x1EEA3 },
	{ 0xE7A2BD, 0x4CBD9 },
	{ 0xE7A2BE, 0x1EEA1 },
	{ 0xE7A2BF, 0x4CBD7 },
	{ 0xE7A380, 0x3CDCA },
	{ 0xE7A381, 0x1E9F6 },
	{ 0xE7A382, 0x3CDCD },
	{ 0xE7A383, 0x2D2D0 },
	{ 0xE7A384, 0x2D2D1 },
	{ 0xE7A385, 0x1EDFC },
	{ 0xE7A386, 0x3CDC8 },
	{ 0xE7A387, 0x3CDCC },
	{ 0xE7A388, 0x2D2CF },
	{ 0xE7A389, 0x2D2D2 },
	{ 0xE7A38A, 0x1EDFE },
	{ 0xE7A38B, 0x1EDFB },
	{ 0xE7A38C, 0x2D2CB },
	{ 0xE7A38D, 0x2D2C8 },
	{ 0xE7A38E, 0x2D2CD },
	{ 0xE7A38F, 0x2D2CA },
	{ 0xE7A390, 0x1EEA4 },
	{ 0xE7A391, 0x2D2CC },
	{ 0xE7A392, 0x3CDCB },
	{ 0xE7A393, 0x3CDC9 },
	{ 0xE7A394, 0x2D2CE },
	{ 0xE7A395, 0x1EEA2 },
	{ 0xE7A396, 0x3D2A1 },
	{ 0xE7A398, 0x3E5F4 },
	{ 0xE7A39A, 0x1F1D4 },
	{ 0xE7A39B, 0x2D8F2 },
	{ 0xE7A39C, 0x3D2A4 },
	{ 0xE7A39D, 0x2D8EC },
	{ 0xE7A39E, 0x2D8F0 },
	{ 0xE7A39F, 0x2D8F6 },
	{ 0xE7A3A0, 0x2D8F7 },
	{ 0xE7A3A1, 0x2D8F3 },
	{ 0xE7A3A2, 0x2D8F4 },
	{ 0xE7A3A3, 0x2D8F1 },
	{ 0xE7A3A4, 0x4CBDD },
	{ 0xE7A3A5, 0x2D8EE },
	{ 0xE7A3A6, 0x4D1EE },
	{ 0xE7A3A7, 0x1F1D6 },
	{ 0xE7A3A8, 0x1F1D3 },
	{ 0xE7A3A9, 0x2D8ED },
	{ 0xE7A3AA, 0x2D8EF },
	{ 0xE7A3AB, 0x3D2A2 },
	{ 0xE7A3AC, 0x1F1D5 },
	{ 0xE7A3AD, 0x2D8F5 },
	{ 0xE7A3AE, 0x3E5F5 },
	{ 0xE7A3AF, 0x1F4D0 },
	{ 0xE7A3B0, 0x3D5E0 },
	{ 0xE7A3B1, 0x3D5E2 },
	{ 0xE7A3B2, 0x2DDF5 },
	{ 0xE7A3B3, 0x2DDEF },
	{ 0xE7A3B4, 0x1F4CF },
	{ 0xE7A3B6, 0x4D7BE },
	{ 0xE7A3B7, 0x1F4CD },
	{ 0xE7A3B8, 0x3D5E1 },
	{ 0xE7A3B9, 0x2DDF7 },
	{ 0xE7A3BA, 0x1F4CE },
	{ 0xE7A3BB, 0x2DDF2 },
	{ 0xE7A3BC, 0x2DDF3 },
	{ 0xE7A3BD, 0x2DDF0 },
	{ 0xE7A3BE, 0x2DDF8 },
	{ 0xE7A3BF, 0x2DDF4 },
	{ 0xE7A480, 0x4D7C0 },
	{ 0xE7A481, 0x1F4D1 },
	{ 0xE7A482, 0x2DDF1 },
	{ 0xE7A484, 0x2DDF9 },
	{ 0xE7A485, 0x2DDF6 },
	{ 0xE7A486, 0x3D8C3 },
	{ 0xE7A487, 0x3D8BE },
	{ 0xE7A488, 0x3D8C0 },
	{ 0xE7A489, 0x2E2C6 },
	{ 0xE7A48A, 0x3D8BF },
	{ 0xE7A48B, 0x3D8BC },
	{ 0xE7A48C, 0x2E2C3 },
	{ 0xE7A48D, 0x3D8C2 },
	{ 0xE7A48E, 0x1F6F0 },
	{ 0xE7A48F, 0x4DCB2 },
	{ 0xE7A490, 0x2E2C7 },
	{ 0xE7A491, 0x2E2C9 },
	{ 0xE7A492, 0x2E2C8 },
	{ 0xE7A493, 0x2E2C4 },
	{ 0xE7A494, 0x2E2C5 },
	{ 0xE7A495, 0x3D8C4 },
	{ 0xE7A497, 0x2E6AD },
	{ 0xE7A498, 0x3DAE1 },
	{ 0xE7A499, 0x1F8D5 },
	{ 0xE7A49A, 0x3DAE2 },
	{ 0xE7A49B, 0x2E6AA },
	{ 0xE7A49C, 0x2E6AC },
	{ 0xE7A49D, 0x2E6A9 },
	{ 0xE7A49E, 0x2E6AE },
	{ 0xE7A49F, 0x4E0C2 },
	{ 0xE7A4A0, 0x3DAE3 },
	{ 0xE7A4A1, 0x2E6AB },
	{ 0xE7A4A2, 0x3E5F6 },
	{ 0xE7A4A3, 0x2E9C9 },
	{ 0xE7A4A4, 0x2E9CC },
	{ 0xE7A4A5, 0x2E9C8 },
	{ 0xE7A4A6, 0x1F9FC },
	{ 0xE7A4A7, 0x2E9CA },
	{ 0xE7A4A8, 0x2E9CB },
	{ 0xE7A4A9, 0x2E9CD },
	{ 0xE7A4AA, 0x1F9FD },
	{ 0xE7A4AB, 0x1FAA1 },
	{ 0xE7A4AC, 0x1F9FE },
	{ 0xE7A4AD, 0x2EBEF },
	{ 0xE7A4AE, 0x3DEC5 },
	{ 0xE7A4AF, 0x2EBF1 },
	{ 0xE7A4B0, 0x3DEC3 },
	{ 0xE7A4B1, 0x2EBF0 },
	{ 0xE7A4B2, 0x3DEC4 },
	{ 0xE7A4B5, 0x2EDE4 },
	{ 0xE7A4B6, 0xFEAE6 },
	{ 0xE7A4B7, 0x3E0BC },
	{ 0xE7A4B8, 0x2F0C3 },
	{ 0xE7A4B9, 0x2F1AA },
	{ 0xE7A4BA, 0x1C6FC },
	{ 0xE7A4BC, 0x3A4B3 },
	{ 0xE7A4BD, 0x2A4F2 },
	{ 0xE7A4BE, 0x1CFA3 },
	{ 0xE7A4BF, 0x2A8C3 },
	{ 0xE7A580, 0x1CFA4 },
	{ 0xE7A581, 0x1CFA5 },
	{ 0xE7A582, 0x2A8C2 },
	{ 0xE7A584, 0x2ACDA },
	{ 0xE7A585, 0x2ACD9 },
	{ 0xE7A586, 0x1D2E9 },
	{ 0xE7A587, 0x1D2EC },
	{ 0xE7A588, 0x1D2EB },
	{ 0xE7A589, 0x1D2EA },
	{ 0xE7A58A, 0x2ACD6 },
	{ 0xE7A58B, 0x2ACD8 },
	{ 0xE7A58C, 0x2ACD7 },
	{ 0xE7A58D, 0x3E5F7 },
	{ 0xE7A58F, 0x2B1CB },
	{ 0xE7A590, 0x1D7AA },
	{ 0xE7A591, 0x2B1CF },
	{ 0xE7A592, 0x2B1CE },
	{ 0xE7A593, 0x2B1CD },
	{ 0xE7A594, 0x2B1C9 },
	{ 0xE7A595, 0x1D7A9 },
	{ 0xE7A596, 0x1D7AD },
	{ 0xE7A597, 0x1D7B0 },
	{ 0xE7A598, 0x3B2EF },
	{ 0xE7A599, 0x3B2F0 },
	{ 0xE7A59A, 0x1D7B1 },
	{ 0xE7A59B, 0x2B1CA },
	{ 0xE7A59C, 0x2B1CC },
	{ 0xE7A59D, 0x1D7AF },
	{ 0xE7A59E, 0x1D7AE },
	{ 0xE7A59F, 0x1D7AC },
	{ 0xE7A5A0, 0x1D7AB },
	{ 0xE7A5A1, 0x2B7E5 },
	{ 0xE7A5A2, 0x3B2F2 },
	{ 0xE7A5A3, 0x2B7E3 },
	{ 0xE7A5A4, 0x2B7DF },
	{ 0xE7A5A5, 0x1DCC0 },
	{ 0xE7A5A6, 0x3BDDE },
	{ 0xE7A5A7, 0x2B7E0 },
	{ 0xE7A5A8, 0x1DCC1 },
	{ 0xE7A5A9, 0x2B7E1 },
	{ 0xE7A5AA, 0x2B7E2 },
	{ 0xE7A5AB, 0x2B7E4 },
	{ 0xE7A5AC, 0x3B7E6 },
	{ 0xE7A5AD, 0x1DCC2 },
	{ 0xE7A5AE, 0x3B7E5 },
	{ 0xE7A5B0, 0x2BED9 },
	{ 0xE7A5B1, 0x3BDDF },
	{ 0xE7A5B2, 0x2BED8 },
	{ 0xE7A5B3, 0x2BED7 },
	{ 0xE7A5B4, 0x2BED6 },
	{ 0xE7A5B5, 0x3BDE4 },
	{ 0xE7A5B6, 0x3BDE2 },
	{ 0xE7A5B7, 0x4B9DA },
	{ 0xE7A5B9, 0x2C5DC },
	{ 0xE7A5BA, 0x1E5D9 },
	{ 0xE7A5BB, 0x4BFC6 },
	{ 0xE7A5BC, 0x2C5D9 },
	{ 0xE7A5BD, 0x2C5DB },
	{ 0xE7A5BE, 0x3C3B8 },
	{ 0xE7A5BF, 0x1E5DA },
	{ 0xE7A680, 0x3C3BD },
	{ 0xE7A681, 0x1E5DB },
	{ 0xE7A682, 0x2C5DA },
	{ 0xE7A683, 0x3C3B9 },
	{ 0xE7A684, 0x3BDE3 },
	{ 0xE7A686, 0x3E5F8 },
	{ 0xE7A687, 0x3C8C8 },
	{ 0xE7A688, 0x2CCC8 },
	{ 0xE7A689, 0x3C8C7 },
	{ 0xE7A68A, 0x2CCC1 },
	{ 0xE7A68B, 0x2CCC2 },
	{ 0xE7A68C, 0x5C7FE },
	{ 0xE7A68D, 0x1E9FE },
	{ 0xE7A68E, 0x1E9FC },
	{ 0xE7A68F, 0x1E9FD },
	{ 0xE7A690, 0x2CCCA },
	{ 0xE7A691, 0x5C8A2 },
	{ 0xE7A692, 0x2CCC9 },
	{ 0xE7A693, 0x2CCC6 },
	{ 0xE7A694, 0x2CCC5 },
	{ 0xE7A695, 0x2CCC4 },
	{ 0xE7A696, 0x2CCC3 },
	{ 0xE7A697, 0x2CCC7 },
	{ 0xE7A698, 0x2CCC0 },
	{ 0xE7A699, 0x3E5F9 },
	{ 0xE7A69A, 0x2D2D3 },
	{ 0xE7A69B, 0x2D2D8 },
	{ 0xE7A69C, 0x2D2D6 },
	{ 0xE7A69D, 0x3CDD0 },
	{ 0xE7A69E, 0x3CDD1 },
	{ 0xE7A69F, 0x3CDCF },
	{ 0xE7A6A0, 0x2D2D5 },
	{ 0xE7A6A1, 0x2D2D4 },
	{ 0xE7A6A2, 0x2D2D7 },
	{ 0xE7A6A3, 0x3E5FA },
	{ 0xE7A6A4, 0x2D8F8 },
	{ 0xE7A6A5, 0x3D2A6 },
	{ 0xE7A6A6, 0x1F1D7 },
	{ 0xE7A6A7, 0x1F4D2 },
	{ 0xE7A6A8, 0x2DDFB },
	{ 0xE7A6A9, 0x3D2A7 },
	{ 0xE7A6AA, 0x1F4D3 },
	{ 0xE7A6AB, 0x2DDFA },
	{ 0xE7A6AC, 0x2E2CB },
	{ 0xE7A6AD, 0x2E2CA },
	{ 0xE7A6AE, 0x1F6F1 },
	{ 0xE7A6AF, 0x3D8C5 },
	{ 0xE7A6B0, 0x2E6AF },
	{ 0xE7A6B1, 0x1F8D6 },
	{ 0xE7A6B2, 0x2E9CE },
	{ 0xE7A6B3, 0x1FBEB },
	{ 0xE7A6B4, 0x2EDE5 },
	{ 0xE7A6B5, 0x3E0BD },
	{ 0xE7A6B6, 0x2F0C5 },
	{ 0xE7A6B7, 0x2F0C4 },
	{ 0xE7A6B8, 0x2A1E7 },
	{ 0xE7A6B9, 0x1D2ED },
	{ 0xE7A6BA, 0x1D2EE },
	{ 0xE7A6BB, 0x2B7E6 },
	{ 0xE7A6BC, 0x3E5FB },
	{ 0xE7A6BD, 0x1E5DD },
	{ 0xE7A6BE, 0x1C6FD },
	{ 0xE7A6BF, 0x1CBB5 },
	{ 0xE7A780, 0x1CBB4 },
	{ 0xE7A781, 0x1CBB3 },
	{ 0xE7A782, 0x4A4E8 },
	{ 0xE7A783, 0x3AABE },
	{ 0xE7A784, 0x3AABD },
	{ 0xE7A785, 0x2A8C4 },
	{ 0xE7A786, 0x3AABF },
	{ 0xE7A787, 0x3AAC2 },
	{ 0xE7A788, 0x1CFA7 },
	{ 0xE7A789, 0x1CFA6 },
	{ 0xE7A78A, 0x3AAC4 },
	{ 0xE7A78B, 0x1D2F1 },
	{ 0xE7A78C, 0x3E5CC },
	{ 0xE7A78D, 0x2ACDC },
	{ 0xE7A78E, 0x2ACDF },
	{ 0xE7A78F, 0x2ACDD },
	{ 0xE7A790, 0x3AEC2 },
	{ 0xE7A791, 0x1D2EF },
	{ 0xE7A792, 0x1D2F0 },
	{ 0xE7A793, 0x3AEC0 },
	{ 0xE7A794, 0x3AEC1 },
	{ 0xE7A795, 0x2ACDB },
	{ 0xE7A796, 0x2ACDE },
	{ 0xE7A797, 0x3AEC3 },
	{ 0xE7A798, 0x1D7B8 },
	{ 0xE7A799, 0x3B2F4 },
	{ 0xE7A79A, 0x3B2F3 },
	{ 0xE7A79B, 0x3B2F9 },
	{ 0xE7A79C, 0x2B1D6 },
	{ 0xE7A79D, 0x2B1D8 },
	{ 0xE7A79E, 0x2B1D7 },
	{ 0xE7A79F, 0x1D7B5 },
	{ 0xE7A7A0, 0x2B1D2 },
	{ 0xE7A7A1, 0x3B2F6 },
	{ 0xE7A7A2, 0x3B2FB },
	{ 0xE7A7A3, 0x1D7B3 },
	{ 0xE7A7A4, 0x1D7B2 },
	{ 0xE7A7A5, 0x3B2F7 },
	{ 0xE7A7A6, 0x1D7B6 },
	{ 0xE7A7A7, 0x1D7B4 },
	{ 0xE7A7A8, 0x3B2F8 },
	{ 0xE7A7A9, 0x1D7B7 },
	{ 0xE7A7AA, 0x2B1D5 },
	{ 0xE7A7AB, 0x2B1D0 },
	{ 0xE7A7AC, 0x2B1D1 },
	{ 0xE7A7AD, 0x2B1D4 },
	{ 0xE7A7AE, 0x2B1D3 },
	{ 0xE7A7B0, 0x3B2FC },
	{ 0xE7A7B1, 0x3B7E9 },
	{ 0xE7A7B2, 0x3B7E7 },
	{ 0xE7A7B3, 0x3B7EB },
	{ 0xE7A7B5, 0x3B7EA },
	{ 0xE7A7B6, 0x2B7E9 },
	{ 0xE7A7B7, 0x2B7EA },
	{ 0xE7A7B8, 0x2B7E8 },
	{ 0xE7A7B9, 0x3B7EC },
	{ 0xE7A7BA, 0x2B7E7 },
	{ 0xE7A7BB, 0x1DCC3 },
	{ 0xE7A7BC, 0xFB7BF },
	{ 0xE7A7BF, 0x3BDE5 },
	{ 0xE7A880, 0x1E1A5 },
	{ 0xE7A881, 0x6CCC8 },
	{ 0xE7A882, 0x2BEDA },
	{ 0xE7A883, 0x2BEDC },
	{ 0xE7A884, 0x2BEDE },
	{ 0xE7A885, 0x1E1A4 },
	{ 0xE7A886, 0x6CCC3 },
	{ 0xE7A887, 0x3BDE6 },
	{ 0xE7A888, 0x1E1A2 },
	{ 0xE7A889, 0x3BDE9 },
	{ 0xE7A88A, 0x2BEDB },
	{ 0xE7A88B, 0x1E1A3 },
	{ 0xE7A88C, 0x2BEDD },
	{ 0xE7A88D, 0x1E1A1 },
	{ 0xE7A88E, 0x3BDE8 },
	{ 0xE7A88F, 0x3C3C1 },
	{ 0xE7A890, 0x2C5E6 },
	{ 0xE7A891, 0x2C5DD },
	{ 0xE7A892, 0x2C5E0 },
	{ 0xE7A893, 0x2C5E4 },
	{ 0xE7A894, 0x1E5E1 },
	{ 0xE7A895, 0x2C5E2 },
	{ 0xE7A896, 0x4BFD0 },
	{ 0xE7A897, 0x2C5E1 },
	{ 0xE7A898, 0x2C5DE },
	{ 0xE7A899, 0x2C5DF },
	{ 0xE7A89A, 0x1E5DF },
	{ 0xE7A89B, 0x2C5E5 },
	{ 0xE7A89C, 0x1E5DE },
	{ 0xE7A89D, 0x3C3C4 },
	{ 0xE7A89E, 0x1E5E3 },
	{ 0xE7A89F, 0x1E5E2 },
	{ 0xE7A8A0, 0x1E5E0 },
	{ 0xE7A8A1, 0x4BFCA },
	{ 0xE7A8A2, 0x2C5E3 },
	{ 0xE7A8A5, 0x3E5A4 },
	{ 0xE7A8A6, 0x2CCD0 },
	{ 0xE7A8A7, 0x4C5DD },
	{ 0xE7A8A8, 0x2CCCF },
	{ 0xE7A8A9, 0x3C8CB },
	{ 0xE7A8AA, 0x3C8CD },
	{ 0xE7A8AB, 0x2CCCB },
	{ 0xE7A8AC, 0x3C8D0 },
	{ 0xE7A8AD, 0x3C8CF },
	{ 0xE7A8AE, 0x1EAA1 },
	{ 0xE7A8AF, 0x2CCCE },
	{ 0xE7A8B0, 0x2CCCD },
	{ 0xE7A8B1, 0x1EAA2 },
	{ 0xE7A8B2, 0x3C8D2 },
	{ 0xE7A8B3, 0xFCAE4 },
	{ 0xE7A8B4, 0x4CBE3 },
	{ 0xE7A8B5, 0x4C5DE },
	{ 0xE7A8B6, 0x4CBEB },
	{ 0xE7A8B7, 0x1EEA9 },
	{ 0xE7A8B8, 0x3CDD5 },
	{ 0xE7A8B9, 0x2D2DA },
	{ 0xE7A8BA, 0x3CDD6 },
	{ 0xE7A8BB, 0x1EEAA },
	{ 0xE7A8BC, 0x1EEA6 },
	{ 0xE7A8BD, 0x1EEA8 },
	{ 0xE7A8BE, 0x3CDDA },
	{ 0xE7A8BF, 0x1EEA5 },
	{ 0xE7A980, 0x1EEA7 },
	{ 0xE7A981, 0x3CDD3 },
	{ 0xE7A982, 0x3CDD7 },
	{ 0xE7A984, 0x2D8F9 },
	{ 0xE7A985, 0x3D2AA },
	{ 0xE7A986, 0x1F1DA },
	{ 0xE7A987, 0x2D8FB },
	{ 0xE7A988, 0x2D8FA },
	{ 0xE7A989, 0x3D5E4 },
	{ 0xE7A98A, 0x2CCCC },
	{ 0xE7A98B, 0x1F1DC },
	{ 0xE7A98C, 0x1F1DB },
	{ 0xE7A98D, 0x1F1D8 },
	{ 0xE7A98E, 0x1F1D9 },
	{ 0xE7A98F, 0x3D2AC },
	{ 0xE7A990, 0xFDBD9 },
	{ 0xE7A993, 0x3D2A9 },
	{ 0xE7A994, 0x2DEA2 },
	{ 0xE7A995, 0x4D7C9 },
	{ 0xE7A996, 0x2DDFE },
	{ 0xE7A997, 0x1F4D4 },
	{ 0xE7A998, 0x2DEA1 },
	{ 0xE7A999, 0x4D7C8 },
	{ 0xE7A99A, 0x2DEA3 },
	{ 0xE7A99B, 0x2DDFD },
	{ 0xE7A99C, 0x2DDFC },
	{ 0xE7A99F, 0x2E2CC },
	{ 0xE7A9A0, 0x1F6F4 },
	{ 0xE7A9A1, 0x1F6F2 },
	{ 0xE7A9A2, 0x1F6F3 },
	{ 0xE7A9A4, 0x3DAE6 },
	{ 0xE7A9A5, 0x4E0C5 },
	{ 0xE7A9A6, 0x3DAE5 },
	{ 0xE7A9A7, 0x2E6B0 },
	{ 0xE7A9A8, 0x2E6B1 },
	{ 0xE7A9A9, 0x1F8D8 },
	{ 0xE7A9AA, 0x3DAE7 },
	{ 0xE7A9AB, 0x1F8D7 },
	{ 0xE7A9AC, 0x2E9D0 },
	{ 0xE7A9AD, 0x2E9D1 },
	{ 0xE7A9AE, 0x2E9CF },
	{ 0xE7A9AF, 0x3DCE4 },
	{ 0xE7A9B0, 0x2EDE6 },
	{ 0xE7A9B1, 0x2EDE7 },
	{ 0xE7A9B2, 0x3E0F6 },
	{ 0xE7A9B3, 0x3E0F7 },
	{ 0xE7A9B4, 0x1C6FE },
	{ 0xE7A9B5, 0x2A2E8 },
	{ 0xE7A9B6, 0x1CBB6 },
	{ 0xE7A9B8, 0x2A8C5 },
	{ 0xE7A9B9, 0x1CFA9 },
	{ 0xE7A9BA, 0x1CFA8 },
	{ 0xE7A9BB, 0x2A8C6 },
	{ 0xE7A9BC, 0x3AEC4 },
	{ 0xE7A9BD, 0x3AEC7 },
	{ 0xE7A9BE, 0x2ACE1 },
	{ 0xE7A9BF, 0x1D2F2 },
	{ 0xE7AA80, 0x2ACE0 },
	{ 0xE7AA81, 0x1D2F3 },
	{ 0xE7AA82, 0x3AEC9 },
	{ 0xE7AA83, 0x3AEC8 },
	{ 0xE7AA84, 0x1D7B9 },
	{ 0xE7AA85, 0x2B1DB },
	{ 0xE7AA86, 0x2B1D9 },
	{ 0xE7AA87, 0x2B1DF },
	{ 0xE7AA88, 0x1D7BA },
	{ 0xE7AA89, 0x2B1DA },
	{ 0xE7AA8A, 0x2B1DE },
	{ 0xE7AA8B, 0x2B1DC },
	{ 0xE7AA8C, 0x2B1DD },
	{ 0xE7AA8F, 0x2B7EB },
	{ 0xE7AA90, 0x2B7ED },
	{ 0xE7AA91, 0x3B7F2 },
	{ 0xE7AA92, 0x1DCC4 },
	{ 0xE7AA93, 0x3B7F1 },
	{ 0xE7AA94, 0x2B7EC },
	{ 0xE7AA95, 0x1DCC5 },
	{ 0xE7AA96, 0x1E1A8 },
	{ 0xE7AA97, 0x1E1A7 },
	{ 0xE7AA98, 0x1E1A6 },
	{ 0xE7AA99, 0x2BEDF },
	{ 0xE7AA9A, 0x3B7F0 },
	{ 0xE7AA9B, 0x4B9E5 },
	{ 0xE7AA9E, 0x2C5E9 },
	{ 0xE7AA9F, 0x1E5E4 },
	{ 0xE7AAA0, 0x1E5E5 },
	{ 0xE7AAA1, 0x3C3C6 },
	{ 0xE7AAA2, 0x2C5E8 },
	{ 0xE7AAA3, 0x2C5E7 },
	{ 0xE7AAA4, 0x3C3C7 },
	{ 0xE7AAA7, 0x3E5FC },
	{ 0xE7AAA8, 0x2CCD1 },
	{ 0xE7AAA9, 0x1EAA4 },
	{ 0xE7AAAA, 0x1EAA3 },
	{ 0xE7AAAB, 0x2CCD2 },
	{ 0xE7AAAC, 0x2CCD3 },
	{ 0xE7AAAE, 0x1EEAC },
	{ 0xE7AAAF, 0x1EEAB },
	{ 0xE7AAB0, 0x3CDDB },
	{ 0xE7AAB1, 0x2D9A1 },
	{ 0xE7AAB2, 0x2D2DB },
	{ 0xE7AAB3, 0x2D2DD },
	{ 0xE7AAB4, 0x2D2DC },
	{ 0xE7AAB5, 0x2D8FE },
	{ 0xE7AAB6, 0x2D8FC },
	{ 0xE7AAB7, 0x2D9A2 },
	{ 0xE7AAB8, 0x2D8FD },
	{ 0xE7AAB9, 0x5D6D2 },
	{ 0xE7AABA, 0x1F1DD },
	{ 0xE7AABB, 0x3D2AF },
	{ 0xE7AABC, 0x4D2A7 },
	{ 0xE7AABD, 0x3D2AE },
	{ 0xE7AABE, 0x2DEA4 },
	{ 0xE7AABF, 0x1F4D5 },
	{ 0xE7AB80, 0x2DEA5 },
	{ 0xE7AB81, 0x2DEA6 },
	{ 0xE7AB82, 0x3D5E8 },
	{ 0xE7AB84, 0x1F6F5 },
	{ 0xE7AB85, 0x1F6F6 },
	{ 0xE7AB86, 0x4E0CB },
	{ 0xE7AB87, 0x1FAA2 },
	{ 0xE7AB88, 0x3DEC9 },
	{ 0xE7AB89, 0x3DEC8 },
	{ 0xE7AB8A, 0x1FCBD },
	{ 0xE7AB8B, 0x1C7A1 },
	{ 0xE7AB8C, 0x3A6FE },
	{ 0xE7AB8D, 0x3A7A1 },
	{ 0xE7AB8E, 0x4A7DB },
	{ 0xE7AB8F, 0x3AAC7 },
	{ 0xE7AB90, 0x3AECE },
	{ 0xE7AB91, 0x2ACE2 },
	{ 0xE7AB92, 0x3AECF },
	{ 0xE7AB93, 0x3AECD },
	{ 0xE7AB94, 0x3AECB },
	{ 0xE7AB95, 0x3AECC },
	{ 0xE7AB97, 0xFACF6 },
	{ 0xE7AB98, 0x2B1E0 },
	{ 0xE7AB99, 0x1D7BB },
	{ 0xE7AB9A, 0x3B3A3 },
	{ 0xE7AB9B, 0x3B3A6 },
	{ 0xE7AB9C, 0x3B3A7 },
	{ 0xE7AB9D, 0x3B3A4 },
	{ 0xE7AB9F, 0x1DDFE },
	{ 0xE7ABA0, 0x1DDFD },
	{ 0xE7ABA1, 0x3B7F3 },
	{ 0xE7ABA2, 0x3BDF1 },
	{ 0xE7ABA3, 0x1E1AA },
	{ 0xE7ABA4, 0x2BEE1 },
	{ 0xE7ABA5, 0x1E1A9 },
	{ 0xE7ABA6, 0x2BEE0 },
	{ 0xE7ABA7, 0x3BDF0 },
	{ 0xE7ABA8, 0x4BFD7 },
	{ 0xE7ABA9, 0x3C3C9 },
	{ 0xE7ABAA, 0x3C3CA },
	{ 0xE7ABAB, 0x2C5EA },
	{ 0xE7ABAC, 0x3C8D4 },
	{ 0xE7ABAD, 0x1EAA5 },
	{ 0xE7ABAE, 0x2CCD4 },
	{ 0xE7ABAF, 0x1EAA6 },
	{ 0xE7ABB0, 0x3C8D5 },
	{ 0xE7ABB1, 0x3D2B0 },
	{ 0xE7ABB2, 0x3D5E9 },
	{ 0xE7ABB3, 0x3D5EA },
	{ 0xE7ABB4, 0x4D7D0 },
	{ 0xE7ABB5, 0x3D8C9 },
	{ 0xE7ABB6, 0x1FAA3 },
	{ 0xE7ABB7, 0x2E9D2 },
	{ 0xE7ABB8, 0x3DFD5 },
	{ 0xE7ABB9, 0x1C8CC },
	{ 0xE7ABBA, 0x1CFAA },
	{ 0xE7ABBB, 0x2A8C7 },
	{ 0xE7ABBC, 0x3AED1 },
	{ 0xE7ABBD, 0x1D2F5 },
	{ 0xE7ABBE, 0x3AED0 },
	{ 0xE7ABBF, 0x1D2F4 },
	{ 0xE7AC80, 0x2ACE3 },
	{ 0xE7AC81, 0x2ACE4 },
	{ 0xE7AC84, 0x2B1E2 },
	{ 0xE7AC85, 0x2B1E4 },
	{ 0xE7AC86, 0x1D7BC },
	{ 0xE7AC88, 0x2B1E6 },
	{ 0xE7AC89, 0x2B1E9 },
	{ 0xE7AC8A, 0x2B1E7 },
	{ 0xE7AC8B, 0x3B3AB },
	{ 0xE7AC8C, 0x4AEF1 },
	{ 0xE7AC8D, 0x3B3AA },
	{ 0xE7AC8E, 0x2B1E8 },
	{ 0xE7AC8F, 0x2B1E5 },
	{ 0xE7AC90, 0x2B1E1 },
	{ 0xE7AC91, 0x1D7BD },
	{ 0xE7AC92, 0x2B1EA },
	{ 0xE7AC93, 0x2B1E3 },
	{ 0xE7AC94, 0x3B3AC },
	{ 0xE7AC96, 0x3B7F8 },
	{ 0xE7AC97, 0x3B7F9 },
	{ 0xE7AC98, 0x2B7F6 },
	{ 0xE7AC99, 0x1DCCB },
	{ 0xE7AC9A, 0x2B8A1 },
	{ 0xE7AC9B, 0x1DCC8 },
	{ 0xE7AC9C, 0x3B7F7 },
	{ 0xE7AC9D, 0x2B7F8 },
	{ 0xE7AC9E, 0x1DCCC },
	{ 0xE7AC9F, 0x3B7FB },
	{ 0xE7ACA0, 0x1DCC6 },
	{ 0xE7ACA1, 0x3B7F6 },
	{ 0xE7ACA2, 0x2B7F3 },
	{ 0xE7ACA3, 0x2B8A2 },
	{ 0xE7ACA4, 0x2B7F4 },
	{ 0xE7ACA5, 0x2B7F1 },
	{ 0xE7ACA6, 0x1DCCA },
	{ 0xE7ACA7, 0x4B3FC },
	{ 0xE7ACA8, 0x1DCC7 },
	{ 0xE7ACA9, 0x4B3FA },
	{ 0xE7ACAA, 0x2B7F7 },
	{ 0xE7ACAB, 0x2B7FA },
	{ 0xE7ACAC, 0x1DCC9 },
	{ 0xE7ACAD, 0x2B7FB },
	{ 0xE7ACAE, 0x1DCCD },
	{ 0xE7ACAF, 0x2B7FC },
	{ 0xE7ACB0, 0x2B7F2 },
	{ 0xE7ACB1, 0x2B7F9 },
	{ 0xE7ACB2, 0x2B7FD },
	{ 0xE7ACB3, 0x2B7F5 },
	{ 0xE7ACB4, 0x2B7F0 },
	{ 0xE7ACB5, 0x2B7EE },
	{ 0xE7ACB6, 0x3B7FA },
	{ 0xE7ACB7, 0x3E5FD },
	{ 0xE7ACB8, 0x2B7FE },
	{ 0xE7ACB9, 0xFB7CD },
	{ 0xE7ACBB, 0x2B7EF },
	{ 0xE7ACBD, 0xFB6FE },
	{ 0xE7ACBF, 0x5BBA4 },
	{ 0xE7AD80, 0x2BEE8 },
	{ 0xE7AD81, 0x3BDFB },
	{ 0xE7AD82, 0x3BDF8 },
	{ 0xE7AD83, 0x3BDF5 },
	{ 0xE7AD84, 0x2BEE4 },
	{ 0xE7AD85, 0x2BEEA },
	{ 0xE7AD86, 0x1E1AD },
	{ 0xE7AD87, 0x2BEE3 },
	{ 0xE7AD88, 0x2BEE5 },
	{ 0xE7AD89, 0x1E1AB },
	{ 0xE7AD8A, 0x2BEE2 },
	{ 0xE7AD8B, 0x1E1B2 },
	{ 0xE7AD8C, 0x2BEE6 },
	{ 0xE7AD8D, 0x1E1B1 },
	{ 0xE7AD8E, 0x2BEE7 },
	{ 0xE7AD8F, 0x1E1B3 },
	{ 0xE7AD90, 0x1E1AE },
	{ 0xE7AD91, 0x1E1B4 },
	{ 0xE7AD92, 0x1E1AF },
	{ 0xE7AD93, 0x3BDF9 },
	{ 0xE7AD94, 0x1E1B0 },
	{ 0xE7AD95, 0x3BDF2 },
	{ 0xE7AD96, 0x1E1AC },
	{ 0xE7AD97, 0x3BDF6 },
	{ 0xE7AD98, 0x2BEE9 },
	{ 0xE7AD99, 0x3E5FE },
	{ 0xE7AD9E, 0x3C3CF },
	{ 0xE7AD9F, 0x4BFE7 },
	{ 0xE7ADA0, 0x1E5E8 },
	{ 0xE7ADA1, 0x2C5F5 },
	{ 0xE7ADA2, 0x3C3CC },
	{ 0xE7ADA3, 0x2C5F8 },
	{ 0xE7ADA4, 0x2C5EC },
	{ 0xE7ADA5, 0x2C5F1 },
	{ 0xE7ADA6, 0x2C5EB },
	{ 0xE7ADA7, 0x1E5EA },
	{ 0xE7ADA8, 0x3C3D5 },
	{ 0xE7ADA9, 0x2C5EF },
	{ 0xE7ADAA, 0x4BFDE },
	{ 0xE7ADAB, 0x3C3CD },
	{ 0xE7ADAC, 0x3BDF7 },
	{ 0xE7ADAD, 0x2C5ED },
	{ 0xE7ADAE, 0x1E5E9 },
	{ 0xE7ADAF, 0x3C3D4 },
	{ 0xE7ADB0, 0x2C5F4 },
	{ 0xE7ADB1, 0x2C5F3 },
	{ 0xE7ADB2, 0x2C5F0 },
	{ 0xE7ADB3, 0x2C5F2 },
	{ 0xE7ADB4, 0x2C5EE },
	{ 0xE7ADB5, 0x1EAAA },
	{ 0xE7ADB6, 0x2C5F7 },
	{ 0xE7ADB7, 0x1E5E6 },
	{ 0xE7ADB8, 0x2C5F6 },
	{ 0xE7ADB9, 0x3C3D1 },
	{ 0xE7ADBB, 0xFC4C5 },
	{ 0xE7AE81, 0x3C8D6 },
	{ 0xE7AE82, 0x2CCE4 },
	{ 0xE7AE83, 0x3C8D8 },
	{ 0xE7AE84, 0x1EAB1 },
	{ 0xE7AE85, 0x2CCDF },
	{ 0xE7AE86, 0x3C8E0 },
	{ 0xE7AE87, 0x1EAB0 },
	{ 0xE7AE88, 0x2CCD5 },
	{ 0xE7AE89, 0x4C5EB },
	{ 0xE7AE8A, 0x2CCD7 },
	{ 0xE7AE8B, 0x1EAA9 },
	{ 0xE7AE8C, 0x2CCDC },
	{ 0xE7AE8D, 0x2CCDB },
	{ 0xE7AE8E, 0x2CCDE },
	{ 0xE7AE8F, 0x1EAAE },
	{ 0xE7AE90, 0x2CCD9 },
	{ 0xE7AE91, 0x2CCD8 },
	{ 0xE7AE92, 0x3C8DA },
	{ 0xE7AE93, 0x3C8DE },
	{ 0xE7AE94, 0x1EAAD },
	{ 0xE7AE95, 0x1EAA8 },
	{ 0xE7AE96, 0x2CCDA },
	{ 0xE7AE97, 0x1EAAB },
	{ 0xE7AE98, 0x2CCE0 },
	{ 0xE7AE99, 0x2CCE2 },
	{ 0xE7AE9B, 0x2CCDD },
	{ 0xE7AE9C, 0x2CCD6 },
	{ 0xE7AE9D, 0x1EAAC },
	{ 0xE7AE9E, 0x3C8D7 },
	{ 0xE7AE9F, 0x3C8DD },
	{ 0xE7AEA0, 0x1EEB4 },
	{ 0xE7AEA1, 0x1EAA7 },
	{ 0xE7AEA2, 0x4C5E4 },
	{ 0xE7AEA3, 0x3C8DC },
	{ 0xE7AEA4, 0x2CCE3 },
	{ 0xE7AEA5, 0x4C5F0 },
	{ 0xE7AEAC, 0x2D2E1 },
	{ 0xE7AEAD, 0x1EEAD },
	{ 0xE7AEAE, 0x3CDDC },
	{ 0xE7AEAF, 0x2D2E3 },
	{ 0xE7AEB0, 0x4CCAB },
	{ 0xE7AEB1, 0x1EEAE },
	{ 0xE7AEB2, 0x3CDE5 },
	{ 0xE7AEB3, 0x3CDDD },
	{ 0xE7AEB4, 0x1EEB0 },
	{ 0xE7AEB5, 0x2D2E6 },
	{ 0xE7AEB6, 0x4CBFA },
	{ 0xE7AEB7, 0x2D2DE },
	{ 0xE7AEB8, 0x1EAAF },
	{ 0xE7AEB9, 0x2D2E4 },
	{ 0xE7AEBA, 0x4CBF3 },
	{ 0xE7AEBB, 0x4CCB1 },
	{ 0xE7AEBC, 0x4CBF4 },
	{ 0xE7AEBD, 0x4CCAA },
	{ 0xE7AEBE, 0x2D2E0 },
	{ 0xE7AEBF, 0x3CDE0 },
	{ 0xE7AF80, 0x1E5E7 },
	{ 0xE7AF81, 0x1EEB3 },
	{ 0xE7AF82, 0x4CCA1 },
	{ 0xE7AF83, 0x4CBF8 },
	{ 0xE7AF84, 0x1EEAF },
	{ 0xE7AF85, 0x4CCA6 },
	{ 0xE7AF86, 0x1EEB1 },
	{ 0xE7AF87, 0x1EEB2 },
	{ 0xE7AF88, 0x4CBF6 },
	{ 0xE7AF89, 0x1F1E0 },
	{ 0xE7AF8A, 0x2D2E5 },
	{ 0xE7AF8B, 0x2D2DF },
	{ 0xE7AF8C, 0x1EEB5 },
	{ 0xE7AF8D, 0x3CDE3 },
	{ 0xE7AF8E, 0x2D2E2 },
	{ 0xE7AF90, 0x3E6A1 },
	{ 0xE7AF94, 0x2D9AC },
	{ 0xE7AF95, 0x2D9A7 },
	{ 0xE7AF96, 0x4D2AD },
	{ 0xE7AF97, 0x5D6E9 },
	{ 0xE7AF98, 0x2D9B1 },
	{ 0xE7AF99, 0x1F1DE },
	{ 0xE7AF9A, 0x2D9A9 },
	{ 0xE7AF9B, 0x1F1E2 },
	{ 0xE7AF9C, 0x2D9AF },
	{ 0xE7AF9D, 0x2D9A6 },
	{ 0xE7AF9E, 0x2D9A3 },
	{ 0xE7AF9F, 0x2D9B2 },
	{ 0xE7AFA0, 0x1F4DB },
	{ 0xE7AFA1, 0x1F1E3 },
	{ 0xE7AFA2, 0x2D9AE },
	{ 0xE7AFA3, 0x2D9A4 },
	{ 0xE7AFA4, 0x1F1E1 },
	{ 0xE7AFA5, 0x2D9A8 },
	{ 0xE7AFA6, 0x1F1E5 },
	{ 0xE7AFA7, 0x2D9A5 },
	{ 0xE7AFA8, 0x2D9AA },
	{ 0xE7AFA9, 0x1F1E4 },
	{ 0xE7AFAA, 0x2D9AD },
	{ 0xE7AFAB, 0x2D9B0 },
	{ 0xE7AFAC, 0x3D2B3 },
	{ 0xE7AFAD, 0x3D2B4 },
	{ 0xE7AFB0, 0x2DEB8 },
	{ 0xE7AFB1, 0x2DEB9 },
	{ 0xE7AFB2, 0x2DEA9 },
	{ 0xE7AFB3, 0x2DEB0 },
	{ 0xE7AFB4, 0x2DEAE },
	{ 0xE7AFB5, 0x4D7DF },
	{ 0xE7AFB6, 0x3D5ED },
	{ 0xE7AFB7, 0x1F4D9 },
	{ 0xE7AFB8, 0x2DEB5 },
	{ 0xE7AFB9, 0x2D9AB },
	{ 0xE7AFBA, 0x3D5EB },
	{ 0xE7AFBB, 0x2DEAC },
	{ 0xE7AFBC, 0x3D5EE },
	{ 0xE7AFBD, 0x2DEB6 },
	{ 0xE7AFBE, 0x1F4D8 },
	{ 0xE7AFBF, 0x2DEAB },
	{ 0xE7B080, 0x2DEAA },
	{ 0xE7B081, 0x2DEB4 },
	{ 0xE7B082, 0x2DEB1 },
	{ 0xE7B083, 0x2DEB3 },
	{ 0xE7B084, 0x4D7D4 },
	{ 0xE7B085, 0x2DEA7 },
	{ 0xE7B086, 0x2DEB7 },
	{ 0xE7B087, 0x1F4D6 },
	{ 0xE7B088, 0x3D5F0 },
	{ 0xE7B089, 0x2DEB2 },
	{ 0xE7B08A, 0x2DEBB },
	{ 0xE7B08B, 0x2DEAF },
	{ 0xE7B08C, 0x1F4DA },
	{ 0xE7B08D, 0x1F4D7 },
	{ 0xE7B08E, 0x2DEAD },
	{ 0xE7B08F, 0x2DEA8 },
	{ 0xE7B090, 0x2DEBA },
	{ 0xE7B091, 0x1F1DF },
	{ 0xE7B092, 0x3D5F1 },
	{ 0xE7B094, 0xFDBDF },
	{ 0xE7B095, 0x4D7D7 },
	{ 0xE7B098, 0x3D5EF },
	{ 0xE7B099, 0x2E2CF },
	{ 0xE7B09A, 0x3D8D0 },
	{ 0xE7B09B, 0x3D8CE },
	{ 0xE7B09C, 0x2E2CD },
	{ 0xE7B09D, 0x2E2D3 },
	{ 0xE7B09E, 0x1F6FA },
	{ 0xE7B09F, 0x2E2D1 },
	{ 0xE7B0A0, 0x2E2D0 },
	{ 0xE7B0A1, 0x1F6FC },
	{ 0xE7B0A2, 0x2E2D6 },
	{ 0xE7B0A3, 0x1F6FB },
	{ 0xE7B0A4, 0x3D8D1 },
	{ 0xE7B0A5, 0x2E2D7 },
	{ 0xE7B0A6, 0x2E2D4 },
	{ 0xE7B0A7, 0x1F6F8 },
	{ 0xE7B0A8, 0x2E2D5 },
	{ 0xE7B0A9, 0x2E2CE },
	{ 0xE7B0AA, 0x1F6F9 },
	{ 0xE7B0AB, 0x1F6F7 },
	{ 0xE7B0AC, 0x2E6B5 },
	{ 0xE7B0AD, 0x2E2D2 },
	{ 0xE7B0AE, 0x3D8CC },
	{ 0xE7B0AF, 0x3E6A2 },
	{ 0xE7B0B0, 0x2E2D8 },
	{ 0xE7B0B2, 0x3E6A3 },
	{ 0xE7B0B3, 0x2E6B2 },
	{ 0xE7B0B4, 0x3DAEF },
	{ 0xE7B0B5, 0x3DAEE },
	{ 0xE7B0B6, 0x4E0CE },
	{ 0xE7B0B7, 0x1F8DD },
	{ 0xE7B0B8, 0x1F8DB },
	{ 0xE7B0B9, 0x2E6B4 },
	{ 0xE7B0BA, 0x4E0CC },
	{ 0xE7B0BB, 0x2E6B6 },
	{ 0xE7B0BC, 0x2E6B3 },
	{ 0xE7B0BD, 0x1F8DC },
	{ 0xE7B0BE, 0x1F8D9 },
	{ 0xE7B0BF, 0x1F8DA },
	{ 0xE7B180, 0x1F8DE },
	{ 0xE7B182, 0x3E6A4 },
	{ 0xE7B183, 0x1FAA5 },
	{ 0xE7B184, 0x3DCE6 },
	{ 0xE7B185, 0x2E9D7 },
	{ 0xE7B186, 0x5ECF9 },
	{ 0xE7B187, 0x2E9D6 },
	{ 0xE7B188, 0x2E9D4 },
	{ 0xE7B189, 0x2E9D3 },
	{ 0xE7B18A, 0x2E9D5 },
	{ 0xE7B18B, 0x3DCE5 },
	{ 0xE7B18C, 0x1FAA4 },
	{ 0xE7B18D, 0x1FAA6 },
	{ 0xE7B18E, 0x3E6A5 },
	{ 0xE7B18F, 0xFE5E7 },
	{ 0xE7B190, 0x1FAFB },
	{ 0xE7B191, 0x3DECC },
	{ 0xE7B192, 0x4E6EF },
	{ 0xE7B193, 0x2EBF3 },
	{ 0xE7B194, 0x2EBF2 },
	{ 0xE7B195, 0x3DCE7 },
	{ 0xE7B196, 0x3DECB },
	{ 0xE7B197, 0x2EDE8 },
	{ 0xE7B198, 0x3DFD8 },
	{ 0xE7B199, 0x2EDEA },
	{ 0xE7B19A, 0x2EDEC },
	{ 0xE7B19B, 0x2EDEB },
	{ 0xE7B19C, 0x2EDE9 },
	{ 0xE7B19D, 0x3DFD7 },
	{ 0xE7B19E, 0x3E0BF },
	{ 0xE7B19F, 0x1FBED },
	{ 0xE7B1A0, 0x1FBEC },
	{ 0xE7B1A2, 0x3E0BE },
	{ 0xE7B1A3, 0x1FCBF },
	{ 0xE7B1A4, 0x1FCBE },
	{ 0xE7B1A5, 0x1FCC0 },
	{ 0xE7B1A6, 0x2EFBC },
	{ 0xE7B1A7, 0x2EFBB },
	{ 0xE7B1A8, 0x3E6A6 },
	{ 0xE7B1A9, 0x2F1AB },
	{ 0xE7B1AA, 0x2F0C6 },
	{ 0xE7B1AB, 0x2F1AC },
	{ 0xE7B1AC, 0x1FDA5 },
	{ 0xE7B1AD, 0x3E1C4 },
	{ 0xE7B1AE, 0x1FDA6 },
	{ 0xE7B1AF, 0x2F1DC },
	{ 0xE7B1B0, 0x4EDDB },
	{ 0xE7B1B1, 0x3E2BA },
	{ 0xE7B1B2, 0x1FDCB },
	{ 0xE7B1B3, 0x1C8CD },
	{ 0xE7B1B4, 0x3AAC9 },
	{ 0xE7B1B5, 0x2A8C8 },
	{ 0xE7B1B6, 0x3AAC8 },
	{ 0xE7B1B7, 0x3AED2 },
	{ 0xE7B1B8, 0x2ACE6 },
	{ 0xE7B1B9, 0x2ACE7 },
	{ 0xE7B1BA, 0x2ACE5 },
	{ 0xE7B1BB, 0x3AED4 },
	{ 0xE7B1BC, 0x3AED3 },
	{ 0xE7B1BD, 0x1D2F6 },
	{ 0xE7B1BE, 0xFADA1 },
	{ 0xE7B1BF, 0x2ACE8 },
	{ 0xE7B280, 0x2ACE9 },
	{ 0xE7B281, 0x2ACEA },
	{ 0xE7B283, 0x3B3B1 },
	{ 0xE7B284, 0x2B1EB },
	{ 0xE7B285, 0x2B1F1 },
	{ 0xE7B286, 0x3B3AE },
	{ 0xE7B287, 0x3B3B0 },
	{ 0xE7B288, 0x2B1EF },
	{ 0xE7B289, 0x1D7BE },
	{ 0xE7B28A, 0x2B1ED },
	{ 0xE7B28B, 0x3B3B2 },
	{ 0xE7B28C, 0x2B1EE },
	{ 0xE7B28D, 0x2B1F0 },
	{ 0xE7B28E, 0x3B3AD },
	{ 0xE7B291, 0x2B1EC },
	{ 0xE7B292, 0x1DCCE },
	{ 0xE7B293, 0x3B7FD },
	{ 0xE7B294, 0x2B8A3 },
	{ 0xE7B295, 0x1DCD0 },
	{ 0xE7B296, 0x2B8A5 },
	{ 0xE7B297, 0x1DCCF },
	{ 0xE7B298, 0x2B8A4 },
	{ 0xE7B299, 0x3B7FE },
	{ 0xE7B29A, 0x3B8A1 },
	{ 0xE7B29B, 0x3B8BE },
	{ 0xE7B29C, 0x3B8A2 },
	{ 0xE7B29D, 0x4B4A2 },
	{ 0xE7B29E, 0x2BEEC },
	{ 0xE7B29F, 0x1E1B5 },
	{ 0xE7B2A0, 0x3BEA1 },
	{ 0xE7B2A1, 0x2BEEE },
	{ 0xE7B2A2, 0x2BEEB },
	{ 0xE7B2A3, 0x2B8A6 },
	{ 0xE7B2A4, 0x3BEA3 },
	{ 0xE7B2A5, 0x1E1B6 },
	{ 0xE7B2A6, 0x3BEA2 },
	{ 0xE7B2A7, 0x3BDFE },
	{ 0xE7B2A8, 0x2BEED },
	{ 0xE7B2A9, 0x3E6A7 },
	{ 0xE7B2AB, 0xFBEA1 },
	{ 0xE7B2AC, 0xFBEA3 },
	{ 0xE7B2AE, 0x3C3D8 },
	{ 0xE7B2AF, 0x2C5FB },
	{ 0xE7B2B0, 0x3C3DC },
	{ 0xE7B2B1, 0x1E5EB },
	{ 0xE7B2B2, 0x2C5F9 },
	{ 0xE7B2B3, 0x1E5EC },
	{ 0xE7B2B4, 0x2C5FA },
	{ 0xE7B2B5, 0x1E5ED },
	{ 0xE7B2B6, 0x4C5F4 },
	{ 0xE7B2B7, 0x3C8E2 },
	{ 0xE7B2B8, 0x3C8E1 },
	{ 0xE7B2B9, 0x1EAB2 },
	{ 0xE7B2BA, 0x2CCE8 },
	{ 0xE7B2BB, 0x2CCE5 },
	{ 0xE7B2BC, 0x2CCE7 },
	{ 0xE7B2BD, 0x1EAB3 },
	{ 0xE7B2BE, 0x1EAB4 },
	{ 0xE7B2BF, 0x2CCE6 },
	{ 0xE7B380, 0xFCBA7 },
	{ 0xE7B381, 0xFCBAB },
	{ 0xE7B382, 0x3CDEF },
	{ 0xE7B383, 0x3CDF1 },
	{ 0xE7B384, 0x3CDED },
	{ 0xE7B385, 0x2D2E7 },
	{ 0xE7B386, 0x3CDF0 },
	{ 0xE7B387, 0x3CDF3 },
	{ 0xE7B388, 0x2D2E8 },
	{ 0xE7B389, 0x3CDF2 },
	{ 0xE7B38A, 0x1EEB6 },
	{ 0xE7B38B, 0x2D2EA },
	{ 0xE7B38C, 0x2D2E9 },
	{ 0xE7B38D, 0x3CDEE },
	{ 0xE7B38E, 0x1A3A3 },
	{ 0xE7B38F, 0x4D2C4 },
	{ 0xE7B390, 0x2D9B6 },
	{ 0xE7B391, 0x2D9B7 },
	{ 0xE7B392, 0x2D9B3 },
	{ 0xE7B393, 0x3D2B7 },
	{ 0xE7B394, 0x2D9B4 },
	{ 0xE7B395, 0x1F1E6 },
	{ 0xE7B396, 0x1F1E7 },
	{ 0xE7B397, 0x2D9B5 },
	{ 0xE7B399, 0x1F4E1 },
	{ 0xE7B39A, 0x3D5F5 },
	{ 0xE7B39B, 0x3D5F4 },
	{ 0xE7B39C, 0x1F4DD },
	{ 0xE7B39D, 0x1F4E2 },
	{ 0xE7B39E, 0x1F4DE },
	{ 0xE7B39F, 0x1F4E0 },
	{ 0xE7B3A0, 0x1F4DC },
	{ 0xE7B3A1, 0x3D2B9 },
	{ 0xE7B3A2, 0x1F4DF },
	{ 0xE7B3A3, 0x3D8D5 },
	{ 0xE7B3A4, 0x4DCDA },
	{ 0xE7B3A5, 0x4DCDB },
	{ 0xE7B3A6, 0x3D8D4 },
	{ 0xE7B3A7, 0x1F6FD },
	{ 0xE7B3A8, 0x2DEBC },
	{ 0xE7B3A9, 0x7C8D7 },
	{ 0xE7B3AA, 0x2E6B8 },
	{ 0xE7B3AB, 0x4E0DA },
	{ 0xE7B3AC, 0x2E6B7 },
	{ 0xE7B3AD, 0x3E6A8 },
	{ 0xE7B3AE, 0x2E9D8 },
	{ 0xE7B3AF, 0x1FAA7 },
	{ 0xE7B3B0, 0x1FAA8 },
	{ 0xE7B3B1, 0x2EDEE },
	{ 0xE7B3B2, 0x2EBF4 },
	{ 0xE7B3B3, 0x3E1E9 },
	{ 0xE7B3B4, 0x2EDED },
	{ 0xE7B3B5, 0x3E0C0 },
	{ 0xE7B3B6, 0x2F1AD },
	{ 0xE7B3B7, 0x2F1F2 },
	{ 0xE7B3B8, 0x1C8CE },
	{ 0xE7B3BA, 0x3A7A2 },
	{ 0xE7B3BB, 0x1CBB7 },
	{ 0xE7B3BC, 0x3AACB },
	{ 0xE7B3BD, 0x2A8C9 },
	{ 0xE7B3BE, 0x1CFAB },
	{ 0xE7B3BF, 0x3AACA },
	{ 0xE7B480, 0x1D2F9 },
	{ 0xE7B481, 0x2ACED },
	{ 0xE7B482, 0x1D2F7 },
	{ 0xE7B483, 0x2ACEB },
	{ 0xE7B484, 0x1D2FC },
	{ 0xE7B485, 0x1D2F8 },
	{ 0xE7B486, 0x1D2FD },
	{ 0xE7B487, 0x1D2FB },
	{ 0xE7B488, 0x2ACEC },
	{ 0xE7B489, 0x1D2FA },
	{ 0xE7B48A, 0x1D7C2 },
	{ 0xE7B48B, 0x1D7C1 },
	{ 0xE7B48C, 0x2B1FC },
	{ 0xE7B48D, 0x1D7CA },
	{ 0xE7B48E, 0x2B1F5 },
	{ 0xE7B48F, 0x2B1FB },
	{ 0xE7B490, 0x1D7C6 },
	{ 0xE7B491, 0x2B1F4 },
	{ 0xE7B492, 0x2B1FA },
	{ 0xE7B493, 0x2B1F8 },
	{ 0xE7B494, 0x1D7C5 },
	{ 0xE7B495, 0x1D7C7 },
	{ 0xE7B496, 0x2B1F7 },
	{ 0xE7B497, 0x1D7C0 },
	{ 0xE7B498, 0x2B1F6 },
	{ 0xE7B499, 0x1D7CB },
	{ 0xE7B49A, 0x1D7C8 },
	{ 0xE7B49B, 0x1D7CC },
	{ 0xE7B49C, 0x1D7C9 },
	{ 0xE7B49D, 0x2B1F3 },
	{ 0xE7B49E, 0x2B1F2 },
	{ 0xE7B49F, 0x2B1F9 },
	{ 0xE7B4A0, 0x1D7C3 },
	{ 0xE7B4A1, 0x1D7BF },
	{ 0xE7B4A2, 0x1D7C4 },
	{ 0xE7B4A3, 0x4AFA5 },
	{ 0xE7B4A4, 0x3B3B7 },
	{ 0xE7B4A5, 0x3B3BB },
	{ 0xE7B4A8, 0x2B8B5 },
	{ 0xE7B4A9, 0x2B8AE },
	{ 0xE7B4AA, 0x4BAA6 },
	{ 0xE7B4AB, 0x1E1BB },
	{ 0xE7B4AC, 0x2B8AD },
	{ 0xE7B4AD, 0x3B8A9 },
	{ 0xE7B4AE, 0x1DCD4 },
	{ 0xE7B4AF, 0x1DCDB },
	{ 0xE7B4B0, 0x1DCD8 },
	{ 0xE7B4B1, 0x1DCDE },
	{ 0xE7B4B2, 0x1DCDD },
	{ 0xE7B4B3, 0x1DCD9 },
	{ 0xE7B4B4, 0x3B8A6 },
	{ 0xE7B4B5, 0x2B8A7 },
	{ 0xE7B4B6, 0x2B8AA },
	{ 0xE7B4B7, 0x3B8A7 },
	{ 0xE7B4B8, 0x2B8A9 },
	{ 0xE7B4B9, 0x1DCD5 },
	{ 0xE7B4BA, 0x2B8AB },
	{ 0xE7B4BB, 0x2B8B4 },
	{ 0xE7B4BC, 0x1DCD6 },
	{ 0xE7B4BD, 0x2B8A8 },
	{ 0xE7B4BE, 0x2B8B1 },
	{ 0xE7B4BF, 0x2B8B2 },
	{ 0xE7B580, 0x1DCD7 },
	{ 0xE7B581, 0x2B8AF },
	{ 0xE7B582, 0x1DCDC },
	{ 0xE7B583, 0x1DCD2 },
	{ 0xE7B584, 0x1DCDA },
	{ 0xE7B585, 0x2B8AC },
	{ 0xE7B586, 0x1DCD1 },
	{ 0xE7B587, 0x2B8B0 },
	{ 0xE7B588, 0x3B8AE },
	{ 0xE7B589, 0x3B8A4 },
	{ 0xE7B58A, 0x2B8B3 },
	{ 0xE7B58B, 0xFB7D4 },
	{ 0xE7B58C, 0x3B8AB },
	{ 0xE7B58D, 0x3BEB4 },
	{ 0xE7B58E, 0x2BFA1 },
	{ 0xE7B58F, 0x2BEF6 },
	{ 0xE7B590, 0x1E1B8 },
	{ 0xE7B591, 0x2BEFD },
	{ 0xE7B592, 0x2BEFA },
	{ 0xE7B593, 0x2BEF2 },
	{ 0xE7B594, 0x2BEFB },
	{ 0xE7B595, 0x1E1BA },
	{ 0xE7B596, 0x2BEF3 },
	{ 0xE7B597, 0x3BEA9 },
	{ 0xE7B598, 0x2BEEF },
	{ 0xE7B599, 0x3BEA6 },
	{ 0xE7B59A, 0x3BEAE },
	{ 0xE7B59B, 0x1E5F3 },
	{ 0xE7B59C, 0x2BEF8 },
	{ 0xE7B59D, 0x3BEAF },
	{ 0xE7B59E, 0x1E1B7 },
	{ 0xE7B59F, 0x2BEFE },
	{ 0xE7B5A0, 0x3BEA8 },
	{ 0xE7B5A1, 0x1E1BE },
	{ 0xE7B5A2, 0x1E1C0 },
	{ 0xE7B5A3, 0x2BEF1 },
	{ 0xE7B5A4, 0x3BEAC },
	{ 0xE7B5A5, 0x4BAA7 },
	{ 0xE7B5A6, 0x1E1BF },
	{ 0xE7B5A7, 0x2BEF4 },
	{ 0xE7B5A8, 0x1E1B9 },
	{ 0xE7B5A9, 0x2BEFC },
	{ 0xE7B5AA, 0x2BEF5 },
	{ 0xE7B5AB, 0x2BEF9 },
	{ 0xE7B5AC, 0x3BEAA },
	{ 0xE7B5AD, 0x2BEF7 },
	{ 0xE7B5AE, 0x1E1BC },
	{ 0xE7B5AF, 0x2BEF0 },
	{ 0xE7B5B0, 0x1E1C1 },
	{ 0xE7B5B1, 0x1DCD3 },
	{ 0xE7B5B2, 0x1E1BD },
	{ 0xE7B5B3, 0x1E1C2 },
	{ 0xE7B5B4, 0x3BEA4 },
	{ 0xE7B5B5, 0x3BEB5 },
	{ 0xE7B5B6, 0x3BEB3 },
	{ 0xE7B5B8, 0x3C3E7 },
	{ 0xE7B5B9, 0x1E5EF },
	{ 0xE7B5BA, 0x2C6A4 },
	{ 0xE7B5BB, 0x2C6A6 },
	{ 0xE7B5BC, 0x2C6A8 },
	{ 0xE7B5BD, 0x2C6AC },
	{ 0xE7B5BE, 0x3BEAB },
	{ 0xE7B5BF, 0x2C6A2 },
	{ 0xE7B680, 0x2C5FE },
	{ 0xE7B681, 0x1E5F1 },
	{ 0xE7B682, 0x4BFF1 },
	{ 0xE7B683, 0x2C6A7 },
	{ 0xE7B684, 0x2C6AB },
	{ 0xE7B685, 0x2C6A3 },
	{ 0xE7B686, 0x2C5FD },
	{ 0xE7B687, 0x3C3E6 },
	{ 0xE7B688, 0x2C5FC },
	{ 0xE7B689, 0x3C3E9 },
	{ 0xE7B68A, 0x3C3E0 },
	{ 0xE7B68B, 0x3C3E2 },
	{ 0xE7B68C, 0x2C6A9 },
	{ 0xE7B68D, 0x2C6A1 },
	{ 0xE7B68E, 0x2C6A5 },
	{ 0xE7B68F, 0x1E5F2 },
	{ 0xE7B690, 0x3C3DE },
	{ 0xE7B691, 0x1E5F0 },
	{ 0xE7B692, 0x2C6AD },
	{ 0xE7B693, 0x1E5EE },
	{ 0xE7B694, 0x2C6AA },
	{ 0xE7B695, 0x3C3E4 },
	{ 0xE7B696, 0x2CCF9 },
	{ 0xE7B697, 0x3C3E8 },
	{ 0xE7B698, 0x3C3EA },
	{ 0xE7B699, 0x3C3E3 },
	{ 0xE7B69C, 0x1EAB7 },
	{ 0xE7B69D, 0x2CCF1 },
	{ 0xE7B69E, 0x1EEC3 },
	{ 0xE7B69F, 0x2CCFB },
	{ 0xE7B6A0, 0x1EABA },
	{ 0xE7B6A1, 0x2CDA1 },
	{ 0xE7B6A2, 0x1EAC0 },
	{ 0xE7B6A3, 0x2CCEC },
	{ 0xE7B6A4, 0x3C8F4 },
	{ 0xE7B6A5, 0x4C5FB },
	{ 0xE7B6A6, 0x2CCFC },
	{ 0xE7B6A7, 0x2CCE9 },
	{ 0xE7B6A8, 0x3C8ED },
	{ 0xE7B6A9, 0x2CCFE },
	{ 0xE7B6AA, 0x2CCED },
	{ 0xE7B6AB, 0x3C8EE },
	{ 0xE7B6AC, 0x1EAC7 },
	{ 0xE7B6AD, 0x1EAC4 },
	{ 0xE7B6AE, 0x2CCFD },
	{ 0xE7B6AF, 0x2CCF7 },
	{ 0xE7B6B0, 0x1EAB6 },
	{ 0xE7B6B1, 0x1EABE },
	{ 0xE7B6B2, 0x1EABD },
	{ 0xE7B6B3, 0x3C8F0 },
	{ 0xE7B6B4, 0x1EABC },
	{ 0xE7B6B5, 0x1EAC2 },
	{ 0xE7B6B6, 0x3C8E9 },
	{ 0xE7B6B7, 0x2CCEA },
	{ 0xE7B6B8, 0x1EAC3 },
	{ 0xE7B6B9, 0x2CCF8 },
	{ 0xE7B6BA, 0x1EABF },
	{ 0xE7B6BB, 0x1EAB5 },
	{ 0xE7B6BC, 0x2CCFA },
	{ 0xE7B6BD, 0x1EAB8 },
	{ 0xE7B6BE, 0x1EAB9 },
	{ 0xE7B6BF, 0x1EAC1 },
	{ 0xE7B780, 0x2CCEF },
	{ 0xE7B781, 0x2CCEE },
	{ 0xE7B782, 0x2CCEB },
	{ 0xE7B783, 0x4C5FC },
	{ 0xE7B784, 0x2CCF3 },
	{ 0xE7B785, 0x2CCF0 },
	{ 0xE7B786, 0x2CCF4 },
	{ 0xE7B787, 0x1EAC6 },
	{ 0xE7B788, 0x3C8E8 },
	{ 0xE7B789, 0x2CDA2 },
	{ 0xE7B78A, 0x1EABB },
	{ 0xE7B78B, 0x2CCF5 },
	{ 0xE7B78C, 0x2CCF6 },
	{ 0xE7B78D, 0x3C8F1 },
	{ 0xE7B78E, 0x2CCF2 },
	{ 0xE7B78F, 0x3C8F3 },
	{ 0xE7B790, 0x3E6A9 },
	{ 0xE7B791, 0x3C8EB },
	{ 0xE7B792, 0x1EAC5 },
	{ 0xE7B793, 0x3E6AB },
	{ 0xE7B796, 0x3CEA2 },
	{ 0xE7B797, 0x2D2EF },
	{ 0xE7B798, 0x1EEBB },
	{ 0xE7B799, 0x1EEC4 },
	{ 0xE7B79A, 0x1EEC0 },
	{ 0xE7B79B, 0x2D2EC },
	{ 0xE7B79C, 0x3CDFC },
	{ 0xE7B79D, 0x1EEBD },
	{ 0xE7B79E, 0x1EEC1 },
	{ 0xE7B79F, 0x2D2F8 },
	{ 0xE7B7A0, 0x1EEB7 },
	{ 0xE7B7A1, 0x2D2F0 },
	{ 0xE7B7A2, 0x3CDF8 },
	{ 0xE7B7A3, 0x1EEBF },
	{ 0xE7B7A4, 0x3CEA4 },
	{ 0xE7B7A5, 0x3CEAF },
	{ 0xE7B7A6, 0x2D2F3 },
	{ 0xE7B7A7, 0x2D2EE },
	{ 0xE7B7A8, 0x1EEBE },
	{ 0xE7B7A9, 0x1EEC2 },
	{ 0xE7B7AA, 0x2D2ED },
	{ 0xE7B7AB, 0x3CEAE },
	{ 0xE7B7AC, 0x1EEBC },
	{ 0xE7B7AD, 0x3CDF7 },
	{ 0xE7B7AE, 0x2D2F7 },
	{ 0xE7B7AF, 0x1EEB9 },
	{ 0xE7B7B0, 0x2D2F6 },
	{ 0xE7B7B1, 0x2D2F5 },
	{ 0xE7B7B2, 0x1EEC5 },
	{ 0xE7B7B3, 0x2D0BB },
	{ 0xE7B7B4, 0x1EEB8 },
	{ 0xE7B7B5, 0x3CEAB },
	{ 0xE7B7B6, 0x2D2F4 },
	{ 0xE7B7B7, 0x2D2EB },
	{ 0xE7B7B8, 0x3CDF5 },
	{ 0xE7B7B9, 0x1EEC6 },
	{ 0xE7B7BA, 0x2D2F2 },
	{ 0xE7B7BB, 0x1EEBA },
	{ 0xE7B7BC, 0x3CEA8 },
	{ 0xE7B7BD, 0x3CEA9 },
	{ 0xE7B7BE, 0x3CEA5 },
	{ 0xE7B7BF, 0x3CEAC },
	{ 0xE7B880, 0x3CEA7 },
	{ 0xE7B881, 0x3CDFE },
	{ 0xE7B882, 0x3CDFD },
	{ 0xE7B883, 0x2D2F1 },
	{ 0xE7B884, 0x4CCC5 },
	{ 0xE7B887, 0x3E6AA },
	{ 0xE7B888, 0x1F1EA },
	{ 0xE7B889, 0x1F1EF },
	{ 0xE7B88A, 0x1F1E8 },
	{ 0xE7B88B, 0x2D9C4 },
	{ 0xE7B88C, 0x2D9BB },
	{ 0xE7B88D, 0x2D9C7 },
	{ 0xE7B88E, 0x2D9BF },
	{ 0xE7B88F, 0x2D9C5 },
	{ 0xE7B890, 0x1F1F0 },
	{ 0xE7B891, 0x1F1E9 },
	{ 0xE7B892, 0x2D9B8 },
	{ 0xE7B893, 0x2D9BE },
	{ 0xE7B894, 0x2D9C8 },
	{ 0xE7B895, 0x2D9C1 },
	{ 0xE7B896, 0x2D9C6 },
	{ 0xE7B897, 0x2D9BA },
	{ 0xE7B898, 0x4D2CC },
	{ 0xE7B899, 0x3D2BB },
	{ 0xE7B89A, 0x2D9C2 },
	{ 0xE7B89B, 0x1F1EB },
	{ 0xE7B89C, 0x2D9C0 },
	{ 0xE7B89D, 0x1F1EE },
	{ 0xE7B89E, 0x1F1ED },
	{ 0xE7B89F, 0x2D9BC },
	{ 0xE7B8A0, 0x2D9BD },
	{ 0xE7B8A1, 0x2D9B9 },
	{ 0xE7B8A2, 0x2D9C3 },
	{ 0xE7B8A3, 0x1F1EC },
	{ 0xE7B8A4, 0x2D9CA },
	{ 0xE7B8A5, 0x2D9C9 },
	{ 0xE7B8A6, 0x3D2C0 },
	{ 0xE7B8A7, 0x3D2BF },
	{ 0xE7B8A9, 0x2DEC7 },
	{ 0xE7B8AA, 0x2DEC3 },
	{ 0xE7B8AB, 0x1F4E9 },
	{ 0xE7B8AC, 0x3D5F9 },
	{ 0xE7B8AD, 0x2DEBD },
	{ 0xE7B8AE, 0x1F4E3 },
	{ 0xE7B8AF, 0x1F4F3 },
	{ 0xE7B8B0, 0x2DEC9 },
	{ 0xE7B8B1, 0x1F4EB },
	{ 0xE7B8B2, 0x1F4E7 },
	{ 0xE7B8B3, 0x2DEC0 },
	{ 0xE7B8B4, 0x1F4EE },
	{ 0xE7B8B5, 0x1F4F1 },
	{ 0xE7B8B6, 0x2DECB },
	{ 0xE7B8B7, 0x1F4E6 },
	{ 0xE7B8B8, 0x2DEC2 },
	{ 0xE7B8B9, 0x1F4EF },
	{ 0xE7B8BA, 0x2DECD },
	{ 0xE7B8BB, 0x2DECA },
	{ 0xE7B8BC, 0x2DEBE },
	{ 0xE7B8BD, 0x1F4EA },
	{ 0xE7B8BE, 0x1F4E4 },
	{ 0xE7B8BF, 0x1F4F2 },
	{ 0xE7B980, 0x2DEC5 },
	{ 0xE7B981, 0x1F4ED },
	{ 0xE7B982, 0x2DEBF },
	{ 0xE7B983, 0x1F4E8 },
	{ 0xE7B984, 0x2DECC },
	{ 0xE7B985, 0x1F4EC },
	{ 0xE7B986, 0x1F4E5 },
	{ 0xE7B987, 0x2DEC6 },
	{ 0xE7B988, 0x1F4F0 },
	{ 0xE7B989, 0x2DEC4 },
	{ 0xE7B98C, 0x2DEC8 },
	{ 0xE7B98D, 0x3D5FA },
	{ 0xE7B98E, 0x4DCDF },
	{ 0xE7B98F, 0x3D8D9 },
	{ 0xE7B990, 0x2E2DA },
	{ 0xE7B991, 0x2E2E0 },
	{ 0xE7B992, 0x1F7A5 },
	{ 0xE7B993, 0x2E2E3 },
	{ 0xE7B994, 0x1F6FE },
	{ 0xE7B995, 0x1F7A1 },
	{ 0xE7B996, 0x2E2DB },
	{ 0xE7B997, 0x2E2E2 },
	{ 0xE7B998, 0x2E2DD },
	{ 0xE7B999, 0x1F7A6 },
	{ 0xE7B99A, 0x1F7A3 },
	{ 0xE7B99B, 0x3D8DB },
	{ 0xE7B99C, 0x2E2D9 },
	{ 0xE7B99D, 0x3D8D8 },
	{ 0xE7B99E, 0x1F7A2 },
	{ 0xE7B99F, 0x2E2DF },
	{ 0xE7B9A0, 0x2E2E1 },
	{ 0xE7B9A1, 0x1F7A4 },
	{ 0xE7B9A2, 0x2E2DE },
	{ 0xE7B9A3, 0x2E2DC },
	{ 0xE7B9A4, 0x3E6AC },
	{ 0xE7B9A5, 0x4DCDE },
	{ 0xE7B9A6, 0x3D8DA },
	{ 0xE7B9A8, 0x2E6C2 },
	{ 0xE7B9A9, 0x1F8E2 },
	{ 0xE7B9AA, 0x1F8E3 },
	{ 0xE7B9AB, 0x1F8DF },
	{ 0xE7B9AC, 0x3DAF2 },
	{ 0xE7B9AD, 0x1F8E0 },
	{ 0xE7B9AE, 0x3DAF4 },
	{ 0xE7B9AF, 0x2E6BE },
	{ 0xE7B9B0, 0x2E6BC },
	{ 0xE7B9B1, 0x3DAF5 },
	{ 0xE7B9B2, 0x2E6C0 },
	{ 0xE7B9B3, 0x1F8E4 },
	{ 0xE7B9B4, 0x2E6C1 },
	{ 0xE7B9B5, 0x2E6BA },
	{ 0xE7B9B6, 0x2E6B9 },
	{ 0xE7B9B7, 0x2E6BD },
	{ 0xE7B9B8, 0x2E6BB },
	{ 0xE7B9B9, 0x1F8E1 },
	{ 0xE7B9BA, 0x2E6BF },
	{ 0xE7B9BB, 0x2E9D9 },
	{ 0xE7B9BC, 0x1FAAB },
	{ 0xE7B9BD, 0x1FAAA },
	{ 0xE7B9BE, 0x2E9DA },
	{ 0xE7B9BF, 0x3DCEC },
	{ 0xE7BA80, 0x2E9DC },
	{ 0xE7BA81, 0x2E9DB },
	{ 0xE7BA82, 0x1FAAC },
	{ 0xE7BA84, 0x3DED3 },
	{ 0xE7BA85, 0x3DED0 },
	{ 0xE7BA86, 0x2EBF9 },
	{ 0xE7BA87, 0x2EBF6 },
	{ 0xE7BA88, 0x2EBF7 },
	{ 0xE7BA89, 0x3DED1 },
	{ 0xE7BA8A, 0x2EBF5 },
	{ 0xE7BA8B, 0x2EBF8 },
	{ 0xE7BA8C, 0x1FAFD },
	{ 0xE7BA8D, 0x2EBFA },
	{ 0xE7BA8E, 0x3DED2 },
	{ 0xE7BA8F, 0x1FAFC },
	{ 0xE7BA91, 0x2EDEF },
	{ 0xE7BA92, 0x3DFDA },
	{ 0xE7BA93, 0x1FCC1 },
	{ 0xE7BA94, 0x1FCC3 },
	{ 0xE7BA95, 0x2EFBD },
	{ 0xE7BA96, 0x1FCC2 },
	{ 0xE7BA97, 0x2F0C7 },
	{ 0xE7BA98, 0x2F1AF },
	{ 0xE7BA99, 0x2F1B1 },
	{ 0xE7BA9A, 0x2F1AE },
	{ 0xE7BA9B, 0x2F1B0 },
	{ 0xE7BA9C, 0x1FDB9 },
	{ 0xE7BA9D, 0x4EDF8 },
	{ 0xE7BA9E, 0x3E2B5 },
	{ 0xE7BCB6, 0x1C8CF },
	{ 0xE7BCB7, 0x4A5D7 },
	{ 0xE7BCB8, 0x1D2FE },
	{ 0xE7BCB9, 0x2B0D2 },
	{ 0xE7BCBA, 0x1D7CD },
	{ 0xE7BCBB, 0x3B8B1 },
	{ 0xE7BCBC, 0xFB1F8 },
	{ 0xE7BCBD, 0x1DCDF },
	{ 0xE7BCBE, 0x2BFA2 },
	{ 0xE7BCBF, 0x2BFA3 },
	{ 0xE7BD80, 0x3E6AD },
	{ 0xE7BD81, 0x3C8F7 },
	{ 0xE7BD83, 0x2D9CB },
	{ 0xE7BD84, 0x1F4F4 },
	{ 0xE7BD85, 0x2DECE },
	{ 0xE7BD86, 0x3D5FD },
	{ 0xE7BD87, 0x3D8DC },
	{ 0xE7BD88, 0x1F7A7 },
	{ 0xE7BD8A, 0x2E6C4 },
	{ 0xE7BD8B, 0x2E6C3 },
	{ 0xE7BD8C, 0x1FAAD },
	{ 0xE7BD8D, 0x2EBFB },
	{ 0xE7BD8E, 0x3DFDB },
	{ 0xE7BD8F, 0x2EDF0 },
	{ 0xE7BD90, 0x1FCE4 },
	{ 0xE7BD91, 0x2A2E9 },
	{ 0xE7BD92, 0x4A2A1 },
	{ 0xE7BD94, 0x1CFAC },
	{ 0xE7BD95, 0x1CBB8 },
	{ 0xE7BD97, 0xFA8CA },
	{ 0xE7BD98, 0x2ACEE },
	{ 0xE7BD99, 0x3AACE },
	{ 0xE7BD9B, 0x2B2A4 },
	{ 0xE7BD9C, 0x2B1FD },
	{ 0xE7BD9D, 0x2B2A3 },
	{ 0xE7BD9E, 0x2B2A1 },
	{ 0xE7BD9F, 0x1D7CE },
	{ 0xE7BDA0, 0x2B2A2 },
	{ 0xE7BDA1, 0x2B1FE },
	{ 0xE7BDA2, 0x3B3BC },
	{ 0xE7BDA3, 0x2B8B6 },
	{ 0xE7BDA4, 0x4BAAB },
	{ 0xE7BDA5, 0x2BFA4 },
	{ 0xE7BDA6, 0x2BFA5 },
	{ 0xE7BDA7, 0x2C6B0 },
	{ 0xE7BDA8, 0x2C6B1 },
	{ 0xE7BDA9, 0x1E5F5 },
	{ 0xE7BDAA, 0x1E5F6 },
	{ 0xE7BDAB, 0x2C6AF },
	{ 0xE7BDAC, 0x2C6B2 },
	{ 0xE7BDAD, 0x2C6AE },
	{ 0xE7BDAE, 0x1E5F4 },
	{ 0xE7BDAF, 0x3C8F8 },
	{ 0xE7BDB0, 0x1EAC8 },
	{ 0xE7BDB1, 0x3C8F9 },
	{ 0xE7BDB2, 0x1E5F7 },
	{ 0xE7BDB3, 0x2CDA3 },
	{ 0xE7BDB5, 0x1EEC7 },
	{ 0xE7BDB6, 0x2D2F9 },
	{ 0xE7BDB7, 0x1EEC8 },
	{ 0xE7BDB8, 0x3CEB0 },
	{ 0xE7BDB9, 0x1F1F1 },
	{ 0xE7BDBA, 0x2D9CE },
	{ 0xE7BDBB, 0x2D9CC },
	{ 0xE7BDBC, 0x2D9CD },
	{ 0xE7BDBD, 0x2DED1 },
	{ 0xE7BDBE, 0x2DED0 },
	{ 0xE7BDBF, 0x2DECF },
	{ 0xE7BE80, 0x7C1E1 },
	{ 0xE7BE82, 0x4DCE8 },
	{ 0xE7BE83, 0x2E6C5 },
	{ 0xE7BE84, 0x4E0EF },
	{ 0xE7BE85, 0x1F8E5 },
	{ 0xE7BE86, 0x2E6C6 },
	{ 0xE7BE87, 0x2EDF1 },
	{ 0xE7BE88, 0x1FCE5 },
	{ 0xE7BE89, 0x2F0C8 },
	{ 0xE7BE8A, 0x1C8D0 },
	{ 0xE7BE8B, 0x1CFAE },
	{ 0xE7BE8C, 0x1CFAD },
	{ 0xE7BE8D, 0x2ACF0 },
	{ 0xE7BE8E, 0x1D3A1 },
	{ 0xE7BE8F, 0x3AEDD },
	{ 0xE7BE90, 0x4AFB0 },
	{ 0xE7BE91, 0x2ACEF },
	{ 0xE7BE92, 0x2B2A6 },
	{ 0xE7BE93, 0x3B3BD },
	{ 0xE7BE94, 0x1D7CF },
	{ 0xE7BE95, 0x2B8B7 },
	{ 0xE7BE96, 0x2B2A5 },
	{ 0xE7BE97, 0x3B3BF },
	{ 0xE7BE98, 0x4AFAF },
	{ 0xE7BE99, 0x3B3BE },
	{ 0xE7BE9A, 0x1DCE1 },
	{ 0xE7BE9B, 0x2B8BA },
	{ 0xE7BE9C, 0x2B8B8 },
	{ 0xE7BE9D, 0x2B8B9 },
	{ 0xE7BE9E, 0x1DCE0 },
	{ 0xE7BEA0, 0x2BFA7 },
	{ 0xE7BEA1, 0x2BFA8 },
	{ 0xE7BEA2, 0x2BFA6 },
	{ 0xE7BEA3, 0x3C3EE },
	{ 0xE7BEA4, 0x1E5FA },
	{ 0xE7BEA5, 0x2C6B4 },
	{ 0xE7BEA6, 0x2C6B3 },
	{ 0xE7BEA7, 0x2C6B5 },
	{ 0xE7BEA8, 0x1E5F9 },
	{ 0xE7BEA9, 0x1E5F8 },
	{ 0xE7BEAB, 0x4C6A6 },
	{ 0xE7BEAC, 0x2D2FA },
	{ 0xE7BEAD, 0x2D2FC },
	{ 0xE7BEAE, 0x3CEB1 },
	{ 0xE7BEAF, 0x1EEC9 },
	{ 0xE7BEB0, 0x2D2FB },
	{ 0xE7BEB1, 0x2D9CF },
	{ 0xE7BEB2, 0x1F1F2 },
	{ 0xE7BEB3, 0x2E2E5 },
	{ 0xE7BEB4, 0x3D8DD },
	{ 0xE7BEB5, 0x2E2E4 },
	{ 0xE7BEB6, 0x1F8E6 },
	{ 0xE7BEB7, 0x2E6C7 },
	{ 0xE7BEB8, 0x1F8E8 },
	{ 0xE7BEB9, 0x1F8E7 },
	{ 0xE7BEBA, 0x2E9DD },
	{ 0xE7BEBB, 0x2EBFC },
	{ 0xE7BEBC, 0x1FAFE },
	{ 0xE7BEBD, 0x1C8D1 },
	{ 0xE7BEBE, 0x2ACF1 },
	{ 0xE7BEBF, 0x1D3A2 },
	{ 0xE7BF80, 0x2B2A9 },
	{ 0xE7BF81, 0x1D7D1 },
	{ 0xE7BF82, 0x2B2A8 },
	{ 0xE7BF83, 0x2B2A7 },
	{ 0xE7BF84, 0x3B3C2 },
	{ 0xE7BF85, 0x1D7D0 },
	{ 0xE7BF86, 0x3B3C3 },
	{ 0xE7BF87, 0x2B8C0 },
	{ 0xE7BF88, 0x4B4BD },
	{ 0xE7BF89, 0x2B8C2 },
	{ 0xE7BF8A, 0x2B8BB },
	{ 0xE7BF8B, 0x2B8BC },
	{ 0xE7BF8C, 0x1DCE2 },
	{ 0xE7BF8D, 0x2B8BD },
	{ 0xE7BF8E, 0x1DCE3 },
	{ 0xE7BF8F, 0x2B8C1 },
	{ 0xE7BF90, 0x2B8BE },
	{ 0xE7BF91, 0x2B8BF },
	{ 0xE7BF92, 0x1DCE4 },
	{ 0xE7BF93, 0x3BEB7 },
	{ 0xE7BF94, 0x1E1C4 },
	{ 0xE7BF95, 0x1E1C5 },
	{ 0xE7BF96, 0x3BEB8 },
	{ 0xE7BF97, 0x2BFA9 },
	{ 0xE7BF9B, 0x2C6B6 },
	{ 0xE7BF9C, 0x2C6B7 },
	{ 0xE7BF9D, 0x3C3F2 },
	{ 0xE7BF9E, 0x2CDA7 },
	{ 0xE7BF9F, 0x1EACB },
	{ 0xE7BFA0, 0x1EAC9 },
	{ 0xE7BFA1, 0x1EACA },
	{ 0xE7BFA2, 0x2CDA4 },
	{ 0xE7BFA3, 0x2CDA5 },
	{ 0xE7BFA4, 0x6E0D8 },
	{ 0xE7BFA5, 0x2CDA6 },
	{ 0xE7BFA6, 0x2D3A3 },
	{ 0xE7BFA7, 0x3CEB2 },
	{ 0xE7BFA8, 0x2D3A4 },
	{ 0xE7BFA9, 0x1EECA },
	{ 0xE7BFAA, 0x2D3A1 },
	{ 0xE7BFAB, 0x2D2FE },
	{ 0xE7BFAC, 0x2D3A2 },
	{ 0xE7BFAD, 0x2D2FD },
	{ 0xE7BFAE, 0x1F1F5 },
	{ 0xE7BFAF, 0x2D9D0 },
	{ 0xE7BFB0, 0x1F1F3 },
	{ 0xE7BFB1, 0x1F1F4 },
	{ 0xE7BFB2, 0x2DED3 },
	{ 0xE7BFB3, 0x1F4F5 },
	{ 0xE7BFB4, 0x2DED2 },
	{ 0xE7BFB5, 0x2E1B4 },
	{ 0xE7BFB6, 0x3D5FE },
	{ 0xE7BFB7, 0x2E2E6 },
	{ 0xE7BFB8, 0x2E2E7 },
	{ 0xE7BFB9, 0x1F7A8 },
	{ 0xE7BFBA, 0x3D8E1 },
	{ 0xE7BFBB, 0x1F7A9 },
	{ 0xE7BFBC, 0x1F4F6 },
	{ 0xE7BFBD, 0x2E6C8 },
	{ 0xE7BFBE, 0x2E6C9 },
	{ 0xE7BFBF, 0x2E9DE },
	{ 0xE88080, 0x1FAAE },
	{ 0xE88081, 0x1C8D2 },
	{ 0xE88082, 0x3E6FB },
	{ 0xE88083, 0x1C8D3 },
	{ 0xE88084, 0x1D7D3 },
	{ 0xE88085, 0x1CFAF },
	{ 0xE88086, 0x1D7D2 },
	{ 0xE88087, 0x2ACF2 },
	{ 0xE88088, 0x3B8B6 },
	{ 0xE88089, 0x4ABA5 },
	{ 0xE8808A, 0x3B3C4 },
	{ 0xE8808B, 0x1E1C6 },
	{ 0xE8808C, 0x1C8D4 },
	{ 0xE8808D, 0x1D3A4 },
	{ 0xE8808E, 0x2ACF3 },
	{ 0xE8808F, 0x2ACF4 },
	{ 0xE88090, 0x1D3A3 },
	{ 0xE88091, 0x1D3A5 },
	{ 0xE88092, 0x1C8D5 },
	{ 0xE88093, 0x4A7E1 },
	{ 0xE88094, 0x2ACF5 },
	{ 0xE88095, 0x1D7D5 },
	{ 0xE88096, 0x2B2AA },
	{ 0xE88097, 0x1D7D7 },
	{ 0xE88098, 0x1D7D4 },
	{ 0xE88099, 0x1D7D6 },
	{ 0xE8809A, 0x3B8B7 },
	{ 0xE8809B, 0x2B8C5 },
	{ 0xE8809C, 0x1DCE5 },
	{ 0xE8809D, 0x3B8B9 },
	{ 0xE8809E, 0x2B8C4 },
	{ 0xE8809F, 0x2B8C3 },
	{ 0xE880A0, 0x4BAB8 },
	{ 0xE880A1, 0x2C6B8 },
	{ 0xE880A3, 0x3C9A2 },
	{ 0xE880A4, 0x2CDA8 },
	{ 0xE880A5, 0x4C6AC },
	{ 0xE880A6, 0x1EECB },
	{ 0xE880A8, 0x1F1F6 },
	{ 0xE880A9, 0x2D9D2 },
	{ 0xE880AA, 0x2D9D1 },
	{ 0xE880AB, 0x3D6A1 },
	{ 0xE880AC, 0x2DED4 },
	{ 0xE880AD, 0x4DCF1 },
	{ 0xE880AE, 0x3D8E2 },
	{ 0xE880AF, 0x3DCEF },
	{ 0xE880B0, 0x2EBFD },
	{ 0xE880B1, 0x4E9AE },
	{ 0xE880B2, 0x4E9AD },
	{ 0xE880B3, 0x1C8D6 },
	{ 0xE880B4, 0x2A4F3 },
	{ 0xE880B5, 0x2A8CA },
	{ 0xE880B6, 0x1D3A6 },
	{ 0xE880B7, 0x2ACF6 },
	{ 0xE880B8, 0x6BBA1 },
	{ 0xE880B9, 0x2B2AC },
	{ 0xE880BA, 0x4AFBA },
	{ 0xE880BB, 0x3B3C9 },
	{ 0xE880BC, 0x3B3C8 },
	{ 0xE880BD, 0x1D7D8 },
	{ 0xE880BE, 0x2B2AB },
	{ 0xE880BF, 0x1D7D9 },
	{ 0xE88180, 0x3B3C7 },
	{ 0xE88181, 0x3E6AF },
	{ 0xE88183, 0x2B8C7 },
	{ 0xE88184, 0x3B8BD },
	{ 0xE88185, 0x3B8BC },
	{ 0xE88186, 0x1DCE7 },
	{ 0xE88187, 0x2B8C6 },
	{ 0xE88188, 0x2B8C8 },
	{ 0xE88189, 0x3B8BB },
	{ 0xE8818A, 0x1DCE6 },
	{ 0xE8818E, 0x3BEBC },
	{ 0xE8818F, 0x2BFAB },
	{ 0xE88190, 0x2BFAC },
	{ 0xE88191, 0x2BFAA },
	{ 0xE88192, 0x1E1C7 },
	{ 0xE88193, 0x3E7A9 },
	{ 0xE88195, 0x4BFFC },
	{ 0xE88196, 0x1E5FB },
	{ 0xE88197, 0x3C3F3 },
	{ 0xE88198, 0x1E5FC },
	{ 0xE88199, 0x4C6B3 },
	{ 0xE8819A, 0x1EACD },
	{ 0xE8819B, 0x3C9A3 },
	{ 0xE8819C, 0x2CDAA },
	{ 0xE8819D, 0x2CDA9 },
	{ 0xE8819E, 0x1EACC },
	{ 0xE8819F, 0x3C9A6 },
	{ 0xE881A0, 0x3BEBB },
	{ 0xE881A1, 0x3C9A5 },
	{ 0xE881A3, 0x3E6B0 },
	{ 0xE881A4, 0x2D3A5 },
	{ 0xE881A5, 0x3CEB4 },
	{ 0xE881A6, 0x3CEB6 },
	{ 0xE881A7, 0x2D3A6 },
	{ 0xE881A8, 0x3CEB7 },
	{ 0xE881AA, 0x3CEB5 },
	{ 0xE881AB, 0x3CEB8 },
	{ 0xE881AC, 0x2D9D3 },
	{ 0xE881AD, 0x4D2DC },
	{ 0xE881AE, 0x3D2C3 },
	{ 0xE881AF, 0x1F4FA },
	{ 0xE881B0, 0x1F4F9 },
	{ 0xE881B1, 0x1F4F7 },
	{ 0xE881B2, 0x1F4F8 },
	{ 0xE881B3, 0x1F4FB },
	{ 0xE881B4, 0x3D6A2 },
	{ 0xE881B5, 0x2E2E8 },
	{ 0xE881B6, 0x1F7AB },
	{ 0xE881B7, 0x1F7AA },
	{ 0xE881B8, 0x2E6CA },
	{ 0xE881B9, 0x2E9DF },
	{ 0xE881BA, 0x3DCF0 },
	{ 0xE881BB, 0x3DCF1 },
	{ 0xE881BC, 0x3DCF2 },
	{ 0xE881BD, 0x1FBEF },
	{ 0xE881BE, 0x1FBEE },
	{ 0xE881BF, 0x1C8D7 },
	{ 0xE88281, 0x6BBA4 },
	{ 0xE88282, 0x2AFFD },
	{ 0xE88284, 0x1E5FE },
	{ 0xE88285, 0x1E1C8 },
	{ 0xE88286, 0x1E5FD },
	{ 0xE88287, 0x1EACE },
	{ 0xE88288, 0x6E0E0 },
	{ 0xE88289, 0x1C8D8 },
	{ 0xE8828A, 0x2A1E8 },
	{ 0xE8828B, 0x1C8D9 },
	{ 0xE8828C, 0x1C8DA },
	{ 0xE8828D, 0x3A4B5 },
	{ 0xE8828E, 0x3A4B6 },
	{ 0xE8828F, 0x2A8CB },
	{ 0xE88290, 0x2A4F6 },
	{ 0xE88291, 0x3A7A4 },
	{ 0xE88292, 0x2A4F7 },
	{ 0xE88293, 0x1CBBA },
	{ 0xE88294, 0x3A7A6 },
	{ 0xE88295, 0x2A4F4 },
	{ 0xE88296, 0x1CBB9 },
	{ 0xE88297, 0x3A7A5 },
	{ 0xE88298, 0x1CBBC },
	{ 0xE88299, 0x2A4F5 },
	{ 0xE8829A, 0x1CBBE },
	{ 0xE8829B, 0x1CBBD },
	{ 0xE8829C, 0x2A4F8 },
	{ 0xE8829D, 0x1CBBB },
	{ 0xE8829E, 0x4A4F0 },
	{ 0xE8829F, 0x3A7A3 },
	{ 0xE882A1, 0x1CFB4 },
	{ 0xE882A2, 0x1CFB2 },
	{ 0xE882A3, 0x2A8CD },
	{ 0xE882A4, 0x3AAD6 },
	{ 0xE882A5, 0x1CFB1 },
	{ 0xE882A6, 0x3AADB },
	{ 0xE882A7, 0x3AAD8 },
	{ 0xE882A8, 0x3AACF },
	{ 0xE882A9, 0x1CFB6 },
	{ 0xE882AA, 0x1CFB8 },
	{ 0xE882AB, 0x1CFB5 },
	{ 0xE882AC, 0x3AAD9 },
	{ 0xE882AD, 0x2A8D0 },
	{ 0xE882AE, 0x2A8CC },
	{ 0xE882AF, 0x1CFB9 },
	{ 0xE882B0, 0x3AAD2 },
	{ 0xE882B1, 0x1CFB3 },
	{ 0xE882B2, 0x1CBBF },
	{ 0xE882B3, 0x3AAD4 },
	{ 0xE882B4, 0x1CFB7 },
	{ 0xE882B5, 0x2A8CF },
	{ 0xE882B6, 0x3AAD7 },
	{ 0xE882B7, 0x4A7E4 },
	{ 0xE882B8, 0x2A8CE },
	{ 0xE882B9, 0x4A7E9 },
	{ 0xE882BA, 0x1CFB0 },
	{ 0xE882BB, 0x3E6B1 },
	{ 0xE88382, 0x2ACFC },
	{ 0xE88383, 0x1D3AA },
	{ 0xE88384, 0x1D3AB },
	{ 0xE88385, 0x2ACFE },
	{ 0xE88386, 0x3AEE6 },
	{ 0xE88387, 0x2ACF8 },
	{ 0xE88388, 0x2ACFB },
	{ 0xE88389, 0x2ADA6 },
	{ 0xE8838A, 0x2ADA4 },
	{ 0xE8838B, 0x3AEE0 },
	{ 0xE8838C, 0x1D3AC },
	{ 0xE8838D, 0x2ADAA },
	{ 0xE8838E, 0x1D3AF },
	{ 0xE8838F, 0x2ADA7 },
	{ 0xE88390, 0x2ACFD },
	{ 0xE88391, 0x2ACFA },
	{ 0xE88392, 0x3AEE1 },
	{ 0xE88393, 0x3AEDE },
	{ 0xE88394, 0x2BFAE },
	{ 0xE88395, 0x2ADA5 },
	{ 0xE88396, 0x1D3A7 },
	{ 0xE88397, 0x2ADA8 },
	{ 0xE88398, 0x2ACF7 },
	{ 0xE88399, 0x2ADA2 },
	{ 0xE8839A, 0x1D3A9 },
	{ 0xE8839B, 0x1D3AE },
	{ 0xE8839C, 0x2ADA3 },
	{ 0xE8839D, 0x1D3B2 },
	{ 0xE8839E, 0x1D3B0 },
	{ 0xE8839F, 0x3AEE5 },
	{ 0xE883A0, 0x2ACF9 },
	{ 0xE883A1, 0x1D3AD },
	{ 0xE883A2, 0x3AEE4 },
	{ 0xE883A3, 0x2ADA1 },
	{ 0xE883A4, 0x1D3B1 },
	{ 0xE883A5, 0x1D3A8 },
	{ 0xE883A6, 0x2ADA9 },
	{ 0xE883AD, 0x1D7DE },
	{ 0xE883AE, 0x3B3CC },
	{ 0xE883AF, 0x1D7E7 },
	{ 0xE883B0, 0x1D7DC },
	{ 0xE883B1, 0x1D7DA },
	{ 0xE883B2, 0x2B2AE },
	{ 0xE883B3, 0x1D7E2 },
	{ 0xE883B4, 0x1D7DF },
	{ 0xE883B5, 0x2B2B0 },
	{ 0xE883B6, 0x3B3CA },
	{ 0xE883B7, 0x3B3D2 },
	{ 0xE883B8, 0x1D7E1 },
	{ 0xE883B9, 0x2B2AF },
	{ 0xE883BA, 0x2B2AD },
	{ 0xE883BB, 0x2B2B2 },
	{ 0xE883BC, 0x1D7E6 },
	{ 0xE883BD, 0x1D7E4 },
	{ 0xE883BE, 0x2BFAD },
	{ 0xE883BF, 0x3B3CB },
	{ 0xE88480, 0x2B2B3 },
	{ 0xE88481, 0x2B2B1 },
	{ 0xE88482, 0x1D7DB },
	{ 0xE88483, 0x3B3CE },
	{ 0xE88484, 0x3B3CD },
	{ 0xE88485, 0x1D7DD },
	{ 0xE88486, 0x1D7E0 },
	{ 0xE88487, 0x3B3CF },
	{ 0xE88488, 0x1D7E3 },
	{ 0xE88489, 0x3AEE3 },
	{ 0xE8848A, 0x1D7E5 },
	{ 0xE88494, 0x3BEC4 },
	{ 0xE88495, 0x2B8D2 },
	{ 0xE88496, 0x1DCE9 },
	{ 0xE88497, 0x3B8C9 },
	{ 0xE88498, 0x2B8C9 },
	{ 0xE88499, 0x2B8CB },
	{ 0xE8849A, 0x3B8C7 },
	{ 0xE8849B, 0x2B8CC },
	{ 0xE8849C, 0x4B4CD },
	{ 0xE8849D, 0x2B8D4 },
	{ 0xE8849E, 0x2B8D0 },
	{ 0xE8849F, 0x2B8CE },
	{ 0xE884A0, 0x4BABB },
	{ 0xE884A1, 0x2B8D1 },
	{ 0xE884A2, 0x2B8D5 },
	{ 0xE884A3, 0x1DCEA },
	{ 0xE884A4, 0x1DCEE },
	{ 0xE884A5, 0x2B8CA },
	{ 0xE884A6, 0x4B4C7 },
	{ 0xE884A7, 0x2B8D3 },
	{ 0xE884A8, 0x4B4D0 },
	{ 0xE884A9, 0x1DCEC },
	{ 0xE884AA, 0x3B8C1 },
	{ 0xE884AB, 0x1DCEB },
	{ 0xE884AC, 0x2B8CF },
	{ 0xE884AD, 0x2B8CD },
	{ 0xE884AE, 0x3B8C2 },
	{ 0xE884AF, 0x1DCE8 },
	{ 0xE884B0, 0x1DCED },
	{ 0xE884B1, 0x3B8C5 },
	{ 0xE884B4, 0x3B8C8 },
	{ 0xE884B9, 0x1E1CE },
	{ 0xE884BA, 0x2BFB6 },
	{ 0xE884BB, 0x3BEBE },
	{ 0xE884BC, 0x4BABE },
	{ 0xE884BD, 0x2BFB4 },
	{ 0xE884BE, 0x1E1D0 },
	{ 0xE884BF, 0x4BAC7 },
	{ 0xE88580, 0x3BEC3 },
	{ 0xE88581, 0x3BEC5 },
	{ 0xE88582, 0x3BEC1 },
	{ 0xE88583, 0x2BFAF },
	{ 0xE88584, 0x2C6C6 },
	{ 0xE88585, 0x3BEBD },
	{ 0xE88586, 0x1E1CF },
	{ 0xE88587, 0x2BFB3 },
	{ 0xE88588, 0x3BEC0 },
	{ 0xE88589, 0x3BEC2 },
	{ 0xE8858A, 0x2BFB0 },
	{ 0xE8858B, 0x1E1CB },
	{ 0xE8858C, 0x1E1D1 },
	{ 0xE8858D, 0x2BFB5 },
	{ 0xE8858E, 0x1E1CD },
	{ 0xE8858F, 0x2BFB2 },
	{ 0xE88590, 0x1EACF },
	{ 0xE88591, 0x1E1CC },
	{ 0xE88592, 0x2BFB1 },
	{ 0xE88593, 0x1E1D2 },
	{ 0xE88594, 0x1E1CA },
	{ 0xE88595, 0x1E1C9 },
	{ 0xE88598, 0x6C3DA },
	{ 0xE8859B, 0x2C6BE },
	{ 0xE8859C, 0x2C6BC },
	{ 0xE8859D, 0x3C3FB },
	{ 0xE8859E, 0x2C6C2 },
	{ 0xE8859F, 0x3C3FE },
	{ 0xE885A0, 0x2C6BA },
	{ 0xE885A1, 0x2C6C7 },
	{ 0xE885A2, 0x2C6BF },
	{ 0xE885A3, 0x3C3F5 },
	{ 0xE885A4, 0x2C6B9 },
	{ 0xE885A5, 0x1E6A4 },
	{ 0xE885A6, 0x1E6AA },
	{ 0xE885A7, 0x2C6C4 },
	{ 0xE885A8, 0x4C0A9 },
	{ 0xE885A9, 0x2C6BD },
	{ 0xE885AA, 0x3C3F6 },
	{ 0xE885AB, 0x1E6A7 },
	{ 0xE885AC, 0x3C3F7 },
	{ 0xE885AD, 0x3C4A3 },
	{ 0xE885AE, 0x1E6A5 },
	{ 0xE885AF, 0x2C6C5 },
	{ 0xE885B0, 0x1E6A2 },
	{ 0xE885B1, 0x1E6A1 },
	{ 0xE885B2, 0x2C6C0 },
	{ 0xE885B3, 0x1E6A6 },
	{ 0xE885B4, 0x1E1D3 },
	{ 0xE885B5, 0x3C3FC },
	{ 0xE885B6, 0x2C6C3 },
	{ 0xE885B7, 0x2C6BB },
	{ 0xE885B8, 0x1E6A3 },
	{ 0xE885B9, 0x1E6A8 },
	{ 0xE885BA, 0x1E6A9 },
	{ 0xE885BD, 0x3C4A2 },
	{ 0xE885BF, 0x1EAD4 },
	{ 0xE88680, 0x1EAD0 },
	{ 0xE88681, 0x3C9A7 },
	{ 0xE88682, 0x1EAD5 },
	{ 0xE88683, 0x2CDAD },
	{ 0xE88684, 0x3C9AA },
	{ 0xE88685, 0x4C6B9 },
	{ 0xE88686, 0x2CDAC },
	{ 0xE88687, 0x2CDAE },
	{ 0xE88688, 0x1EAD2 },
	{ 0xE88689, 0x2CDAB },
	{ 0xE8868A, 0x1EAD3 },
	{ 0xE8868B, 0x2CDB1 },
	{ 0xE8868C, 0x2CDB0 },
	{ 0xE8868D, 0x2CDAF },
	{ 0xE8868E, 0x4C6C6 },
	{ 0xE8868F, 0x1EAD1 },
	{ 0xE88690, 0x4D2E7 },
	{ 0xE88692, 0x3CEBB },
	{ 0xE88693, 0x3CEBD },
	{ 0xE88694, 0x3CEB9 },
	{ 0xE88695, 0x2D3AA },
	{ 0xE88696, 0x3CEBC },
	{ 0xE88697, 0x2D3AD },
	{ 0xE88698, 0x1EED1 },
	{ 0xE88699, 0x2D3AC },
	{ 0xE8869A, 0x1EED0 },
	{ 0xE8869B, 0x1EECC },
	{ 0xE8869C, 0x1EECD },
	{ 0xE8869D, 0x1EECE },
	{ 0xE8869E, 0x2D3A9 },
	{ 0xE8869F, 0x2D3A8 },
	{ 0xE886A0, 0x1EECF },
	{ 0xE886A1, 0x3CEBA },
	{ 0xE886A2, 0x2D3AB },
	{ 0xE886A3, 0x2D3A7 },
	{ 0xE886A6, 0x2D9D5 },
	{ 0xE886A7, 0x2D9DF },
	{ 0xE886A8, 0x1F1F9 },
	{ 0xE886A9, 0x1F1F8 },
	{ 0xE886AA, 0x3D2C9 },
	{ 0xE886AB, 0x2D9D9 },
	{ 0xE886AC, 0x2D9DB },
	{ 0xE886AD, 0x3D2C7 },
	{ 0xE886AE, 0x2D9D6 },
	{ 0xE886AF, 0x3D2C4 },
	{ 0xE886B0, 0x2D9DA },
	{ 0xE886B1, 0x2D9D4 },
	{ 0xE886B2, 0x2D9DD },
	{ 0xE886B3, 0x1F1F7 },
	{ 0xE886B4, 0x2D9DC },
	{ 0xE886B5, 0x2D9D8 },
	{ 0xE886B7, 0x2D9DE },
	{ 0xE886B8, 0x3D6A3 },
	{ 0xE886B9, 0x2D9D7 },
	{ 0xE886BA, 0x1F4FE },
	{ 0xE886BB, 0x2DED5 },
	{ 0xE886BC, 0x2DEDB },
	{ 0xE886BD, 0x1F5A4 },
	{ 0xE886BE, 0x1F5A6 },
	{ 0xE886BF, 0x1F5A3 },
	{ 0xE88780, 0x1F5A2 },
	{ 0xE88781, 0x4D8A7 },
	{ 0xE88782, 0x1F5A1 },
	{ 0xE88783, 0x1F4FD },
	{ 0xE88784, 0x2DED6 },
	{ 0xE88785, 0x2DED9 },
	{ 0xE88786, 0x1F4FC },
	{ 0xE88787, 0x2DEDA },
	{ 0xE88788, 0x3D6A4 },
	{ 0xE88789, 0x1F5A5 },
	{ 0xE8878A, 0x2DED8 },
	{ 0xE8878B, 0x7C8FC },
	{ 0xE8878C, 0x2DED7 },
	{ 0xE8878D, 0x1F7AC },
	{ 0xE8878E, 0x3D8E5 },
	{ 0xE8878F, 0x1F7AD },
	{ 0xE88790, 0x2E2EB },
	{ 0xE88791, 0x2E2E9 },
	{ 0xE88792, 0x2E2EA },
	{ 0xE88794, 0x3DAF7 },
	{ 0xE88795, 0x2E6CC },
	{ 0xE88796, 0x3DAF8 },
	{ 0xE88797, 0x2E6CB },
	{ 0xE88798, 0x1F8E9 },
	{ 0xE88799, 0x2E9E1 },
	{ 0xE8879A, 0x1FAAF },
	{ 0xE8879B, 0x2E9E0 },
	{ 0xE8879D, 0x2EBFE },
	{ 0xE8879E, 0x2EDF2 },
	{ 0xE8879F, 0x1FBF0 },
	{ 0xE887A0, 0x2F1B2 },
	{ 0xE887A1, 0x2F1B3 },
	{ 0xE887A2, 0x1FCC4 },
	{ 0xE887A3, 0x1C8DB },
	{ 0xE887A4, 0x4A7EC },
	{ 0xE887A5, 0x1CFBA },
	{ 0xE887A6, 0x2BFB7 },
	{ 0xE887A7, 0x1EAD6 },
	{ 0xE887A8, 0x1F5A7 },
	{ 0xE887A9, 0x2DEDC },
	{ 0xE887AA, 0x1C8DC },
	{ 0xE887AB, 0x4A4F3 },
	{ 0xE887AC, 0x1D7E9 },
	{ 0xE887AD, 0x1D7E8 },
	{ 0xE887AE, 0x2BFB8 },
	{ 0xE887AF, 0x3BEC7 },
	{ 0xE887B0, 0x4BACC },
	{ 0xE887B1, 0x4CCE2 },
	{ 0xE887B2, 0x2D9E0 },
	{ 0xE887B3, 0x1C8DD },
	{ 0xE887B4, 0x1D3B3 },
	{ 0xE887B5, 0x4BACD },
	{ 0xE887B6, 0x3BEC8 },
	{ 0xE887B7, 0x2BFB9 },
	{ 0xE887B8, 0x2BFBA },
	{ 0xE887B9, 0x2BFBB },
	{ 0xE887BA, 0x1EAD7 },
	{ 0xE887BB, 0x1F1FA },
	{ 0xE887BC, 0x1C8DE },
	{ 0xE887BD, 0x4A7ED },
	{ 0xE887BE, 0x1CFBB },
	{ 0xE887BF, 0x2ADAB },
	{ 0xE88880, 0x1D7EA },
	{ 0xE88881, 0x2B2B4 },
	{ 0xE88882, 0x1DCEF },
	{ 0xE88883, 0x3BEC9 },
	{ 0xE88884, 0x2BFBC },
	{ 0xE88885, 0x1E6AB },
	{ 0xE88887, 0x1EAD8 },
	{ 0xE88888, 0x1F1FB },
	{ 0xE88889, 0x1F5A8 },
	{ 0xE8888A, 0x1F7AE },
	{ 0xE8888B, 0x2E6CD },
	{ 0xE8888C, 0x1C8DF },
	{ 0xE8888D, 0x1CFBC },
	{ 0xE8888E, 0x3AADD },
	{ 0xE8888F, 0x4A7EE },
	{ 0xE88890, 0x1D7EB },
	{ 0xE88891, 0x2B8D6 },
	{ 0xE88892, 0x1E1D4 },
	{ 0xE88893, 0x3C9AB },
	{ 0xE88894, 0x1EAD9 },
	{ 0xE88895, 0x2CDB2 },
	{ 0xE88896, 0x2D3AE },
	{ 0xE88898, 0x3D2CA },
	{ 0xE88899, 0x3D8E8 },
	{ 0xE8889A, 0x3DAF9 },
	{ 0xE8889B, 0x1C8E0 },
	{ 0xE8889C, 0x1E1D5 },
	{ 0xE8889D, 0x2C6C8 },
	{ 0xE8889E, 0x1EADA },
	{ 0xE8889F, 0x1C8E1 },
	{ 0xE888A0, 0x2A8D1 },
	{ 0xE888A1, 0x2ADAC },
	{ 0xE888A2, 0x1D3B4 },
	{ 0xE888A4, 0x3AEE8 },
	{ 0xE888A5, 0x2B2B6 },
	{ 0xE888A6, 0x4AFCF },
	{ 0xE888A7, 0x3B3D7 },
	{ 0xE888A8, 0x1D7EE },
	{ 0xE888A9, 0x3B3D8 },
	{ 0xE888AA, 0x1D7EC },
	{ 0xE888AB, 0x1D7ED },
	{ 0xE888AC, 0x1D7EF },
	{ 0xE888AD, 0x3B3D5 },
	{ 0xE888AF, 0x2B2B5 },
	{ 0xE888B2, 0x2B8DB },
	{ 0xE888B3, 0x2B8D8 },
	{ 0xE888B4, 0x2B8DA },
	{ 0xE888B5, 0x1DCF0 },
	{ 0xE888B6, 0x1DCF2 },
	{ 0xE888B7, 0x1DCF1 },
	{ 0xE888B8, 0x2B8D7 },
	{ 0xE888B9, 0x1DCF3 },
	{ 0xE888BA, 0x2B8D9 },
	{ 0xE888BC, 0x2BFBD },
	{ 0xE888BD, 0x2BFBE },
	{ 0xE888BF, 0x2BFBF },
	{ 0xE88980, 0x2C6CB },
	{ 0xE88981, 0x3C4A6 },
	{ 0xE88982, 0x2C6CC },
	{ 0xE88983, 0x4C0AE },
	{ 0xE88984, 0x2C6CA },
	{ 0xE88985, 0x2C6CD },
	{ 0xE88986, 0x4C0AD },
	{ 0xE88987, 0x1E6AC },
	{ 0xE88988, 0x3E6B4 },
	{ 0xE88989, 0x2C6C9 },
	{ 0xE8898A, 0x3C9AD },
	{ 0xE8898B, 0x1EADB },
	{ 0xE8898C, 0x3C9AE },
	{ 0xE8898E, 0x2D3B3 },
	{ 0xE8898F, 0x2D3AF },
	{ 0xE88990, 0x2D3B2 },
	{ 0xE88991, 0x2D3B4 },
	{ 0xE88992, 0x2D3B1 },
	{ 0xE88993, 0x2D3B0 },
	{ 0xE88995, 0x2D9E1 },
	{ 0xE88996, 0x2D9E2 },
	{ 0xE88997, 0x2D9E3 },
	{ 0xE88998, 0x1F1FC },
	{ 0xE88999, 0x1F1FD },
	{ 0xE8899A, 0x2DEDE },
	{ 0xE8899B, 0x2DEDD },
	{ 0xE8899C, 0x2DEDF },
	{ 0xE8899E, 0x2E2ED },
	{ 0xE8899F, 0x2E2EC },
	{ 0xE889A1, 0x2E6CF },
	{ 0xE889A2, 0x3DAFA },
	{ 0xE889A3, 0x2E6D0 },
	{ 0xE889A4, 0x2E6CE },
	{ 0xE889A5, 0x3DAFB },
	{ 0xE889A6, 0x1FAB0 },
	{ 0xE889A7, 0x4E4AC },
	{ 0xE889A8, 0x2E9E2 },
	{ 0xE889A9, 0x2E9E3 },
	{ 0xE889AA, 0x3DED5 },
	{ 0xE889AB, 0x2EDF3 },
	{ 0xE889AC, 0x2EFBE },
	{ 0xE889AD, 0x2F0C9 },
	{ 0xE889AE, 0x1C8E2 },
	{ 0xE889AF, 0x1CBC0 },
	{ 0xE889B1, 0x1F5A9 },
	{ 0xE889B2, 0x1C8E3 },
	{ 0xE889B3, 0xFB2B2 },
	{ 0xE889B4, 0x2B8DC },
	{ 0xE889B5, 0x2BFC0 },
	{ 0xE889B6, 0x3DAFC },
	{ 0xE889B7, 0x1FCEC },
	{ 0xE889B8, 0x2A2EA },
	{ 0xE889B9, 0x4A1D3 },
	{ 0xE889BB, 0x3A4B8 },
	{ 0xE889BC, 0x2A2EB },
	{ 0xE889BD, 0x2A2ED },
	{ 0xE889BE, 0x1C8E4 },
	{ 0xE889BF, 0x2A2EE },
	{ 0xE88A80, 0x2A2EC },
	{ 0xE88A81, 0x4A3AF },
	{ 0xE88A83, 0x2A5A2 },
	{ 0xE88A84, 0x2A5A3 },
	{ 0xE88A85, 0x2A4FB },
	{ 0xE88A86, 0x3A7A8 },
	{ 0xE88A87, 0x4A4FB },
	{ 0xE88A89, 0x4A4F5 },
	{ 0xE88A8A, 0x2A5A1 },
	{ 0xE88A8B, 0x1CBC2 },
	{ 0xE88A8C, 0x3A7A9 },
	{ 0xE88A8D, 0x1CBC3 },
	{ 0xE88A8E, 0x2A4FC },
	{ 0xE88A8F, 0x2A4FA },
	{ 0xE88A90, 0x2A4F9 },
	{ 0xE88A91, 0x2A4FD },
	{ 0xE88A92, 0x1CBC1 },
	{ 0xE88A93, 0x2A4FE },
	{ 0xE88A94, 0x2ADAD },
	{ 0xE88A95, 0x3A7AB },
	{ 0xE88A96, 0x4A4F9 },
	{ 0xE88A98, 0x2A8D6 },
	{ 0xE88A99, 0x1CFBF },
	{ 0xE88A9A, 0x2A8D5 },
	{ 0xE88A9B, 0x2A8D7 },
	{ 0xE88A9C, 0x3AAE0 },
	{ 0xE88A9D, 0x1CFBE },
	{ 0xE88A9E, 0x2A8DC },
	{ 0xE88A9F, 0x1CFC2 },
	{ 0xE88AA0, 0x2A8D2 },
	{ 0xE88AA1, 0x2A8E0 },
	{ 0xE88AA2, 0x2A8E6 },
	{ 0xE88AA3, 0x1CFC9 },
	{ 0xE88AA4, 0x2A8E3 },
	{ 0xE88AA5, 0x1CFC6 },
	{ 0xE88AA6, 0x3AAEB },
	{ 0xE88AA7, 0x2A8D9 },
	{ 0xE88AA8, 0x2A8DF },
	{ 0xE88AA9, 0x2A8E1 },
	{ 0xE88AAA, 0x3AAE6 },
	{ 0xE88AAB, 0x2A8D4 },
	{ 0xE88AAC, 0x1CFC5 },
	{ 0xE88AAD, 0x1CFC0 },
	{ 0xE88AAE, 0x2A8DA },
	{ 0xE88AAF, 0x1CFC7 },
	{ 0xE88AB0, 0x1CFCA },
	{ 0xE88AB1, 0x1CFC4 },
	{ 0xE88AB2, 0x3AAEC },
	{ 0xE88AB3, 0x1CFBD },
	{ 0xE88AB4, 0x2A8DE },
	{ 0xE88AB5, 0x2A8D8 },
	{ 0xE88AB6, 0x2A8E5 },
	{ 0xE88AB7, 0x1CFCC },
	{ 0xE88AB8, 0x1CFC8 },
	{ 0xE88AB9, 0x1CFC3 },
	{ 0xE88ABA, 0x2A8DD },
	{ 0xE88ABB, 0x1D7F0 },
	{ 0xE88ABC, 0x2A8DB },
	{ 0xE88ABD, 0x1CFC1 },
	{ 0xE88ABE, 0x1CFCB },
	{ 0xE88ABF, 0x4A7FA },
	{ 0xE88B80, 0x2A8D3 },
	{ 0xE88B81, 0x4A7FE },
	{ 0xE88B82, 0x2A8E2 },
	{ 0xE88B83, 0x2A8E4 },
	{ 0xE88B84, 0x3AADE },
	{ 0xE88B85, 0xFA8E3 },
	{ 0xE88B89, 0x3AAE8 },
	{ 0xE88B8A, 0x4A7FB },
	{ 0xE88B90, 0x3AEF6 },
	{ 0xE88B91, 0x1D3C5 },
	{ 0xE88B92, 0x1D3BF },
	{ 0xE88B93, 0x1D3C7 },
	{ 0xE88B94, 0x1D3C4 },
	{ 0xE88B95, 0x2ADB4 },
	{ 0xE88B96, 0x2ADB7 },
	{ 0xE88B97, 0x1D3C0 },
	{ 0xE88B98, 0x3AEEA },
	{ 0xE88B99, 0x2ADAE },
	{ 0xE88B9A, 0x4ABBA },
	{ 0xE88B9B, 0x1D3B9 },
	{ 0xE88B9C, 0x1D3C3 },
	{ 0xE88B9D, 0x3AEEB },
	{ 0xE88B9E, 0x1D3C6 },
	{ 0xE88B9F, 0x1D3C8 },
	{ 0xE88BA0, 0x2ADC3 },
	{ 0xE88BA1, 0x2ADBA },
	{ 0xE88BA2, 0x3AEF8 },
	{ 0xE88BA3, 0x1D3B8 },
	{ 0xE88BA4, 0x2ADC2 },
	{ 0xE88BA5, 0x1D3BC },
	{ 0xE88BA6, 0x1D3BA },
	{ 0xE88BA7, 0x1D3B5 },
	{ 0xE88BA8, 0x2ADB2 },
	{ 0xE88BA9, 0x3AEF2 },
	{ 0xE88BAA, 0x2ADC1 },
	{ 0xE88BAB, 0x2ADB6 },
	{ 0xE88BAC, 0x2ADB9 },
	{ 0xE88BAD, 0x2ADC6 },
	{ 0xE88BAE, 0x3AEF4 },
	{ 0xE88BAF, 0x1D3C9 },
	{ 0xE88BB0, 0x2ADC0 },
	{ 0xE88BB1, 0x1D3C1 },
	{ 0xE88BB2, 0x2ADBB },
	{ 0xE88BB3, 0x2ADC5 },
	{ 0xE88BB4, 0x2ADB8 },
	{ 0xE88BB5, 0x2ADBC },
	{ 0xE88BB6, 0x2ADBF },
	{ 0xE88BB7, 0x3AEE9 },
	{ 0xE88BB8, 0x3AEEE },
	{ 0xE88BB9, 0x2ADB0 },
	{ 0xE88BBA, 0x2ADC4 },
	{ 0xE88BBB, 0x2ADBE },
	{ 0xE88BBC, 0x3AEEF },
	{ 0xE88BBD, 0x3AEFA },
	{ 0xE88BBE, 0x2ADAF },
	{ 0xE88BBF, 0x6B4BC },
	{ 0xE88C80, 0x2ADB3 },
	{ 0xE88C81, 0x1D3C2 },
	{ 0xE88C82, 0x1D3BD },
	{ 0xE88C83, 0x1D3B6 },
	{ 0xE88C84, 0x1D3BB },
	{ 0xE88C85, 0x1D3B7 },
	{ 0xE88C86, 0x1D3CA },
	{ 0xE88C87, 0x2ADB1 },
	{ 0xE88C88, 0x2B2C7 },
	{ 0xE88C89, 0x1D3BE },
	{ 0xE88C8A, 0x4ABBD },
	{ 0xE88C8B, 0x3AEF9 },
	{ 0xE88C8C, 0x2ADBD },
	{ 0xE88C8D, 0x2A9C2 },
	{ 0xE88C8E, 0x3AEF7 },
	{ 0xE88C90, 0x3E6B5 },
	{ 0xE88C92, 0x3E6B7 },
	{ 0xE88C96, 0x2B2CA },
	{ 0xE88C97, 0x1D7FE },
	{ 0xE88C98, 0x3B3E2 },
	{ 0xE88C99, 0x2B2BA },
	{ 0xE88C9A, 0x4AFDD },
	{ 0xE88C9B, 0x2B2C5 },
	{ 0xE88C9C, 0x2B2C1 },
	{ 0xE88C9D, 0x3B8CD },
	{ 0xE88C9E, 0x2B2D4 },
	{ 0xE88C9F, 0x3B3D9 },
	{ 0xE88CA0, 0x2B2CC },
	{ 0xE88CA1, 0x3B3DF },
	{ 0xE88CA2, 0x2B2C2 },
	{ 0xE88CA3, 0x3B8DB },
	{ 0xE88CA4, 0x2B2CB },
	{ 0xE88CA5, 0x2B2BC },
	{ 0xE88CA6, 0x2B2C0 },
	{ 0xE88CA7, 0x2B2D7 },
	{ 0xE88CA8, 0x1D8A3 },
	{ 0xE88CA9, 0x2B2CF },
	{ 0xE88CAA, 0x2B2C6 },
	{ 0xE88CAB, 0x1D7F1 },
	{ 0xE88CAC, 0x2B2D5 },
	{ 0xE88CAD, 0x2B2B8 },
	{ 0xE88CAE, 0x4AFDA },
	{ 0xE88CAF, 0x2B2CE },
	{ 0xE88CB0, 0x4AFE3 },
	{ 0xE88CB1, 0x1D8A2 },
	{ 0xE88CB2, 0x1D7FB },
	{ 0xE88CB3, 0x2B2B7 },
	{ 0xE88CB4, 0x1D7F9 },
	{ 0xE88CB5, 0x1D7F8 },
	{ 0xE88CB6, 0x1D7FD },
	{ 0xE88CB7, 0x2B2CD },
	{ 0xE88CB8, 0x1D7F5 },
	{ 0xE88CB9, 0x1D7FC },
	{ 0xE88CBA, 0x2ADB5 },
	{ 0xE88CBB, 0x2BFC1 },
	{ 0xE88CBC, 0x2B2C8 },
	{ 0xE88CBD, 0x4AFDF },
	{ 0xE88CBE, 0x3AADF },
	{ 0xE88CBF, 0x2B2BE },
	{ 0xE88D80, 0x1D8A1 },
	{ 0xE88D81, 0x2B2BF },
	{ 0xE88D82, 0x2B2C3 },
	{ 0xE88D83, 0x1D8A4 },
	{ 0xE88D84, 0x2B2B9 },
	{ 0xE88D85, 0x2B2D1 },
	{ 0xE88D86, 0x3BED7 },
	{ 0xE88D87, 0x2B2D0 },
	{ 0xE88D88, 0x2B2D8 },
	{ 0xE88D89, 0x1D7F7 },
	{ 0xE88D8A, 0x1D7F4 },
	{ 0xE88D8B, 0x2B2D6 },
	{ 0xE88D8C, 0x2B2D2 },
	{ 0xE88D8D, 0x2B2C9 },
	{ 0xE88D8E, 0x2B2C4 },
	{ 0xE88D8F, 0x1D7FA },
	{ 0xE88D90, 0x1D7F6 },
	{ 0xE88D91, 0x2B2BB },
	{ 0xE88D92, 0x1D7F2 },
	{ 0xE88D93, 0x2B2D3 },
	{ 0xE88D94, 0x1D7F3 },
	{ 0xE88D95, 0x4AFDC },
	{ 0xE88D96, 0x2B2BD },
	{ 0xE88D97, 0x3B3DA },
	{ 0xE88D98, 0x3B3E3 },
	{ 0xE88DA2, 0x3E6B6 },
	{ 0xE88DA3, 0x3ADB3 },
	{ 0xE88DB0, 0x4B4E7 },
	{ 0xE88DB1, 0x3B8CE },
	{ 0xE88DB2, 0x3B8D1 },
	{ 0xE88DB3, 0x2B8E2 },
	{ 0xE88DB4, 0x2B8E4 },
	{ 0xE88DB5, 0x2B8E9 },
	{ 0xE88DB6, 0x2B8FD },
	{ 0xE88DB7, 0x1DDA3 },
	{ 0xE88DB8, 0x1DCF7 },
	{ 0xE88DB9, 0x3B8D4 },
	{ 0xE88DBA, 0x2B8E1 },
	{ 0xE88DBB, 0x1DDA4 },
	{ 0xE88DBC, 0x1DDA5 },
	{ 0xE88DBD, 0x2B8EC },
	{ 0xE88DBE, 0x2B8F3 },
	{ 0xE88DBF, 0x2B8F9 },
	{ 0xE88E80, 0x3B8D0 },
	{ 0xE88E81, 0x2B8E6 },
	{ 0xE88E82, 0x4B4ED },
	{ 0xE88E83, 0x2B8ED },
	{ 0xE88E84, 0x3B8CF },
	{ 0xE88E85, 0x3B8DD },
	{ 0xE88E86, 0x1DDA6 },
	{ 0xE88E87, 0x2B8FB },
	{ 0xE88E88, 0x2B8F6 },
	{ 0xE88E89, 0x1DDA1 },
	{ 0xE88E8A, 0x1DCFD },
	{ 0xE88E8B, 0x2B8F2 },
	{ 0xE88E8C, 0x2B8EE },
	{ 0xE88E8D, 0x2B8E0 },
	{ 0xE88E8E, 0x1DCF4 },
	{ 0xE88E8F, 0x2B8E5 },
	{ 0xE88E90, 0x2B8DD },
	{ 0xE88E91, 0x3B8D5 },
	{ 0xE88E92, 0x1DCFC },
	{ 0xE88E93, 0x1DCFE },
	{ 0xE88E94, 0x2B8EA },
	{ 0xE88E95, 0x2B8E7 },
	{ 0xE88E96, 0x1DCF9 },
	{ 0xE88E97, 0x2B8F7 },
	{ 0xE88E98, 0x1DCF6 },
	{ 0xE88E99, 0x2B8E8 },
	{ 0xE88E9A, 0x2BFEA },
	{ 0xE88E9B, 0x2B8F0 },
	{ 0xE88E9C, 0x3B8DE },
	{ 0xE88E9D, 0x2B8EF },
	{ 0xE88E9E, 0x1DCF5 },
	{ 0xE88E9F, 0x3B8D7 },
	{ 0xE88EA0, 0x1DDA2 },
	{ 0xE88EA1, 0x3B8D2 },
	{ 0xE88EA2, 0x1DCF8 },
	{ 0xE88EA3, 0x2B8DE },
	{ 0xE88EA4, 0x2B8E3 },
	{ 0xE88EA5, 0x2B8F4 },
	{ 0xE88EA6, 0x2B8FA },
	{ 0xE88EA7, 0x1DDA7 },
	{ 0xE88EA8, 0x2B8DF },
	{ 0xE88EA9, 0x2B8EB },
	{ 0xE88EAA, 0x2B8F1 },
	{ 0xE88EAB, 0x1DCFB },
	{ 0xE88EAC, 0x4B4EF },
	{ 0xE88EAD, 0x3B8D8 },
	{ 0xE88EAE, 0x2B8FC },
	{ 0xE88EAF, 0x2B8F5 },
	{ 0xE88EB0, 0x2B8F8 },
	{ 0xE88EB7, 0x3B8DF },
	{ 0xE88EB9, 0xFB7F8 },
	{ 0xE88EBD, 0x1DCFA },
	{ 0xE88EBE, 0x4BAE8 },
	{ 0xE88EBF, 0x2BFD1 },
	{ 0xE88F80, 0x2BFC5 },
	{ 0xE88F81, 0x1E1DD },
	{ 0xE88F82, 0x2BFE2 },
	{ 0xE88F83, 0x2BFEB },
	{ 0xE88F84, 0x2BFEE },
	{ 0xE88F85, 0x1E1DB },
	{ 0xE88F86, 0x2BFCD },
	{ 0xE88F87, 0x2BFE6 },
	{ 0xE88F88, 0x2BFCE },
	{ 0xE88F89, 0x2BFDC },
	{ 0xE88F8A, 0x1E1E8 },
	{ 0xE88F8B, 0x2BFD8 },
	{ 0xE88F8C, 0x1E1E5 },
	{ 0xE88F8D, 0x3BEDE },
	{ 0xE88F8E, 0x2BFD9 },
	{ 0xE88F8F, 0x2BFC2 },
	{ 0xE88F90, 0x5BBEF },
	{ 0xE88F91, 0x2BFE7 },
	{ 0xE88F92, 0x3BECF },
	{ 0xE88F93, 0x3BED9 },
	{ 0xE88F94, 0x1E1EE },
	{ 0xE88F95, 0x2BFE4 },
	{ 0xE88F96, 0x2BFDA },
	{ 0xE88F97, 0x2BFF0 },
	{ 0xE88F98, 0x2BFD5 },
	{ 0xE88F99, 0x2C6ED },
	{ 0xE88F9A, 0x3BECD },
	{ 0xE88F9B, 0x2BFF3 },
	{ 0xE88F9C, 0x1E1EC },
	{ 0xE88F9D, 0x2BFD3 },
	{ 0xE88F9E, 0x2BFDF },
	{ 0xE88F9F, 0x1E1EF },
	{ 0xE88FA0, 0x1E1DA },
	{ 0xE88FA1, 0x2BFD7 },
	{ 0xE88FA2, 0x2BFF1 },
	{ 0xE88FA3, 0x2BFD0 },
	{ 0xE88FA4, 0x2BFC9 },
	{ 0xE88FA5, 0x2BFD4 },
	{ 0xE88FA6, 0x3BEDF },
	{ 0xE88FA7, 0x2BFC8 },
	{ 0xE88FA8, 0x2BFC6 },
	{ 0xE88FA9, 0x1E1D6 },
	{ 0xE88FAA, 0x2BFE8 },
	{ 0xE88FAB, 0x2BFCF },
	{ 0xE88FAC, 0x2BFEC },
	{ 0xE88FAD, 0x3BECB },
	{ 0xE88FAE, 0x2BFED },
	{ 0xE88FAF, 0x1E1DE },
	{ 0xE88FB0, 0x1E1E3 },
	{ 0xE88FB1, 0x1E1DF },
	{ 0xE88FB2, 0x1E1E7 },
	{ 0xE88FB3, 0x2BFE3 },
	{ 0xE88FB4, 0x1E1E0 },
	{ 0xE88FB5, 0x2BFDB },
	{ 0xE88FB6, 0x2BFCB },
	{ 0xE88FB7, 0xFBEE6 },
	{ 0xE88FB8, 0x1E1D8 },
	{ 0xE88FB9, 0x2BFC3 },
	{ 0xE88FBA, 0x2BFE5 },
	{ 0xE88FBB, 0x2BFEF },
	{ 0xE88FBC, 0x2BFCA },
	{ 0xE88FBD, 0x1E1E6 },
	{ 0xE88FBE, 0x2BFF4 },
	{ 0xE88FBF, 0x2BFD6 },
	{ 0xE89080, 0x3BED2 },
	{ 0xE89081, 0x2BFD2 },
	{ 0xE89082, 0x3BEDC },
	{ 0xE89083, 0x1E1D7 },
	{ 0xE89084, 0x1E1EB },
	{ 0xE89085, 0x3BEDA },
	{ 0xE89086, 0x2BFE1 },
	{ 0xE89087, 0x1E1ED },
	{ 0xE89088, 0x3BED0 },
	{ 0xE89089, 0x2BFDD },
	{ 0xE8908A, 0x1E1E2 },
	{ 0xE8908B, 0x1E1DC },
	{ 0xE8908C, 0x1E1E4 },
	{ 0xE8908D, 0x1E1D9 },
	{ 0xE8908E, 0x1E1EA },
	{ 0xE8908F, 0x2BFDE },
	{ 0xE89090, 0x2BFCC },
	{ 0xE89091, 0x2BFE0 },
	{ 0xE89092, 0x2BFC7 },
	{ 0xE89093, 0x2BFE9 },
	{ 0xE89094, 0x3BED8 },
	{ 0xE89095, 0x4BAE7 },
	{ 0xE89096, 0x3BEDD },
	{ 0xE89097, 0x3BED6 },
	{ 0xE89098, 0x3BECE },
	{ 0xE8909B, 0x2BFF2 },
	{ 0xE8909E, 0x3E6B9 },
	{ 0xE8909F, 0x3BEDB },
	{ 0xE890A1, 0x3E6B8 },
	{ 0xE890A3, 0x2BFC4 },
	{ 0xE890A9, 0x2C6EC },
	{ 0xE890AA, 0x3C4AD },
	{ 0xE890AB, 0x2C7A4 },
	{ 0xE890AC, 0x1E5DC },
	{ 0xE890AD, 0x2C6F1 },
	{ 0xE890AE, 0x3C4B1 },
	{ 0xE890AF, 0x2C6EF },
	{ 0xE890B0, 0x2C6DA },
	{ 0xE890B1, 0x1E6B0 },
	{ 0xE890B2, 0x2C6EA },
	{ 0xE890B3, 0x2C6FE },
	{ 0xE890B4, 0x2C6E6 },
	{ 0xE890B5, 0x1E6B8 },
	{ 0xE890B6, 0x2C6FD },
	{ 0xE890B7, 0x2C6E4 },
	{ 0xE890B8, 0x1E1E9 },
	{ 0xE890B9, 0x2C6F4 },
	{ 0xE890BA, 0x2C6E5 },
	{ 0xE890BB, 0x2C6FB },
	{ 0xE890BC, 0x1E6B7 },
	{ 0xE890BD, 0x1E6AF },
	{ 0xE890BE, 0x3C4BA },
	{ 0xE890BF, 0x2C6CF },
	{ 0xE89180, 0x2C6D7 },
	{ 0xE89181, 0x3C4B5 },
	{ 0xE89182, 0x2C6F0 },
	{ 0xE89183, 0x2C6E8 },
	{ 0xE89184, 0x2C7A3 },
	{ 0xE89185, 0x2C6EB },
	{ 0xE89186, 0x1E6BD },
	{ 0xE89187, 0x2C6FC },
	{ 0xE89188, 0x3C4AC },
	{ 0xE89189, 0x1E6B4 },
	{ 0xE8918A, 0x3C4BE },
	{ 0xE8918B, 0x2C6EE },
	{ 0xE8918C, 0x2C6F6 },
	{ 0xE8918D, 0x2C6DB },
	{ 0xE8918E, 0x2C6F5 },
	{ 0xE8918F, 0x3C4A7 },
	{ 0xE89190, 0x2C7A8 },
	{ 0xE89191, 0x2C6D6 },
	{ 0xE89192, 0x2C6F7 },
	{ 0xE89193, 0x3C4B3 },
	{ 0xE89194, 0x2C7A6 },
	{ 0xE89195, 0x3C4BF },
	{ 0xE89196, 0x2C6D0 },
	{ 0xE89197, 0x1E1E1 },
	{ 0xE89198, 0x3C4C0 },
	{ 0xE89199, 0x2C6DE },
	{ 0xE8919A, 0x2C6DD },
	{ 0xE8919B, 0x1E6B6 },
	{ 0xE8919C, 0x3C4B2 },
	{ 0xE8919D, 0x2C6E1 },
	{ 0xE8919E, 0x2C6E3 },
	{ 0xE8919F, 0x2C6F2 },
	{ 0xE891A0, 0x2C7A5 },
	{ 0xE891A1, 0x1E6B9 },
	{ 0xE891A2, 0x3C4B8 },
	{ 0xE891A3, 0x1E6BA },
	{ 0xE891A4, 0x3C4B0 },
	{ 0xE891A5, 0x2C6D5 },
	{ 0xE891A6, 0x1E6B2 },
	{ 0xE891A7, 0x2C6D9 },
	{ 0xE891A8, 0x2C7A1 },
	{ 0xE891A9, 0x1E6BB },
	{ 0xE891AA, 0x4C0C4 },
	{ 0xE891AB, 0x1E6B3 },
	{ 0xE891AC, 0x1E6B5 },
	{ 0xE891AD, 0x1E6BC },
	{ 0xE891AE, 0x2C7A7 },
	{ 0xE891AF, 0x2C6F8 },
	{ 0xE891B0, 0x2C6F3 },
	{ 0xE891B1, 0x3C4BC },
	{ 0xE891B2, 0x3C4AF },
	{ 0xE891B3, 0x2C6E0 },
	{ 0xE891B4, 0x2C6DF },
	{ 0xE891B5, 0x1E6B1 },
	{ 0xE891B6, 0x2C6D1 },
	{ 0xE891B7, 0x1E6AE },
	{ 0xE891B8, 0x2C6E9 },
	{ 0xE891B9, 0x2C6D2 },
	{ 0xE891BA, 0x2C6E7 },
	{ 0xE891BB, 0x3C4AE },
	{ 0xE891BC, 0x4C0C1 },
	{ 0xE891BD, 0x2C6DC },
	{ 0xE891BE, 0x2C7A2 },
	{ 0xE891BF, 0x3C4AA },
	{ 0xE89280, 0x3C4B9 },
	{ 0xE89281, 0x4C0B6 },
	{ 0xE89282, 0x1E6AD },
	{ 0xE89283, 0x3C4BB },
	{ 0xE89284, 0x3C4A8 },
	{ 0xE89286, 0x2C6D8 },
	{ 0xE89288, 0x4C0C6 },
	{ 0xE8928D, 0x2C6D4 },
	{ 0xE8928E, 0x2C6FA },
	{ 0xE8928F, 0x2C6D3 },
	{ 0xE89290, 0x1EAE8 },
	{ 0xE89291, 0x2CDDA },
	{ 0xE89292, 0x3C9B5 },
	{ 0xE89293, 0x3C9C4 },
	{ 0xE89294, 0x2CDC9 },
	{ 0xE89295, 0x3C9B3 },
	{ 0xE89296, 0x3C9B8 },
	{ 0xE89297, 0x2CDB3 },
	{ 0xE89298, 0x2CDD1 },
	{ 0xE89299, 0x1EAE0 },
	{ 0xE8929A, 0x2CDC2 },
	{ 0xE8929B, 0x2CDCC },
	{ 0xE8929C, 0x1EAE3 },
	{ 0xE8929D, 0x2CDC5 },
	{ 0xE8929E, 0x1EAE1 },
	{ 0xE8929F, 0x2CDB6 },
	{ 0xE892A0, 0x2CDD4 },
	{ 0xE892A1, 0x2CDB5 },
	{ 0xE892A2, 0x2CDC8 },
	{ 0xE892A3, 0x3C9BC },
	{ 0xE892A4, 0x2CDB4 },
	{ 0xE892A5, 0x3C9B9 },
	{ 0xE892A6, 0x4C6EC },
	{ 0xE892A7, 0x2CDC6 },
	{ 0xE892A8, 0x2CDCF },
	{ 0xE892A9, 0x2CDCD },
	{ 0xE892AA, 0x2CDC1 },
	{ 0xE892AB, 0x2CDBC },
	{ 0xE892AC, 0x2CDBA },
	{ 0xE892AD, 0x3C9C2 },
	{ 0xE892AE, 0x2CDBB },
	{ 0xE892AF, 0x2CDCE },
	{ 0xE892B0, 0x2CDD9 },
	{ 0xE892B1, 0x2CDC3 },
	{ 0xE892B2, 0x1EAE2 },
	{ 0xE892B3, 0x3C9BB },
	{ 0xE892B4, 0x2CDBE },
	{ 0xE892B5, 0x3C9BA },
	{ 0xE892B6, 0x2CDD2 },
	{ 0xE892B7, 0x3C9C1 },
	{ 0xE892B8, 0x1EAE5 },
	{ 0xE892B9, 0x2CDBD },
	{ 0xE892BA, 0x2CDB7 },
	{ 0xE892BB, 0x2CDC7 },
	{ 0xE892BC, 0x1EAE9 },
	{ 0xE892BD, 0x3C9B2 },
	{ 0xE892BE, 0x4C6D8 },
	{ 0xE892BF, 0x1EADD },
	{ 0xE89380, 0x1EAE6 },
	{ 0xE89381, 0x2CDBF },
	{ 0xE89382, 0x2CDB9 },
	{ 0xE89383, 0x3C9B6 },
	{ 0xE89384, 0x1EADF },
	{ 0xE89385, 0x2C6F9 },
	{ 0xE89386, 0x1EADE },
	{ 0xE89387, 0x2CDCA },
	{ 0xE89388, 0x3C4B6 },
	{ 0xE89389, 0x1EADC },
	{ 0xE8938A, 0x1EAEB },
	{ 0xE8938B, 0x1EAE4 },
	{ 0xE8938C, 0x2CDCB },
	{ 0xE8938D, 0x2CDC0 },
	{ 0xE8938E, 0x2CDB8 },
	{ 0xE8938F, 0x2CDD3 },
	{ 0xE89390, 0x2CDC4 },
	{ 0xE89391, 0x1EAEA },
	{ 0xE89392, 0x2CDD7 },
	{ 0xE89393, 0x1EAE7 },
	{ 0xE89394, 0x2CDD6 },
	{ 0xE89395, 0x3C9BF },
	{ 0xE89396, 0x2CDD0 },
	{ 0xE89397, 0x2CDD5 },
	{ 0xE89398, 0x3C9BE },
	{ 0xE8939A, 0x3C9C3 },
	{ 0xE8939B, 0x2CDD8 },
	{ 0xE8939E, 0x3E6BB },
	{ 0xE893A1, 0x3E6BC },
	{ 0xE893A2, 0x3E6BA },
	{ 0xE893A4, 0x3C9BD },
	{ 0xE893A7, 0x2D3DC },
	{ 0xE893A8, 0x2D3DD },
	{ 0xE893A9, 0x2D3D0 },
	{ 0xE893AA, 0x2D3CF },
	{ 0xE893AB, 0x2D3CB },
	{ 0xE893AC, 0x1EEDD },
	{ 0xE893AD, 0x3CECF },
	{ 0xE893AE, 0x1EED5 },
	{ 0xE893AF, 0x2D3DF },
	{ 0xE893B0, 0x2D3DE },
	{ 0xE893B1, 0x2C6CE },
	{ 0xE893B2, 0x2D3C8 },
	{ 0xE893B3, 0x2D3CC },
	{ 0xE893B4, 0x2D3C6 },
	{ 0xE893B5, 0x3CEC4 },
	{ 0xE893B6, 0x2D3D9 },
	{ 0xE893B7, 0x2D3CA },
	{ 0xE893B8, 0x3CEC2 },
	{ 0xE893B9, 0x2D3E0 },
	{ 0xE893BA, 0x2D3C3 },
	{ 0xE893BB, 0x2D3C1 },
	{ 0xE893BC, 0x2D3CD },
	{ 0xE893BD, 0x2D3D7 },
	{ 0xE893BE, 0x2D3D2 },
	{ 0xE893BF, 0x1EEDF },
	{ 0xE89480, 0x2D3B8 },
	{ 0xE89481, 0x3CEC0 },
	{ 0xE89482, 0x2D3D6 },
	{ 0xE89483, 0x3CECC },
	{ 0xE89484, 0x3CEC6 },
	{ 0xE89485, 0x3CED4 },
	{ 0xE89486, 0x1EEE0 },
	{ 0xE89487, 0x2C6E2 },
	{ 0xE89488, 0x2D3C4 },
	{ 0xE89489, 0x2D3BB },
	{ 0xE8948A, 0x2D3BE },
	{ 0xE8948B, 0x2D3E4 },
	{ 0xE8948C, 0x2D3C5 },
	{ 0xE8948D, 0x2D3BC },
	{ 0xE8948E, 0x2D3BA },
	{ 0xE8948F, 0x2D3B7 },
	{ 0xE89490, 0x4CCFA },
	{ 0xE89491, 0x1EED9 },
	{ 0xE89492, 0x2D3CE },
	{ 0xE89493, 0x1EED8 },
	{ 0xE89494, 0x1EEDC },
	{ 0xE89495, 0x2D3C9 },
	{ 0xE89496, 0x2D3D1 },
	{ 0xE89497, 0x1EED2 },
	{ 0xE89498, 0x2D3E1 },
	{ 0xE89499, 0x2D3E5 },
	{ 0xE8949A, 0x1EED4 },
	{ 0xE8949B, 0x3CECB },
	{ 0xE8949C, 0x2D3C0 },
	{ 0xE8949D, 0x2D3D4 },
	{ 0xE8949E, 0x2D3D8 },
	{ 0xE8949F, 0x2D3BD },
	{ 0xE894A0, 0x2D3E2 },
	{ 0xE894A1, 0x1EEDB },
	{ 0xE894A2, 0x4CCEA },
	{ 0xE894A3, 0x1EEDA },
	{ 0xE894A4, 0x2D3B5 },
	{ 0xE894A5, 0x1EEDE },
	{ 0xE894A6, 0x2D3DB },
	{ 0xE894A7, 0x2D3BF },
	{ 0xE894A8, 0x2D3D3 },
	{ 0xE894A9, 0x2D3B9 },
	{ 0xE894AA, 0x2D3C7 },
	{ 0xE894AB, 0x2D3C2 },
	{ 0xE894AC, 0x1EED6 },
	{ 0xE894AD, 0x1EED7 },
	{ 0xE894AE, 0x2D3D5 },
	{ 0xE894AF, 0x2D3E6 },
	{ 0xE894B0, 0x2D3E3 },
	{ 0xE894B1, 0x2D3DA },
	{ 0xE894B2, 0x4CCF8 },
	{ 0xE894B3, 0x3CECD },
	{ 0xE894B4, 0x3CECE },
	{ 0xE894B5, 0x3CED2 },
	{ 0xE894B8, 0x4CCF4 },
	{ 0xE894BB, 0x2D3B6 },
	{ 0xE894BD, 0x1EED3 },
	{ 0xE894BE, 0x2D9F4 },
	{ 0xE894BF, 0x3D2DA },
	{ 0xE89580, 0x2D9EB },
	{ 0xE89581, 0x2D9EE },
	{ 0xE89582, 0x3D2D2 },
	{ 0xE89583, 0x1F2A5 },
	{ 0xE89584, 0x2D9F0 },
	{ 0xE89585, 0x2D9E5 },
	{ 0xE89586, 0x2D9EC },
	{ 0xE89587, 0x2D9F2 },
	{ 0xE89588, 0x1F2A2 },
	{ 0xE89589, 0x1F2A6 },
	{ 0xE8958A, 0x1F1FE },
	{ 0xE8958B, 0x3D2D9 },
	{ 0xE8958C, 0x3D2D0 },
	{ 0xE8958D, 0x2D9E7 },
	{ 0xE8958E, 0x2D9F7 },
	{ 0xE8958F, 0x4CDA5 },
	{ 0xE89590, 0x4D3B3 },
	{ 0xE89591, 0x2D9F1 },
	{ 0xE89592, 0x4D3A4 },
	{ 0xE89593, 0x2D9E8 },
	{ 0xE89594, 0x2DAA2 },
	{ 0xE89595, 0x2D9FA },
	{ 0xE89596, 0x2D9E4 },
	{ 0xE89597, 0x2DEF2 },
	{ 0xE89598, 0x2D9EA },
	{ 0xE89599, 0x1F2A1 },
	{ 0xE8959A, 0x3D2D8 },
	{ 0xE8959B, 0x2D9F5 },
	{ 0xE8959C, 0x3D2D4 },
	{ 0xE8959D, 0x2DAA1 },
	{ 0xE8959E, 0x1F2A9 },
	{ 0xE8959F, 0x3D2D6 },
	{ 0xE895A0, 0x2D9FC },
	{ 0xE895A1, 0x2D9E9 },
	{ 0xE895A2, 0x2D9EF },
	{ 0xE895A3, 0x2D9F3 },
	{ 0xE895A4, 0x2D9ED },
	{ 0xE895A5, 0x2DAA3 },
	{ 0xE895A6, 0x2D9FE },
	{ 0xE895A7, 0x2D9FB },
	{ 0xE895A8, 0x1F2A3 },
	{ 0xE895A9, 0x1F2A4 },
	{ 0xE895AA, 0x1F2A8 },
	{ 0xE895AB, 0x2D9E6 },
	{ 0xE895AC, 0x2DAA4 },
	{ 0xE895AD, 0x1F2A7 },
	{ 0xE895AE, 0x2D9F8 },
	{ 0xE895AF, 0x3D2CF },
	{ 0xE895B0, 0x3D2D5 },
	{ 0xE895B1, 0x2D9F6 },
	{ 0xE895B3, 0x3E6BD },
	{ 0xE895B5, 0x2D9F9 },
	{ 0xE895B6, 0x2DFA1 },
	{ 0xE895B7, 0x2DEEC },
	{ 0xE895B8, 0x2DEF1 },
	{ 0xE895B9, 0x2DEFE },
	{ 0xE895BA, 0x2DEF0 },
	{ 0xE895BB, 0x2DEE8 },
	{ 0xE895BC, 0x2DEED },
	{ 0xE895BD, 0x4D8BE },
	{ 0xE895BE, 0x1F5AC },
	{ 0xE895BF, 0x3D6AB },
	{ 0xE89680, 0x2DEE1 },
	{ 0xE89681, 0x2DEF9 },
	{ 0xE89682, 0x2DEFB },
	{ 0xE89683, 0x2DEE0 },
	{ 0xE89684, 0x1F5AB },
	{ 0xE89685, 0x2DEFD },
	{ 0xE89686, 0x2DEF5 },
	{ 0xE89687, 0x1F5B2 },
	{ 0xE89688, 0x2DEFC },
	{ 0xE89689, 0x2DEEE },
	{ 0xE8968A, 0x1F5B4 },
	{ 0xE8968B, 0x2DEE6 },
	{ 0xE8968C, 0x2D9FD },
	{ 0xE8968D, 0x2DEF6 },
	{ 0xE8968E, 0x2DEF3 },
	{ 0xE8968F, 0x2DEE2 },
	{ 0xE89690, 0x2DFA3 },
	{ 0xE89691, 0x1F5AE },
	{ 0xE89692, 0x3D6A8 },
	{ 0xE89693, 0x3D6A9 },
	{ 0xE89694, 0x1F5AF },
	{ 0xE89695, 0x2DEE4 },
	{ 0xE89696, 0x2DEF4 },
	{ 0xE89697, 0x3D6AD },
	{ 0xE89698, 0x2DFA2 },
	{ 0xE89699, 0x2DEF7 },
	{ 0xE8969A, 0x2DEEA },
	{ 0xE8969B, 0x1F5B1 },
	{ 0xE8969C, 0x1F5AD },
	{ 0xE8969D, 0x2DEF8 },
	{ 0xE8969E, 0x2DEEB },
	{ 0xE8969F, 0x2DFA4 },
	{ 0xE896A0, 0x2DEE5 },
	{ 0xE896A1, 0x2DEEF },
	{ 0xE896A2, 0x2DEFA },
	{ 0xE896A3, 0x2DEE7 },
	{ 0xE896A4, 0x2DEE9 },
	{ 0xE896A5, 0x4D8C0 },
	{ 0xE896A6, 0x1F5B5 },
	{ 0xE896A7, 0x2DEE3 },
	{ 0xE896A8, 0x1F5B3 },
	{ 0xE896A9, 0x1F7B0 },
	{ 0xE896AA, 0x1F5AA },
	{ 0xE896AB, 0x3D6AC },
	{ 0xE896AC, 0x3D6B0 },
	{ 0xE896AF, 0x1F5B0 },
	{ 0xE896B0, 0x1F7B4 },
	{ 0xE896B1, 0x2E2FD },
	{ 0xE896B2, 0x3D8EC },
	{ 0xE896B3, 0x2E2F3 },
	{ 0xE896B4, 0x2E2EE },
	{ 0xE896B5, 0x2E2F4 },
	{ 0xE896B6, 0x2E2FE },
	{ 0xE896B7, 0x2E3A4 },
	{ 0xE896B8, 0x2E3A3 },
	{ 0xE896B9, 0x1F7B6 },
	{ 0xE896BA, 0x1F7B5 },
	{ 0xE896BB, 0x3D8EE },
	{ 0xE896BC, 0x4DDAC },
	{ 0xE896BD, 0x2E2F5 },
	{ 0xE896BE, 0x2E3A5 },
	{ 0xE896BF, 0x2E2F8 },
	{ 0xE89780, 0x2E2F0 },
	{ 0xE89781, 0x3D8EF },
	{ 0xE89782, 0x2E2F2 },
	{ 0xE89783, 0x2E2F1 },
	{ 0xE89784, 0x2E2F7 },
	{ 0xE89785, 0x2E2FC },
	{ 0xE89786, 0x2E2EF },
	{ 0xE89787, 0x2E2F6 },
	{ 0xE89788, 0x2E2FB },
	{ 0xE89789, 0x1F7B3 },
	{ 0xE8978A, 0x4DDA8 },
	{ 0xE8978B, 0x2E2F9 },
	{ 0xE8978C, 0x3D8EB },
	{ 0xE8978D, 0x1F7B1 },
	{ 0xE8978E, 0x2E2FA },
	{ 0xE8978F, 0x1F7AF },
	{ 0xE89790, 0x1F7B2 },
	{ 0xE89791, 0x2E6E0 },
	{ 0xE89792, 0x2E3A1 },
	{ 0xE89794, 0x3E6BE },
	{ 0xE89795, 0x1F8ED },
	{ 0xE89796, 0x3DAFE },
	{ 0xE89797, 0x2E6D8 },
	{ 0xE89798, 0x2E6DC },
	{ 0xE89799, 0x2E6D4 },
	{ 0xE8979A, 0x2E6D7 },
	{ 0xE8979B, 0x3DAFD },
	{ 0xE8979C, 0x2E6DF },
	{ 0xE8979D, 0x1F8EB },
	{ 0xE8979E, 0x2E6E4 },
	{ 0xE8979F, 0x2E6DD },
	{ 0xE897A0, 0x4E0FA },
	{ 0xE897A1, 0x2E6D5 },
	{ 0xE897A2, 0x2E6E5 },
	{ 0xE897A3, 0x2E6DE },
	{ 0xE897A4, 0x1F8EE },
	{ 0xE897A5, 0x1F8EF },
	{ 0xE897A6, 0x2E6E2 },
	{ 0xE897A7, 0x3DBA2 },
	{ 0xE897A8, 0x2E6D6 },
	{ 0xE897A9, 0x1F8EA },
	{ 0xE897AA, 0x1F8EC },
	{ 0xE897AB, 0x2E6D1 },
	{ 0xE897AC, 0x2E6D9 },
	{ 0xE897AD, 0x2E6D3 },
	{ 0xE897AE, 0x3DCFB },
	{ 0xE897AF, 0x2E6E3 },
	{ 0xE897B0, 0x2E6E1 },
	{ 0xE897B1, 0x2E6D2 },
	{ 0xE897B2, 0x2E6DA },
	{ 0xE897B3, 0x4E0FB },
	{ 0xE897B4, 0x3DBA5 },
	{ 0xE897B5, 0x3E6BF },
	{ 0xE897B6, 0x2E9EA },
	{ 0xE897B7, 0x1F8F0 },
	{ 0xE897B8, 0x2E6DB },
	{ 0xE897B9, 0x1FAB2 },
	{ 0xE897BA, 0x1FAB4 },
	{ 0xE897BB, 0x1FAB1 },
	{ 0xE897BC, 0x3DCF6 },
	{ 0xE897BD, 0x2E9EF },
	{ 0xE897BE, 0x2E9E7 },
	{ 0xE897BF, 0x2E9E5 },
	{ 0xE89880, 0x2E9E9 },
	{ 0xE89881, 0x2E9E6 },
	{ 0xE89882, 0x3DCF8 },
	{ 0xE89883, 0x3DCFC },
	{ 0xE89884, 0x2E9EB },
	{ 0xE89885, 0x2E9ED },
	{ 0xE89886, 0x1FAB5 },
	{ 0xE89887, 0x1FAB7 },
	{ 0xE89888, 0x3DDA2 },
	{ 0xE89889, 0x2E9EC },
	{ 0xE8988A, 0x1FAB8 },
	{ 0xE8988B, 0x1FAB6 },
	{ 0xE8988C, 0x2E9EE },
	{ 0xE8988D, 0x3DCFE },
	{ 0xE8988E, 0x4E4B7 },
	{ 0xE8988F, 0x3DDA3 },
	{ 0xE89890, 0x3DCF7 },
	{ 0xE89891, 0x1FAB3 },
	{ 0xE89893, 0x3DDA1 },
	{ 0xE89895, 0x3DEDB },
	{ 0xE89896, 0x3DEDA },
	{ 0xE89897, 0x1FBA1 },
	{ 0xE89898, 0x2ECA1 },
	{ 0xE89899, 0x2ECA7 },
	{ 0xE8989A, 0x1FBA3 },
	{ 0xE8989B, 0x2E9E8 },
	{ 0xE8989C, 0x2ECA6 },
	{ 0xE8989D, 0x3DEDC },
	{ 0xE8989E, 0x2ECAD },
	{ 0xE8989F, 0x2ECA4 },
	{ 0xE898A0, 0x2ECAB },
	{ 0xE898A1, 0x2ECAA },
	{ 0xE898A2, 0x2E9E4 },
	{ 0xE898A3, 0x2ECA5 },
	{ 0xE898A4, 0x2E3A2 },
	{ 0xE898A5, 0x2ECAE },
	{ 0xE898A6, 0x2ECA3 },
	{ 0xE898A7, 0x2ECA8 },
	{ 0xE898A8, 0x3DED8 },
	{ 0xE898A9, 0x2ECAC },
	{ 0xE898AA, 0x2ECA2 },
	{ 0xE898AB, 0x3DED6 },
	{ 0xE898AC, 0x2EDF7 },
	{ 0xE898AD, 0x1FBA2 },
	{ 0xE898AE, 0x2ECA9 },
	{ 0xE898AF, 0x3DED7 },
	{ 0xE898B1, 0x2EFC3 },
	{ 0xE898B2, 0x2EDF8 },
	{ 0xE898B3, 0x2EDF6 },
	{ 0xE898B4, 0x2EDF4 },
	{ 0xE898B5, 0x2EDF5 },
	{ 0xE898B6, 0x2EDF9 },
	{ 0xE898B7, 0x3E6C0 },
	{ 0xE898B8, 0x1FCC5 },
	{ 0xE898B9, 0x2EFC1 },
	{ 0xE898BA, 0x2EFBF },
	{ 0xE898BB, 0x2EFC4 },
	{ 0xE898BC, 0x2EFC2 },
	{ 0xE898BD, 0x3E0C3 },
	{ 0xE898BE, 0x2EFC5 },
	{ 0xE898BF, 0x1FCC6 },
	{ 0xE89980, 0x2EFC0 },
	{ 0xE89981, 0x3E0AF },
	{ 0xE89982, 0x3E1C6 },
	{ 0xE89983, 0x2F0CA },
	{ 0xE89985, 0x3E6C1 },
	{ 0xE89986, 0x2F1B4 },
	{ 0xE89987, 0x2F1B5 },
	{ 0xE89988, 0x2F1B6 },
	{ 0xE89989, 0x3E1C7 },
	{ 0xE8998A, 0x3E1FC },
	{ 0xE8998B, 0x2F2B5 },
	{ 0xE8998C, 0x2F2AD },
	{ 0xE8998D, 0x2A2EF },
	{ 0xE8998E, 0x1CFCD },
	{ 0xE89990, 0x1D3CB },
	{ 0xE89991, 0x4AFE8 },
	{ 0xE89992, 0x2B2DA },
	{ 0xE89993, 0x2B2D9 },
	{ 0xE89994, 0x1D8A5 },
	{ 0xE89995, 0x1DDA8 },
	{ 0xE89996, 0x2B9A1 },
	{ 0xE89997, 0x3B8E3 },
	{ 0xE89998, 0x3B8E0 },
	{ 0xE89999, 0x2B8FE },
	{ 0xE8999A, 0x3B8E1 },
	{ 0xE8999B, 0x1E1F0 },
	{ 0xE8999C, 0x1E6BF },
	{ 0xE8999D, 0x3BEE1 },
	{ 0xE8999E, 0x1E6BE },
	{ 0xE8999F, 0x1E6C0 },
	{ 0xE899A0, 0x5C9CE },
	{ 0xE899A1, 0x2CDDB },
	{ 0xE899A2, 0x2D3E7 },
	{ 0xE899A3, 0x2DAA5 },
	{ 0xE899A4, 0x2DAA7 },
	{ 0xE899A5, 0x2DAA6 },
	{ 0xE899A6, 0x7B2E1 },
	{ 0xE899A7, 0x1F5B6 },
	{ 0xE899A8, 0x2DFA5 },
	{ 0xE899A9, 0x2E3A6 },
	{ 0xE899AA, 0x2F1F3 },
	{ 0xE899AB, 0x1C8E5 },
	{ 0xE899AC, 0x3A7AD },
	{ 0xE899AD, 0x2A8E9 },
	{ 0xE899AE, 0x2A8EA },
	{ 0xE899AF, 0x2A8E8 },
	{ 0xE899B0, 0x2A8E7 },
	{ 0xE899B1, 0x1CFCE },
	{ 0xE899B2, 0x3E6C2 },
	{ 0xE899B3, 0x2ADCA },
	{ 0xE899B4, 0x2ADC8 },
	{ 0xE899B5, 0x3AFA3 },
	{ 0xE899B6, 0x3AEFC },
	{ 0xE899B7, 0x2ADC7 },
	{ 0xE899B8, 0x3AEFE },
	{ 0xE899B9, 0x1D3CC },
	{ 0xE899BA, 0x1D3CE },
	{ 0xE899BB, 0x1D3CD },
	{ 0xE899BC, 0x2ADC9 },
	{ 0xE899BD, 0x3AFA4 },
	{ 0xE899BE, 0xFADBE },
	{ 0xE89A84, 0x3B3E9 },
	{ 0xE89A85, 0x2B2E6 },
	{ 0xE89A86, 0x2B2E3 },
	{ 0xE89A87, 0x2B2E1 },
	{ 0xE89A88, 0x4AFED },
	{ 0xE89A89, 0x3B3EC },
	{ 0xE89A8A, 0x1D8A6 },
	{ 0xE89A8B, 0x2B2E4 },
	{ 0xE89A8C, 0x1D8AB },
	{ 0xE89A8D, 0x2B2DE },
	{ 0xE89A8E, 0x2B2ED },
	{ 0xE89A8F, 0x3B3EF },
	{ 0xE89A90, 0x2B2EF },
	{ 0xE89A91, 0x2B2DF },
	{ 0xE89A92, 0x3B3EE },
	{ 0xE89A93, 0x1D8A8 },
	{ 0xE89A94, 0x2B2F0 },
	{ 0xE89A95, 0x2B2EB },
	{ 0xE89A96, 0x2B2DD },
	{ 0xE89A97, 0x2B2E2 },
	{ 0xE89A98, 0x2B2EC },
	{ 0xE89A99, 0x2B2E8 },
	{ 0xE89A9A, 0x2B2E5 },
	{ 0xE89A9B, 0x3B3EB },
	{ 0xE89A9C, 0x1D8AD },
	{ 0xE89A9D, 0x2B2EE },
	{ 0xE89A9E, 0x2B2E0 },
	{ 0xE89A9F, 0x3B3EA },
	{ 0xE89AA0, 0x3B3F0 },
	{ 0xE89AA1, 0x2B2E9 },
	{ 0xE89AA2, 0x2B2DB },
	{ 0xE89AA3, 0x1D8AC },
	{ 0xE89AA4, 0x1D8A9 },
	{ 0xE89AA5, 0x2B2E7 },
	{ 0xE89AA6, 0x3B3ED },
	{ 0xE89AA7, 0x2B2EA },
	{ 0xE89AA8, 0x2B2DC },
	{ 0xE89AA9, 0x1D8AA },
	{ 0xE89AAA, 0x1D8A7 },
	{ 0xE89AAD, 0x4B4FA },
	{ 0xE89AAE, 0x3B8E6 },
	{ 0xE89AAF, 0x1DDB2 },
	{ 0xE89AB0, 0x2B9A8 },
	{ 0xE89AB1, 0x1DDB1 },
	{ 0xE89AB2, 0x3B8E4 },
	{ 0xE89AB3, 0x2B9AB },
	{ 0xE89AB4, 0x2B9AE },
	{ 0xE89AB5, 0x1DDAE },
	{ 0xE89AB6, 0x1DDAC },
	{ 0xE89AB7, 0x2B9A3 },
	{ 0xE89AB8, 0x2B9AC },
	{ 0xE89AB9, 0x2B9AA },
	{ 0xE89ABA, 0x2B9A7 },
	{ 0xE89ABB, 0x2B9AF },
	{ 0xE89ABC, 0x2B9B0 },
	{ 0xE89ABD, 0x2B9B2 },
	{ 0xE89ABE, 0x2B9B3 },
	{ 0xE89ABF, 0x2B9A2 },
	{ 0xE89B80, 0x1DDAB },
	{ 0xE89B81, 0x2B9A5 },
	{ 0xE89B82, 0x2B9A4 },
	{ 0xE89B83, 0x2B9B1 },
	{ 0xE89B84, 0x1DDAD },
	{ 0xE89B85, 0x2B9A6 },
	{ 0xE89B86, 0x1DDAF },
	{ 0xE89B87, 0x1DDAA },
	{ 0xE89B88, 0x2B9A9 },
	{ 0xE89B89, 0x1DDB3 },
	{ 0xE89B8A, 0x4B5A6 },
	{ 0xE89B8B, 0x1DDB0 },
	{ 0xE89B8C, 0x2B9AD },
	{ 0xE89B8F, 0xFB8BA },
	{ 0xE89B90, 0x1E1F7 },
	{ 0xE89B91, 0x2C0A5 },
	{ 0xE89B92, 0x4BAF1 },
	{ 0xE89B93, 0x2BFF8 },
	{ 0xE89B94, 0x1E1F4 },
	{ 0xE89B95, 0x3BEE2 },
	{ 0xE89B96, 0x2C7AE },
	{ 0xE89B97, 0x2C0A3 },
	{ 0xE89B98, 0x2BFF5 },
	{ 0xE89B99, 0x1E1F2 },
	{ 0xE89B9A, 0x2BFFA },
	{ 0xE89B9B, 0x1E1F5 },
	{ 0xE89B9C, 0x2BFFE },
	{ 0xE89B9D, 0x2BFFC },
	{ 0xE89B9E, 0x1E1F8 },
	{ 0xE89B9F, 0x1E1F1 },
	{ 0xE89BA0, 0x4BAF6 },
	{ 0xE89BA1, 0x3BEE3 },
	{ 0xE89BA2, 0x2BFF6 },
	{ 0xE89BA3, 0x2BFF9 },
	{ 0xE89BA4, 0x1E1F6 },
	{ 0xE89BA5, 0x4BAEF },
	{ 0xE89BA6, 0x2BFF7 },
	{ 0xE89BA7, 0x5BBFB },
	{ 0xE89BA8, 0x2C0A4 },
	{ 0xE89BA9, 0x2C0A2 },
	{ 0xE89BAA, 0x2BFFB },
	{ 0xE89BAB, 0x2BFFD },
	{ 0xE89BAC, 0x2C0A1 },
	{ 0xE89BAD, 0x1E1F3 },
	{ 0xE89BAE, 0x3BEE8 },
	{ 0xE89BB5, 0x2C7AF },
	{ 0xE89BB6, 0x2C7B5 },
	{ 0xE89BB7, 0x2C7AB },
	{ 0xE89BB8, 0x2C7B1 },
	{ 0xE89BB9, 0x1E6C1 },
	{ 0xE89BBA, 0x2C7AD },
	{ 0xE89BBB, 0x1E6C7 },
	{ 0xE89BBC, 0x3C4C4 },
	{ 0xE89BBD, 0x3C4C5 },
	{ 0xE89BBE, 0x1E6C6 },
	{ 0xE89BBF, 0x3C4C9 },
	{ 0xE89C80, 0x1E6C5 },
	{ 0xE89C81, 0x2C7B4 },
	{ 0xE89C82, 0x1E6C8 },
	{ 0xE89C83, 0x1E6C9 },
	{ 0xE89C84, 0x2C7AA },
	{ 0xE89C85, 0x2C7B7 },
	{ 0xE89C86, 0x1E6CA },
	{ 0xE89C87, 0x1E6C4 },
	{ 0xE89C88, 0x1E6C3 },
	{ 0xE89C89, 0x2C7B3 },
	{ 0xE89C8A, 0x1E6CB },
	{ 0xE89C8B, 0x2C7A9 },
	{ 0xE89C8C, 0x2C7AC },
	{ 0xE89C8D, 0x2C7B6 },
	{ 0xE89C8E, 0x2C7B2 },
	{ 0xE89C8F, 0x4C0D9 },
	{ 0xE89C90, 0x4C0D2 },
	{ 0xE89C91, 0x2CDFB },
	{ 0xE89C92, 0x2CDF0 },
	{ 0xE89C93, 0x1E6C2 },
	{ 0xE89C94, 0x5C2DD },
	{ 0xE89C95, 0x3C4C6 },
	{ 0xE89C96, 0x3C4C8 },
	{ 0xE89C98, 0x1EAF2 },
	{ 0xE89C99, 0x2CDE4 },
	{ 0xE89C9A, 0x2CDF9 },
	{ 0xE89C9B, 0x2CDE5 },
	{ 0xE89C9C, 0x1EAED },
	{ 0xE89C9D, 0x3C9CF },
	{ 0xE89C9E, 0x2CDE2 },
	{ 0xE89C9F, 0x4C0D5 },
	{ 0xE89CA0, 0x2CDEB },
	{ 0xE89CA1, 0x2CDE3 },
	{ 0xE89CA2, 0x1EAEF },
	{ 0xE89CA3, 0x2CDDD },
	{ 0xE89CA4, 0x2CDF8 },
	{ 0xE89CA5, 0x1EAF0 },
	{ 0xE89CA6, 0x2CDF5 },
	{ 0xE89CA7, 0x2CDF6 },
	{ 0xE89CA8, 0x2CDDE },
	{ 0xE89CA9, 0x1EAF5 },
	{ 0xE89CAA, 0x2CDED },
	{ 0xE89CAB, 0x3C9CA },
	{ 0xE89CAC, 0x2CDE7 },
	{ 0xE89CAD, 0x2CDEE },
	{ 0xE89CAE, 0x2CDE1 },
	{ 0xE89CAF, 0x4C6FE },
	{ 0xE89CB0, 0x2CDFA },
	{ 0xE89CB1, 0x2CDF2 },
	{ 0xE89CB2, 0x2CDEC },
	{ 0xE89CB3, 0x2CDDC },
	{ 0xE89CB4, 0x1EAF1 },
	{ 0xE89CB5, 0x2CDF3 },
	{ 0xE89CB6, 0x3C9C5 },
	{ 0xE89CB7, 0x1EAF4 },
	{ 0xE89CB8, 0x2CDF7 },
	{ 0xE89CB9, 0x3C9CC },
	{ 0xE89CBA, 0x2CDF1 },
	{ 0xE89CBB, 0x1EAEE },
	{ 0xE89CBC, 0x2CDEF },
	{ 0xE89CBD, 0x3C9C9 },
	{ 0xE89CBE, 0x2CDE9 },
	{ 0xE89CBF, 0x1EAEC },
	{ 0xE89D80, 0x2CDE0 },
	{ 0xE89D81, 0x2CDE8 },
	{ 0xE89D82, 0x2CDF4 },
	{ 0xE89D83, 0x2CDE6 },
	{ 0xE89D84, 0xFCCB3 },
	{ 0xE89D85, 0x3C9CE },
	{ 0xE89D86, 0x2CDEA },
	{ 0xE89D87, 0x3C9CB },
	{ 0xE89D8A, 0x3E6C3 },
	{ 0xE89D8C, 0x1EEEA },
	{ 0xE89D8D, 0x2C7B0 },
	{ 0xE89D8E, 0x2D3F9 },
	{ 0xE89D8F, 0x2D4A4 },
	{ 0xE89D90, 0x2D3F8 },
	{ 0xE89D91, 0x2D3F4 },
	{ 0xE89D92, 0x2D3F1 },
	{ 0xE89D93, 0x1EEEB },
	{ 0xE89D94, 0x2D3EF },
	{ 0xE89D95, 0x1EAF3 },
	{ 0xE89D96, 0x2D3E8 },
	{ 0xE89D97, 0x1EEE9 },
	{ 0xE89D98, 0x2D3EE },
	{ 0xE89D99, 0x1EEE8 },
	{ 0xE89D9A, 0x2D3F3 },
	{ 0xE89D9B, 0x2D3F0 },
	{ 0xE89D9C, 0x2D4A2 },
	{ 0xE89D9D, 0x2D3FB },
	{ 0xE89D9E, 0x2D3F5 },
	{ 0xE89D9F, 0x2D3FA },
	{ 0xE89DA0, 0x1EEE4 },
	{ 0xE89DA1, 0x2D3F2 },
	{ 0xE89DA2, 0x2D4A7 },
	{ 0xE89DA3, 0x2D3E9 },
	{ 0xE89DA4, 0x2D3EA },
	{ 0xE89DA5, 0x2D4A3 },
	{ 0xE89DA6, 0x1EEE5 },
	{ 0xE89DA7, 0x2D4A8 },
	{ 0xE89DA8, 0x1EEE7 },
	{ 0xE89DA9, 0x2D4A9 },
	{ 0xE89DAA, 0x2D3F7 },
	{ 0xE89DAB, 0x2CDDF },
	{ 0xE89DAC, 0x2D3FD },
	{ 0xE89DAD, 0x2D3F6 },
	{ 0xE89DAE, 0x2D4A1 },
	{ 0xE89DAF, 0x2D3FC },
	{ 0xE89DB0, 0x5D0D5 },
	{ 0xE89DB1, 0x3CEDD },
	{ 0xE89DB2, 0x4CDA8 },
	{ 0xE89DB3, 0x2D3ED },
	{ 0xE89DB4, 0x1EEE2 },
	{ 0xE89DB5, 0x2D4A6 },
	{ 0xE89DB6, 0x1EEE3 },
	{ 0xE89DB7, 0x2D3EB },
	{ 0xE89DB8, 0x1EEE6 },
	{ 0xE89DB9, 0x2DAB2 },
	{ 0xE89DBA, 0x2D3FE },
	{ 0xE89DBB, 0x2D4A5 },
	{ 0xE89DBC, 0x4CDB1 },
	{ 0xE89DBD, 0x3CED9 },
	{ 0xE89E81, 0x2DAAF },
	{ 0xE89E82, 0x1EEE1 },
	{ 0xE89E83, 0x1F2AA },
	{ 0xE89E84, 0x2DAB9 },
	{ 0xE89E85, 0x2DAB5 },
	{ 0xE89E86, 0x4D3BC },
	{ 0xE89E87, 0x2DAB3 },
	{ 0xE89E88, 0x2DAAE },
	{ 0xE89E89, 0x2DABD },
	{ 0xE89E8A, 0x3D2DB },
	{ 0xE89E8B, 0x3D2DD },
	{ 0xE89E8C, 0x4D3C4 },
	{ 0xE89E8D, 0x1F2AE },
	{ 0xE89E8E, 0x3D2DF },
	{ 0xE89E8F, 0x2DAAA },
	{ 0xE89E90, 0x2DAB6 },
	{ 0xE89E91, 0x2DAB7 },
	{ 0xE89E92, 0x2DAAD },
	{ 0xE89E93, 0x2DAAC },
	{ 0xE89E94, 0x2DABA },
	{ 0xE89E95, 0x4D3C1 },
	{ 0xE89E96, 0x2DAB0 },
	{ 0xE89E97, 0x2DAAB },
	{ 0xE89E98, 0x2DAB1 },
	{ 0xE89E99, 0x3D2E2 },
	{ 0xE89E9A, 0x2DABC },
	{ 0xE89E9B, 0x2DAA9 },
	{ 0xE89E9C, 0x2DABB },
	{ 0xE89E9D, 0x2DAB8 },
	{ 0xE89E9E, 0x1F2AC },
	{ 0xE89E9F, 0x1F2AB },
	{ 0xE89EA0, 0x4D3B9 },
	{ 0xE89EA1, 0x3D2DE },
	{ 0xE89EA2, 0x1F2AD },
	{ 0xE89EA3, 0x2DAB4 },
	{ 0xE89EA4, 0x2DAA8 },
	{ 0xE89EA5, 0x3E6C5 },
	{ 0xE89EA9, 0x3E6C4 },
	{ 0xE89EAA, 0x2DFA7 },
	{ 0xE89EAB, 0x1F5BC },
	{ 0xE89EAC, 0x2DFAB },
	{ 0xE89EAD, 0x2DFA8 },
	{ 0xE89EAE, 0x2DFAF },
	{ 0xE89EAF, 0x2DFB5 },
	{ 0xE89EB0, 0x2DFAA },
	{ 0xE89EB1, 0x3D6BA },
	{ 0xE89EB2, 0x2DFBE },
	{ 0xE89EB3, 0x1F5B9 },
	{ 0xE89EB4, 0x2DFB8 },
	{ 0xE89EB5, 0x2DFAD },
	{ 0xE89EB6, 0x2DFB9 },
	{ 0xE89EB7, 0x2DFB4 },
	{ 0xE89EB8, 0x2DFBB },
	{ 0xE89EB9, 0x2DFAC },
	{ 0xE89EBA, 0x1F5BE },
	{ 0xE89EBB, 0x1F5BD },
	{ 0xE89EBC, 0x2DFAE },
	{ 0xE89EBD, 0x2DFBC },
	{ 0xE89EBE, 0x2DFA6 },
	{ 0xE89EBF, 0x2DFBA },
	{ 0xE89F80, 0x1F5B7 },
	{ 0xE89F81, 0x3D6B9 },
	{ 0xE89F82, 0x2DFB2 },
	{ 0xE89F83, 0x2DFB1 },
	{ 0xE89F84, 0x2DFB6 },
	{ 0xE89F85, 0x2DFA9 },
	{ 0xE89F86, 0x1F5BB },
	{ 0xE89F87, 0x3D6BB },
	{ 0xE89F88, 0x1F5BF },
	{ 0xE89F89, 0x2DFB0 },
	{ 0xE89F8A, 0x2DFB7 },
	{ 0xE89F8B, 0x1F5C0 },
	{ 0xE89F8C, 0x2DFB3 },
	{ 0xE89F8D, 0x3D6B6 },
	{ 0xE89F8E, 0x3D6B4 },
	{ 0xE89F91, 0x1F5B8 },
	{ 0xE89F92, 0x1F5BA },
	{ 0xE89F93, 0x2E3B3 },
	{ 0xE89F94, 0x2E3B1 },
	{ 0xE89F95, 0x3DBA8 },
	{ 0xE89F96, 0x3D8F6 },
	{ 0xE89F97, 0x2E3B7 },
	{ 0xE89F98, 0x2E3B5 },
	{ 0xE89F99, 0x2E3B8 },
	{ 0xE89F9A, 0x3D8F8 },
	{ 0xE89F9B, 0x2E3AA },
	{ 0xE89F9C, 0x2E3B2 },
	{ 0xE89F9D, 0x2E3BC },
	{ 0xE89F9E, 0x2DFBD },
	{ 0xE89F9F, 0x2E3AE },
	{ 0xE89FA0, 0x1F7BA },
	{ 0xE89FA1, 0x2D3EC },
	{ 0xE89FA2, 0x2E3A9 },
	{ 0xE89FA3, 0x2E3B6 },
	{ 0xE89FA4, 0x2E3B0 },
	{ 0xE89FA5, 0x2E3AD },
	{ 0xE89FA6, 0x2E3A8 },
	{ 0xE89FA7, 0x2E3A7 },
	{ 0xE89FA8, 0x2E3BB },
	{ 0xE89FA9, 0x3D8F3 },
	{ 0xE89FAA, 0x2E3AC },
	{ 0xE89FAB, 0x2E3AB },
	{ 0xE89FAC, 0x1F7B8 },
	{ 0xE89FAD, 0x2E3B4 },
	{ 0xE89FAE, 0x3D8F4 },
	{ 0xE89FAF, 0x1F7B7 },
	{ 0xE89FB0, 0x3D8F5 },
	{ 0xE89FB1, 0x5E4C8 },
	{ 0xE89FB2, 0x1F7B9 },
	{ 0xE89FB3, 0x2E3AF },
	{ 0xE89FB4, 0x2E3BA },
	{ 0xE89FB5, 0x3E6C6 },
	{ 0xE89FB6, 0x2E6E9 },
	{ 0xE89FB7, 0x2E6EA },
	{ 0xE89FB8, 0x3DBAC },
	{ 0xE89FB9, 0x1F8F4 },
	{ 0xE89FBA, 0x2E6E7 },
	{ 0xE89FBB, 0x1F8F1 },
	{ 0xE89FBC, 0x2E6EF },
	{ 0xE89FBD, 0x3DBA7 },
	{ 0xE89FBE, 0x1F8F5 },
	{ 0xE89FBF, 0x2E6F1 },
	{ 0xE8A080, 0x2E6E6 },
	{ 0xE8A081, 0x2E3B9 },
	{ 0xE8A082, 0x2E6F3 },
	{ 0xE8A083, 0x2E6E8 },
	{ 0xE8A084, 0x5E9C3 },
	{ 0xE8A085, 0x1F8F2 },
	{ 0xE8A086, 0x2E6EE },
	{ 0xE8A087, 0x3DBA9 },
	{ 0xE8A088, 0x2E6F0 },
	{ 0xE8A089, 0x2E6EB },
	{ 0xE8A08A, 0x2E6F2 },
	{ 0xE8A08B, 0x2E6ED },
	{ 0xE8A08C, 0x2E6EC },
	{ 0xE8A08D, 0x1F8F3 },
	{ 0xE8A08E, 0x3D8F7 },
	{ 0xE8A08F, 0x3DBAB },
	{ 0xE8A090, 0x2E9F1 },
	{ 0xE8A091, 0x2E9F2 },
	{ 0xE8A092, 0x3DDA5 },
	{ 0xE8A093, 0x2E9F4 },
	{ 0xE8A094, 0x1FAB9 },
	{ 0xE8A095, 0x1FABA },
	{ 0xE8A096, 0x2E9F5 },
	{ 0xE8A097, 0x2E9F3 },
	{ 0xE8A098, 0x3DDA4 },
	{ 0xE8A099, 0x2E9F0 },
	{ 0xE8A09A, 0x3DEDD },
	{ 0xE8A09B, 0x2ECB1 },
	{ 0xE8A09C, 0x2ECB4 },
	{ 0xE8A09D, 0x2ECB0 },
	{ 0xE8A09E, 0x4E1A6 },
	{ 0xE8A09F, 0x1FBA7 },
	{ 0xE8A0A0, 0x2ECB2 },
	{ 0xE8A0A1, 0x1FBA6 },
	{ 0xE8A0A2, 0x1FBA5 },
	{ 0xE8A0A3, 0x1FBA4 },
	{ 0xE8A0A4, 0x2ECB3 },
	{ 0xE8A0A5, 0x2EDFE },
	{ 0xE8A0A6, 0x2EDFC },
	{ 0xE8A0A7, 0x3DFDF },
	{ 0xE8A0A8, 0x2EDFB },
	{ 0xE8A0A9, 0x2ECAF },
	{ 0xE8A0AA, 0x2EDFD },
	{ 0xE8A0AB, 0x2ECB5 },
	{ 0xE8A0AC, 0x2EDFA },
	{ 0xE8A0AD, 0x3E0C5 },
	{ 0xE8A0AE, 0x2EFC8 },
	{ 0xE8A0AF, 0x2EFA6 },
	{ 0xE8A0B0, 0x2EFC6 },
	{ 0xE8A0B1, 0x1FCC7 },
	{ 0xE8A0B2, 0x2EFC7 },
	{ 0xE8A0B3, 0x2EFC9 },
	{ 0xE8A0B4, 0x3E6C7 },
	{ 0xE8A0B5, 0x2F0CD },
	{ 0xE8A0B6, 0x1FCE6 },
	{ 0xE8A0B7, 0x2F0CC },
	{ 0xE8A0B8, 0x2F0CB },
	{ 0xE8A0B9, 0x1FCE7 },
	{ 0xE8A0BA, 0x4ECA3 },
	{ 0xE8A0BB, 0x1FDA7 },
	{ 0xE8A0BC, 0x2F1DD },
	{ 0xE8A0BD, 0x2F1F5 },
	{ 0xE8A0BE, 0x2F1F4 },
	{ 0xE8A0BF, 0x2F1F6 },
	{ 0xE8A180, 0x1C8E6 },
	{ 0xE8A181, 0x2ADCB },
	{ 0xE8A182, 0x3AFA6 },
	{ 0xE8A183, 0x2B2F1 },
	{ 0xE8A184, 0x2B2F2 },
	{ 0xE8A185, 0x3B8EA },
	{ 0xE8A186, 0x3BEEA },
	{ 0xE8A187, 0x3BEE9 },
	{ 0xE8A188, 0x2C0A6 },
	{ 0xE8A189, 0x6CECF },
	{ 0xE8A18A, 0x2ECB6 },
	{ 0xE8A18B, 0x2F0CE },
	{ 0xE8A18C, 0x1C8E7 },
	{ 0xE8A18D, 0x1D3CF },
	{ 0xE8A18E, 0x2ADCC },
	{ 0xE8A18F, 0x3B3F1 },
	{ 0xE8A190, 0x3E6C8 },
	{ 0xE8A191, 0x4B5A7 },
	{ 0xE8A192, 0x2B9B4 },
	{ 0xE8A193, 0x1DDB4 },
	{ 0xE8A195, 0x2C0A8 },
	{ 0xE8A196, 0x2C0A7 },
	{ 0xE8A197, 0x1E1F9 },
	{ 0xE8A198, 0x3C4CD },
	{ 0xE8A199, 0x1E6CC },
	{ 0xE8A19A, 0x2D4AA },
	{ 0xE8A19B, 0x1EEEC },
	{ 0xE8A19C, 0x3CEDF },
	{ 0xE8A19D, 0x1EEED },
	{ 0xE8A19E, 0x3D2E3 },
	{ 0xE8A19F, 0x3D2E4 },
	{ 0xE8A1A0, 0x4D3CB },
	{ 0xE8A1A1, 0x1F2AF },
	{ 0xE8A1A2, 0x1FCE8 },
	{ 0xE8A1A3, 0x1C8E8 },
	{ 0xE8A1A6, 0x3AFA7 },
	{ 0xE8A1A7, 0x2ADCD },
	{ 0xE8A1A8, 0x1CFD0 },
	{ 0xE8A1A9, 0x2ADCF },
	{ 0xE8A1AA, 0x2ADCE },
	{ 0xE8A1AB, 0x1D3D0 },
	{ 0xE8A1AD, 0x2B2F3 },
	{ 0xE8A1AE, 0x3B3F4 },
	{ 0xE8A1AF, 0x2B2FA },
	{ 0xE8A1B0, 0x1D8AE },
	{ 0xE8A1B1, 0x2B2F8 },
	{ 0xE8A1B2, 0x2B2F6 },
	{ 0xE8A1B3, 0x3B3F7 },
	{ 0xE8A1B4, 0x2B2FD },
	{ 0xE8A1B5, 0x2B2F4 },
	{ 0xE8A1B6, 0x2B2F5 },
	{ 0xE8A1B7, 0x1D8AF },
	{ 0xE8A1B8, 0x3B3F2 },
	{ 0xE8A1B9, 0x1D8B3 },
	{ 0xE8A1BA, 0x3B3F3 },
	{ 0xE8A1BB, 0x3B3F5 },
	{ 0xE8A1BC, 0x2B2FE },
	{ 0xE8A1BD, 0x1D8B2 },
	{ 0xE8A1BE, 0x2B2FC },
	{ 0xE8A1BF, 0x2B2F9 },
	{ 0xE8A280, 0x2B2F7 },
	{ 0xE8A281, 0x1D8B0 },
	{ 0xE8A282, 0x1D8B1 },
	{ 0xE8A283, 0x2B2FB },
	{ 0xE8A284, 0x3B3F6 },
	{ 0xE8A287, 0x3E6C9 },
	{ 0xE8A288, 0x1DDB6 },
	{ 0xE8A289, 0x2B9B5 },
	{ 0xE8A28A, 0x3B8F2 },
	{ 0xE8A28B, 0x1DDBB },
	{ 0xE8A28C, 0x2B9C5 },
	{ 0xE8A28D, 0x1DDBA },
	{ 0xE8A28E, 0x2B9C7 },
	{ 0xE8A28F, 0x3B8EE },
	{ 0xE8A290, 0x3B8F4 },
	{ 0xE8A291, 0x2B9BB },
	{ 0xE8A292, 0x1DDB8 },
	{ 0xE8A293, 0x2B9C6 },
	{ 0xE8A294, 0x3B8EC },
	{ 0xE8A295, 0x2B9B6 },
	{ 0xE8A296, 0x1DDB9 },
	{ 0xE8A297, 0x2B9C2 },
	{ 0xE8A298, 0x2B9BE },
	{ 0xE8A299, 0x2B9C0 },
	{ 0xE8A29A, 0x2B9BA },
	{ 0xE8A29B, 0x2B9C1 },
	{ 0xE8A29C, 0x3B8EB },
	{ 0xE8A29D, 0x4B5AF },
	{ 0xE8A29E, 0x1DDB5 },
	{ 0xE8A29F, 0x2B9BD },
	{ 0xE8A2A0, 0x3B8F3 },
	{ 0xE8A2A1, 0x2B9BC },
	{ 0xE8A2A2, 0x2B9B8 },
	{ 0xE8A2A3, 0x3B8ED },
	{ 0xE8A2A4, 0x2B9C3 },
	{ 0xE8A2A5, 0x3B8EF },
	{ 0xE8A2A6, 0x3B8F1 },
	{ 0xE8A2A7, 0x2B9BF },
	{ 0xE8A2A8, 0x2B9B7 },
	{ 0xE8A2A9, 0x3B8F0 },
	{ 0xE8A2AA, 0x2B9B9 },
	{ 0xE8A2AB, 0x1DDB7 },
	{ 0xE8A2AC, 0x2B9C4 },
	{ 0xE8A2B1, 0x1E1FC },
	{ 0xE8A2B2, 0x2C0B3 },
	{ 0xE8A2B3, 0x4BAFB },
	{ 0xE8A2B4, 0x3BEF0 },
	{ 0xE8A2B5, 0x3BEF2 },
	{ 0xE8A2B6, 0x2C0AF },
	{ 0xE8A2B7, 0x2C0B1 },
	{ 0xE8A2B8, 0x2C0AC },
	{ 0xE8A2B9, 0x2C0AB },
	{ 0xE8A2BA, 0x2C0A9 },
	{ 0xE8A2BB, 0x3BEED },
	{ 0xE8A2BC, 0x2C0B0 },
	{ 0xE8A2BD, 0x2C0B2 },
	{ 0xE8A2BE, 0x2C0AE },
	{ 0xE8A2BF, 0x3BEEF },
	{ 0xE8A380, 0x2C0AD },
	{ 0xE8A381, 0x1E1FA },
	{ 0xE8A382, 0x1E1FB },
	{ 0xE8A389, 0x2C0B5 },
	{ 0xE8A38A, 0x1E6D4 },
	{ 0xE8A38B, 0x2C7B9 },
	{ 0xE8A38C, 0x2C7BF },
	{ 0xE8A38D, 0x2C7BA },
	{ 0xE8A38E, 0x2C7BB },
	{ 0xE8A38F, 0x3C4CE },
	{ 0xE8A390, 0x2C7C0 },
	{ 0xE8A391, 0x5C2EC },
	{ 0xE8A392, 0x1E6D6 },
	{ 0xE8A393, 0x4C0E1 },
	{ 0xE8A394, 0x1E6CE },
	{ 0xE8A395, 0x1E6D5 },
	{ 0xE8A396, 0x2C7B8 },
	{ 0xE8A397, 0x2C0AA },
	{ 0xE8A398, 0x1E6D1 },
	{ 0xE8A399, 0x1E6CF },
	{ 0xE8A39A, 0x2C7BE },
	{ 0xE8A39B, 0x2C7BD },
	{ 0xE8A39C, 0x1E6D0 },
	{ 0xE8A39D, 0x1E6D2 },
	{ 0xE8A39E, 0x2C7BC },
	{ 0xE8A39F, 0x1E6CD },
	{ 0xE8A3A0, 0x3C4CF },
	{ 0xE8A3A1, 0x1E6D3 },
	{ 0xE8A3A6, 0x3CEE0 },
	{ 0xE8A3A7, 0x2CDFD },
	{ 0xE8A3A8, 0x1EAFC },
	{ 0xE8A3A9, 0x3C9D9 },
	{ 0xE8A3AA, 0x3C9D2 },
	{ 0xE8A3AB, 0x2CEAA },
	{ 0xE8A3AC, 0x2CEA9 },
	{ 0xE8A3AD, 0x3C9D7 },
	{ 0xE8A3AE, 0x2CEA4 },
	{ 0xE8A3AF, 0x1EAFE },
	{ 0xE8A3B0, 0x2CEA8 },
	{ 0xE8A3B1, 0x2CDFE },
	{ 0xE8A3B2, 0x2CEA1 },
	{ 0xE8A3B3, 0x1EAF6 },
	{ 0xE8A3B4, 0x1EAF8 },
	{ 0xE8A3B5, 0x3C9D4 },
	{ 0xE8A3B6, 0x2CEA6 },
	{ 0xE8A3B7, 0x2CDFC },
	{ 0xE8A3B8, 0x1EAFA },
	{ 0xE8A3B9, 0x1EAF9 },
	{ 0xE8A3BA, 0x2CEA2 },
	{ 0xE8A3BB, 0x2CEA7 },
	{ 0xE8A3BC, 0x2CEA5 },
	{ 0xE8A3BD, 0x1EAFB },
	{ 0xE8A3BE, 0x2CEA3 },
	{ 0xE8A3BF, 0x3C9D1 },
	{ 0xE8A480, 0x3C9D6 },
	{ 0xE8A481, 0x2C0B4 },
	{ 0xE8A482, 0x1EAF7 },
	{ 0xE8A483, 0x3C9D8 },
	{ 0xE8A485, 0x2D4AB },
	{ 0xE8A486, 0x2D4B2 },
	{ 0xE8A487, 0x1EEEF },
	{ 0xE8A488, 0x4CDC6 },
	{ 0xE8A489, 0x2D4B6 },
	{ 0xE8A48A, 0x1EEF3 },
	{ 0xE8A48B, 0x2D4AE },
	{ 0xE8A48C, 0x2D4AC },
	{ 0xE8A48D, 0x4CDBE },
	{ 0xE8A48E, 0x2D4B5 },
	{ 0xE8A48F, 0x3CEE1 },
	{ 0xE8A490, 0x1EEEE },
	{ 0xE8A491, 0x2D4B4 },
	{ 0xE8A492, 0x1EEF0 },
	{ 0xE8A493, 0x1EEF1 },
	{ 0xE8A494, 0x2D4AD },
	{ 0xE8A495, 0x1EEF2 },
	{ 0xE8A496, 0x2D4B3 },
	{ 0xE8A497, 0x2D4AF },
	{ 0xE8A498, 0x2D4B0 },
	{ 0xE8A499, 0x2D4B1 },
	{ 0xE8A49A, 0x1EAFD },
	{ 0xE8A49B, 0x3CEE2 },
	{ 0xE8A49E, 0x2DABE },
	{ 0xE8A49F, 0x2DACA },
	{ 0xE8A4A0, 0x4D3D3 },
	{ 0xE8A4A1, 0x1F2B4 },
	{ 0xE8A4A2, 0x2DAC5 },
	{ 0xE8A4A3, 0x2DAC7 },
	{ 0xE8A4A4, 0x3D2E5 },
	{ 0xE8A4A5, 0x1F2B2 },
	{ 0xE8A4A6, 0x2DABF },
	{ 0xE8A4A7, 0x2DAC3 },
	{ 0xE8A4A8, 0x4D3D0 },
	{ 0xE8A4A9, 0x2DAC6 },
	{ 0xE8A4AA, 0x1F2B0 },
	{ 0xE8A4AB, 0x1F2B3 },
	{ 0xE8A4AC, 0x2DAC9 },
	{ 0xE8A4AD, 0x2DAC1 },
	{ 0xE8A4AE, 0x2DAC2 },
	{ 0xE8A4AF, 0x2DAC8 },
	{ 0xE8A4B0, 0x2DAC0 },
	{ 0xE8A4B1, 0x2DAC4 },
	{ 0xE8A4B2, 0x1F2B1 },
	{ 0xE8A4B3, 0x2DFC0 },
	{ 0xE8A4B5, 0x2DFBF },
	{ 0xE8A4B6, 0x1F5C2 },
	{ 0xE8A4B7, 0x2DFC5 },
	{ 0xE8A4B8, 0x1F5C4 },
	{ 0xE8A4B9, 0x3D6C0 },
	{ 0xE8A4BA, 0x4D8E2 },
	{ 0xE8A4BB, 0x1F5C1 },
	{ 0xE8A4BC, 0x2DFC1 },
	{ 0xE8A4BD, 0x1F5C5 },
	{ 0xE8A4BE, 0x2DFC2 },
	{ 0xE8A4BF, 0x3D6BF },
	{ 0xE8A580, 0x3D6BD },
	{ 0xE8A581, 0x2DFC3 },
	{ 0xE8A582, 0x2DFC6 },
	{ 0xE8A583, 0x3D6C2 },
	{ 0xE8A584, 0x1F5C3 },
	{ 0xE8A586, 0x2E3C1 },
	{ 0xE8A588, 0x3D8F9 },
	{ 0xE8A589, 0x2E3C4 },
	{ 0xE8A58A, 0x3D8FA },
	{ 0xE8A58B, 0x2E3BE },
	{ 0xE8A58C, 0x2E3C0 },
	{ 0xE8A58D, 0x3D8FC },
	{ 0xE8A58E, 0x3D8FB },
	{ 0xE8A58F, 0x2E3BF },
	{ 0xE8A590, 0x2E3C2 },
	{ 0xE8A591, 0x2E3C3 },
	{ 0xE8A592, 0x2DFC4 },
	{ 0xE8A593, 0x2E3BD },
	{ 0xE8A594, 0x3E6CA },
	{ 0xE8A596, 0x1F8F8 },
	{ 0xE8A597, 0x2E6F7 },
	{ 0xE8A598, 0x2E6FA },
	{ 0xE8A599, 0x2E6FC },
	{ 0xE8A59A, 0x2E6F5 },
	{ 0xE8A59B, 0x2E6F6 },
	{ 0xE8A59C, 0x2E6F9 },
	{ 0xE8A59D, 0x2E6FB },
	{ 0xE8A59E, 0x1F8F9 },
	{ 0xE8A59F, 0x1F8F7 },
	{ 0xE8A5A0, 0x1F8F6 },
	{ 0xE8A5A1, 0x2E6F8 },
	{ 0xE8A5A2, 0x2E6F4 },
	{ 0xE8A5A3, 0x2E9F6 },
	{ 0xE8A5A4, 0x1FABB },
	{ 0xE8A5A5, 0x3DDA9 },
	{ 0xE8A5A6, 0x2E9F7 },
	{ 0xE8A5A7, 0x3DDA8 },
	{ 0xE8A5A9, 0x2ECB8 },
	{ 0xE8A5AA, 0x1FBA8 },
	{ 0xE8A5AB, 0x2ECBA },
	{ 0xE8A5AC, 0x1FBA9 },
	{ 0xE8A5AD, 0x2ECB7 },
	{ 0xE8A5AE, 0x2ECB9 },
	{ 0xE8A5AF, 0x1FBF2 },
	{ 0xE8A5B0, 0x5F4B8 },
	{ 0xE8A5B1, 0x2EEA1 },
	{ 0xE8A5B2, 0x1FBF1 },
	{ 0xE8A5B3, 0x2EFCC },
	{ 0xE8A5B4, 0x2EFCB },
	{ 0xE8A5B5, 0x4ECA5 },
	{ 0xE8A5B6, 0x2EFCA },
	{ 0xE8A5B7, 0xFE8CA },
	{ 0xE8A5B8, 0x3E1C9 },
	{ 0xE8A5B9, 0x2F1B7 },
	{ 0xE8A5BA, 0x2F1B8 },
	{ 0xE8A5BB, 0x2F1BA },
	{ 0xE8A5BC, 0x2F1B9 },
	{ 0xE8A5BD, 0x3E1FD },
	{ 0xE8A5BE, 0x2A2F0 },
	{ 0xE8A5BF, 0x1C8E9 },
	{ 0xE8A681, 0x1D3D1 },
	{ 0xE8A682, 0x2B9C8 },
	{ 0xE8A683, 0x1E1FD },
	{ 0xE8A684, 0x3E6CB },
	{ 0xE8A685, 0x2C7C1 },
	{ 0xE8A686, 0x1F7BB },
	{ 0xE8A687, 0x3DBAF },
	{ 0xE8A688, 0x2E6FD },
	{ 0xE8A689, 0x3E0C6 },
	{ 0xE8A68A, 0x3E1CA },
	{ 0xE8A68B, 0x1CBC4 },
	{ 0xE8A68C, 0x3AFA9 },
	{ 0xE8A68D, 0x4AFF6 },
	{ 0xE8A68E, 0x4AFF5 },
	{ 0xE8A68F, 0x1DDBD },
	{ 0xE8A690, 0x4B5B4 },
	{ 0xE8A691, 0x3B8F6 },
	{ 0xE8A692, 0x3B8F5 },
	{ 0xE8A693, 0x1DDBC },
	{ 0xE8A694, 0x3B8F7 },
	{ 0xE8A695, 0x2C0B6 },
	{ 0xE8A696, 0x1E1FE },
	{ 0xE8A697, 0x2C0B8 },
	{ 0xE8A698, 0x2C0B7 },
	{ 0xE8A699, 0x6CEE0 },
	{ 0xE8A69A, 0x3BEF4 },
	{ 0xE8A69B, 0x2C7C2 },
	{ 0xE8A69C, 0x1E6D7 },
	{ 0xE8A69D, 0x2CEAB },
	{ 0xE8A69E, 0x2CEAE },
	{ 0xE8A69F, 0x2CEAD },
	{ 0xE8A6A0, 0x4C7B5 },
	{ 0xE8A6A1, 0x2CEAC },
	{ 0xE8A6A2, 0x2D4B7 },
	{ 0xE8A6A3, 0x2D4B9 },
	{ 0xE8A6A4, 0x2D4B8 },
	{ 0xE8A6A5, 0x3CEE5 },
	{ 0xE8A6A6, 0x1F2B6 },
	{ 0xE8A6A7, 0x3D2E6 },
	{ 0xE8A6A8, 0x4D3D9 },
	{ 0xE8A6A9, 0x3CEE4 },
	{ 0xE8A6AA, 0x1F2B5 },
	{ 0xE8A6AB, 0x3D6C6 },
	{ 0xE8A6AC, 0x1F5C6 },
	{ 0xE8A6AD, 0x2DFC7 },
	{ 0xE8A6AE, 0x2DFC9 },
	{ 0xE8A6AF, 0x2DFC8 },
	{ 0xE8A6B0, 0x3D8FE },
	{ 0xE8A6B1, 0x3D8FD },
	{ 0xE8A6B2, 0x1F7BC },
	{ 0xE8A6B3, 0x3D9A1 },
	{ 0xE8A6B4, 0x4E1AF },
	{ 0xE8A6B5, 0x3DBB1 },
	{ 0xE8A6B6, 0x2E7A1 },
	{ 0xE8A6B7, 0x2E6FE },
	{ 0xE8A6B8, 0xFE3F7 },
	{ 0xE8A6B9, 0x2E9F8 },
	{ 0xE8A6BA, 0x1FABC },
	{ 0xE8A6BB, 0x3DDAA },
	{ 0xE8A6BC, 0x3DEE1 },
	{ 0xE8A6BD, 0x1FBAA },
	{ 0xE8A6BE, 0x2EEA3 },
	{ 0xE8A6BF, 0x2EEA2 },
	{ 0xE8A780, 0x1FDA8 },
	{ 0xE8A792, 0x1CBC5 },
	{ 0xE8A793, 0x2ADD0 },
	{ 0xE8A794, 0x1D3D2 },
	{ 0xE8A795, 0x2B9CB },
	{ 0xE8A796, 0x2B9C9 },
	{ 0xE8A797, 0x4B5B9 },
	{ 0xE8A798, 0x4B5B8 },
	{ 0xE8A799, 0x2B9CA },
	{ 0xE8A79A, 0x2C0BA },
	{ 0xE8A79B, 0x2C0BB },
	{ 0xE8A79C, 0x2C7C9 },
	{ 0xE8A79D, 0x2C0B9 },
	{ 0xE8A79F, 0x2C7C3 },
	{ 0xE8A7A0, 0x2C7C7 },
	{ 0xE8A7A1, 0x2C7C6 },
	{ 0xE8A7A2, 0x2C7C8 },
	{ 0xE8A7A3, 0x1E6D8 },
	{ 0xE8A7A4, 0x2C7C5 },
	{ 0xE8A7A5, 0x2C7C4 },
	{ 0xE8A7A6, 0x2C7CA },
	{ 0xE8A7A7, 0x3C4D4 },
	{ 0xE8A7A8, 0x2CEB1 },
	{ 0xE8A7A9, 0x2CEAF },
	{ 0xE8A7AA, 0x3C9DC },
	{ 0xE8A7AB, 0x2CEB0 },
	{ 0xE8A7AC, 0x2D4BC },
	{ 0xE8A7AD, 0x2D4BA },
	{ 0xE8A7AE, 0x3CEE6 },
	{ 0xE8A7B0, 0x2D4BB },
	{ 0xE8A7B1, 0x2DACB },
	{ 0xE8A7B2, 0x2DFCA },
	{ 0xE8A7B3, 0x2DFCB },
	{ 0xE8A7B4, 0x1F7BD },
	{ 0xE8A7B5, 0x3DBB2 },
	{ 0xE8A7B6, 0x2E7A2 },
	{ 0xE8A7B7, 0x2E9F9 },
	{ 0xE8A7B8, 0x1FABD },
	{ 0xE8A7B9, 0x4E1B7 },
	{ 0xE8A7BA, 0x2ECBB },
	{ 0xE8A7BB, 0x2EEA4 },
	{ 0xE8A7BC, 0x1FBF3 },
	{ 0xE8A7BD, 0x4E9C5 },
	{ 0xE8A7BE, 0x2EFCD },
	{ 0xE8A7BF, 0x2F1BB },
	{ 0xE8A880, 0x1CBC6 },
	{ 0xE8A882, 0x1D3D4 },
	{ 0xE8A883, 0x1D3D5 },
	{ 0xE8A884, 0x2ADD1 },
	{ 0xE8A885, 0x3AFAA },
	{ 0xE8A886, 0x3AFAC },
	{ 0xE8A887, 0x2ADD2 },
	{ 0xE8A888, 0x1D3D3 },
	{ 0xE8A889, 0x4AFFC },
	{ 0xE8A88A, 0x1D8B9 },
	{ 0xE8A88B, 0x3B3FB },
	{ 0xE8A88C, 0x1D8B7 },
	{ 0xE8A88D, 0x3B3FA },
	{ 0xE8A88E, 0x1D8B6 },
	{ 0xE8A88F, 0x1D8BD },
	{ 0xE8A890, 0x1D8B5 },
	{ 0xE8A891, 0x1D8BE },
	{ 0xE8A892, 0x2B3A1 },
	{ 0xE8A893, 0x1D8BB },
	{ 0xE8A894, 0x4AFFD },
	{ 0xE8A895, 0x1D8B8 },
	{ 0xE8A896, 0x1D8BC },
	{ 0xE8A897, 0x1D8BA },
	{ 0xE8A898, 0x1D8B4 },
	{ 0xE8A899, 0x3B3FC },
	{ 0xE8A89B, 0x1DDC5 },
	{ 0xE8A89C, 0x3B8FE },
	{ 0xE8A89D, 0x1DDBF },
	{ 0xE8A89E, 0x2B9CF },
	{ 0xE8A89F, 0x1DDC4 },
	{ 0xE8A8A0, 0x3B9A3 },
	{ 0xE8A8A1, 0x3B9A9 },
	{ 0xE8A8A2, 0x1DDC6 },
	{ 0xE8A8A3, 0x1DDC0 },
	{ 0xE8A8A4, 0x6C4F0 },
	{ 0xE8A8A5, 0x1DDC1 },
	{ 0xE8A8A6, 0x3B8F9 },
	{ 0xE8A8A7, 0x2B9CD },
	{ 0xE8A8A8, 0x3B8FB },
	{ 0xE8A8A9, 0x3B9A5 },
	{ 0xE8A8AA, 0x1DDBE },
	{ 0xE8A8AB, 0x3B9A2 },
	{ 0xE8A8AC, 0x2B9CE },
	{ 0xE8A8AD, 0x1DDC3 },
	{ 0xE8A8AE, 0x4B5BD },
	{ 0xE8A8AF, 0x5B5DB },
	{ 0xE8A8B0, 0x2B9CC },
	{ 0xE8A8B1, 0x1DDC2 },
	{ 0xE8A8B2, 0x3B8FA },
	{ 0xE8A8B4, 0x1E2AB },
	{ 0xE8A8B5, 0x3BEFC },
	{ 0xE8A8B6, 0x1E2AD },
	{ 0xE8A8B7, 0x4BBAF },
	{ 0xE8A8B8, 0x3BEFD },
	{ 0xE8A8B9, 0x2C0BE },
	{ 0xE8A8BA, 0x1E2AC },
	{ 0xE8A8BB, 0x1E2A1 },
	{ 0xE8A8BC, 0x1E2A5 },
	{ 0xE8A8BD, 0x3BFA4 },
	{ 0xE8A8BE, 0x1E6EB },
	{ 0xE8A8BF, 0x2C7CF },
	{ 0xE8A980, 0x2C0C0 },
	{ 0xE8A981, 0x1E2A6 },
	{ 0xE8A982, 0x3BEFE },
	{ 0xE8A983, 0x3BEF5 },
	{ 0xE8A984, 0x2C0C3 },
	{ 0xE8A985, 0x2C0C4 },
	{ 0xE8A986, 0x1E2AA },
	{ 0xE8A987, 0x4BBB0 },
	{ 0xE8A988, 0x2C0C6 },
	{ 0xE8A989, 0x3BFA1 },
	{ 0xE8A98A, 0x2C0C8 },
	{ 0xE8A98B, 0x3BFA3 },
	{ 0xE8A98C, 0x2C0C9 },
	{ 0xE8A98D, 0x2C0BD },
	{ 0xE8A98E, 0x2C0BC },
	{ 0xE8A98F, 0x2C0CA },
	{ 0xE8A990, 0x1E2A9 },
	{ 0xE8A991, 0x2C0C7 },
	{ 0xE8A992, 0x2C0C5 },
	{ 0xE8A993, 0x4BBAC },
	{ 0xE8A994, 0x1E2A7 },
	{ 0xE8A995, 0x1E2A3 },
	{ 0xE8A996, 0x1E2AE },
	{ 0xE8A997, 0x2C0C1 },
	{ 0xE8A998, 0x2C0C2 },
	{ 0xE8A999, 0x2C0BF },
	{ 0xE8A99A, 0x3BEF8 },
	{ 0xE8A99B, 0x1E2A8 },
	{ 0xE8A99C, 0x4BBB1 },
	{ 0xE8A99D, 0x3BFA2 },
	{ 0xE8A99E, 0x1E2A4 },
	{ 0xE8A9A0, 0x1E2A2 },
	{ 0xE8A9A1, 0x2C7CE },
	{ 0xE8A9A2, 0x1E6E6 },
	{ 0xE8A9A3, 0x1E6E1 },
	{ 0xE8A9A4, 0x3C4E0 },
	{ 0xE8A9A5, 0x3C4D9 },
	{ 0xE8A9A6, 0x1E6DC },
	{ 0xE8A9A7, 0x3C4E3 },
	{ 0xE8A9A8, 0x1E6EC },
	{ 0xE8A9A9, 0x1E6DD },
	{ 0xE8A9AA, 0x3C4D5 },
	{ 0xE8A9AB, 0x1E6D9 },
	{ 0xE8A9AC, 0x1E6E8 },
	{ 0xE8A9AD, 0x1E6E5 },
	{ 0xE8A9AE, 0x1E6E7 },
	{ 0xE8A9AF, 0x3C4D8 },
	{ 0xE8A9B0, 0x1E6DE },
	{ 0xE8A9B1, 0x1E6E3 },
	{ 0xE8A9B2, 0x1E6DA },
	{ 0xE8A9B3, 0x1E6DB },
	{ 0xE8A9B4, 0x2C7D6 },
	{ 0xE8A9B5, 0x2C7D3 },
	{ 0xE8A9B6, 0x2C7CB },
	{ 0xE8A9B7, 0x2C7D0 },
	{ 0xE8A9B8, 0x3C4DB },
	{ 0xE8A9B9, 0x1E6E9 },
	{ 0xE8A9BA, 0x2C7D7 },
	{ 0xE8A9BB, 0x1E6EA },
	{ 0xE8A9BC, 0x1E6E0 },
	{ 0xE8A9BD, 0x3C4DC },
	{ 0xE8A9BE, 0x3C4E1 },
	{ 0xE8A9BF, 0x2C7CD },
	{ 0xE8AA80, 0x3C4D6 },
	{ 0xE8AA81, 0x2C7D5 },
	{ 0xE8AA82, 0x2C7D1 },
	{ 0xE8AA83, 0x2C7D4 },
	{ 0xE8AA84, 0x2C7D2 },
	{ 0xE8AA85, 0x1E6E4 },
	{ 0xE8AA86, 0x2C7CC },
	{ 0xE8AA87, 0x1E6DF },
	{ 0xE8AA88, 0x3C4DD },
	{ 0xE8AA8B, 0x2CEB4 },
	{ 0xE8AA8C, 0x1EBA2 },
	{ 0xE8AA8D, 0x1EBA5 },
	{ 0xE8AA8E, 0x3C9DF },
	{ 0xE8AA8F, 0x2CEB6 },
	{ 0xE8AA90, 0x3C9E4 },
	{ 0xE8AA91, 0x1EBAD },
	{ 0xE8AA92, 0x2CEB5 },
	{ 0xE8AA93, 0x1EBA7 },
	{ 0xE8AA94, 0x3C9E3 },
	{ 0xE8AA95, 0x1EEF8 },
	{ 0xE8AA96, 0x2CEB7 },
	{ 0xE8AA97, 0x4C7C5 },
	{ 0xE8AA98, 0x1EBAC },
	{ 0xE8AA99, 0x2CEB3 },
	{ 0xE8AA9A, 0x1EBAE },
	{ 0xE8AA9B, 0x3C9DE },
	{ 0xE8AA9C, 0x3C9E2 },
	{ 0xE8AA9D, 0x3C9EB },
	{ 0xE8AA9E, 0x1EBA3 },
	{ 0xE8AA9F, 0x3C9E8 },
	{ 0xE8AAA0, 0x1E6E2 },
	{ 0xE8AAA1, 0x1EBA6 },
	{ 0xE8AAA2, 0x3C9E0 },
	{ 0xE8AAA3, 0x1EBA4 },
	{ 0xE8AAA4, 0x1EBA8 },
	{ 0xE8AAA5, 0x1EBAA },
	{ 0xE8AAA6, 0x1EBA1 },
	{ 0xE8AAA7, 0x1EBAF },
	{ 0xE8AAA8, 0x1EBAB },
	{ 0xE8AAA9, 0x3C9E5 },
	{ 0xE8AAAA, 0x1EBA9 },
	{ 0xE8AAAB, 0x2CEB2 },
	{ 0xE8AAAC, 0x3C9E6 },
	{ 0xE8AAAD, 0xFCCC1 },
	{ 0xE8AAAF, 0x3CEF4 },
	{ 0xE8AAB0, 0x1EFA1 },
	{ 0xE8AAB1, 0x3CEE7 },
	{ 0xE8AAB2, 0x1EEFB },
	{ 0xE8AAB3, 0x3CEF2 },
	{ 0xE8AAB4, 0x3CEF0 },
	{ 0xE8AAB5, 0x3CEEE },
	{ 0xE8AAB6, 0x1EFA4 },
	{ 0xE8AAB7, 0x3CEEC },
	{ 0xE8AAB8, 0x2D4BF },
	{ 0xE8AAB9, 0x1EFA5 },
	{ 0xE8AABA, 0x2D4CB },
	{ 0xE8AABB, 0x2D4C4 },
	{ 0xE8AABC, 0x1EEF4 },
	{ 0xE8AABD, 0x2D4CC },
	{ 0xE8AABE, 0x2D4C6 },
	{ 0xE8AABF, 0x1EEFE },
	{ 0xE8AB80, 0x2D4C7 },
	{ 0xE8AB81, 0x3CEF3 },
	{ 0xE8AB82, 0x1EEFD },
	{ 0xE8AB83, 0x2D4CA },
	{ 0xE8AB84, 0x1EEF7 },
	{ 0xE8AB85, 0x2D4C8 },
	{ 0xE8AB86, 0x2D4BE },
	{ 0xE8AB87, 0x1EEF6 },
	{ 0xE8AB88, 0x2DAD6 },
	{ 0xE8AB89, 0x1EEFC },
	{ 0xE8AB8A, 0x3CEF5 },
	{ 0xE8AB8B, 0x1EEF9 },
	{ 0xE8AB8C, 0x3CEE9 },
	{ 0xE8AB8D, 0x1EFA3 },
	{ 0xE8AB8E, 0x3CEEA },
	{ 0xE8AB8F, 0x2D4BD },
	{ 0xE8AB90, 0x3CEF6 },
	{ 0xE8AB91, 0x2D4C1 },
	{ 0xE8AB92, 0x1EEF5 },
	{ 0xE8AB93, 0x2D4C0 },
	{ 0xE8AB94, 0x2D4C2 },
	{ 0xE8AB95, 0x2D4C3 },
	{ 0xE8AB96, 0x1EFA2 },
	{ 0xE8AB97, 0x2D4C5 },
	{ 0xE8AB98, 0x2D4C9 },
	{ 0xE8AB99, 0x2D4CD },
	{ 0xE8AB9B, 0x1EFA6 },
	{ 0xE8AB9C, 0x1F2BC },
	{ 0xE8AB9D, 0x2DAD1 },
	{ 0xE8AB9E, 0x2DAD7 },
	{ 0xE8AB9F, 0x2DAD4 },
	{ 0xE8ABA0, 0x2DACC },
	{ 0xE8ABA1, 0x2DAD8 },
	{ 0xE8ABA2, 0x2DACD },
	{ 0xE8ABA3, 0x3D2EA },
	{ 0xE8ABA4, 0x2DAD3 },
	{ 0xE8ABA5, 0x3D2EB },
	{ 0xE8ABA6, 0x1F2B7 },
	{ 0xE8ABA7, 0x1F2BD },
	{ 0xE8ABA8, 0x2DAD9 },
	{ 0xE8ABA9, 0x3CEEF },
	{ 0xE8ABAA, 0x3D2E7 },
	{ 0xE8ABAB, 0x1F2B9 },
	{ 0xE8ABAC, 0x3D2EE },
	{ 0xE8ABAD, 0x1F2C3 },
	{ 0xE8ABAE, 0x1F2BE },
	{ 0xE8ABAF, 0x2DADB },
	{ 0xE8ABB0, 0x2DAD5 },
	{ 0xE8ABB1, 0x1F2BA },
	{ 0xE8ABB2, 0x2DACE },
	{ 0xE8ABB3, 0x1F2C4 },
	{ 0xE8ABB4, 0x2DACF },
	{ 0xE8ABB5, 0x2DAD0 },
	{ 0xE8ABB6, 0x1F2C5 },
	{ 0xE8ABB7, 0x1F2C2 },
	{ 0xE8ABB8, 0x1EEFA },
	{ 0xE8ABB9, 0x3D2E9 },
	{ 0xE8ABBA, 0x1F2B8 },
	{ 0xE8ABBB, 0x2DADC },
	{ 0xE8ABBC, 0x1F2C6 },
	{ 0xE8ABBD, 0x3D2E8 },
	{ 0xE8ABBE, 0x1F2BF },
	{ 0xE8ABBF, 0x2DADA },
	{ 0xE8AC80, 0x1F2BB },
	{ 0xE8AC81, 0x1F2C0 },
	{ 0xE8AC82, 0x1F2C1 },
	{ 0xE8AC83, 0x3E6CC },
	{ 0xE8AC84, 0x1F5CE },
	{ 0xE8AC85, 0x2DFD0 },
	{ 0xE8AC86, 0x2DFD9 },
	{ 0xE8AC87, 0x2DFD6 },
	{ 0xE8AC88, 0x2DFD8 },
	{ 0xE8AC89, 0x3D6C9 },
	{ 0xE8AC8A, 0x1F5CB },
	{ 0xE8AC8B, 0x2DFD1 },
	{ 0xE8AC8C, 0x3D6CA },
	{ 0xE8AC8D, 0x2DFD7 },
	{ 0xE8AC8E, 0x1F5C7 },
	{ 0xE8AC8F, 0x2DFD3 },
	{ 0xE8AC90, 0x1F5CF },
	{ 0xE8AC91, 0x2DFCF },
	{ 0xE8AC92, 0x2DFD4 },
	{ 0xE8AC93, 0x2DFDB },
	{ 0xE8AC94, 0x2DAD2 },
	{ 0xE8AC95, 0x2DFD5 },
	{ 0xE8AC96, 0x2DFCE },
	{ 0xE8AC97, 0x1F5C8 },
	{ 0xE8AC98, 0x2DFCD },
	{ 0xE8AC99, 0x1F5C9 },
	{ 0xE8AC9A, 0x2DFDC },
	{ 0xE8AC9B, 0x1F5CA },
	{ 0xE8AC9C, 0x2DFDA },
	{ 0xE8AC9D, 0x1F5CD },
	{ 0xE8AC9E, 0x2DFCC },
	{ 0xE8AC9F, 0x3D6C8 },
	{ 0xE8ACA0, 0x1F5CC },
	{ 0xE8ACA2, 0x2DFD2 },
	{ 0xE8ACA3, 0x2E3C7 },
	{ 0xE8ACA4, 0x2E3D5 },
	{ 0xE8ACA5, 0x2E3D0 },
	{ 0xE8ACA6, 0x2E3D2 },
	{ 0xE8ACA7, 0x2E3C6 },
	{ 0xE8ACA8, 0x1F7BE },
	{ 0xE8ACA9, 0x3D9AA },
	{ 0xE8ACAA, 0x2E3C5 },
	{ 0xE8ACAB, 0x1F7C1 },
	{ 0xE8ACAC, 0x1F7C0 },
	{ 0xE8ACAD, 0x3D9A6 },
	{ 0xE8ACAE, 0x2E3D4 },
	{ 0xE8ACAF, 0x2E3CC },
	{ 0xE8ACB0, 0x2E3C9 },
	{ 0xE8ACB1, 0x2E3CF },
	{ 0xE8ACB2, 0x3D9A4 },
	{ 0xE8ACB3, 0x2E3C8 },
	{ 0xE8ACB4, 0x3D9A8 },
	{ 0xE8ACB5, 0x2E3CA },
	{ 0xE8ACB6, 0x2E3D3 },
	{ 0xE8ACB7, 0x2E3D1 },
	{ 0xE8ACB8, 0x3D9A3 },
	{ 0xE8ACB9, 0x1F7BF },
	{ 0xE8ACBA, 0x2E3D8 },
	{ 0xE8ACBB, 0x2E3D6 },
	{ 0xE8ACBC, 0x2E3CD },
	{ 0xE8ACBD, 0x2E3D7 },
	{ 0xE8ACBE, 0x2E3CE },
	{ 0xE8ACBF, 0x3DBB4 },
	{ 0xE8AD80, 0x2E7A6 },
	{ 0xE8AD81, 0x1F8FA },
	{ 0xE8AD82, 0x2E7AD },
	{ 0xE8AD83, 0x3DBB5 },
	{ 0xE8AD84, 0x4E1BA },
	{ 0xE8AD85, 0x2ECBE },
	{ 0xE8AD86, 0x1F9A3 },
	{ 0xE8AD87, 0x2E3CB },
	{ 0xE8AD88, 0x2E7A4 },
	{ 0xE8AD89, 0x1F8FD },
	{ 0xE8AD8A, 0x2E7A5 },
	{ 0xE8AD8B, 0x2E7AA },
	{ 0xE8AD8C, 0x3DBB6 },
	{ 0xE8AD8D, 0x3DDB3 },
	{ 0xE8AD8E, 0x1F9A1 },
	{ 0xE8AD8F, 0x1F9A2 },
	{ 0xE8AD90, 0x2E7A3 },
	{ 0xE8AD91, 0x2E7AC },
	{ 0xE8AD92, 0x2E7AE },
	{ 0xE8AD93, 0x2E7A7 },
	{ 0xE8AD94, 0x2E7A9 },
	{ 0xE8AD95, 0x2E7AB },
	{ 0xE8AD96, 0x2E7A8 },
	{ 0xE8AD97, 0x2E7AF },
	{ 0xE8AD98, 0x1F8FC },
	{ 0xE8AD99, 0x1F9A4 },
	{ 0xE8AD9A, 0x1F8FE },
	{ 0xE8AD9C, 0x1F8FB },
	{ 0xE8AD9D, 0x2E9FC },
	{ 0xE8AD9E, 0x4E4CD },
	{ 0xE8AD9F, 0x1FAC2 },
	{ 0xE8ADA0, 0x2E9FA },
	{ 0xE8ADA1, 0x3DDB0 },
	{ 0xE8ADA2, 0x3DDAC },
	{ 0xE8ADA3, 0x2E9FE },
	{ 0xE8ADA4, 0x3DDB2 },
	{ 0xE8ADA5, 0x2EAA1 },
	{ 0xE8ADA6, 0x1FAC0 },
	{ 0xE8ADA7, 0x2EAA2 },
	{ 0xE8ADA8, 0x2E9FD },
	{ 0xE8ADA9, 0x3DDAB },
	{ 0xE8ADAA, 0x2E9FB },
	{ 0xE8ADAB, 0x1FAC3 },
	{ 0xE8ADAC, 0x1FABF },
	{ 0xE8ADAD, 0x2EAA3 },
	{ 0xE8ADAE, 0x3DDAE },
	{ 0xE8ADAF, 0x1FAC1 },
	{ 0xE8ADB0, 0x1FABE },
	{ 0xE8ADB1, 0x3DCED },
	{ 0xE8ADB3, 0x4E7BB },
	{ 0xE8ADB4, 0x1FBAB },
	{ 0xE8ADB5, 0x3DEE2 },
	{ 0xE8ADB6, 0x4E7C1 },
	{ 0xE8ADB7, 0x1FBAC },
	{ 0xE8ADB8, 0x2ECBD },
	{ 0xE8ADB9, 0x2ECBC },
	{ 0xE8ADBA, 0x2ECBF },
	{ 0xE8ADBB, 0x2ECC0 },
	{ 0xE8ADBC, 0x3DEE3 },
	{ 0xE8ADBD, 0x1FBAD },
	{ 0xE8ADBE, 0x2EEA5 },
	{ 0xE8ADBF, 0x2EEAA },
	{ 0xE8AE80, 0x1FBF4 },
	{ 0xE8AE81, 0x3DFE1 },
	{ 0xE8AE82, 0x2EEA7 },
	{ 0xE8AE83, 0x3DFE2 },
	{ 0xE8AE84, 0x2EEA6 },
	{ 0xE8AE85, 0x2EEA9 },
	{ 0xE8AE86, 0x2EEA8 },
	{ 0xE8AE87, 0x3E0C8 },
	{ 0xE8AE88, 0x2EFD1 },
	{ 0xE8AE89, 0x4EAFC },
	{ 0xE8AE8A, 0x1FCC8 },
	{ 0xE8AE8B, 0x2EFD0 },
	{ 0xE8AE8C, 0x2EFCE },
	{ 0xE8AE8D, 0x3E0C7 },
	{ 0xE8AE8E, 0x2EFCF },
	{ 0xE8AE90, 0x3E0C9 },
	{ 0xE8AE91, 0x3E0FB },
	{ 0xE8AE92, 0x1FCEA },
	{ 0xE8AE93, 0x1FCE9 },
	{ 0xE8AE94, 0x2F0CF },
	{ 0xE8AE95, 0x2F0D0 },
	{ 0xE8AE96, 0x1FCEB },
	{ 0xE8AE97, 0x3E1CB },
	{ 0xE8AE98, 0x2F1BC },
	{ 0xE8AE99, 0x2F1BD },
	{ 0xE8AE9A, 0x1FDB4 },
	{ 0xE8AE9B, 0x3E1EB },
	{ 0xE8AE9C, 0x1FDBA },
	{ 0xE8AE9D, 0x3E1FE },
	{ 0xE8AE9E, 0x2F1F7 },
	{ 0xE8AE9F, 0x2F2B6 },
	{ 0xE8B0B7, 0x1CBC7 },
	{ 0xE8B0B8, 0x5B0C6 },
	{ 0xE8B0B9, 0x2B9D0 },
	{ 0xE8B0BA, 0x3B9AA },
	{ 0xE8B0BB, 0x2B9D1 },
	{ 0xE8B0BC, 0x2C7D8 },
	{ 0xE8B0BD, 0x2CEB8 },
	{ 0xE8B0BE, 0x2D4CE },
	{ 0xE8B0BF, 0x1F5D1 },
	{ 0xE8B180, 0x3D6CD },
	{ 0xE8B181, 0x1F5D0 },
	{ 0xE8B182, 0x2E3D9 },
	{ 0xE8B183, 0x2E7B0 },
	{ 0xE8B184, 0x3DFE4 },
	{ 0xE8B185, 0x2EFD2 },
	{ 0xE8B186, 0x1CBC8 },
	{ 0xE8B187, 0x2B3A2 },
	{ 0xE8B188, 0x1D8BF },
	{ 0xE8B189, 0x1DDC7 },
	{ 0xE8B18A, 0x2C7DA },
	{ 0xE8B18B, 0x2C7D9 },
	{ 0xE8B18C, 0x1EFA7 },
	{ 0xE8B18D, 0x2D4CF },
	{ 0xE8B18E, 0x1EFA8 },
	{ 0xE8B18F, 0x2DFDD },
	{ 0xE8B190, 0x1F7C2 },
	{ 0xE8B191, 0x3DDB4 },
	{ 0xE8B192, 0x3E6CD },
	{ 0xE8B193, 0x3E2A1 },
	{ 0xE8B194, 0x1FDC3 },
	{ 0xE8B195, 0x1CBC9 },
	{ 0xE8B196, 0x2A8EB },
	{ 0xE8B197, 0x2B3A3 },
	{ 0xE8B198, 0x3B9AD },
	{ 0xE8B199, 0x4B5CD },
	{ 0xE8B19A, 0x1DDC8 },
	{ 0xE8B19B, 0x3B9AC },
	{ 0xE8B19C, 0x2B9D2 },
	{ 0xE8B19D, 0x2B9D3 },
	{ 0xE8B19E, 0x3BFAA },
	{ 0xE8B19F, 0x2C0CB },
	{ 0xE8B1A0, 0x3BFA9 },
	{ 0xE8B1A1, 0x1E2AF },
	{ 0xE8B1A2, 0x1E6ED },
	{ 0xE8B1A3, 0x3C4E4 },
	{ 0xE8B1A4, 0x2C7DC },
	{ 0xE8B1A5, 0x2C7DB },
	{ 0xE8B1A6, 0x2C7DD },
	{ 0xE8B1A7, 0x3C9ED },
	{ 0xE8B1A8, 0x2CEB9 },
	{ 0xE8B1A9, 0x2CEBA },
	{ 0xE8B1AA, 0x1EBB0 },
	{ 0xE8B1AB, 0x1F2C7 },
	{ 0xE8B1AC, 0x1EFA9 },
	{ 0xE8B1AD, 0x1F2C8 },
	{ 0xE8B1AF, 0x2DFE1 },
	{ 0xE8B1B0, 0x2DFDE },
	{ 0xE8B1B1, 0x2DFE0 },
	{ 0xE8B1B2, 0x2DFDF },
	{ 0xE8B1B3, 0x1F5D2 },
	{ 0xE8B1B4, 0x3D9AB },
	{ 0xE8B1B5, 0x2E3DA },
	{ 0xE8B1B6, 0x2E7B2 },
	{ 0xE8B1B7, 0x2E7B1 },
	{ 0xE8B1B8, 0x2A5A4 },
	{ 0xE8B1B9, 0x1D8C1 },
	{ 0xE8B1BA, 0x1D8C0 },
	{ 0xE8B1BB, 0x2B3A4 },
	{ 0xE8B1BC, 0x3B9AE },
	{ 0xE8B1BD, 0x2B9D4 },
	{ 0xE8B1BE, 0x3BFAC },
	{ 0xE8B1BF, 0x3BFAB },
	{ 0xE8B280, 0x2C0CD },
	{ 0xE8B281, 0x2C0CC },
	{ 0xE8B282, 0x1E2B0 },
	{ 0xE8B283, 0x3BFAD },
	{ 0xE8B284, 0x2C7DF },
	{ 0xE8B285, 0x2C7E0 },
	{ 0xE8B286, 0x2C7DE },
	{ 0xE8B287, 0x4C0F8 },
	{ 0xE8B288, 0x3C4E5 },
	{ 0xE8B289, 0x1E6EF },
	{ 0xE8B28A, 0x1E6EE },
	{ 0xE8B28B, 0x4C7D4 },
	{ 0xE8B28C, 0x1EBB2 },
	{ 0xE8B28D, 0x1EBB1 },
	{ 0xE8B28E, 0x3CEFA },
	{ 0xE8B28F, 0x2D4D0 },
	{ 0xE8B290, 0x2DADF },
	{ 0xE8B291, 0x2DADD },
	{ 0xE8B292, 0x2DADE },
	{ 0xE8B293, 0x1F2C9 },
	{ 0xE8B294, 0x2DFE3 },
	{ 0xE8B295, 0x2DFE2 },
	{ 0xE8B296, 0x3D6CF },
	{ 0xE8B297, 0x2E3DD },
	{ 0xE8B298, 0x2E3DC },
	{ 0xE8B299, 0x2E3DB },
	{ 0xE8B29A, 0x2E7B3 },
	{ 0xE8B29B, 0x3E1CD },
	{ 0xE8B29C, 0x2F1F8 },
	{ 0xE8B29D, 0x1CBCA },
	{ 0xE8B29E, 0x1D3D6 },
	{ 0xE8B29F, 0x3AFAE },
	{ 0xE8B2A0, 0x1D3D7 },
	{ 0xE8B2A1, 0x1D8C2 },
	{ 0xE8B2A2, 0x1D8C3 },
	{ 0xE8B2A3, 0x2B3A6 },
	{ 0xE8B2A4, 0x2B3A5 },
	{ 0xE8B2A5, 0x2B9D5 },
	{ 0xE8B2A6, 0x3B9B0 },
	{ 0xE8B2A7, 0x1DDCE },
	{ 0xE8B2A8, 0x1DDCC },
	{ 0xE8B2A9, 0x1DDC9 },
	{ 0xE8B2AA, 0x1DDCD },
	{ 0xE8B2AB, 0x1DDCB },
	{ 0xE8B2AC, 0x1DDCA },
	{ 0xE8B2AD, 0x3B9B2 },
	{ 0xE8B2AE, 0x3B9B1 },
	{ 0xE8B2AF, 0x1E2B1 },
	{ 0xE8B2B0, 0x2C0D0 },
	{ 0xE8B2B1, 0x3BFAF },
	{ 0xE8B2B2, 0x1E6F4 },
	{ 0xE8B2B3, 0x1E2B3 },
	{ 0xE8B2B4, 0x1E2B8 },
	{ 0xE8B2B5, 0x2C0D2 },
	{ 0xE8B2B6, 0x1E2BA },
	{ 0xE8B2B7, 0x1E2B9 },
	{ 0xE8B2B8, 0x1E2BC },
	{ 0xE8B2B9, 0x2C0D1 },
	{ 0xE8B2BA, 0x2C0CE },
	{ 0xE8B2BB, 0x1E2B6 },
	{ 0xE8B2BC, 0x1E2B2 },
	{ 0xE8B2BD, 0x1E2B4 },
	{ 0xE8B2BE, 0x2C0CF },
	{ 0xE8B2BF, 0x1E2BB },
	{ 0xE8B380, 0x1E2B7 },
	{ 0xE8B381, 0x1E2B5 },
	{ 0xE8B382, 0x1E6F6 },
	{ 0xE8B383, 0x1E6F5 },
	{ 0xE8B384, 0x1E6F3 },
	{ 0xE8B385, 0x1E6F7 },
	{ 0xE8B386, 0x4C0FE },
	{ 0xE8B387, 0x1E6F1 },
	{ 0xE8B388, 0x1E6F2 },
	{ 0xE8B389, 0x3C4E9 },
	{ 0xE8B38A, 0x1E6F0 },
	{ 0xE8B38B, 0x5C3AD },
	{ 0xE8B38C, 0x2C7E1 },
	{ 0xE8B38D, 0x3C4E7 },
	{ 0xE8B38F, 0x2CEBC },
	{ 0xE8B390, 0x3C9F0 },
	{ 0xE8B391, 0x1EBB4 },
	{ 0xE8B392, 0x1EBB5 },
	{ 0xE8B393, 0x1EBB3 },
	{ 0xE8B394, 0x3C9F2 },
	{ 0xE8B395, 0x2CEBB },
	{ 0xE8B396, 0x3C9F1 },
	{ 0xE8B397, 0x2CEBD },
	{ 0xE8B398, 0x3E6CE },
	{ 0xE8B399, 0x2D4D3 },
	{ 0xE8B39A, 0x2D4D5 },
	{ 0xE8B39B, 0x3CEFE },
	{ 0xE8B39C, 0x1EFB2 },
	{ 0xE8B39D, 0x2D4D6 },
	{ 0xE8B39E, 0x1EFAB },
	{ 0xE8B39F, 0x2D4D2 },
	{ 0xE8B3A0, 0x1EFAA },
	{ 0xE8B3A1, 0x1EFB4 },
	{ 0xE8B3A2, 0x1EFB0 },
	{ 0xE8B3A3, 0x1EFB1 },
	{ 0xE8B3A4, 0x1EFAD },
	{ 0xE8B3A5, 0x2D4D1 },
	{ 0xE8B3A6, 0x1EFAC },
	{ 0xE8B3A7, 0x2D4D7 },
	{ 0xE8B3A8, 0x2D4D4 },
	{ 0xE8B3A9, 0x3CEFD },
	{ 0xE8B3AA, 0x1EFB3 },
	{ 0xE8B3AB, 0x3CFA2 },
	{ 0xE8B3AC, 0x1EFAE },
	{ 0xE8B3AD, 0x1EFAF },
	{ 0xE8B3AE, 0x2DAE1 },
	{ 0xE8B3AF, 0x3D2F5 },
	{ 0xE8B3B0, 0x2DAE3 },
	{ 0xE8B3B1, 0x2DAE2 },
	{ 0xE8B3B2, 0x3D2F3 },
	{ 0xE8B3B3, 0x2DAE4 },
	{ 0xE8B3B4, 0x1F2CA },
	{ 0xE8B3B5, 0x2DAE0 },
	{ 0xE8B3B6, 0x3D6D1 },
	{ 0xE8B3B7, 0x3D6D2 },
	{ 0xE8B3B8, 0x1F5D6 },
	{ 0xE8B3B9, 0x2DFE4 },
	{ 0xE8B3BA, 0x1F5D3 },
	{ 0xE8B3BB, 0x1F5D7 },
	{ 0xE8B3BC, 0x1F5D5 },
	{ 0xE8B3BD, 0x1F5D4 },
	{ 0xE8B3BE, 0x2E3DE },
	{ 0xE8B3BF, 0x4DDE9 },
	{ 0xE8B480, 0x2E3E1 },
	{ 0xE8B481, 0x7C3D2 },
	{ 0xE8B482, 0x2E3E0 },
	{ 0xE8B483, 0x3D9AE },
	{ 0xE8B484, 0x2E3DF },
	{ 0xE8B485, 0x1F7C3 },
	{ 0xE8B486, 0x2E7B4 },
	{ 0xE8B487, 0x2E7B5 },
	{ 0xE8B488, 0x1F9A5 },
	{ 0xE8B489, 0x2E7B6 },
	{ 0xE8B48A, 0x1F9A6 },
	{ 0xE8B48B, 0x3DBB8 },
	{ 0xE8B48C, 0x3E6CF },
	{ 0xE8B48D, 0x1FAC5 },
	{ 0xE8B48E, 0x4E4CF },
	{ 0xE8B48F, 0x1FAC4 },
	{ 0xE8B490, 0x2ECC1 },
	{ 0xE8B491, 0x3DEE5 },
	{ 0xE8B492, 0x3DEE6 },
	{ 0xE8B493, 0x1FBAE },
	{ 0xE8B494, 0x2ECC2 },
	{ 0xE8B495, 0x2EEAB },
	{ 0xE8B496, 0x1FBF5 },
	{ 0xE8B497, 0x1FBF6 },
	{ 0xE8B498, 0x3E6D0 },
	{ 0xE8B499, 0x2EFD3 },
	{ 0xE8B49A, 0x3E0CA },
	{ 0xE8B49B, 0x1FCED },
	{ 0xE8B49C, 0x3E1CE },
	{ 0xE8B5A4, 0x1CBCB },
	{ 0xE8B5A5, 0x3B9B3 },
	{ 0xE8B5A6, 0x1DDD0 },
	{ 0xE8B5A7, 0x1DDCF },
	{ 0xE8B5A8, 0x2C7E2 },
	{ 0xE8B5A9, 0x2C7E3 },
	{ 0xE8B5AB, 0x1EBB6 },
	{ 0xE8B5AC, 0x2DAE5 },
	{ 0xE8B5AD, 0x1EFB5 },
	{ 0xE8B5AE, 0x2DAE6 },
	{ 0xE8B5AF, 0x2DFE5 },
	{ 0xE8B5B0, 0x1CBCC },
	{ 0xE8B5B1, 0x3A4BA },
	{ 0xE8B5B2, 0x2ADD3 },
	{ 0xE8B5B3, 0x1D3D9 },
	{ 0xE8B5B4, 0x1D3D8 },
	{ 0xE8B5B6, 0x2B3A7 },
	{ 0xE8B5B7, 0x1D8C4 },
	{ 0xE8B5B8, 0x2B3A8 },
	{ 0xE8B5B9, 0x2B9D8 },
	{ 0xE8B5BA, 0x3B9B9 },
	{ 0xE8B5BB, 0x2B9D7 },
	{ 0xE8B5BC, 0x3B9B7 },
	{ 0xE8B5BD, 0x2B9D6 },
	{ 0xE8B5BE, 0x3B9B5 },
	{ 0xE8B5BF, 0x3B9B8 },
	{ 0xE8B680, 0x2C0D4 },
	{ 0xE8B681, 0x1E2BF },
	{ 0xE8B682, 0x3BFB9 },
	{ 0xE8B683, 0x3BFB4 },
	{ 0xE8B684, 0x2C0D3 },
	{ 0xE8B685, 0x1E2BE },
	{ 0xE8B686, 0x3BFB7 },
	{ 0xE8B687, 0x3BFB0 },
	{ 0xE8B688, 0x3BFB3 },
	{ 0xE8B689, 0x2C0D5 },
	{ 0xE8B68A, 0x1E2BD },
	{ 0xE8B68B, 0x3BFB8 },
	{ 0xE8B68C, 0x2C7E5 },
	{ 0xE8B68D, 0x2C7E8 },
	{ 0xE8B68E, 0x2C7E6 },
	{ 0xE8B68F, 0x2C7E7 },
	{ 0xE8B690, 0x2C7EB },
	{ 0xE8B691, 0x2C7E4 },
	{ 0xE8B692, 0x2C7EC },
	{ 0xE8B693, 0x2C7E9 },
	{ 0xE8B694, 0x2C7EA },
	{ 0xE8B695, 0x1EBB8 },
	{ 0xE8B696, 0x2CEBE },
	{ 0xE8B697, 0x3C9F5 },
	{ 0xE8B698, 0x3C9F3 },
	{ 0xE8B699, 0x1EBB7 },
	{ 0xE8B69A, 0x3C9F4 },
	{ 0xE8B69B, 0x2D4DB },
	{ 0xE8B69C, 0x2D4D9 },
	{ 0xE8B69D, 0x3CFA6 },
	{ 0xE8B69E, 0x4CDF5 },
	{ 0xE8B69F, 0x1EFB6 },
	{ 0xE8B6A0, 0x2D4D8 },
	{ 0xE8B6A1, 0x2D4DA },
	{ 0xE8B6A2, 0x3CFA5 },
	{ 0xE8B6A3, 0x1EFB7 },
	{ 0xE8B6A4, 0x3CFA3 },
	{ 0xE8B6A5, 0x2DAE7 },
	{ 0xE8B6A6, 0x3D2F7 },
	{ 0xE8B6A7, 0x2DAE8 },
	{ 0xE8B6A8, 0x1F5D8 },
	{ 0xE8B6A9, 0x3D9B1 },
	{ 0xE8B6AA, 0x2E7B8 },
	{ 0xE8B6AB, 0x2E7BA },
	{ 0xE8B6AC, 0x2E7B7 },
	{ 0xE8B6AD, 0x2E7B9 },
	{ 0xE8B6AE, 0x2EAA4 },
	{ 0xE8B6AF, 0x2ECC3 },
	{ 0xE8B6B0, 0x3E6D1 },
	{ 0xE8B6B2, 0x2F1DE },
	{ 0xE8B6B3, 0x1CBCD },
	{ 0xE8B6B4, 0x1D3DA },
	{ 0xE8B6B5, 0x2B3A9 },
	{ 0xE8B6B6, 0x2B3AB },
	{ 0xE8B6B7, 0x2B3AA },
	{ 0xE8B6B9, 0x2B9DB },
	{ 0xE8B6BA, 0x1DDD2 },
	{ 0xE8B6BB, 0x3B9BE },
	{ 0xE8B6BC, 0x2B9D9 },
	{ 0xE8B6BD, 0x3B9BA },
	{ 0xE8B6BE, 0x1DDD1 },
	{ 0xE8B6BF, 0x2B9DC },
	{ 0xE8B780, 0x3B9BD },
	{ 0xE8B781, 0x2B9DD },
	{ 0xE8B782, 0x2B9DA },
	{ 0xE8B783, 0x6C5B8 },
	{ 0xE8B785, 0x2C0E1 },
	{ 0xE8B786, 0x1E2C7 },
	{ 0xE8B787, 0x2C0D9 },
	{ 0xE8B788, 0x2C0DF },
	{ 0xE8B789, 0x3BFBF },
	{ 0xE8B78A, 0x3BFBA },
	{ 0xE8B78B, 0x1E2C2 },
	{ 0xE8B78C, 0x1E2C5 },
	{ 0xE8B78D, 0x2C0D8 },
	{ 0xE8B78E, 0x1E2C0 },
	{ 0xE8B78F, 0x2C0DC },
	{ 0xE8B790, 0x2C7F2 },
	{ 0xE8B791, 0x1E2C4 },
	{ 0xE8B792, 0x3BFBB },
	{ 0xE8B793, 0x2C0D7 },
	{ 0xE8B794, 0x3BFBE },
	{ 0xE8B795, 0x2C0DD },
	{ 0xE8B796, 0x2C0DA },
	{ 0xE8B797, 0x2C0E0 },
	{ 0xE8B798, 0x2C0D6 },
	{ 0xE8B799, 0x2C0DE },
	{ 0xE8B79A, 0x1E2C3 },
	{ 0xE8B79B, 0x1E2C6 },
	{ 0xE8B79C, 0x2C0DB },
	{ 0xE8B79D, 0x1E2C1 },
	{ 0xE8B79F, 0x1E6F9 },
	{ 0xE8B7A0, 0x2C7EE },
	{ 0xE8B7A1, 0x1E6F8 },
	{ 0xE8B7A2, 0x2C7F5 },
	{ 0xE8B7A3, 0x2C7F4 },
	{ 0xE8B7A4, 0x1E7A1 },
	{ 0xE8B7A6, 0x1E7A2 },
	{ 0xE8B7A7, 0x2C7F6 },
	{ 0xE8B7A8, 0x1E6FA },
	{ 0xE8B7A9, 0x2C7F3 },
	{ 0xE8B7AA, 0x1E6FE },
	{ 0xE8B7AB, 0x2C7F8 },
	{ 0xE8B7AC, 0x2C7EF },
	{ 0xE8B7AD, 0x3C4EB },
	{ 0xE8B7AE, 0x2C7F1 },
	{ 0xE8B7AF, 0x1E6FB },
	{ 0xE8B7B0, 0x2C7ED },
	{ 0xE8B7B1, 0x2C7F0 },
	{ 0xE8B7B2, 0x2C7F7 },
	{ 0xE8B7B3, 0x1E6FC },
	{ 0xE8B7B4, 0x2C7F9 },
	{ 0xE8B7BA, 0x1E6FD },
	{ 0xE8B7BC, 0x1EBB9 },
	{ 0xE8B7BD, 0x2CEC3 },
	{ 0xE8B7BE, 0x2CEC9 },
	{ 0xE8B7BF, 0x2CEC1 },
	{ 0xE8B880, 0x2CECA },
	{ 0xE8B881, 0x3C9FB },
	{ 0xE8B882, 0x2CEC0 },
	{ 0xE8B883, 0x2CEC5 },
	{ 0xE8B884, 0x2CECB },
	{ 0xE8B885, 0x2CEC8 },
	{ 0xE8B886, 0x2CEC7 },
	{ 0xE8B887, 0x2CEC6 },
	{ 0xE8B888, 0x3C9FA },
	{ 0xE8B889, 0x2CEBF },
	{ 0xE8B88A, 0x2CEC4 },
	{ 0xE8B88B, 0x3C9F9 },
	{ 0xE8B88D, 0x2CEC2 },
	{ 0xE8B88F, 0x1EFBC },
	{ 0xE8B890, 0x1EFB9 },
	{ 0xE8B891, 0x2D4E4 },
	{ 0xE8B892, 0x2D4E9 },
	{ 0xE8B893, 0x2D4EB },
	{ 0xE8B894, 0x2D4E8 },
	{ 0xE8B895, 0x2D4E1 },
	{ 0xE8B896, 0x2D4E3 },
	{ 0xE8B897, 0x2D4ED },
	{ 0xE8B898, 0x2D4EA },
	{ 0xE8B899, 0x2D4E5 },
	{ 0xE8B89A, 0x2D4EE },
	{ 0xE8B89B, 0x2D4E2 },
	{ 0xE8B89C, 0x2D4EC },
	{ 0xE8B89D, 0x1EFBA },
	{ 0xE8B89E, 0x1EFC0 },
	{ 0xE8B89F, 0x1EFBE },
	{ 0xE8B8A0, 0x2D4DC },
	{ 0xE8B8A1, 0x1EFBF },
	{ 0xE8B8A2, 0x1EFBB },
	{ 0xE8B8A3, 0x2D4DD },
	{ 0xE8B8A4, 0x2D4DF },
	{ 0xE8B8A5, 0x2D4DE },
	{ 0xE8B8A6, 0x2D4E6 },
	{ 0xE8B8A7, 0x2D4E7 },
	{ 0xE8B8A8, 0x3CFAC },
	{ 0xE8B8A9, 0x1EFBD },
	{ 0xE8B8AA, 0x3CFAB },
	{ 0xE8B8AB, 0x1EFB8 },
	{ 0xE8B8AE, 0x2D4E0 },
	{ 0xE8B8B0, 0x2DAF2 },
	{ 0xE8B8B1, 0x1F2CC },
	{ 0xE8B8B2, 0x3D2FE },
	{ 0xE8B8B3, 0x2DAE9 },
	{ 0xE8B8B4, 0x1F2CD },
	{ 0xE8B8B5, 0x1F2D0 },
	{ 0xE8B8B6, 0x2DAEE },
	{ 0xE8B8B7, 0x5D1C8 },
	{ 0xE8B8B8, 0x2DAEB },
	{ 0xE8B8B9, 0x1F2CF },
	{ 0xE8B8BA, 0x4D4A9 },
	{ 0xE8B8BB, 0x3D2FB },
	{ 0xE8B8BC, 0x2DAEF },
	{ 0xE8B8BD, 0x2DAF0 },
	{ 0xE8B8BE, 0x2DAEA },
	{ 0xE8B8BF, 0x2DAF3 },
	{ 0xE8B980, 0x2DAEC },
	{ 0xE8B981, 0x2DAF1 },
	{ 0xE8B982, 0x1F2CE },
	{ 0xE8B983, 0x3D2FC },
	{ 0xE8B984, 0x1F2CB },
	{ 0xE8B985, 0x2DAED },
	{ 0xE8B986, 0x3D6D4 },
	{ 0xE8B987, 0x2DFEB },
	{ 0xE8B988, 0x1F5DB },
	{ 0xE8B989, 0x1F5D9 },
	{ 0xE8B98A, 0x1F5DC },
	{ 0xE8B98B, 0x1F5DA },
	{ 0xE8B98C, 0x2DFEA },
	{ 0xE8B98D, 0x2DFE7 },
	{ 0xE8B98E, 0x2DFE6 },
	{ 0xE8B98F, 0x3D6D5 },
	{ 0xE8B990, 0x2DFE9 },
	{ 0xE8B991, 0x4D9AD },
	{ 0xE8B993, 0x2DFE8 },
	{ 0xE8B994, 0x2E3EF },
	{ 0xE8B995, 0x1F7C9 },
	{ 0xE8B996, 0x2E3E6 },
	{ 0xE8B997, 0x2E3E5 },
	{ 0xE8B998, 0x3D9B2 },
	{ 0xE8B999, 0x1F7C4 },
	{ 0xE8B99A, 0x2E3EB },
	{ 0xE8B99B, 0x2E3EA },
	{ 0xE8B99C, 0x2E3E2 },
	{ 0xE8B99D, 0x2E3ED },
	{ 0xE8B99E, 0x2E3E7 },
	{ 0xE8B99F, 0x1F7C8 },
	{ 0xE8B9A0, 0x2E3E4 },
	{ 0xE8B9A1, 0x2E3EC },
	{ 0xE8B9A2, 0x2E3E3 },
	{ 0xE8B9A3, 0x1F7C5 },
	{ 0xE8B9A4, 0x1F7C7 },
	{ 0xE8B9A5, 0x2E3E8 },
	{ 0xE8B9A6, 0x1F7C6 },
	{ 0xE8B9A7, 0x2E3E9 },
	{ 0xE8B9A8, 0x3DBBA },
	{ 0xE8B9A9, 0x2E3EE },
	{ 0xE8B9AA, 0x2E7BE },
	{ 0xE8B9AB, 0x3DBB9 },
	{ 0xE8B9AC, 0x1F9AB },
	{ 0xE8B9AD, 0x2E7BB },
	{ 0xE8B9AE, 0x4E1D2 },
	{ 0xE8B9AF, 0x2E7BF },
	{ 0xE8B9B0, 0x3DBBB },
	{ 0xE8B9B1, 0x4E1CF },
	{ 0xE8B9B2, 0x1F9A8 },
	{ 0xE8B9B3, 0x2E7BD },
	{ 0xE8B9B4, 0x1F9AD },
	{ 0xE8B9B5, 0x3DBBC },
	{ 0xE8B9B6, 0x1F9AA },
	{ 0xE8B9B7, 0x3DBBD },
	{ 0xE8B9B8, 0x2E7BC },
	{ 0xE8B9B9, 0x4E1D4 },
	{ 0xE8B9BA, 0x1F9AC },
	{ 0xE8B9BB, 0x2E7C0 },
	{ 0xE8B9BC, 0x1F9A7 },
	{ 0xE8BA81, 0x1FAC7 },
	{ 0xE8BA82, 0x1FAC9 },
	{ 0xE8BA83, 0x3DDB7 },
	{ 0xE8BA84, 0x2EAA7 },
	{ 0xE8BA85, 0x1FAC8 },
	{ 0xE8BA86, 0x2EAA5 },
	{ 0xE8BA87, 0x1F9A9 },
	{ 0xE8BA88, 0x2EAA6 },
	{ 0xE8BA89, 0x1FAC6 },
	{ 0xE8BA8A, 0x1FBAF },
	{ 0xE8BA8B, 0x1FBB1 },
	{ 0xE8BA8C, 0x2ECC5 },
	{ 0xE8BA8D, 0x1FBB0 },
	{ 0xE8BA8E, 0x2ECC4 },
	{ 0xE8BA90, 0x2EEB0 },
	{ 0xE8BA91, 0x1FBF7 },
	{ 0xE8BA92, 0x2EEAF },
	{ 0xE8BA93, 0x1FBF8 },
	{ 0xE8BA94, 0x2EEAD },
	{ 0xE8BA95, 0x2EEAC },
	{ 0xE8BA96, 0x2EEB1 },
	{ 0xE8BA97, 0x2EEB2 },
	{ 0xE8BA98, 0x2EFD4 },
	{ 0xE8BA99, 0x3E0CB },
	{ 0xE8BA9A, 0x2EEAE },
	{ 0xE8BA9D, 0x2F0D4 },
	{ 0xE8BA9E, 0x2F0D1 },
	{ 0xE8BA9F, 0x2F0D2 },
	{ 0xE8BAA0, 0x2F0D3 },
	{ 0xE8BAA1, 0x1FDA9 },
	{ 0xE8BAA2, 0x3E1D0 },
	{ 0xE8BAA3, 0x2F1C0 },
	{ 0xE8BAA4, 0x2F1BF },
	{ 0xE8BAA5, 0x2F1BE },
	{ 0xE8BAA6, 0x2F1DF },
	{ 0xE8BAA7, 0x3E1EC },
	{ 0xE8BAA8, 0x2F2AE },
	{ 0xE8BAA9, 0x2F1F9 },
	{ 0xE8BAAA, 0x1FDBB },
	{ 0xE8BAAB, 0x1CBCE },
	{ 0xE8BAAC, 0x1D8C5 },
	{ 0xE8BAAD, 0x3B9BF },
	{ 0xE8BAAE, 0xFB8EC },
	{ 0xE8BAAF, 0x3B9C0 },
	{ 0xE8BAB0, 0x3BFC0 },
	{ 0xE8BAB1, 0x3C4F3 },
	{ 0xE8BAB2, 0x1E7A3 },
	{ 0xE8BAB3, 0x3C9FD },
	{ 0xE8BAB4, 0x3C9FC },
	{ 0xE8BAB6, 0x3CFB0 },
	{ 0xE8BAB7, 0x3CFB2 },
	{ 0xE8BAB8, 0x3CFAF },
	{ 0xE8BAB9, 0x3CFB1 },
	{ 0xE8BABA, 0x1EFC1 },
	{ 0xE8BABC, 0x3E6D2 },
	{ 0xE8BABD, 0x2DAF4 },
	{ 0xE8BABE, 0xFD8B3 },
	{ 0xE8BABF, 0x3D9B5 },
	{ 0xE8BB80, 0x1F7CA },
	{ 0xE8BB81, 0x3D9B6 },
	{ 0xE8BB82, 0x2E7C1 },
	{ 0xE8BB83, 0x3DBBF },
	{ 0xE8BB84, 0x4E1D6 },
	{ 0xE8BB86, 0x3DDB8 },
	{ 0xE8BB87, 0x4E7D1 },
	{ 0xE8BB89, 0x2F1FA },
	{ 0xE8BB8A, 0x1CBCF },
	{ 0xE8BB8B, 0x1CFD1 },
	{ 0xE8BB8C, 0x1D3DC },
	{ 0xE8BB8D, 0x1D3DB },
	{ 0xE8BB8E, 0x5B0D5 },
	{ 0xE8BB8F, 0x1D8C8 },
	{ 0xE8BB90, 0x3B4A1 },
	{ 0xE8BB91, 0x2B3AC },
	{ 0xE8BB92, 0x1D8C6 },
	{ 0xE8BB93, 0x2B3AD },
	{ 0xE8BB94, 0x1D8C7 },
	{ 0xE8BB95, 0x3E6D3 },
	{ 0xE8BB96, 0x3B9C1 },
	{ 0xE8BB97, 0x2B9E2 },
	{ 0xE8BB98, 0x2B9DE },
	{ 0xE8BB99, 0x3B9C7 },
	{ 0xE8BB9A, 0x4B5E3 },
	{ 0xE8BB9B, 0x1DDD3 },
	{ 0xE8BB9C, 0x2B9E1 },
	{ 0xE8BB9D, 0x2B9E0 },
	{ 0xE8BB9E, 0x2B9DF },
	{ 0xE8BB9F, 0x1DDD4 },
	{ 0xE8BBA0, 0x2B9E3 },
	{ 0xE8BBA1, 0x2B9E4 },
	{ 0xE8BBA4, 0x3BFC5 },
	{ 0xE8BBA5, 0x2C0E8 },
	{ 0xE8BBA6, 0x2C0E6 },
	{ 0xE8BBA7, 0x2C0EA },
	{ 0xE8BBA8, 0x2C0EB },
	{ 0xE8BBA9, 0x2C0F1 },
	{ 0xE8BBAA, 0x3BFC7 },
	{ 0xE8BBAB, 0x2C0ED },
	{ 0xE8BBAC, 0x2C0EF },
	{ 0xE8BBAD, 0x5C3D0 },
	{ 0xE8BBAE, 0x2C0E7 },
	{ 0xE8BBAF, 0x2C0E2 },
	{ 0xE8BBB0, 0x4BBD5 },
	{ 0xE8BBB1, 0x2C0EE },
	{ 0xE8BBB2, 0x3BFC4 },
	{ 0xE8BBB3, 0x3BFC6 },
	{ 0xE8BBB4, 0x2C0F0 },
	{ 0xE8BBB5, 0x2C0E9 },
	{ 0xE8BBB6, 0x2C0EC },
	{ 0xE8BBB7, 0x2C0E3 },
	{ 0xE8BBB8, 0x1E2C9 },
	{ 0xE8BBB9, 0x2C0E5 },
	{ 0xE8BBBA, 0x2C0E4 },
	{ 0xE8BBBB, 0x1E2C8 },
	{ 0xE8BBBC, 0x1E2CA },
	{ 0xE8BBBD, 0x3BFC9 },
	{ 0xE8BBBE, 0x1E7A6 },
	{ 0xE8BBBF, 0x2C7FB },
	{ 0xE8BC80, 0x2C7FD },
	{ 0xE8BC81, 0x2C7FC },
	{ 0xE8BC82, 0x2C8A3 },
	{ 0xE8BC83, 0x1E7A4 },
	{ 0xE8BC84, 0x3C4F6 },
	{ 0xE8BC85, 0x2C7FE },
	{ 0xE8BC86, 0x2C7FA },
	{ 0xE8BC87, 0x2C8A1 },
	{ 0xE8BC88, 0x2C8A2 },
	{ 0xE8BC89, 0x1E7A5 },
	{ 0xE8BC8A, 0x1E7A7 },
	{ 0xE8BC8B, 0x2C8A4 },
	{ 0xE8BC8D, 0x2CECF },
	{ 0xE8BC8E, 0x2CECE },
	{ 0xE8BC8F, 0x4C7EA },
	{ 0xE8BC90, 0x2CECC },
	{ 0xE8BC91, 0x2CECD },
	{ 0xE8BC92, 0x1EBBB },
	{ 0xE8BC93, 0x1EBBD },
	{ 0xE8BC94, 0x1EBBA },
	{ 0xE8BC95, 0x1EBBC },
	{ 0xE8BC96, 0x2D4F5 },
	{ 0xE8BC97, 0x2D4F6 },
	{ 0xE8BC98, 0x2D4F1 },
	{ 0xE8BC99, 0x3CFB6 },
	{ 0xE8BC9A, 0x2D4F2 },
	{ 0xE8BC9B, 0x1EFC3 },
	{ 0xE8BC9C, 0x1EFC8 },
	{ 0xE8BC9D, 0x1EFC2 },
	{ 0xE8BC9E, 0x1EFC9 },
	{ 0xE8BC9F, 0x1EFC4 },
	{ 0xE8BCA0, 0x2D4F3 },
	{ 0xE8BCA1, 0x4CEAD },
	{ 0xE8BCA2, 0x3CFB3 },
	{ 0xE8BCA3, 0x2D4F4 },
	{ 0xE8BCA4, 0x2D4F0 },
	{ 0xE8BCA5, 0x1EFCA },
	{ 0xE8BCA6, 0x1EFC6 },
	{ 0xE8BCA7, 0x3CFB5 },
	{ 0xE8BCA8, 0x4CEAB },
	{ 0xE8BCA9, 0x1EFC5 },
	{ 0xE8BCAA, 0x1EFC7 },
	{ 0xE8BCAB, 0x3CFB4 },
	{ 0xE8BCAC, 0x2D4EF },
	{ 0xE8BCAD, 0x3D3A4 },
	{ 0xE8BCAE, 0x2DAF6 },
	{ 0xE8BCAF, 0x1F2D2 },
	{ 0xE8BCB0, 0x3D3A2 },
	{ 0xE8BCB1, 0x3D3A1 },
	{ 0xE8BCB2, 0x2DAF8 },
	{ 0xE8BCB3, 0x1F2D4 },
	{ 0xE8BCB4, 0x2DAFB },
	{ 0xE8BCB5, 0x2DAF7 },
	{ 0xE8BCB6, 0x2DAF5 },
	{ 0xE8BCB7, 0x2DAFA },
	{ 0xE8BCB8, 0x1F2D3 },
	{ 0xE8BCB9, 0x2DAF9 },
	{ 0xE8BCBA, 0x7B4B2 },
	{ 0xE8BCBB, 0x1F2D1 },
	{ 0xE8BCBC, 0x3D3A5 },
	{ 0xE8BCBD, 0x3D6D9 },
	{ 0xE8BCBE, 0x1F5DE },
	{ 0xE8BCBF, 0x1F5E1 },
	{ 0xE8BD80, 0x2DFED },
	{ 0xE8BD81, 0x3D6DA },
	{ 0xE8BD82, 0x1F5DF },
	{ 0xE8BD83, 0x2DFEC },
	{ 0xE8BD84, 0x1F5DD },
	{ 0xE8BD85, 0x1F5E0 },
	{ 0xE8BD86, 0x2E3F0 },
	{ 0xE8BD87, 0x2E3F1 },
	{ 0xE8BD88, 0x2E3F2 },
	{ 0xE8BD89, 0x1F7CB },
	{ 0xE8BD8A, 0x3D9B7 },
	{ 0xE8BD8B, 0x2E3F3 },
	{ 0xE8BD8D, 0x1F7CC },
	{ 0xE8BD8E, 0x1F9AF },
	{ 0xE8BD8F, 0x2E7C4 },
	{ 0xE8BD90, 0x2E7C5 },
	{ 0xE8BD91, 0x2E7C3 },
	{ 0xE8BD92, 0x2E7C2 },
	{ 0xE8BD93, 0x2E7C6 },
	{ 0xE8BD94, 0x1F9AE },
	{ 0xE8BD95, 0x2EAAB },
	{ 0xE8BD96, 0x2EAA9 },
	{ 0xE8BD97, 0x2EAAA },
	{ 0xE8BD98, 0x2EAAC },
	{ 0xE8BD99, 0x2EAA8 },
	{ 0xE8BD9A, 0x2EAAD },
	{ 0xE8BD9B, 0x2ECC7 },
	{ 0xE8BD9C, 0x3DEE7 },
	{ 0xE8BD9D, 0x2ECC8 },
	{ 0xE8BD9E, 0x2ECC6 },
	{ 0xE8BD9F, 0x1FBB2 },
	{ 0xE8BDA0, 0x2EEB3 },
	{ 0xE8BDA1, 0x1FBF9 },
	{ 0xE8BDA2, 0x2EEB4 },
	{ 0xE8BDA3, 0x2EFD6 },
	{ 0xE8BDA4, 0x2EFD5 },
	{ 0xE8BDA5, 0x3E2A2 },
	{ 0xE8BE9B, 0x1CBD0 },
	{ 0xE8BE9C, 0x1E2CB },
	{ 0xE8BE9D, 0x3BFCB },
	{ 0xE8BE9E, 0x3C4F7 },
	{ 0xE8BE9F, 0x1E7A8 },
	{ 0xE8BEA0, 0x3C4F8 },
	{ 0xE8BEA1, 0x3CAA1 },
	{ 0xE8BEA2, 0x3CAA2 },
	{ 0xE8BEA3, 0x1EBBE },
	{ 0xE8BEA4, 0x3CFB7 },
	{ 0xE8BEA5, 0x3D3A7 },
	{ 0xE8BEA6, 0x1F2D6 },
	{ 0xE8BEA7, 0x3D3A6 },
	{ 0xE8BEA8, 0x1F2D5 },
	{ 0xE8BEAA, 0x3E6D4 },
	{ 0xE8BEAC, 0x3D9B8 },
	{ 0xE8BEAD, 0x1F9B0 },
	{ 0xE8BEAE, 0x1FAA9 },
	{ 0xE8BEAF, 0x1FBB3 },
	{ 0xE8BEB0, 0x1CBD1 },
	{ 0xE8BEB1, 0x1D8C9 },
	{ 0xE8BEB2, 0x1E7A9 },
	{ 0xE8BEB3, 0x3CFB9 },
	{ 0xE8BEB4, 0x2E7C7 },
	{ 0xE8BEB5, 0x3A7AF },
	{ 0xE8BEB6, 0x4A1D4 },
	{ 0xE8BEB7, 0xFA1EA },
	{ 0xE8BEB8, 0x4A3B0 },
	{ 0xE8BEB9, 0x3A4BB },
	{ 0xE8BEBB, 0xFA2F1 },
	{ 0xE8BEBC, 0xFA2F2 },
	{ 0xE8BEBE, 0x3A7B0 },
	{ 0xE8BEBF, 0x2A5A6 },
	{ 0xE8BF80, 0x4A5A1 },
	{ 0xE8BF81, 0x3A7B3 },
	{ 0xE8BF82, 0x1CBD2 },
	{ 0xE8BF83, 0x4A5A3 },
	{ 0xE8BF84, 0x1CBD5 },
	{ 0xE8BF85, 0x1CBD4 },
	{ 0xE8BF86, 0x1CBD3 },
	{ 0xE8BF87, 0x3A7B1 },
	{ 0xE8BF88, 0xFA5B2 },
	{ 0xE8BF89, 0x2A5A5 },
	{ 0xE8BF8A, 0x3AAF2 },
	{ 0xE8BF8B, 0x2A8ED },
	{ 0xE8BF8C, 0x3AAF0 },
	{ 0xE8BF8D, 0x2A8EF },
	{ 0xE8BF8E, 0x1CFD2 },
	{ 0xE8BF8F, 0x3AAF4 },
	{ 0xE8BF90, 0x4A8A6 },
	{ 0xE8BF91, 0x1CFD4 },
	{ 0xE8BF92, 0x2A8EC },
	{ 0xE8BF93, 0x2A8EE },
	{ 0xE8BF94, 0x1CFD3 },
	{ 0xE8BF95, 0x2A8F1 },
	{ 0xE8BF96, 0x2A8F0 },
	{ 0xE8BF97, 0x2A8F2 },
	{ 0xE8BF98, 0x3AAF3 },
	{ 0xE8BF99, 0x3AAF1 },
	{ 0xE8BF9C, 0xFA8F1 },
	{ 0xE8BF9F, 0xFA8EE },
	{ 0xE8BFA0, 0x2ADD7 },
	{ 0xE8BFA1, 0x2ADD5 },
	{ 0xE8BFA2, 0x1D3DF },
	{ 0xE8BFA3, 0x2ADD4 },
	{ 0xE8BFA4, 0x1D3E4 },
	{ 0xE8BFA5, 0x1D3E1 },
	{ 0xE8BFA6, 0x1D3DE },
	{ 0xE8BFA7, 0x3AFB1 },
	{ 0xE8BFA8, 0x1D3E5 },
	{ 0xE8BFA9, 0x3AFB2 },
	{ 0xE8BFAA, 0x1D3E0 },
	{ 0xE8BFAB, 0x1D3E3 },
	{ 0xE8BFAC, 0x6B4E0 },
	{ 0xE8BFAD, 0x1D3E2 },
	{ 0xE8BFAE, 0x2ADD6 },
	{ 0xE8BFAF, 0x3AFB3 },
	{ 0xE8BFB0, 0x1D3DD },
	{ 0xE8BFB1, 0x3AFB0 },
	{ 0xE8BFB4, 0x1D8CF },
	{ 0xE8BFB5, 0x2B3AF },
	{ 0xE8BFB6, 0x2B3B5 },
	{ 0xE8BFB7, 0x1D8CC },
	{ 0xE8BFB8, 0x1D8D3 },
	{ 0xE8BFB9, 0x3B4A5 },
	{ 0xE8BFBA, 0x1D8CE },
	{ 0xE8BFBB, 0x2B3B2 },
	{ 0xE8BFBC, 0x2B3B4 },
	{ 0xE8BFBD, 0x1D8D1 },
	{ 0xE8BFBE, 0x2B3AE },
	{ 0xE8BFBF, 0x2B3B1 },
	{ 0xE98080, 0x1D8CD },
	{ 0xE98081, 0x1D8CA },
	{ 0xE98082, 0x2B3B0 },
	{ 0xE98083, 0x1D8D0 },
	{ 0xE98084, 0x2B3B3 },
	{ 0xE98085, 0x1D8D2 },
	{ 0xE98086, 0x1D8CB },
	{ 0xE98087, 0x4B0AF },
	{ 0xE98088, 0x3B4A7 },
	{ 0xE98089, 0x3B4A6 },
	{ 0xE9808B, 0x2B9E6 },
	{ 0xE9808C, 0x2B9E9 },
	{ 0xE9808D, 0x1DDD6 },
	{ 0xE9808E, 0x3B9CB },
	{ 0xE9808F, 0x1DDE0 },
	{ 0xE98090, 0x1DDDC },
	{ 0xE98091, 0x2B9E7 },
	{ 0xE98092, 0x3B9CA },
	{ 0xE98093, 0x3B9CE },
	{ 0xE98094, 0x1DDE4 },
	{ 0xE98095, 0x1DDDD },
	{ 0xE98096, 0x1DDE2 },
	{ 0xE98097, 0x1DDD8 },
	{ 0xE98098, 0x4B5E8 },
	{ 0xE98099, 0x1DDD5 },
	{ 0xE9809A, 0x1DDD7 },
	{ 0xE9809B, 0x1DDE3 },
	{ 0xE9809C, 0x2B9E8 },
	{ 0xE9809D, 0x1DDDB },
	{ 0xE9809E, 0x1DDDE },
	{ 0xE9809F, 0x1DDDA },
	{ 0xE980A0, 0x1DDDF },
	{ 0xE980A1, 0x2B9EA },
	{ 0xE980A2, 0x1DDE1 },
	{ 0xE980A3, 0x1DDD9 },
	{ 0xE980A4, 0x2B9E5 },
	{ 0xE980A5, 0x3B9CC },
	{ 0xE980A8, 0x3BFCF },
	{ 0xE980A9, 0x3BFD0 },
	{ 0xE980AA, 0x3BFCD },
	{ 0xE980AB, 0x3BFCC },
	{ 0xE980AC, 0x3BFD1 },
	{ 0xE980AD, 0x2C0F2 },
	{ 0xE980AE, 0x1E2CC },
	{ 0xE980AF, 0x2C0F4 },
	{ 0xE980B0, 0x3BFD5 },
	{ 0xE980B1, 0x1E2CE },
	{ 0xE980B2, 0x1E2D0 },
	{ 0xE980B3, 0x4B5E6 },
	{ 0xE980B4, 0x2C0F3 },
	{ 0xE980B5, 0x1E2CD },
	{ 0xE980B6, 0x1E2D1 },
	{ 0xE980B7, 0x3BFD6 },
	{ 0xE980B8, 0x1E2CF },
	{ 0xE980BA, 0x3BFD4 },
	{ 0xE980BB, 0x3BFD7 },
	{ 0xE980BC, 0x1E7AF },
	{ 0xE980BD, 0x2C8A9 },
	{ 0xE980BE, 0x1E7B7 },
	{ 0xE980BF, 0x2C8A6 },
	{ 0xE98180, 0x3C4FD },
	{ 0xE98181, 0x1E7B8 },
	{ 0xE98182, 0x1E7AD },
	{ 0xE98183, 0x3C4F9 },
	{ 0xE98184, 0x2C8A7 },
	{ 0xE98185, 0x3C4FC },
	{ 0xE98186, 0x3C4FA },
	{ 0xE98187, 0x1E7B2 },
	{ 0xE98188, 0x3C4FB },
	{ 0xE98189, 0x2C8A8 },
	{ 0xE9818A, 0x1E7AB },
	{ 0xE9818B, 0x1E7AA },
	{ 0xE9818C, 0x3C4FE },
	{ 0xE9818D, 0x1E7B5 },
	{ 0xE9818E, 0x1E7B4 },
	{ 0xE9818F, 0x1E7B3 },
	{ 0xE98190, 0x1E7B1 },
	{ 0xE98191, 0x1E7B6 },
	{ 0xE98192, 0x2C8A5 },
	{ 0xE98193, 0x1E7AC },
	{ 0xE98194, 0x1E7AE },
	{ 0xE98195, 0x1E7B0 },
	{ 0xE98198, 0x1EBC0 },
	{ 0xE98199, 0x1EBC3 },
	{ 0xE9819A, 0x3CAA4 },
	{ 0xE9819B, 0x1EBC7 },
	{ 0xE9819C, 0x1EBC1 },
	{ 0xE9819D, 0x1EBC6 },
	{ 0xE9819E, 0x1EBC4 },
	{ 0xE9819F, 0x3CAA7 },
	{ 0xE981A0, 0x1EBBF },
	{ 0xE981A1, 0x3CAA6 },
	{ 0xE981A2, 0x1EBC5 },
	{ 0xE981A3, 0x1EBC2 },
	{ 0xE981A4, 0xFCCEB },
	{ 0xE981A6, 0x4CEB2 },
	{ 0xE981A7, 0x2D4FA },
	{ 0xE981A8, 0x1EFCD },
	{ 0xE981A9, 0x1EFCB },
	{ 0xE981AA, 0x3CFBC },
	{ 0xE981AB, 0x2D4FB },
	{ 0xE981AC, 0x4CEB3 },
	{ 0xE981AD, 0x1EFCE },
	{ 0xE981AE, 0x1EFCC },
	{ 0xE981AF, 0x2D4F9 },
	{ 0xE981B0, 0x2D4F8 },
	{ 0xE981B1, 0x3CFBB },
	{ 0xE981B2, 0x1F2DA },
	{ 0xE981B3, 0x2D4F7 },
	{ 0xE981B4, 0x1F2D8 },
	{ 0xE981B5, 0x1F2D7 },
	{ 0xE981B6, 0x2DAFC },
	{ 0xE981B7, 0x1EFCF },
	{ 0xE981B8, 0x1F2D9 },
	{ 0xE981B9, 0x2DAFD },
	{ 0xE981BA, 0x1F2DC },
	{ 0xE981BB, 0x2DAFE },
	{ 0xE981BC, 0x1F2DB },
	{ 0xE981BD, 0x1F5E3 },
	{ 0xE981BE, 0x2DFEF },
	{ 0xE981BF, 0x1F5E2 },
	{ 0xE98280, 0x1F5E7 },
	{ 0xE98281, 0x1F5E5 },
	{ 0xE98282, 0x1F5E6 },
	{ 0xE98283, 0x1F7CE },
	{ 0xE98284, 0x1F5E4 },
	{ 0xE98285, 0x2DFEE },
	{ 0xE98286, 0x2DBA1 },
	{ 0xE98287, 0x1F7CD },
	{ 0xE98288, 0x1F7CF },
	{ 0xE98289, 0x3D9BA },
	{ 0xE9828A, 0x1F9B1 },
	{ 0xE9828B, 0x1F9B2 },
	{ 0xE9828C, 0x4E1DF },
	{ 0xE9828D, 0x2EAAE },
	{ 0xE9828E, 0x4E9D2 },
	{ 0xE9828F, 0x1FCCA },
	{ 0xE98290, 0x1FCC9 },
	{ 0xE98291, 0x1CBD7 },
	{ 0xE98292, 0x3A2DE },
	{ 0xE98293, 0x3A2DD },
	{ 0xE98294, 0x2A2F5 },
	{ 0xE98295, 0x1D8D4 },
	{ 0xE98296, 0x3A4BC },
	{ 0xE98297, 0x2A2F2 },
	{ 0xE98298, 0x2A2F3 },
	{ 0xE98299, 0x2A2F1 },
	{ 0xE9829A, 0x3A4BD },
	{ 0xE9829B, 0x2A2F4 },
	{ 0xE9829C, 0x3E6D5 },
	{ 0xE9829E, 0x2A5AA },
	{ 0xE9829F, 0x2A5A7 },
	{ 0xE982A0, 0x2A5AC },
	{ 0xE982A1, 0x2A5A8 },
	{ 0xE982A2, 0x1CBD8 },
	{ 0xE982A3, 0x1CBDB },
	{ 0xE982A4, 0x3A7B5 },
	{ 0xE982A5, 0x2A5A9 },
	{ 0xE982A6, 0x1CBDA },
	{ 0xE982A7, 0x2A5AB },
	{ 0xE982A8, 0x3A7B9 },
	{ 0xE982A9, 0x3A7B4 },
	{ 0xE982AA, 0x1CBD9 },
	{ 0xE982AB, 0x3B9D1 },
	{ 0xE982AD, 0x3AAF7 },
	{ 0xE982AE, 0x4A8AB },
	{ 0xE982AF, 0x2A8F5 },
	{ 0xE982B0, 0x2A8F7 },
	{ 0xE982B1, 0x1CFD7 },
	{ 0xE982B2, 0x2A8F3 },
	{ 0xE982B3, 0x2A8F6 },
	{ 0xE982B4, 0x2A8F4 },
	{ 0xE982B5, 0x1CFD5 },
	{ 0xE982B6, 0x1CFD8 },
	{ 0xE982B7, 0x3AAF5 },
	{ 0xE982B8, 0x1CFD6 },
	{ 0xE982B9, 0x3AAF8 },
	{ 0xE982BC, 0x3AFB5 },
	{ 0xE982BD, 0x2ADD9 },
	{ 0xE982BE, 0x2ADDD },
	{ 0xE982BF, 0x2ADDA },
	{ 0xE98380, 0x3AFB8 },
	{ 0xE98381, 0x1D3E8 },
	{ 0xE98382, 0x3AFB4 },
	{ 0xE98383, 0x1D3E9 },
	{ 0xE98384, 0x3AFBE },
	{ 0xE98385, 0x2ADDC },
	{ 0xE98386, 0x3AFB7 },
	{ 0xE98387, 0x2ADDE },
	{ 0xE98388, 0x2ADE0 },
	{ 0xE98389, 0x3AFBC },
	{ 0xE9838A, 0x1D3E6 },
	{ 0xE9838B, 0x2ADDF },
	{ 0xE9838C, 0x4C1B9 },
	{ 0xE9838D, 0x3AFBB },
	{ 0xE9838E, 0x1D3E7 },
	{ 0xE98392, 0xFC5ED },
	{ 0xE98394, 0x2B9F1 },
	{ 0xE98395, 0x2ADDB },
	{ 0xE98396, 0x2B3B6 },
	{ 0xE98397, 0x2B3BF },
	{ 0xE98398, 0x2B3BD },
	{ 0xE98399, 0x2B3B8 },
	{ 0xE9839A, 0x2B3B9 },
	{ 0xE9839B, 0x2B3BE },
	{ 0xE9839C, 0x2B3C0 },
	{ 0xE9839D, 0x1D8D6 },
	{ 0xE9839E, 0x3B4A9 },
	{ 0xE9839F, 0x2B3BB },
	{ 0xE983A0, 0x2B3B7 },
	{ 0xE983A1, 0x1D8D5 },
	{ 0xE983A2, 0x1D8D7 },
	{ 0xE983A3, 0x2B3BA },
	{ 0xE983A4, 0x2B3C1 },
	{ 0xE983A5, 0x2B3BC },
	{ 0xE983A8, 0x1DDE5 },
	{ 0xE983A9, 0x2B9F4 },
	{ 0xE983AA, 0x2B9EC },
	{ 0xE983AB, 0x2B9F2 },
	{ 0xE983AC, 0x2B9F3 },
	{ 0xE983AD, 0x1DDE6 },
	{ 0xE983AE, 0x3B9CF },
	{ 0xE983AF, 0x2B9EB },
	{ 0xE983B0, 0x2B9ED },
	{ 0xE983B1, 0x2ADD8 },
	{ 0xE983B2, 0x2B9EF },
	{ 0xE983B3, 0x2B9F0 },
	{ 0xE983B4, 0x2B9EE },
	{ 0xE983B5, 0x1E2D3 },
	{ 0xE983B6, 0x4CEBB },
	{ 0xE983B7, 0x3B9D2 },
	{ 0xE983B9, 0x2C0FB },
	{ 0xE983BA, 0x2DBA2 },
	{ 0xE983BB, 0x2C0FC },
	{ 0xE983BC, 0x2C0F9 },
	{ 0xE983BD, 0x1DDE7 },
	{ 0xE983BE, 0x1E2D5 },
	{ 0xE983BF, 0x2C0F8 },
	{ 0xE98480, 0x2C0FE },
	{ 0xE98481, 0x2C0FD },
	{ 0xE98482, 0x1E2D2 },
	{ 0xE98483, 0x2C1A3 },
	{ 0xE98484, 0x2C0F7 },
	{ 0xE98485, 0x2C1A2 },
	{ 0xE98486, 0x2C0F5 },
	{ 0xE98487, 0x2C1A1 },
	{ 0xE98488, 0x2C0FA },
	{ 0xE98489, 0x1E2D4 },
	{ 0xE9848A, 0x3BFD9 },
	{ 0xE9848B, 0x2C8B0 },
	{ 0xE9848C, 0x3C5A3 },
	{ 0xE9848D, 0x2C8AB },
	{ 0xE9848E, 0x2C8B1 },
	{ 0xE9848F, 0x2C8AC },
	{ 0xE98490, 0x2C8AA },
	{ 0xE98491, 0x2C8AD },
	{ 0xE98492, 0x1E7B9 },
	{ 0xE98493, 0x3C5A4 },
	{ 0xE98494, 0x2C8AF },
	{ 0xE98495, 0x3C5A5 },
	{ 0xE98496, 0x2C8AE },
	{ 0xE98497, 0x1E7BA },
	{ 0xE98498, 0x1EBC9 },
	{ 0xE98499, 0x1EBC8 },
	{ 0xE9849A, 0x2CED6 },
	{ 0xE9849B, 0x2CED9 },
	{ 0xE9849C, 0x2CED1 },
	{ 0xE9849D, 0x2CED5 },
	{ 0xE9849E, 0x1EBCA },
	{ 0xE9849F, 0x2CED4 },
	{ 0xE984A0, 0x2CED2 },
	{ 0xE984A1, 0x2CED8 },
	{ 0xE984A2, 0x2CED3 },
	{ 0xE984A3, 0x2CED0 },
	{ 0xE984A4, 0x2CED7 },
	{ 0xE984A5, 0x3CAAA },
	{ 0xE984A6, 0x2D5A3 },
	{ 0xE984A7, 0x1EFD2 },
	{ 0xE984A8, 0x2E3F4 },
	{ 0xE984A9, 0x2D4FE },
	{ 0xE984AA, 0x2D5A1 },
	{ 0xE984AB, 0x2D4FD },
	{ 0xE984AC, 0x2C0F6 },
	{ 0xE984AD, 0x1EFD1 },
	{ 0xE984AE, 0x2D5A4 },
	{ 0xE984AF, 0x2D4FC },
	{ 0xE984B0, 0x1EFD0 },
	{ 0xE984B1, 0x1EFD3 },
	{ 0xE984B2, 0x2D5A2 },
	{ 0xE984B3, 0x2DBA3 },
	{ 0xE984B4, 0x1F2DD },
	{ 0xE984B5, 0x2DBA4 },
	{ 0xE984B6, 0x2DBA5 },
	{ 0xE984B7, 0x3D3AB },
	{ 0xE984B8, 0x2DFF0 },
	{ 0xE984B9, 0x1F5E8 },
	{ 0xE984BA, 0x2E3F5 },
	{ 0xE984BB, 0x2E3F6 },
	{ 0xE984BC, 0x3D9BC },
	{ 0xE984BD, 0x3D9BB },
	{ 0xE984BE, 0x2E3F7 },
	{ 0xE984BF, 0x2E7C9 },
	{ 0xE98580, 0x2E7C8 },
	{ 0xE98581, 0x2EAB0 },
	{ 0xE98583, 0x2EAAF },
	{ 0xE98584, 0x2ECCA },
	{ 0xE98585, 0x2ECCB },
	{ 0xE98586, 0x2ECC9 },
	{ 0xE98587, 0x2EEB5 },
	{ 0xE98588, 0x1FBFA },
	{ 0xE98589, 0x1CBDC },
	{ 0xE9858A, 0x1D3EB },
	{ 0xE9858B, 0x1D3EA },
	{ 0xE9858C, 0x1D8DA },
	{ 0xE9858D, 0x1D8D9 },
	{ 0xE9858E, 0x2B3C3 },
	{ 0xE9858F, 0x2B3C4 },
	{ 0xE98590, 0x2B3C2 },
	{ 0xE98591, 0x3B4AA },
	{ 0xE98592, 0x1D8D8 },
	{ 0xE98593, 0x2B9F8 },
	{ 0xE98594, 0x3B9D5 },
	{ 0xE98595, 0x2B9F9 },
	{ 0xE98596, 0x2B9F5 },
	{ 0xE98597, 0x1DDE8 },
	{ 0xE98598, 0x2B9F6 },
	{ 0xE98599, 0x3B9D4 },
	{ 0xE9859A, 0x2B9F7 },
	{ 0xE9859C, 0x3E6D7 },
	{ 0xE9859F, 0x2C1A6 },
	{ 0xE985A0, 0x2C1A8 },
	{ 0xE985A1, 0x2C1A4 },
	{ 0xE985A2, 0x2C1A7 },
	{ 0xE985A3, 0x1E2D6 },
	{ 0xE985A4, 0x2C1A5 },
	{ 0xE985A5, 0x1E2D7 },
	{ 0xE985A7, 0x3C5A8 },
	{ 0xE985A8, 0x2C2F9 },
	{ 0xE985A9, 0x1E7BD },
	{ 0xE985AA, 0x1E7BC },
	{ 0xE985AB, 0x3C5A7 },
	{ 0xE985AC, 0x1E7BB },
	{ 0xE985AD, 0x4C1BA },
	{ 0xE985AE, 0x2C8B2 },
	{ 0xE985AF, 0x2C8B3 },
	{ 0xE985B0, 0x4C1BB },
	{ 0xE985B2, 0x2CEDB },
	{ 0xE985B3, 0x2CEDD },
	{ 0xE985B4, 0x1EBCE },
	{ 0xE985B5, 0x1EBCB },
	{ 0xE985B6, 0x3CAAC },
	{ 0xE985B7, 0x1EBCD },
	{ 0xE985B8, 0x1EBCC },
	{ 0xE985B9, 0x2CEDC },
	{ 0xE985BA, 0x2CEDA },
	{ 0xE985BB, 0x3CAAB },
	{ 0xE985BC, 0x3CAAD },
	{ 0xE98680, 0x2D5AB },
	{ 0xE98681, 0x2D5A8 },
	{ 0xE98682, 0x2D5A9 },
	{ 0xE98683, 0x1EFD7 },
	{ 0xE98684, 0x2D5AA },
	{ 0xE98685, 0x2D5A5 },
	{ 0xE98686, 0x2D5A6 },
	{ 0xE98687, 0x1EFD4 },
	{ 0xE98688, 0x3CFBF },
	{ 0xE98689, 0x1EFD5 },
	{ 0xE9868A, 0x2D5A7 },
	{ 0xE9868B, 0x1EFD6 },
	{ 0xE9868C, 0x3CFC0 },
	{ 0xE9868D, 0x2DBA9 },
	{ 0xE9868E, 0x3D3AD },
	{ 0xE9868F, 0x2DBAA },
	{ 0xE98690, 0x2DBA7 },
	{ 0xE98691, 0x2DBA8 },
	{ 0xE98692, 0x1F2DE },
	{ 0xE98693, 0x2DBA6 },
	{ 0xE98694, 0x4D4C2 },
	{ 0xE98695, 0x3D3AC },
	{ 0xE98696, 0x3D3AF },
	{ 0xE98698, 0x4D9BF },
	{ 0xE98699, 0x2DFF4 },
	{ 0xE9869A, 0x2DFF1 },
	{ 0xE9869B, 0x2DFF3 },
	{ 0xE9869C, 0x1F5EB },
	{ 0xE9869D, 0x2DFF7 },
	{ 0xE9869E, 0x1F5EA },
	{ 0xE9869F, 0x2DFF5 },
	{ 0xE986A0, 0x2DFF8 },
	{ 0xE986A1, 0x2DFF6 },
	{ 0xE986A2, 0x2DFF2 },
	{ 0xE986A3, 0x1F5E9 },
	{ 0xE986A5, 0x2E3F9 },
	{ 0xE986A6, 0x4DEA4 },
	{ 0xE986A7, 0x2E3FA },
	{ 0xE986A8, 0x2E3F8 },
	{ 0xE986A9, 0x3D9BD },
	{ 0xE986AA, 0x2E3FC },
	{ 0xE986AB, 0x1F7D0 },
	{ 0xE986AC, 0x1F7D1 },
	{ 0xE986AD, 0x2E7CB },
	{ 0xE986AE, 0x1F9B4 },
	{ 0xE986AF, 0x2E3FB },
	{ 0xE986B0, 0x2E7CA },
	{ 0xE986B1, 0x1F9B3 },
	{ 0xE986B2, 0x2EAB3 },
	{ 0xE986B3, 0x2EAB4 },
	{ 0xE986B4, 0x1FACA },
	{ 0xE986B5, 0x2EAB2 },
	{ 0xE986B6, 0x4E4E5 },
	{ 0xE986B7, 0x2EAB1 },
	{ 0xE986B9, 0x2ECCC },
	{ 0xE986BA, 0x1FBB4 },
	{ 0xE986BB, 0x3DEE8 },
	{ 0xE986BC, 0x2EFD7 },
	{ 0xE986BD, 0x2F0D6 },
	{ 0xE986BE, 0x2F0D5 },
	{ 0xE986BF, 0x3E0FE },
	{ 0xE98780, 0x1FCEE },
	{ 0xE98781, 0x1FDAA },
	{ 0xE98782, 0x2F0D7 },
	{ 0xE98783, 0x2F1E0 },
	{ 0xE98784, 0x3E1ED },
	{ 0xE98785, 0x1FDBC },
	{ 0xE98786, 0x1CBDD },
	{ 0xE98787, 0x1CFD9 },
	{ 0xE98789, 0x1E7BE },
	{ 0xE9878B, 0x1FACB },
	{ 0xE9878C, 0x1CBDE },
	{ 0xE9878D, 0x1D3EC },
	{ 0xE9878E, 0x1DDE9 },
	{ 0xE9878F, 0x1E2D8 },
	{ 0xE98790, 0x1F7D2 },
	{ 0xE98791, 0x1CFDA },
	{ 0xE98793, 0x2ADE2 },
	{ 0xE98794, 0x2ADE1 },
	{ 0xE98795, 0x2B3C5 },
	{ 0xE98796, 0x3B4B0 },
	{ 0xE98797, 0x1D8DD },
	{ 0xE98798, 0x1D8DB },
	{ 0xE98799, 0x1D8DF },
	{ 0xE9879A, 0x2B3C7 },
	{ 0xE9879B, 0x3B4AD },
	{ 0xE9879C, 0x1D8DE },
	{ 0xE9879D, 0x1D8DC },
	{ 0xE9879E, 0x3B4AF },
	{ 0xE9879F, 0x3B4AE },
	{ 0xE987A0, 0x3B4B1 },
	{ 0xE987A2, 0x2B3C6 },
	{ 0xE987A3, 0x1DDEC },
	{ 0xE987A4, 0x2BAA1 },
	{ 0xE987A5, 0x3B9D8 },
	{ 0xE987A6, 0x1DDEB },
	{ 0xE987A7, 0x1DDED },
	{ 0xE987A8, 0x2BAA6 },
	{ 0xE987A9, 0x1DDEF },
	{ 0xE987AA, 0x2BAA3 },
	{ 0xE987AB, 0x2BAA4 },
	{ 0xE987AC, 0x2B9FA },
	{ 0xE987AD, 0x1DDEE },
	{ 0xE987AE, 0x2BAA7 },
	{ 0xE987AF, 0x4B5FB },
	{ 0xE987B0, 0x3B9D7 },
	{ 0xE987B1, 0x2B9FC },
	{ 0xE987B2, 0x3B9D6 },
	{ 0xE987B3, 0x2B9FD },
	{ 0xE987B4, 0x2B9FB },
	{ 0xE987B5, 0x1DDEA },
	{ 0xE987B6, 0x3B9D9 },
	{ 0xE987B7, 0x2BAA5 },
	{ 0xE987B8, 0x2B9FE },
	{ 0xE987B9, 0x2BAA2 },
	{ 0xE987BD, 0x2C1B4 },
	{ 0xE987BE, 0x3BFDD },
	{ 0xE987BF, 0x2C1B3 },
	{ 0xE98880, 0x2C1B1 },
	{ 0xE98881, 0x2C1A9 },
	{ 0xE98882, 0x2C1B8 },
	{ 0xE98883, 0x2C1AC },
	{ 0xE98884, 0x2C1B6 },
	{ 0xE98885, 0x2C1BD },
	{ 0xE98886, 0x2C1B5 },
	{ 0xE98887, 0x1E2E0 },
	{ 0xE98888, 0x3BFE6 },
	{ 0xE98889, 0x1E2DC },
	{ 0xE9888A, 0x2C1AA },
	{ 0xE9888B, 0x3BFE0 },
	{ 0xE9888C, 0x2C1B0 },
	{ 0xE9888D, 0x1E2DE },
	{ 0xE9888E, 0x3BFE8 },
	{ 0xE9888F, 0x2C1AF },
	{ 0xE98890, 0x1E2DF },
	{ 0xE98891, 0x1E2E1 },
	{ 0xE98892, 0x2C1B2 },
	{ 0xE98893, 0x3BFE9 },
	{ 0xE98894, 0x1E2D9 },
	{ 0xE98895, 0x1E2DA },
	{ 0xE98896, 0x2C1BE },
	{ 0xE98897, 0x2C1BC },
	{ 0xE98898, 0x3BFE2 },
	{ 0xE98899, 0x2C1BB },
	{ 0xE9889A, 0x2C1AD },
	{ 0xE9889B, 0x3BFE5 },
	{ 0xE9889C, 0x2C1B9 },
	{ 0xE9889D, 0x4BBE6 },
	{ 0xE9889E, 0x1E2DD },
	{ 0xE9889F, 0x6CFEF },
	{ 0xE988A0, 0x3BFDE },
	{ 0xE988A1, 0x3E6D9 },
	{ 0xE988A2, 0x3BFE3 },
	{ 0xE988A3, 0x1E2DB },
	{ 0xE988A4, 0x2C1BA },
	{ 0xE988A5, 0x2C1AB },
	{ 0xE988A6, 0x2C1AE },
	{ 0xE988A7, 0x2C1B7 },
	{ 0xE988AB, 0x3E6D8 },
	{ 0xE988AD, 0x2CFA2 },
	{ 0xE988AE, 0x2C8BD },
	{ 0xE988AF, 0x3C5AE },
	{ 0xE988B0, 0x2C8B6 },
	{ 0xE988B1, 0x2C8C9 },
	{ 0xE988B2, 0x2C8D2 },
	{ 0xE988B3, 0x2C8B9 },
	{ 0xE988B4, 0x1E7C9 },
	{ 0xE988B5, 0x3C5AB },
	{ 0xE988B6, 0x2C8C6 },
	{ 0xE988B7, 0x1E7BF },
	{ 0xE988B8, 0x1E7C1 },
	{ 0xE988B9, 0x1E7CD },
	{ 0xE988BA, 0x2C8B7 },
	{ 0xE988BB, 0x3C5B7 },
	{ 0xE988BC, 0x3C5AF },
	{ 0xE988BD, 0x1E7C2 },
	{ 0xE988BE, 0x1E7C4 },
	{ 0xE988BF, 0x1E7CE },
	{ 0xE98980, 0x1E7C3 },
	{ 0xE98981, 0x3C5B9 },
	{ 0xE98982, 0x4C1C1 },
	{ 0xE98983, 0x4C1C6 },
	{ 0xE98984, 0x3C5B8 },
	{ 0xE98985, 0x1E7CC },
	{ 0xE98986, 0x2C8BF },
	{ 0xE98987, 0x4C1C8 },
	{ 0xE98988, 0x2C8B4 },
	{ 0xE98989, 0x1E7CA },
	{ 0xE9898A, 0x2C8BE },
	{ 0xE9898B, 0x1E7C6 },
	{ 0xE9898C, 0x2C8D0 },
	{ 0xE9898D, 0x1E7CB },
	{ 0xE9898E, 0x2C8CE },
	{ 0xE9898F, 0x2C8C2 },
	{ 0xE98990, 0x2C8CC },
	{ 0xE98991, 0x1E7C8 },
	{ 0xE98992, 0x2C8B5 },
	{ 0xE98993, 0x2C8CF },
	{ 0xE98994, 0x2C8CA },
	{ 0xE98995, 0x3C5AA },
	{ 0xE98996, 0x2C8D1 },
	{ 0xE98997, 0x1E7C0 },
	{ 0xE98998, 0x4C1C0 },
	{ 0xE98999, 0x3C5AD },
	{ 0xE9899A, 0x1E7CF },
	{ 0xE9899B, 0x1E7C5 },
	{ 0xE9899C, 0x3C5B1 },
	{ 0xE9899D, 0x3C5A9 },
	{ 0xE9899E, 0x2C8BB },
	{ 0xE9899F, 0x3C5B4 },
	{ 0xE989A0, 0x2C8C3 },
	{ 0xE989A1, 0x2C8C7 },
	{ 0xE989A2, 0x3C5B3 },
	{ 0xE989A3, 0x2C8CB },
	{ 0xE989A4, 0x1E7C7 },
	{ 0xE989A5, 0x2C8BA },
	{ 0xE989A6, 0x2C8B8 },
	{ 0xE989A7, 0x2C8C4 },
	{ 0xE989A8, 0x4C1C2 },
	{ 0xE989A9, 0x4C1C3 },
	{ 0xE989AA, 0x3C5B2 },
	{ 0xE989AB, 0x3C5B5 },
	{ 0xE989AC, 0x2C8C1 },
	{ 0xE989AD, 0x2C8C0 },
	{ 0xE989AE, 0x3C5B6 },
	{ 0xE989AF, 0x2C8C5 },
	{ 0xE989B0, 0x2C8C8 },
	{ 0xE989B2, 0x2C8CD },
	{ 0xE989B3, 0x3E6DA },
	{ 0xE989B4, 0xFC5F2 },
	{ 0xE989B5, 0x4C7F5 },
	{ 0xE989B6, 0x2CEE0 },
	{ 0xE989B7, 0xFCDA2 },
	{ 0xE989B8, 0x1EBCF },
	{ 0xE989B9, 0x2CEEA },
	{ 0xE989BA, 0x2CEE2 },
	{ 0xE989BB, 0x1EBD5 },
	{ 0xE989BC, 0x1EBD9 },
	{ 0xE989BD, 0x2CEF3 },
	{ 0xE989BE, 0x2CEFB },
	{ 0xE989BF, 0x2CEEC },
	{ 0xE98A80, 0x1EBD1 },
	{ 0xE98A81, 0x3CAB4 },
	{ 0xE98A82, 0x2CEF0 },
	{ 0xE98A83, 0x2C8BC },
	{ 0xE98A84, 0x3CAB5 },
	{ 0xE98A85, 0x1EBD2 },
	{ 0xE98A86, 0x2CEF7 },
	{ 0xE98A87, 0x2CEFC },
	{ 0xE98A88, 0x2CEF4 },
	{ 0xE98A89, 0x3CAAF },
	{ 0xE98A8A, 0x2CEF6 },
	{ 0xE98A8B, 0x2CFA1 },
	{ 0xE98A8C, 0x2CEF8 },
	{ 0xE98A8D, 0x2CEE6 },
	{ 0xE98A8E, 0x2CEEF },
	{ 0xE98A8F, 0x3C5B0 },
	{ 0xE98A90, 0x3CAB8 },
	{ 0xE98A91, 0x1EBDA },
	{ 0xE98A92, 0x3CAB3 },
	{ 0xE98A93, 0x1EBD6 },
	{ 0xE98A94, 0x2CEE4 },
	{ 0xE98A95, 0x2CEF1 },
	{ 0xE98A96, 0x1EBD4 },
	{ 0xE98A97, 0x2CEEB },
	{ 0xE98A98, 0x1EBD3 },
	{ 0xE98A99, 0x2CEF9 },
	{ 0xE98A9A, 0x2CEE8 },
	{ 0xE98A9B, 0x2CEE1 },
	{ 0xE98A9C, 0x1EBD7 },
	{ 0xE98A9D, 0x2CEFE },
	{ 0xE98A9E, 0x3CAB9 },
	{ 0xE98A9F, 0x4C7F7 },
	{ 0xE98AA0, 0x2CEE3 },
	{ 0xE98AA1, 0x2CEF5 },
	{ 0xE98AA2, 0x2CEF2 },
	{ 0xE98AA3, 0x2CEED },
	{ 0xE98AA4, 0x2CEDF },
	{ 0xE98AA5, 0x2CEDE },
	{ 0xE98AA6, 0x2CEE7 },
	{ 0xE98AA7, 0x2CEFA },
	{ 0xE98AA8, 0x1EBD8 },
	{ 0xE98AA9, 0x2CEFD },
	{ 0xE98AAA, 0x2CEE5 },
	{ 0xE98AAB, 0x2CEE9 },
	{ 0xE98AAC, 0x1EBD0 },
	{ 0xE98AAD, 0x3CAB2 },
	{ 0xE98AAE, 0x3CAB7 },
	{ 0xE98AAF, 0xFCDA7 },
	{ 0xE98AB0, 0x3E7AA },
	{ 0xE98AB1, 0x3CAB1 },
	{ 0xE98AB2, 0x1EFE3 },
	{ 0xE98AB3, 0x1EFDE },
	{ 0xE98AB4, 0x2D5CD },
	{ 0xE98AB5, 0x2D5C9 },
	{ 0xE98AB6, 0x2D5B1 },
	{ 0xE98AB7, 0x1EFDA },
	{ 0xE98AB8, 0x3CFC2 },
	{ 0xE98AB9, 0x3CFD0 },
	{ 0xE98ABA, 0x4CEC5 },
	{ 0xE98ABB, 0x1EFD9 },
	{ 0xE98ABC, 0x1EFDF },
	{ 0xE98ABD, 0x4CEC7 },
	{ 0xE98ABE, 0x3CFC3 },
	{ 0xE98ABF, 0x3CFC1 },
	{ 0xE98B80, 0x2D5AF },
	{ 0xE98B81, 0x1EFDD },
	{ 0xE98B82, 0x2D5BB },
	{ 0xE98B83, 0x2D5AD },
	{ 0xE98B84, 0x2D5AE },
	{ 0xE98B85, 0x1EFD8 },
	{ 0xE98B86, 0x2D5CC },
	{ 0xE98B87, 0x1EFE1 },
	{ 0xE98B88, 0x2D5BE },
	{ 0xE98B89, 0x2D5C3 },
	{ 0xE98B8A, 0x2D5BD },
	{ 0xE98B8B, 0x2DBBC },
	{ 0xE98B8C, 0x2D5B9 },
	{ 0xE98B8D, 0x2D5C1 },
	{ 0xE98B8E, 0x2D5BF },
	{ 0xE98B8F, 0x2D5B2 },
	{ 0xE98B90, 0x2D5AC },
	{ 0xE98B91, 0x2D5C7 },
	{ 0xE98B92, 0x1EFE0 },
	{ 0xE98B93, 0x2D5C8 },
	{ 0xE98B94, 0x3CFC8 },
	{ 0xE98B95, 0x2D5C2 },
	{ 0xE98B96, 0x3CFC9 },
	{ 0xE98B97, 0x2D5B7 },
	{ 0xE98B98, 0x2D5B5 },
	{ 0xE98B99, 0x2D5B0 },
	{ 0xE98B9A, 0x3CFCB },
	{ 0xE98B9B, 0x3CFCE },
	{ 0xE98B9C, 0x3CFC4 },
	{ 0xE98B9D, 0x2D5B8 },
	{ 0xE98B9E, 0x2D5C5 },
	{ 0xE98B9F, 0x2D5B4 },
	{ 0xE98BA0, 0x2D5C4 },
	{ 0xE98BA1, 0x2D5CA },
	{ 0xE98BA2, 0x3CFD1 },
	{ 0xE98BA3, 0x4CEC6 },
	{ 0xE98BA4, 0x1EFDC },
	{ 0xE98BA5, 0x3CFC5 },
	{ 0xE98BA6, 0x2D5C0 },
	{ 0xE98BA7, 0x2D5C6 },
	{ 0xE98BA8, 0x2D5BC },
	{ 0xE98BA9, 0x2D5B6 },
	{ 0xE98BAA, 0x1EFDB },
	{ 0xE98BAB, 0x3CFD2 },
	{ 0xE98BAC, 0x4CEC4 },
	{ 0xE98BAD, 0x3CFCC },
	{ 0xE98BAE, 0x2CEEE },
	{ 0xE98BAF, 0x2D5BA },
	{ 0xE98BB0, 0x1EFE2 },
	{ 0xE98BB1, 0x2D5B3 },
	{ 0xE98BB2, 0xFD2EB },
	{ 0xE98BB3, 0x3CFCD },
	{ 0xE98BB4, 0x3E6DB },
	{ 0xE98BB5, 0x3E6DC },
	{ 0xE98BB6, 0x3CAB0 },
	{ 0xE98BB7, 0x2DBC1 },
	{ 0xE98BB8, 0x1F2E1 },
	{ 0xE98BB9, 0x2DBC0 },
	{ 0xE98BBA, 0x2DBBE },
	{ 0xE98BBB, 0x2DBD0 },
	{ 0xE98BBC, 0x1F2E5 },
	{ 0xE98BBD, 0x3D3B5 },
	{ 0xE98BBE, 0x2DBCD },
	{ 0xE98BBF, 0x2DBC5 },
	{ 0xE98C80, 0x2DBCF },
	{ 0xE98C81, 0x2DBB7 },
	{ 0xE98C82, 0x2DBC3 },
	{ 0xE98C83, 0x3D3BD },
	{ 0xE98C84, 0x1F2E7 },
	{ 0xE98C85, 0x3D3BE },
	{ 0xE98C86, 0x2DBAF },
	{ 0xE98C87, 0x3D3B8 },
	{ 0xE98C88, 0x2DBAD },
	{ 0xE98C89, 0x2DBCE },
	{ 0xE98C8A, 0x3D3B2 },
	{ 0xE98C8B, 0x2DBCC },
	{ 0xE98C8C, 0x2DBCB },
	{ 0xE98C8D, 0x2DBBB },
	{ 0xE98C8E, 0x2DBBA },
	{ 0xE98C8F, 0x2DBB0 },
	{ 0xE98C90, 0x1F2E9 },
	{ 0xE98C91, 0x4D4C3 },
	{ 0xE98C92, 0x2DBB6 },
	{ 0xE98C93, 0x2DBBF },
	{ 0xE98C94, 0x2DBCA },
	{ 0xE98C95, 0x1F2EC },
	{ 0xE98C96, 0x2DBD1 },
	{ 0xE98C97, 0x3D3B6 },
	{ 0xE98C98, 0x1F5F3 },
	{ 0xE98C99, 0x1F2EE },
	{ 0xE98C9A, 0x1F2E8 },
	{ 0xE98C9B, 0x2DBB4 },
	{ 0xE98C9C, 0x3D3B7 },
	{ 0xE98C9D, 0x2DBBD },
	{ 0xE98C9E, 0x2DBAC },
	{ 0xE98C9F, 0x2DBAE },
	{ 0xE98CA0, 0x1F2DF },
	{ 0xE98CA1, 0x1F2EB },
	{ 0xE98CA2, 0x1F2E4 },
	{ 0xE98CA3, 0x2DBB5 },
	{ 0xE98CA4, 0x2DBC4 },
	{ 0xE98CA5, 0x2D5CB },
	{ 0xE98CA6, 0x1F2EA },
	{ 0xE98CA7, 0x2DBAB },
	{ 0xE98CA8, 0x1F5EE },
	{ 0xE98CA9, 0x2DBC6 },
	{ 0xE98CAA, 0x2DBC9 },
	{ 0xE98CAB, 0x1F2E6 },
	{ 0xE98CAC, 0x3D3BB },
	{ 0xE98CAD, 0x2DBB9 },
	{ 0xE98CAE, 0x1F2ED },
	{ 0xE98CAF, 0x1F2E3 },
	{ 0xE98CB0, 0x3D3BC },
	{ 0xE98CB1, 0x3D3B9 },
	{ 0xE98CB2, 0x3D3BA },
	{ 0xE98CB3, 0x1F2E2 },
	{ 0xE98CB4, 0x2DBC2 },
	{ 0xE98CB5, 0x2DBC8 },
	{ 0xE98CB6, 0x1F2E0 },
	{ 0xE98CB7, 0x4D4C5 },
	{ 0xE98CB8, 0x2DBB2 },
	{ 0xE98CB9, 0x2DBC7 },
	{ 0xE98CBA, 0xFD8D9 },
	{ 0xE98CBB, 0xFD8C8 },
	{ 0xE98CBC, 0x2DBB3 },
	{ 0xE98CBD, 0x7B4E3 },
	{ 0xE98CBF, 0x3E6DD },
	{ 0xE98D80, 0xFD8D5 },
	{ 0xE98D82, 0x3E6DE },
	{ 0xE98D83, 0x4D4C9 },
	{ 0xE98D85, 0x3D3B1 },
	{ 0xE98D86, 0x2DBB8 },
	{ 0xE98D87, 0x2DFFE },
	{ 0xE98D88, 0x3D6E5 },
	{ 0xE98D89, 0x2E0A5 },
	{ 0xE98D8A, 0x1F5F0 },
	{ 0xE98D8B, 0x1F5F2 },
	{ 0xE98D8C, 0x2E0AB },
	{ 0xE98D8D, 0x1F5EC },
	{ 0xE98D8E, 0x2E0B9 },
	{ 0xE98D8F, 0x2E0B1 },
	{ 0xE98D90, 0x2E0A6 },
	{ 0xE98D91, 0x2E0A7 },
	{ 0xE98D92, 0x2E0B0 },
	{ 0xE98D93, 0x3D6E6 },
	{ 0xE98D94, 0x1F5F9 },
	{ 0xE98D95, 0x2E0AF },
	{ 0xE98D96, 0x2DFFD },
	{ 0xE98D97, 0x2E0AE },
	{ 0xE98D98, 0x2E0A2 },
	{ 0xE98D99, 0x2E0BA },
	{ 0xE98D9A, 0x1F5F8 },
	{ 0xE98D9B, 0x1F5F6 },
	{ 0xE98D9C, 0x2E0A3 },
	{ 0xE98D9D, 0x3D6DD },
	{ 0xE98D9E, 0x2E0B6 },
	{ 0xE98D9F, 0x3D6E7 },
	{ 0xE98DA0, 0x2E0A8 },
	{ 0xE98DA1, 0x2E0B5 },
	{ 0xE98DA2, 0x3D6E4 },
	{ 0xE98DA3, 0x2E0B7 },
	{ 0xE98DA4, 0x2DFFC },
	{ 0xE98DA5, 0x1F5F1 },
	{ 0xE98DA6, 0x3D6DB },
	{ 0xE98DA7, 0x2E0B8 },
	{ 0xE98DA8, 0x3D6E8 },
	{ 0xE98DA9, 0x3D6DE },
	{ 0xE98DAA, 0x2E0AC },
	{ 0xE98DAB, 0x3D6EB },
	{ 0xE98DAC, 0x1F5F5 },
	{ 0xE98DAD, 0x2E0A9 },
	{ 0xE98DAE, 0x3D6E1 },
	{ 0xE98DAF, 0x4D9C9 },
	{ 0xE98DB0, 0x1F5F7 },
	{ 0xE98DB1, 0x2E0B2 },
	{ 0xE98DB2, 0x3D6E2 },
	{ 0xE98DB3, 0x3D6E3 },
	{ 0xE98DB4, 0x3D6DF },
	{ 0xE98DB5, 0x1F5EF },
	{ 0xE98DB6, 0x2E0A4 },
	{ 0xE98DB7, 0x2E0B3 },
	{ 0xE98DB8, 0x3D6DC },
	{ 0xE98DB9, 0x2E0AD },
	{ 0xE98DBA, 0x2DBB1 },
	{ 0xE98DBB, 0x2E0B4 },
	{ 0xE98DBC, 0x2E0A1 },
	{ 0xE98DBD, 0x3D6E0 },
	{ 0xE98DBE, 0x1F5F4 },
	{ 0xE98DBF, 0x3D6EA },
	{ 0xE98E80, 0x2E4AF },
	{ 0xE98E81, 0x4D9C7 },
	{ 0xE98E82, 0x1F5ED },
	{ 0xE98E83, 0x2DFFA },
	{ 0xE98E84, 0x4D9C6 },
	{ 0xE98E85, 0xFDDC1 },
	{ 0xE98E86, 0x3E6DF },
	{ 0xE98E87, 0xFDDB9 },
	{ 0xE98E88, 0x2E4AC },
	{ 0xE98E89, 0x2E4A5 },
	{ 0xE98E8A, 0x1F7D4 },
	{ 0xE98E8B, 0x3D9C3 },
	{ 0xE98E8C, 0x2E3FE },
	{ 0xE98E8D, 0x2E4B0 },
	{ 0xE98E8E, 0x2E4A7 },
	{ 0xE98E8F, 0x2E0AA },
	{ 0xE98E90, 0x3D9C0 },
	{ 0xE98E91, 0x2E4B2 },
	{ 0xE98E92, 0x2E4A1 },
	{ 0xE98E93, 0x3D9C2 },
	{ 0xE98E94, 0x1F7D3 },
	{ 0xE98E95, 0x2E4AB },
	{ 0xE98E96, 0x1F7D5 },
	{ 0xE98E97, 0x1F7DD },
	{ 0xE98E98, 0x1F7DB },
	{ 0xE98E99, 0x2E4AD },
	{ 0xE98E9A, 0x1F7DC },
	{ 0xE98E9B, 0x2E4A3 },
	{ 0xE98E9C, 0x3D9C9 },
	{ 0xE98E9D, 0x2E4A4 },
	{ 0xE98E9E, 0x2E4A9 },
	{ 0xE98E9F, 0x2E4AE },
	{ 0xE98EA0, 0x3D9BE },
	{ 0xE98EA1, 0x2DFF9 },
	{ 0xE98EA2, 0x1F7D6 },
	{ 0xE98EA3, 0x2E4B7 },
	{ 0xE98EA4, 0x2E4B4 },
	{ 0xE98EA5, 0x2E7E1 },
	{ 0xE98EA6, 0x2E4AA },
	{ 0xE98EA7, 0x2E4A6 },
	{ 0xE98EA8, 0x2E4B5 },
	{ 0xE98EA9, 0x2E7D6 },
	{ 0xE98EAA, 0x2E4A8 },
	{ 0xE98EAB, 0x4DEB1 },
	{ 0xE98EAC, 0x1F7D9 },
	{ 0xE98EAD, 0x3D9C4 },
	{ 0xE98EAE, 0x1F7D8 },
	{ 0xE98EAF, 0x2DFFB },
	{ 0xE98EB0, 0x1F7DA },
	{ 0xE98EB1, 0x2E4B1 },
	{ 0xE98EB2, 0x2E4B3 },
	{ 0xE98EB3, 0x1F7D7 },
	{ 0xE98EB4, 0x2E4B6 },
	{ 0xE98EB5, 0x2E3FD },
	{ 0xE98EB6, 0x4DEA9 },
	{ 0xE98EB7, 0x2E4A2 },
	{ 0xE98EB8, 0x3D9C6 },
	{ 0xE98EB9, 0xFE1B3 },
	{ 0xE98EBB, 0x3D9C5 },
	{ 0xE98EBC, 0x3E6E1 },
	{ 0xE98EBD, 0x3E6E2 },
	{ 0xE98EBE, 0x3E6E0 },
	{ 0xE98EBF, 0xFE1C3 },
	{ 0xE98F80, 0x2E7DF },
	{ 0xE98F81, 0x3DBD0 },
	{ 0xE98F82, 0x2E7CF },
	{ 0xE98F83, 0x1F9B8 },
	{ 0xE98F84, 0x2E7DD },
	{ 0xE98F85, 0x3DBC4 },
	{ 0xE98F86, 0x3DBC5 },
	{ 0xE98F87, 0x2E7CD },
	{ 0xE98F88, 0x1F9B9 },
	{ 0xE98F89, 0x4E1E7 },
	{ 0xE98F8A, 0x2E7D8 },
	{ 0xE98F8B, 0x3DBC3 },
	{ 0xE98F8C, 0x2E7D4 },
	{ 0xE98F8D, 0x1F9BE },
	{ 0xE98F8E, 0x2E7DE },
	{ 0xE98F8F, 0x2E7CE },
	{ 0xE98F90, 0x2E7D1 },
	{ 0xE98F91, 0x1F9B6 },
	{ 0xE98F92, 0x2E7E0 },
	{ 0xE98F93, 0x3DBC8 },
	{ 0xE98F94, 0x2E7D9 },
	{ 0xE98F95, 0x2E7DC },
	{ 0xE98F96, 0x1F9BC },
	{ 0xE98F97, 0x1F9C1 },
	{ 0xE98F98, 0x1F9BF },
	{ 0xE98F99, 0x2E7D5 },
	{ 0xE98F9A, 0x2E7D0 },
	{ 0xE98F9B, 0x3DBCD },
	{ 0xE98F9C, 0x1F9BA },
	{ 0xE98F9D, 0x1F9BB },
	{ 0xE98F9E, 0x2E7CC },
	{ 0xE98F9F, 0x1F9B7 },
	{ 0xE98FA0, 0x3DBCF },
	{ 0xE98FA1, 0x1F9B5 },
	{ 0xE98FA2, 0x1F9BD },
	{ 0xE98FA3, 0x2E7DB },
	{ 0xE98FA4, 0x1F9C0 },
	{ 0xE98FA5, 0x3DBCA },
	{ 0xE98FA6, 0x2E7D7 },
	{ 0xE98FA7, 0x2E7E2 },
	{ 0xE98FA8, 0x1F9C2 },
	{ 0xE98FA9, 0x3DBC1 },
	{ 0xE98FAA, 0x3DBC2 },
	{ 0xE98FAB, 0x3DBCE },
	{ 0xE98FAC, 0x2E7D3 },
	{ 0xE98FAD, 0x3DBC7 },
	{ 0xE98FAE, 0x2E7DA },
	{ 0xE98FAF, 0x3E6E5 },
	{ 0xE98FB1, 0x3E6E3 },
	{ 0xE98FB2, 0x3E6E4 },
	{ 0xE98FB3, 0x3DDC1 },
	{ 0xE98FB4, 0x3DEEA },
	{ 0xE98FB5, 0x2EAC1 },
	{ 0xE98FB6, 0x2EAD0 },
	{ 0xE98FB7, 0x2EAC3 },
	{ 0xE98FB8, 0x2EACA },
	{ 0xE98FB9, 0x2E7D2 },
	{ 0xE98FBA, 0x2EAC8 },
	{ 0xE98FBB, 0x2EAB7 },
	{ 0xE98FBC, 0x2EACE },
	{ 0xE98FBD, 0x1FACE },
	{ 0xE98FBE, 0x2EABB },
	{ 0xE98FBF, 0x2EACD },
	{ 0xE99080, 0x2EAC2 },
	{ 0xE99081, 0x4E4E7 },
	{ 0xE99082, 0x3DDC3 },
	{ 0xE99083, 0x1FACD },
	{ 0xE99084, 0x3DDBC },
	{ 0xE99085, 0x3DDBF },
	{ 0xE99086, 0x2EAD2 },
	{ 0xE99087, 0x2EAC4 },
	{ 0xE99088, 0x3DDBE },
	{ 0xE99089, 0x2EAC9 },
	{ 0xE9908A, 0x2EACC },
	{ 0xE9908B, 0x2EAB5 },
	{ 0xE9908C, 0x2EACF },
	{ 0xE9908D, 0x2EAC0 },
	{ 0xE9908E, 0x2EAC5 },
	{ 0xE9908F, 0x2EAB9 },
	{ 0xE99090, 0x2EABD },
	{ 0xE99091, 0x2EAD1 },
	{ 0xE99092, 0x2EAC7 },
	{ 0xE99093, 0x2EAB6 },
	{ 0xE99094, 0x2EABA },
	{ 0xE99095, 0x2EABC },
	{ 0xE99096, 0x2EAC6 },
	{ 0xE99097, 0x3DDBD },
	{ 0xE99098, 0x1FACC },
	{ 0xE99099, 0x2EABF },
	{ 0xE9909A, 0x3DDC4 },
	{ 0xE9909B, 0x3DDC5 },
	{ 0xE9909C, 0x3DDC7 },
	{ 0xE9909D, 0x4E4EB },
	{ 0xE9909E, 0x3DDC2 },
	{ 0xE9909F, 0x3DDBA },
	{ 0xE990A0, 0x2EAB8 },
	{ 0xE990A2, 0x3E6E6 },
	{ 0xE990A3, 0x3E6E7 },
	{ 0xE990A4, 0x3E6E8 },
	{ 0xE990A5, 0xFE6D7 },
	{ 0xE990A7, 0x3DDC6 },
	{ 0xE990A8, 0x2EABE },
	{ 0xE990A9, 0x2ECD0 },
	{ 0xE990AA, 0x2ECD4 },
	{ 0xE990AB, 0x1FBBB },
	{ 0xE990AC, 0x2ECD6 },
	{ 0xE990AD, 0x3DEED },
	{ 0xE990AE, 0x1FBB5 },
	{ 0xE990AF, 0x4E4EF },
	{ 0xE990B0, 0x2ECD2 },
	{ 0xE990B1, 0x2ECD8 },
	{ 0xE990B2, 0x1FBBA },
	{ 0xE990B3, 0x1FBB6 },
	{ 0xE990B4, 0x4E7DC },
	{ 0xE990B5, 0x1FBB7 },
	{ 0xE990B6, 0x2ECCF },
	{ 0xE990B7, 0x2ECD5 },
	{ 0xE990B8, 0x1FBB9 },
	{ 0xE990B9, 0x2ECD3 },
	{ 0xE990BA, 0x1FBB8 },
	{ 0xE990BB, 0x2ECCE },
	{ 0xE990BC, 0x2EACB },
	{ 0xE990BD, 0x2ECD1 },
	{ 0xE990BE, 0x4E7E2 },
	{ 0xE990BF, 0x2ECCD },
	{ 0xE99180, 0x2ECD7 },
	{ 0xE99182, 0x3DFE9 },
	{ 0xE99183, 0x3DFEE },
	{ 0xE99184, 0x1FBFB },
	{ 0xE99185, 0x2EEBC },
	{ 0xE99186, 0x2EEBF },
	{ 0xE99187, 0x2EEBB },
	{ 0xE99188, 0x2EEBD },
	{ 0xE99189, 0x2EEBE },
	{ 0xE9918A, 0x2EEB8 },
	{ 0xE9918B, 0x2EEB9 },
	{ 0xE9918C, 0x2EEB6 },
	{ 0xE9918D, 0x3DFEA },
	{ 0xE9918E, 0x3DFEC },
	{ 0xE9918F, 0x2EEBA },
	{ 0xE99190, 0x2EEB7 },
	{ 0xE99191, 0x1FBFC },
	{ 0xE99192, 0x1FBFD },
	{ 0xE99194, 0x3DFEB },
	{ 0xE99195, 0x2EFD9 },
	{ 0xE99196, 0x3E0D2 },
	{ 0xE99197, 0x2EFDB },
	{ 0xE99198, 0x4EBA9 },
	{ 0xE99199, 0x5F6DD },
	{ 0xE9919A, 0x3E0D5 },
	{ 0xE9919B, 0x3E0D4 },
	{ 0xE9919C, 0x3E0D6 },
	{ 0xE9919D, 0x2EFDA },
	{ 0xE9919E, 0x2EFDC },
	{ 0xE9919F, 0x3E0CF },
	{ 0xE991A0, 0x1FCCC },
	{ 0xE991A1, 0x3E0D3 },
	{ 0xE991A2, 0x2EFD8 },
	{ 0xE991A3, 0x1FCCB },
	{ 0xE991A4, 0x1FCCD },
	{ 0xE991A5, 0x3E0D7 },
	{ 0xE991A6, 0x3E6EA },
	{ 0xE991A7, 0x3E6E9 },
	{ 0xE991A8, 0x2F0D9 },
	{ 0xE991A9, 0x2F0DA },
	{ 0xE991AA, 0x1FCEF },
	{ 0xE991AB, 0x2F0D8 },
	{ 0xE991AC, 0x3E1A2 },
	{ 0xE991AD, 0x2F1C2 },
	{ 0xE991AE, 0x2F1C1 },
	{ 0xE991AF, 0x2F1C3 },
	{ 0xE991B0, 0x1FDAC },
	{ 0xE991B1, 0x2F1C4 },
	{ 0xE991B2, 0x1FDAB },
	{ 0xE991B3, 0x2F1C5 },
	{ 0xE991B4, 0x2F1E1 },
	{ 0xE991B5, 0x2F1E4 },
	{ 0xE991B6, 0x2F1E3 },
	{ 0xE991B7, 0x1FDB5 },
	{ 0xE991B8, 0x2F1E2 },
	{ 0xE991B9, 0x4EDE2 },
	{ 0xE991BA, 0x3E1EF },
	{ 0xE991BB, 0x3E2A3 },
	{ 0xE991BC, 0x1FDBF },
	{ 0xE991BD, 0x1FDBD },
	{ 0xE991BE, 0x1FDBE },
	{ 0xE991BF, 0x1FDC4 },
	{ 0xE99280, 0x2F2B0 },
	{ 0xE99281, 0x2F2B1 },
	{ 0xE99282, 0x2F2AF },
	{ 0xE99283, 0x2F2B7 },
	{ 0xE99284, 0x3E2B6 },
	{ 0xE995B7, 0x1CFDB },
	{ 0xE995B8, 0x4A5AB },
	{ 0xE995B9, 0x4B0BA },
	{ 0xE995BA, 0x2BAA8 },
	{ 0xE995BB, 0x2C1BF },
	{ 0xE995BC, 0x2D5CE },
	{ 0xE995BD, 0x2E7E3 },
	{ 0xE995BE, 0x5F1D6 },
	{ 0xE99680, 0x1CFDC },
	{ 0xE99681, 0x3AFC0 },
	{ 0xE99682, 0x1D3ED },
	{ 0xE99683, 0x1D8E0 },
	{ 0xE99684, 0x4B0BB },
	{ 0xE99685, 0x3B4B2 },
	{ 0xE99686, 0x2BAA9 },
	{ 0xE99687, 0x3B9DC },
	{ 0xE99688, 0x2BAAA },
	{ 0xE99689, 0x1DDF0 },
	{ 0xE9968B, 0x1E2E4 },
	{ 0xE9968C, 0x2C1C1 },
	{ 0xE9968D, 0x2C1C0 },
	{ 0xE9968E, 0x1E2E8 },
	{ 0xE9968F, 0x1E2E3 },
	{ 0xE99690, 0x2C1C2 },
	{ 0xE99691, 0x1E2E5 },
	{ 0xE99692, 0x1E2E7 },
	{ 0xE99693, 0x1E2E6 },
	{ 0xE99694, 0x1E2E2 },
	{ 0xE99695, 0x3BFEC },
	{ 0xE99696, 0xFBFFE },
	{ 0xE99697, 0x3E6EB },
	{ 0xE99698, 0x1E7D0 },
	{ 0xE99699, 0x3C5BC },
	{ 0xE9969A, 0x3C5BA },
	{ 0xE9969B, 0x2C8D6 },
	{ 0xE9969C, 0x2C8D4 },
	{ 0xE9969D, 0x4C1D3 },
	{ 0xE9969E, 0x2C8D5 },
	{ 0xE9969F, 0x2C8D3 },
	{ 0xE996A0, 0xFC5FB },
	{ 0xE996A1, 0x1EBDB },
	{ 0xE996A2, 0x3CABD },
	{ 0xE996A3, 0x1EBDE },
	{ 0xE996A4, 0x1EBE0 },
	{ 0xE996A5, 0x1EBDF },
	{ 0xE996A6, 0x4C8A2 },
	{ 0xE996A7, 0x3CABE },
	{ 0xE996A8, 0x1EBDC },
	{ 0xE996A9, 0x1EBDD },
	{ 0xE996AB, 0x2D5D0 },
	{ 0xE996AC, 0x2D5CF },
	{ 0xE996AD, 0x1EFE4 },
	{ 0xE996AE, 0x2D5D1 },
	{ 0xE996AF, 0x3CFD3 },
	{ 0xE996B0, 0x2D5D2 },
	{ 0xE996B1, 0x1EFE5 },
	{ 0xE996B2, 0x3CFD5 },
	{ 0xE996B3, 0x3CFD6 },
	{ 0xE996B4, 0x4CECA },
	{ 0xE996B5, 0x2DBD9 },
	{ 0xE996B6, 0x2DBD7 },
	{ 0xE996B7, 0x2E0C0 },
	{ 0xE996B8, 0x3D3C2 },
	{ 0xE996B9, 0x2DBD5 },
	{ 0xE996BA, 0x2DBD6 },
	{ 0xE996BB, 0x1F2EF },
	{ 0xE996BC, 0x2DBD2 },
	{ 0xE996BD, 0x2DBDA },
	{ 0xE996BE, 0x2DBD4 },
	{ 0xE996BF, 0x2DBD8 },
	{ 0xE99780, 0x2E0BC },
	{ 0xE99781, 0x3D3C4 },
	{ 0xE99782, 0x3D3C0 },
	{ 0xE99783, 0x2E0BE },
	{ 0xE99784, 0x3D6ED },
	{ 0xE99785, 0x2E0BF },
	{ 0xE99786, 0x1F5FE },
	{ 0xE99787, 0x2E0BB },
	{ 0xE99788, 0x1F5FD },
	{ 0xE99789, 0x2E0BD },
	{ 0xE9978A, 0x1F5FA },
	{ 0xE9978B, 0x1F5FB },
	{ 0xE9978C, 0x1F5FC },
	{ 0xE9978D, 0x2DBD3 },
	{ 0xE9978E, 0x3E6EC },
	{ 0xE99790, 0x1F7E0 },
	{ 0xE99791, 0x2E4BA },
	{ 0xE99792, 0x2E4B8 },
	{ 0xE99793, 0x2E4B9 },
	{ 0xE99794, 0x1F7DE },
	{ 0xE99795, 0x1F7E1 },
	{ 0xE99796, 0x1F7DF },
	{ 0xE99797, 0x3D9CB },
	{ 0xE99798, 0x3D9CA },
	{ 0xE99799, 0x7CBC0 },
	{ 0xE9979A, 0x2E7E4 },
	{ 0xE9979B, 0x2E7E5 },
	{ 0xE9979C, 0x1F9C3 },
	{ 0xE9979D, 0x3DBD3 },
	{ 0xE9979E, 0x2EAD3 },
	{ 0xE9979F, 0x2EAD5 },
	{ 0xE997A0, 0x2EAD4 },
	{ 0xE997A1, 0x1FACF },
	{ 0xE997A2, 0x1FBBC },
	{ 0xE997A3, 0x2ECDB },
	{ 0xE997A4, 0x2ECDA },
	{ 0xE997A5, 0x2ECD9 },
	{ 0xE997A6, 0xFE8F2 },
	{ 0xE997A7, 0x3E6ED },
	{ 0xE997B5, 0xFA5B9 },
	{ 0xE9989C, 0x1CFDD },
	{ 0xE9989D, 0x3A1C3 },
	{ 0xE9989E, 0x2A1E9 },
	{ 0xE998A0, 0x2A2F8 },
	{ 0xE998A1, 0x1C8EA },
	{ 0xE998A2, 0x2A2F6 },
	{ 0xE998A3, 0x2A2F9 },
	{ 0xE998A4, 0x2A2F7 },
	{ 0xE998A5, 0x4A5AE },
	{ 0xE998A6, 0x3A7BB },
	{ 0xE998A7, 0x3A7BA },
	{ 0xE998A8, 0x2A5AE },
	{ 0xE998A9, 0x3A7BF },
	{ 0xE998AA, 0x1CBE2 },
	{ 0xE998AB, 0x3A7BC },
	{ 0xE998AC, 0x1CBE3 },
	{ 0xE998AD, 0x2A5B0 },
	{ 0xE998AE, 0x1CBE0 },
	{ 0xE998AF, 0x2A5AF },
	{ 0xE998B0, 0x2A5AD },
	{ 0xE998B1, 0x1CBE1 },
	{ 0xE998B2, 0x1CBDF },
	{ 0xE998B3, 0x3A7BD },
	{ 0xE998B4, 0x3A7BE },
	{ 0xE998B7, 0x3AAF9 },
	{ 0xE998B8, 0x4A8B3 },
	{ 0xE998B9, 0x2A8F8 },
	{ 0xE998BA, 0x2A8FB },
	{ 0xE998BB, 0x1CFE0 },
	{ 0xE998BC, 0x2A8FA },
	{ 0xE998BD, 0x2A8F9 },
	{ 0xE998BE, 0x3AAFC },
	{ 0xE998BF, 0x1CFDF },
	{ 0xE99980, 0x1CFDE },
	{ 0xE99981, 0x3AAFB },
	{ 0xE99982, 0x1CFE2 },
	{ 0xE99983, 0x2A8FC },
	{ 0xE99984, 0x1CFE1 },
	{ 0xE9998A, 0x2ADE7 },
	{ 0xE9998B, 0x1D3EF },
	{ 0xE9998C, 0x1D3F0 },
	{ 0xE9998D, 0x1D3F1 },
	{ 0xE9998E, 0x2ADE8 },
	{ 0xE9998F, 0x2ADE4 },
	{ 0xE99990, 0x1D3EE },
	{ 0xE99991, 0x2ADE5 },
	{ 0xE99992, 0x4ABDD },
	{ 0xE99993, 0x2ADE6 },
	{ 0xE99994, 0x2ADE3 },
	{ 0xE99995, 0x4ABDB },
	{ 0xE99996, 0x3B4B6 },
	{ 0xE99997, 0x4B0BF },
	{ 0xE99998, 0x1D8E7 },
	{ 0xE99999, 0x3B4B4 },
	{ 0xE9999A, 0x3B9DE },
	{ 0xE9999B, 0x1D8E4 },
	{ 0xE9999C, 0x2B3C8 },
	{ 0xE9999D, 0x1D8E5 },
	{ 0xE9999E, 0x1D8E8 },
	{ 0xE9999F, 0x2B3C9 },
	{ 0xE999A0, 0x3B4B3 },
	{ 0xE999A1, 0x1D8E3 },
	{ 0xE999A2, 0x1D8E1 },
	{ 0xE999A3, 0x1D8E2 },
	{ 0xE999A4, 0x1D8E6 },
	{ 0xE999AA, 0x1DDF1 },
	{ 0xE999AB, 0x2BAAD },
	{ 0xE999AC, 0x1DDF9 },
	{ 0xE999AD, 0x2BAAC },
	{ 0xE999AE, 0x3B9E1 },
	{ 0xE999AF, 0x2BAAF },
	{ 0xE999B0, 0x1DDF5 },
	{ 0xE999B1, 0x2BAAE },
	{ 0xE999B2, 0x1E2F0 },
	{ 0xE999B3, 0x1DDF3 },
	{ 0xE999B4, 0x1DDF6 },
	{ 0xE999B5, 0x1DDF2 },
	{ 0xE999B6, 0x1DDF7 },
	{ 0xE999B7, 0x1DDF8 },
	{ 0xE999B8, 0x1DDF4 },
	{ 0xE999B9, 0x3B9E5 },
	{ 0xE999BB, 0x3BFF1 },
	{ 0xE999BC, 0x2BAAB },
	{ 0xE999BD, 0x1E2EC },
	{ 0xE999BE, 0x2C1C4 },
	{ 0xE999BF, 0x3BFF2 },
	{ 0xE99A80, 0x2C1C8 },
	{ 0xE99A81, 0x3BFF3 },
	{ 0xE99A82, 0x3BFF5 },
	{ 0xE99A83, 0x2C1C7 },
	{ 0xE99A84, 0x1E2F1 },
	{ 0xE99A85, 0x1E2ED },
	{ 0xE99A86, 0x1E2EE },
	{ 0xE99A87, 0x2C1C3 },
	{ 0xE99A88, 0x2C1C5 },
	{ 0xE99A89, 0x2C1C6 },
	{ 0xE99A8A, 0x1E2E9 },
	{ 0xE99A8B, 0x1E2EB },
	{ 0xE99A8C, 0x3BFF0 },
	{ 0xE99A8D, 0x1E2EF },
	{ 0xE99A8E, 0x1E2EA },
	{ 0xE99A8F, 0x3C5C0 },
	{ 0xE99A91, 0x2C8D9 },
	{ 0xE99A92, 0x2C8D7 },
	{ 0xE99A93, 0x2C8D8 },
	{ 0xE99A94, 0x1E7D2 },
	{ 0xE99A95, 0x1E7D3 },
	{ 0xE99A96, 0x3C5C2 },
	{ 0xE99A97, 0x2C8DA },
	{ 0xE99A98, 0x1E7D1 },
	{ 0xE99A99, 0x1EBE1 },
	{ 0xE99A9A, 0x4C8A4 },
	{ 0xE99A9B, 0x1EBE3 },
	{ 0xE99A9C, 0x1EBE2 },
	{ 0xE99A9D, 0x3CAC5 },
	{ 0xE99A9E, 0x2CFA3 },
	{ 0xE99A9F, 0x3CAC6 },
	{ 0xE99AA0, 0x3CAC4 },
	{ 0xE99AA1, 0x2CFA4 },
	{ 0xE99AA2, 0x2D5D4 },
	{ 0xE99AA3, 0x3CFDA },
	{ 0xE99AA4, 0x2D5D3 },
	{ 0xE99AA5, 0x3CFDB },
	{ 0xE99AA6, 0x4D4D2 },
	{ 0xE99AA7, 0x1F2F0 },
	{ 0xE99AA8, 0x1F2F1 },
	{ 0xE99AA9, 0x2DBDB },
	{ 0xE99AAA, 0x1F2F2 },
	{ 0xE99AAB, 0x3D3C8 },
	{ 0xE99AAC, 0x2E0C3 },
	{ 0xE99AAD, 0x3D6F0 },
	{ 0xE99AAE, 0x2E0C1 },
	{ 0xE99AAF, 0x3D6EF },
	{ 0xE99AB0, 0x2E0C2 },
	{ 0xE99AB1, 0x1F6A1 },
	{ 0xE99AB2, 0x3D6F1 },
	{ 0xE99AB3, 0x2E4BB },
	{ 0xE99AB4, 0x1F9C4 },
	{ 0xE99AB5, 0x3DDC9 },
	{ 0xE99AB6, 0x3AAFD },
	{ 0xE99AB7, 0x3D3C9 },
	{ 0xE99AB8, 0x1F6A2 },
	{ 0xE99AB9, 0x1CFE3 },
	{ 0xE99ABA, 0x4B0C1 },
	{ 0xE99ABB, 0x1D8E9 },
	{ 0xE99ABC, 0x2B3CA },
	{ 0xE99ABD, 0x3B4B9 },
	{ 0xE99ABE, 0xFB2EF },
	{ 0xE99ABF, 0x2BAB0 },
	{ 0xE99B80, 0x1DDFA },
	{ 0xE99B81, 0x1E2F2 },
	{ 0xE99B82, 0x2C1C9 },
	{ 0xE99B83, 0x2C1CB },
	{ 0xE99B84, 0x1E2F4 },
	{ 0xE99B85, 0x1E2F3 },
	{ 0xE99B86, 0x1E2F5 },
	{ 0xE99B87, 0x1E2F6 },
	{ 0xE99B88, 0x2C1CA },
	{ 0xE99B89, 0x1E7D6 },
	{ 0xE99B8A, 0x1E7D7 },
	{ 0xE99B8B, 0x1E7D5 },
	{ 0xE99B8C, 0x1EBE4 },
	{ 0xE99B8D, 0x1E7D4 },
	{ 0xE99B8E, 0x2C8DB },
	{ 0xE99B8F, 0x4C1D7 },
	{ 0xE99B90, 0x3CAC7 },
	{ 0xE99B91, 0x3CAC9 },
	{ 0xE99B92, 0x1EBE5 },
	{ 0xE99B93, 0x2D5D5 },
	{ 0xE99B94, 0x2DBDC },
	{ 0xE99B95, 0x1F2F3 },
	{ 0xE99B96, 0x1F6A3 },
	{ 0xE99B97, 0x2E4BC },
	{ 0xE99B98, 0x2E4C0 },
	{ 0xE99B99, 0x1F7E4 },
	{ 0xE99B9A, 0x2E4BD },
	{ 0xE99B9B, 0x1F7E5 },
	{ 0xE99B9C, 0x1F7E3 },
	{ 0xE99B9D, 0x2E4C1 },
	{ 0xE99B9E, 0x1F7E6 },
	{ 0xE99B9F, 0x2E4BF },
	{ 0xE99BA1, 0x2E7E6 },
	{ 0xE99BA2, 0x1F7E2 },
	{ 0xE99BA3, 0x1F9C5 },
	{ 0xE99BA4, 0x3DEF0 },
	{ 0xE99BA5, 0x2F0DB },
	{ 0xE99BA6, 0x3E1A5 },
	{ 0xE99BA7, 0x3E2AF },
	{ 0xE99BA8, 0x1CFE4 },
	{ 0xE99BA9, 0x1DDFC },
	{ 0xE99BAA, 0x1DDFB },
	{ 0xE99BAB, 0xFB9AA },
	{ 0xE99BAC, 0x3BFFE },
	{ 0xE99BAD, 0x3BFFC },
	{ 0xE99BAE, 0x3BFFB },
	{ 0xE99BAF, 0x1E2F7 },
	{ 0xE99BB0, 0x2C1CD },
	{ 0xE99BB1, 0x2C1CC },
	{ 0xE99BB2, 0x1E2F8 },
	{ 0xE99BB4, 0x3C5C6 },
	{ 0xE99BB5, 0x2C8DF },
	{ 0xE99BB6, 0x1E7DB },
	{ 0xE99BB7, 0x1E7D8 },
	{ 0xE99BB8, 0x2C8DE },
	{ 0xE99BB9, 0x1E7DA },
	{ 0xE99BBA, 0x2C8DC },
	{ 0xE99BBB, 0x1E7D9 },
	{ 0xE99BBC, 0x3C5C7 },
	{ 0xE99BBD, 0x2C8DD },
	{ 0xE99BBF, 0x2CFA5 },
	{ 0xE99C80, 0x1EBE6 },
	{ 0xE99C82, 0x2D5D8 },
	{ 0xE99C83, 0x5D2BB },
	{ 0xE99C84, 0x1EFE6 },
	{ 0xE99C85, 0x2D5D6 },
	{ 0xE99C86, 0x1EFE7 },
	{ 0xE99C87, 0x1EFE8 },
	{ 0xE99C88, 0x2D5D7 },
	{ 0xE99C89, 0x1EFE9 },
	{ 0xE99C8A, 0x3CFE0 },
	{ 0xE99C8B, 0x2DBDD },
	{ 0xE99C8C, 0x3D3D0 },
	{ 0xE99C8D, 0x1F2F7 },
	{ 0xE99C8E, 0x1F2F4 },
	{ 0xE99C8F, 0x1F2F9 },
	{ 0xE99C90, 0x2DBDF },
	{ 0xE99C91, 0x1F2F5 },
	{ 0xE99C92, 0x2DBDE },
	{ 0xE99C93, 0x1F2F8 },
	{ 0xE99C94, 0x3D3CD },
	{ 0xE99C95, 0x3D3CC },
	{ 0xE99C96, 0x1F2F6 },
	{ 0xE99C97, 0x3D3D1 },
	{ 0xE99C98, 0x2E0C6 },
	{ 0xE99C99, 0x2E0C8 },
	{ 0xE99C9A, 0x3D6F4 },
	{ 0xE99C9B, 0x3D6F5 },
	{ 0xE99C9C, 0x1F6A4 },
	{ 0xE99C9D, 0x2E0C7 },
	{ 0xE99C9E, 0x1F6A5 },
	{ 0xE99C9F, 0x2E0C5 },
	{ 0xE99CA0, 0x2E0C4 },
	{ 0xE99CA1, 0x4DEB8 },
	{ 0xE99CA2, 0x2E4C3 },
	{ 0xE99CA3, 0x2E4C2 },
	{ 0xE99CA4, 0x1F7E7 },
	{ 0xE99CA5, 0x2E4C4 },
	{ 0xE99CA6, 0x2E7EB },
	{ 0xE99CA7, 0x1F9C7 },
	{ 0xE99CA8, 0x2E7EA },
	{ 0xE99CA9, 0x2E7E7 },
	{ 0xE99CAA, 0x1F9C6 },
	{ 0xE99CAB, 0x2E7E8 },
	{ 0xE99CAC, 0x2E7E9 },
	{ 0xE99CAE, 0x2EAD6 },
	{ 0xE99CAF, 0x2EAD7 },
	{ 0xE99CB0, 0x1FAD0 },
	{ 0xE99CB1, 0x3DDCF },
	{ 0xE99CB2, 0x1FBBF },
	{ 0xE99CB3, 0x3DDCC },
	{ 0xE99CB4, 0x3DDCE },
	{ 0xE99CB5, 0x2ECDC },
	{ 0xE99CB6, 0x3DEF2 },
	{ 0xE99CB7, 0x3DEF1 },
	{ 0xE99CB8, 0x1FBBD },
	{ 0xE99CB9, 0x1FBBE },
	{ 0xE99CBA, 0x2ECDD },
	{ 0xE99CBB, 0x3E6EE },
	{ 0xE99CBC, 0x3DFF1 },
	{ 0xE99CBD, 0x1FBFE },
	{ 0xE99CBE, 0x1FCA1 },
	{ 0xE99CBF, 0x2EEC0 },
	{ 0xE99D80, 0x3DFF2 },
	{ 0xE99D81, 0x3E0D9 },
	{ 0xE99D82, 0x1FCF0 },
	{ 0xE99D83, 0x2F0DD },
	{ 0xE99D84, 0x1FCF2 },
	{ 0xE99D85, 0x3E1A6 },
	{ 0xE99D86, 0x2F0DC },
	{ 0xE99D87, 0x2F0DE },
	{ 0xE99D88, 0x1FCF1 },
	{ 0xE99D89, 0x2F1C6 },
	{ 0xE99D8A, 0x4EDE4 },
	{ 0xE99D8B, 0x2F1FB },
	{ 0xE99D8D, 0x3E6EF },
	{ 0xE99D90, 0x3E2C5 },
	{ 0xE99D91, 0x3AAFE },
	{ 0xE99D92, 0x1CFE5 },
	{ 0xE99D95, 0x3C5C9 },
	{ 0xE99D96, 0x1E7DC },
	{ 0xE99D97, 0x4C8B5 },
	{ 0xE99D98, 0x2CFA6 },
	{ 0xE99D99, 0x3CACC },
	{ 0xE99D9A, 0x2D5D9 },
	{ 0xE99D9B, 0x1F2FA },
	{ 0xE99D9C, 0x1F2FB },
	{ 0xE99D9D, 0x3D9CF },
	{ 0xE99D9E, 0x1CFE6 },
	{ 0xE99D9F, 0x3C0A1 },
	{ 0xE99DA0, 0x1EFEA },
	{ 0xE99DA1, 0x1F9C8 },
	{ 0xE99DA2, 0x1D3F2 },
	{ 0xE99DA3, 0x3ABA1 },
	{ 0xE99DA4, 0x3CACE },
	{ 0xE99DA6, 0x1F2FC },
	{ 0xE99DA7, 0x3DEF3 },
	{ 0xE99DA8, 0x1FCCE },
	{ 0xE99DA9, 0x1D3F3 },
	{ 0xE99DAA, 0x2BAB1 },
	{ 0xE99DAB, 0x4BBF7 },
	{ 0xE99DAC, 0x2C1CE },
	{ 0xE99DAD, 0x3C0A4 },
	{ 0xE99DAE, 0x2C1D0 },
	{ 0xE99DAF, 0x3C0A2 },
	{ 0xE99DB0, 0x2C1CF },
	{ 0xE99DB2, 0x2C8E3 },
	{ 0xE99DB3, 0x2C8E0 },
	{ 0xE99DB4, 0x1E7DD },
	{ 0xE99DB5, 0x6DAA4 },
	{ 0xE99DB6, 0x1E7DE },
	{ 0xE99DB7, 0x2C8E1 },
	{ 0xE99DB8, 0x2C8E2 },
	{ 0xE99DB9, 0x3C5CB },
	{ 0xE99DBA, 0x2CFA8 },
	{ 0xE99DBB, 0x2CFAD },
	{ 0xE99DBC, 0x1EBE7 },
	{ 0xE99DBD, 0x2CFA7 },
	{ 0xE99DBE, 0x2CFA9 },
	{ 0xE99DBF, 0x2CFB0 },
	{ 0xE99E80, 0x2CFAB },
	{ 0xE99E81, 0x2CFAF },
	{ 0xE99E82, 0x2CFAC },
	{ 0xE99E83, 0x2CFAA },
	{ 0xE99E84, 0x2CFAE },
	{ 0xE99E85, 0x1EBE8 },
	{ 0xE99E87, 0x3CFE2 },
	{ 0xE99E88, 0x2D5DC },
	{ 0xE99E89, 0x3CFE3 },
	{ 0xE99E8A, 0x2D5DA },
	{ 0xE99E8B, 0x1EFEC },
	{ 0xE99E8C, 0x3CFE4 },
	{ 0xE99E8D, 0x1EFEB },
	{ 0xE99E8E, 0x2D5DB },
	{ 0xE99E8F, 0x1EFED },
	{ 0xE99E93, 0x3D3D3 },
	{ 0xE99E94, 0x2DBE2 },
	{ 0xE99E95, 0x4D4DF },
	{ 0xE99E96, 0x4D4E7 },
	{ 0xE99E97, 0x2DBE1 },
	{ 0xE99E98, 0x1F2FD },
	{ 0xE99E99, 0x2DBE0 },
	{ 0xE99E9A, 0x2E0C9 },
	{ 0xE99E9B, 0x3D6FA },
	{ 0xE99E9C, 0x2E0CB },
	{ 0xE99E9D, 0x2E0CD },
	{ 0xE99E9E, 0x2E0CC },
	{ 0xE99E9F, 0x3D6FB },
	{ 0xE99EA0, 0x1F6A6 },
	{ 0xE99EA1, 0x2E0CA },
	{ 0xE99EA2, 0x2E4CB },
	{ 0xE99EA3, 0x1F7E8 },
	{ 0xE99EA4, 0x2E4C9 },
	{ 0xE99EA5, 0x2E4CC },
	{ 0xE99EA6, 0x1F7E9 },
	{ 0xE99EA7, 0x4DEC3 },
	{ 0xE99EA8, 0x2E4C7 },
	{ 0xE99EA9, 0x3D9D0 },
	{ 0xE99EAA, 0x2E4CA },
	{ 0xE99EAB, 0x2E4C8 },
	{ 0xE99EAC, 0x2E4C5 },
	{ 0xE99EAD, 0x1F7EA },
	{ 0xE99EAE, 0x2E4C6 },
	{ 0xE99EB0, 0x4E1FC },
	{ 0xE99EB1, 0x3DBDF },
	{ 0xE99EB2, 0x3DBDD },
	{ 0xE99EB3, 0x2E7EC },
	{ 0xE99EB4, 0x3DBDE },
	{ 0xE99EB5, 0x3DBE0 },
	{ 0xE99EB6, 0x2E7EE },
	{ 0xE99EB7, 0x2E7ED },
	{ 0xE99EB8, 0x3DDD0 },
	{ 0xE99EB9, 0x2EAD8 },
	{ 0xE99EBA, 0x3DDD1 },
	{ 0xE99EBB, 0x2EAD9 },
	{ 0xE99EBC, 0x4E7F1 },
	{ 0xE99EBD, 0x3DEF5 },
	{ 0xE99EBE, 0x3DEF4 },
	{ 0xE99EBF, 0x2ECDE },
	{ 0xE99F80, 0x3DFF3 },
	{ 0xE99F81, 0x1FCA3 },
	{ 0xE99F82, 0x4E9DE },
	{ 0xE99F83, 0x1FCA2 },
	{ 0xE99F84, 0x2EFDD },
	{ 0xE99F85, 0x2EFDE },
	{ 0xE99F86, 0x1FCF3 },
	{ 0xE99F87, 0x2F0DF },
	{ 0xE99F88, 0x3E1A8 },
	{ 0xE99F89, 0x1FDB6 },
	{ 0xE99F8A, 0x3E2BB },
	{ 0xE99F8B, 0x1D3F4 },
	{ 0xE99F8C, 0x1E2F9 },
	{ 0xE99F8D, 0x2CFB2 },
	{ 0xE99F8E, 0x2CFB1 },
	{ 0xE99F8F, 0x2D5DE },
	{ 0xE99F90, 0x2D5DD },
	{ 0xE99F91, 0x4CED7 },
	{ 0xE99F92, 0x3D3D5 },
	{ 0xE99F93, 0x1F6A7 },
	{ 0xE99F94, 0x2E0CF },
	{ 0xE99F95, 0x2E0CE },
	{ 0xE99F96, 0x2E4CF },
	{ 0xE99F97, 0x2E4CD },
	{ 0xE99F98, 0x2E4D0 },
	{ 0xE99F99, 0x2E4CE },
	{ 0xE99F9A, 0x3D9D1 },
	{ 0xE99F9B, 0x4E5A9 },
	{ 0xE99F9C, 0x1F9C9 },
	{ 0xE99F9D, 0x2E7EF },
	{ 0xE99F9E, 0x2E7F0 },
	{ 0xE99F9F, 0x2E7F1 },
	{ 0xE99FA0, 0x4E5A7 },
	{ 0xE99FA1, 0x2ECDF },
	{ 0xE99FA2, 0x3DEF6 },
	{ 0xE99FA3, 0x2EEC1 },
	{ 0xE99FA4, 0x3E1A9 },
	{ 0xE99FA5, 0x2F0E0 },
	{ 0xE99FAD, 0x1D3F5 },
	{ 0xE99FAE, 0x3C5CF },
	{ 0xE99FAF, 0x3CFE5 },
	{ 0xE99FB0, 0x2DBE3 },
	{ 0xE99FB1, 0x2E0D0 },
	{ 0xE99FB2, 0x3DBE1 },
	{ 0xE99FB3, 0x1D3F6 },
	{ 0xE99FB4, 0x4C1E3 },
	{ 0xE99FB5, 0x3C5D0 },
	{ 0xE99FB6, 0x1EBE9 },
	{ 0xE99FB7, 0x4C8C6 },
	{ 0xE99FB8, 0x2DBE4 },
	{ 0xE99FB9, 0x1F7EB },
	{ 0xE99FBA, 0x2E4D1 },
	{ 0xE99FBB, 0x1F9CA },
	{ 0xE99FBC, 0x3DDD3 },
	{ 0xE99FBD, 0x2EADA },
	{ 0xE99FBE, 0x2EADB },
	{ 0xE99FBF, 0x1FBC0 },
	{ 0xE9A080, 0x2EFDF },
	{ 0xE9A081, 0x1D3F7 },
	{ 0xE9A082, 0x1DEA1 },
	{ 0xE9A083, 0x1DEA2 },
	{ 0xE9A084, 0x2BAB2 },
	{ 0xE9A085, 0x1E2FA },
	{ 0xE9A086, 0x1E2FB },
	{ 0xE9A087, 0x2C1D1 },
	{ 0xE9A088, 0x1E2FC },
	{ 0xE9A089, 0x4C1E8 },
	{ 0xE9A08A, 0x1E7E2 },
	{ 0xE9A08B, 0x3C5D2 },
	{ 0xE9A08C, 0x1E7E4 },
	{ 0xE9A08D, 0x2C8E5 },
	{ 0xE9A08E, 0x2C8E6 },
	{ 0xE9A08F, 0x2C8E4 },
	{ 0xE9A090, 0x1E7DF },
	{ 0xE9A091, 0x1E7E0 },
	{ 0xE9A092, 0x1E7E3 },
	{ 0xE9A093, 0x1E7E1 },
	{ 0xE9A094, 0x3CAD4 },
	{ 0xE9A095, 0x3CAD5 },
	{ 0xE9A096, 0x2CFB3 },
	{ 0xE9A097, 0x1EBEA },
	{ 0xE9A098, 0x1EBEB },
	{ 0xE9A099, 0x3CAD2 },
	{ 0xE9A09A, 0x3CAD6 },
	{ 0xE9A09B, 0x2D5E5 },
	{ 0xE9A09C, 0x1EFF0 },
	{ 0xE9A09D, 0x2D5E0 },
	{ 0xE9A09E, 0x2D5DF },
	{ 0xE9A09F, 0x3CFE9 },
	{ 0xE9A0A0, 0x2D5E4 },
	{ 0xE9A0A1, 0x1EFEE },
	{ 0xE9A0A2, 0x3CFE7 },
	{ 0xE9A0A3, 0x4CEDA },
	{ 0xE9A0A4, 0x1F3A6 },
	{ 0xE9A0A5, 0x4D4F0 },
	{ 0xE9A0A6, 0x2D5E1 },
	{ 0xE9A0A7, 0x2D5E6 },
	{ 0xE9A0A8, 0x2D5E3 },
	{ 0xE9A0A9, 0x2D5E2 },
	{ 0xE9A0AA, 0x3CFE6 },
	{ 0xE9A0AB, 0x1EFEF },
	{ 0xE9A0AD, 0x1F3A4 },
	{ 0xE9A0AE, 0x3D3DC },
	{ 0xE9A0AF, 0x2DBE6 },
	{ 0xE9A0B0, 0x1F2FE },
	{ 0xE9A0B1, 0x3D3D9 },
	{ 0xE9A0B2, 0x2DBE7 },
	{ 0xE9A0B3, 0x3D3DA },
	{ 0xE9A0B4, 0x3D2A8 },
	{ 0xE9A0B5, 0x2DBE5 },
	{ 0xE9A0B6, 0x3D3D8 },
	{ 0xE9A0B7, 0x1F3A3 },
	{ 0xE9A0B8, 0x1F3A1 },
	{ 0xE9A0B9, 0x1F3A5 },
	{ 0xE9A0BA, 0x3D3DD },
	{ 0xE9A0BB, 0x1F3A2 },
	{ 0xE9A0BC, 0x3D3DB },
	{ 0xE9A0BD, 0x3D3DF },
	{ 0xE9A0BE, 0x4DECF },
	{ 0xE9A0BF, 0x3D9DB },
	{ 0xE9A180, 0x3D7A6 },
	{ 0xE9A181, 0x2E0D1 },
	{ 0xE9A182, 0x4D9F0 },
	{ 0xE9A183, 0x2E0D6 },
	{ 0xE9A184, 0x2E0D2 },
	{ 0xE9A185, 0x2E0D5 },
	{ 0xE9A186, 0x1F6A8 },
	{ 0xE9A187, 0x3D7A8 },
	{ 0xE9A188, 0x2DEC1 },
	{ 0xE9A189, 0x2E0D4 },
	{ 0xE9A18A, 0x2E0D3 },
	{ 0xE9A18B, 0x3D9D9 },
	{ 0xE9A18C, 0x1F7EE },
	{ 0xE9A18D, 0x1F7EC },
	{ 0xE9A18E, 0x1F7EF },
	{ 0xE9A18F, 0x1F7ED },
	{ 0xE9A190, 0x2E4D2 },
	{ 0xE9A191, 0x2E4D3 },
	{ 0xE9A192, 0x2E4D4 },
	{ 0xE9A193, 0x1F7F0 },
	{ 0xE9A194, 0x3D9D6 },
	{ 0xE9A195, 0x3D9D8 },
	{ 0xE9A196, 0x3DBE5 },
	{ 0xE9A197, 0x2E7F5 },
	{ 0xE9A198, 0x1F9CC },
	{ 0xE9A199, 0x2E7F3 },
	{ 0xE9A19A, 0x4E2B0 },
	{ 0xE9A19B, 0x1F9CD },
	{ 0xE9A19C, 0x2E7F2 },
	{ 0xE9A19D, 0x2E7F4 },
	{ 0xE9A19E, 0x1F9CB },
	{ 0xE9A19F, 0x2EADF },
	{ 0xE9A1A0, 0x2EADC },
	{ 0xE9A1A1, 0x4E5AC },
	{ 0xE9A1A2, 0x2EADD },
	{ 0xE9A1A3, 0x2EADE },
	{ 0xE9A1A4, 0x2ECE0 },
	{ 0xE9A1A5, 0x1FBC2 },
	{ 0xE9A1A6, 0x3DEF8 },
	{ 0xE9A1A7, 0x1FBC1 },
	{ 0xE9A1A8, 0x3DEF7 },
	{ 0xE9A1A9, 0x2EEC3 },
	{ 0xE9A1AA, 0x2EEC2 },
	{ 0xE9A1AB, 0x1FCA4 },
	{ 0xE9A1AC, 0x3E0DD },
	{ 0xE9A1AD, 0x3E0DE },
	{ 0xE9A1AE, 0x3E0DC },
	{ 0xE9A1AF, 0x1FCCF },
	{ 0xE9A1B0, 0x1FCF4 },
	{ 0xE9A1B1, 0x1FDAD },
	{ 0xE9A1B2, 0x2F1C7 },
	{ 0xE9A1B3, 0x2F1FC },
	{ 0xE9A1B4, 0x2F1FD },
	{ 0xE9A2A8, 0x1D3F8 },
	{ 0xE9A2A9, 0x2C1D2 },
	{ 0xE9A2AB, 0x4C1F1 },
	{ 0xE9A2AC, 0x2C8E7 },
	{ 0xE9A2AD, 0x2CFB4 },
	{ 0xE9A2AE, 0x2CFB5 },
	{ 0xE9A2AF, 0x1EBEC },
	{ 0xE9A2B0, 0x4C8D7 },
	{ 0xE9A2B1, 0x1EBED },
	{ 0xE9A2B2, 0x2D5E7 },
	{ 0xE9A2B3, 0x1EFF1 },
	{ 0xE9A2B5, 0x3D3E1 },
	{ 0xE9A2B6, 0x1F6A9 },
	{ 0xE9A2B7, 0x3D7AA },
	{ 0xE9A2B8, 0x2E4D5 },
	{ 0xE9A2B9, 0x3D9DC },
	{ 0xE9A2BA, 0x1F7F1 },
	{ 0xE9A2BB, 0x2E7F8 },
	{ 0xE9A2BC, 0x1F9CE },
	{ 0xE9A2BD, 0x2E7F7 },
	{ 0xE9A2BE, 0x2E7F9 },
	{ 0xE9A2BF, 0x2E7F6 },
	{ 0xE9A380, 0x2ECE3 },
	{ 0xE9A381, 0x2EAE0 },
	{ 0xE9A382, 0x2EAE1 },
	{ 0xE9A383, 0x3DDD6 },
	{ 0xE9A384, 0x1FAD1 },
	{ 0xE9A386, 0x2ECE2 },
	{ 0xE9A387, 0x3DEFB },
	{ 0xE9A388, 0x3DEF9 },
	{ 0xE9A389, 0x2ECE1 },
	{ 0xE9A38A, 0x3DEFA },
	{ 0xE9A38B, 0x2EEC4 },
	{ 0xE9A38C, 0x2F1FE },
	{ 0xE9A38D, 0x3E2A5 },
	{ 0xE9A39B, 0x1D3F9 },
	{ 0xE9A39C, 0x3DEFC },
	{ 0xE9A39D, 0x3E2A6 },
	{ 0xE9A39F, 0x1D3FA },
	{ 0xE9A3A1, 0x3B9E7 },
	{ 0xE9A3A2, 0x1D8EA },
	{ 0xE9A3A3, 0x2B3CB },
	{ 0xE9A3A4, 0x3E6F0 },
	{ 0xE9A3A5, 0x2BAB3 },
	{ 0xE9A3A6, 0x3B9E8 },
	{ 0xE9A3A7, 0x1E2FD },
	{ 0xE9A3A9, 0x1E3A2 },
	{ 0xE9A3AA, 0x1E2FE },
	{ 0xE9A3AB, 0x2C1D3 },
	{ 0xE9A3AC, 0x3C5DB },
	{ 0xE9A3AD, 0x1E3A4 },
	{ 0xE9A3AF, 0x1E3A1 },
	{ 0xE9A3B0, 0x3C0AB },
	{ 0xE9A3B1, 0x3C5DC },
	{ 0xE9A3B2, 0x1E3A3 },
	{ 0xE9A3B3, 0x3C5D4 },
	{ 0xE9A3B4, 0x1E7E6 },
	{ 0xE9A3B5, 0x3C5D9 },
	{ 0xE9A3B6, 0x2C8E8 },
	{ 0xE9A3B7, 0x3C5D7 },
	{ 0xE9A3B8, 0x3CADD },
	{ 0xE9A3B9, 0x2C8E9 },
	{ 0xE9A3BA, 0x2D5E9 },
	{ 0xE9A3BB, 0x4C1FB },
	{ 0xE9A3BC, 0x1E7E5 },
	{ 0xE9A3BD, 0x1E7E7 },
	{ 0xE9A3BE, 0x1E7E8 },
	{ 0xE9A3BF, 0x3C5D8 },
	{ 0xE9A480, 0x2CFB7 },
	{ 0xE9A481, 0x3CADE },
	{ 0xE9A482, 0x2CFB6 },
	{ 0xE9A483, 0x1EBEE },
	{ 0xE9A484, 0x5CBCC },
	{ 0xE9A485, 0x1EBEF },
	{ 0xE9A486, 0x3CADB },
	{ 0xE9A487, 0x2CFB8 },
	{ 0xE9A488, 0x2D5E8 },
	{ 0xE9A489, 0x1EBF1 },
	{ 0xE9A48A, 0x1EFF2 },
	{ 0xE9A48B, 0x4CEE3 },
	{ 0xE9A48C, 0x1EBF0 },
	{ 0xE9A48E, 0x3E6FA },
	{ 0xE9A490, 0x1F3A7 },
	{ 0xE9A491, 0x2D5EA },
	{ 0xE9A492, 0x1EFF4 },
	{ 0xE9A493, 0x1EFF3 },
	{ 0xE9A494, 0x2D5EB },
	{ 0xE9A495, 0x2D5EE },
	{ 0xE9A496, 0x2D5EC },
	{ 0xE9A497, 0x2D5ED },
	{ 0xE9A498, 0x1EFF5 },
	{ 0xE9A499, 0x3CFEB },
	{ 0xE9A49A, 0x1F3AC },
	{ 0xE9A49B, 0x1F3AA },
	{ 0xE9A49C, 0x3D3E5 },
	{ 0xE9A49D, 0x3D3E6 },
	{ 0xE9A49E, 0x1F3A9 },
	{ 0xE9A49F, 0x2DBE9 },
	{ 0xE9A4A0, 0x3D3E4 },
	{ 0xE9A4A1, 0x1F3AB },
	{ 0xE9A4A2, 0x3D3E2 },
	{ 0xE9A4A3, 0x3D3E3 },
	{ 0xE9A4A4, 0x2DBE8 },
	{ 0xE9A4A5, 0x2E0D7 },
	{ 0xE9A4A6, 0x4D4FE },
	{ 0xE9A4A7, 0x2DBEA },
	{ 0xE9A4A8, 0x1F3A8 },
	{ 0xE9A4A9, 0x2DBEB },
	{ 0xE9A4AA, 0x2E0DA },
	{ 0xE9A4AB, 0x2E0D8 },
	{ 0xE9A4AC, 0x2E0D9 },
	{ 0xE9A4AD, 0x2E0DE },
	{ 0xE9A4AE, 0x1F7F5 },
	{ 0xE9A4AF, 0x2E0DD },
	{ 0xE9A4B0, 0x2E0E0 },
	{ 0xE9A4B1, 0x2E0DF },
	{ 0xE9A4B2, 0x2E0DC },
	{ 0xE9A4B3, 0x2E0DB },
	{ 0xE9A4B4, 0x4D5A1 },
	{ 0xE9A4B5, 0x1F6AA },
	{ 0xE9A4B6, 0x3D9E2 },
	{ 0xE9A4B7, 0x4DAA9 },
	{ 0xE9A4B8, 0x3D9E1 },
	{ 0xE9A4B9, 0x3D9E6 },
	{ 0xE9A4BA, 0x2E4D8 },
	{ 0xE9A4BB, 0x3D9E5 },
	{ 0xE9A4BC, 0x2E4D7 },
	{ 0xE9A4BD, 0x1F7F4 },
	{ 0xE9A4BE, 0x1F7F2 },
	{ 0xE9A4BF, 0x1F7F3 },
	{ 0xE9A580, 0x3D9E3 },
	{ 0xE9A581, 0x2E4D6 },
	{ 0xE9A582, 0x3E6F1 },
	{ 0xE9A583, 0x2E7FC },
	{ 0xE9A584, 0x3DBE9 },
	{ 0xE9A585, 0x1F9CF },
	{ 0xE9A586, 0x4E2B8 },
	{ 0xE9A587, 0x2E7FB },
	{ 0xE9A588, 0x2E7FA },
	{ 0xE9A589, 0x1F9D0 },
	{ 0xE9A58A, 0x4E5BA },
	{ 0xE9A58B, 0x2EAE6 },
	{ 0xE9A58C, 0x2EAE5 },
	{ 0xE9A58D, 0x3DDD8 },
	{ 0xE9A58E, 0x2EAE3 },
	{ 0xE9A58F, 0x3DEFE },
	{ 0xE9A590, 0x2EAE2 },
	{ 0xE9A591, 0x1FAD3 },
	{ 0xE9A592, 0x1FAD2 },
	{ 0xE9A593, 0x2EAE7 },
	{ 0xE9A594, 0x2EEC5 },
	{ 0xE9A595, 0x1FCA5 },
	{ 0xE9A596, 0x2ECE5 },
	{ 0xE9A597, 0x1FBC3 },
	{ 0xE9A598, 0x2ECE4 },
	{ 0xE9A599, 0x2EAE4 },
	{ 0xE9A59A, 0x3DFF8 },
	{ 0xE9A59B, 0x2EEC6 },
	{ 0xE9A59C, 0x1FCD0 },
	{ 0xE9A59D, 0x3E1AA },
	{ 0xE9A59E, 0x1FDAE },
	{ 0xE9A59F, 0x2F1C8 },
	{ 0xE9A5A0, 0x4EEA4 },
	{ 0xE9A5A1, 0x2F2A1 },
	{ 0xE9A696, 0x1D3FB },
	{ 0xE9A697, 0x2BAB4 },
	{ 0xE9A698, 0x2E0E1 },
	{ 0xE9A699, 0x1D3FC },
	{ 0xE9A69A, 0x3C5DF },
	{ 0xE9A69B, 0x5CBCE },
	{ 0xE9A69C, 0x2CFBA },
	{ 0xE9A69D, 0x2CFB9 },
	{ 0xE9A69E, 0x2DBEC },
	{ 0xE9A69F, 0x5DAA6 },
	{ 0xE9A6A0, 0x3D3E8 },
	{ 0xE9A6A1, 0x2E0E3 },
	{ 0xE9A6A2, 0x3D7B0 },
	{ 0xE9A6A3, 0x2E0E2 },
	{ 0xE9A6A4, 0x3D9E7 },
	{ 0xE9A6A5, 0x1F7F6 },
	{ 0xE9A6A6, 0x2E7FD },
	{ 0xE9A6A7, 0x2E7FE },
	{ 0xE9A6A8, 0x1FAD4 },
	{ 0xE9A6A9, 0x3DFA1 },
	{ 0xE9A6AA, 0x3E0E0 },
	{ 0xE9A6AB, 0x2F2A2 },
	{ 0xE9A6AC, 0x1D8EB },
	{ 0xE9A6AD, 0x1E3A6 },
	{ 0xE9A6AE, 0x1E3A5 },
	{ 0xE9A6AF, 0x2C8EA },
	{ 0xE9A6B0, 0x2C8EC },
	{ 0xE9A6B1, 0x1E7EA },
	{ 0xE9A6B2, 0x2C8EB },
	{ 0xE9A6B3, 0x1E7E9 },
	{ 0xE9A6B4, 0x1E7EB },
	{ 0xE9A6B5, 0x2C8ED },
	{ 0xE9A6B6, 0x3CAE3 },
	{ 0xE9A6B7, 0x3CAE2 },
	{ 0xE9A6B8, 0x3CAE6 },
	{ 0xE9A6B9, 0x2CFBC },
	{ 0xE9A6BA, 0x2CFBE },
	{ 0xE9A6BB, 0x2CFBD },
	{ 0xE9A6BC, 0x3CAE1 },
	{ 0xE9A6BD, 0x2CFC0 },
	{ 0xE9A6BE, 0x3CAE0 },
	{ 0xE9A6BF, 0x3CAEC },
	{ 0xE9A780, 0x3CAE4 },
	{ 0xE9A781, 0x1EBF2 },
	{ 0xE9A782, 0x2CFBF },
	{ 0xE9A783, 0x2CFBB },
	{ 0xE9A784, 0x3CAEA },
	{ 0xE9A786, 0x4C8E0 },
	{ 0xE9A787, 0x2CFC1 },
	{ 0xE9A788, 0x3CFF3 },
	{ 0xE9A789, 0x2D5F5 },
	{ 0xE9A78A, 0x3CFED },
	{ 0xE9A78B, 0x2D5F8 },
	{ 0xE9A78C, 0x2D5FA },
	{ 0xE9A78D, 0x2D5F0 },
	{ 0xE9A78E, 0x2D5F4 },
	{ 0xE9A78F, 0x2D5F1 },
	{ 0xE9A790, 0x1EFF7 },
	{ 0xE9A791, 0x1EFFA },
	{ 0xE9A792, 0x1EFFC },
	{ 0xE9A793, 0x2D5F2 },
	{ 0xE9A794, 0x2D5F3 },
	{ 0xE9A795, 0x1EFFB },
	{ 0xE9A796, 0x2D5F6 },
	{ 0xE9A797, 0x2D5F9 },
	{ 0xE9A798, 0x2D5F7 },
	{ 0xE9A799, 0x1EFFD },
	{ 0xE9A79A, 0x3CFEE },
	{ 0xE9A79B, 0x1EFF9 },
	{ 0xE9A79C, 0x2D5EF },
	{ 0xE9A79D, 0x1EFF6 },
	{ 0xE9A79E, 0x3CFF2 },
	{ 0xE9A79F, 0x1EFF8 },
	{ 0xE9A7A0, 0x3CFF4 },
	{ 0xE9A7A1, 0x3D3F0 },
	{ 0xE9A7A2, 0x1F3AE },
	{ 0xE9A7A3, 0x2DBF2 },
	{ 0xE9A7A4, 0x2DBF0 },
	{ 0xE9A7A5, 0x2DBEF },
	{ 0xE9A7A6, 0x3D3F1 },
	{ 0xE9A7A7, 0x2DBF5 },
	{ 0xE9A7A8, 0x3D3EB },
	{ 0xE9A7A9, 0x2DBF4 },
	{ 0xE9A7AA, 0x2DBF3 },
	{ 0xE9A7AB, 0x3D3EC },
	{ 0xE9A7AC, 0x2DBEE },
	{ 0xE9A7AD, 0x1F3AD },
	{ 0xE9A7AE, 0x2DBED },
	{ 0xE9A7AF, 0x3D3EA },
	{ 0xE9A7B0, 0x2DBF1 },
	{ 0xE9A7B1, 0x1F3AF },
	{ 0xE9A7B3, 0x3D7B4 },
	{ 0xE9A7B4, 0x2E0E6 },
	{ 0xE9A7B5, 0x3D7B7 },
	{ 0xE9A7B6, 0x2E0EA },
	{ 0xE9A7B7, 0x2E0E7 },
	{ 0xE9A7B8, 0x2E0E9 },
	{ 0xE9A7B9, 0x2E0E8 },
	{ 0xE9A7BA, 0x2E0E5 },
	{ 0xE9A7BB, 0x2E0EB },
	{ 0xE9A7BC, 0x2E0EE },
	{ 0xE9A7BD, 0x2E0EC },
	{ 0xE9A7BE, 0x2E0ED },
	{ 0xE9A7BF, 0x1F6AC },
	{ 0xE9A880, 0x3D7B3 },
	{ 0xE9A881, 0x1F6AB },
	{ 0xE9A882, 0x2E0E4 },
	{ 0xE9A883, 0x2E0EF },
	{ 0xE9A884, 0x2E4DD },
	{ 0xE9A885, 0x2E4E0 },
	{ 0xE9A886, 0x2E4E2 },
	{ 0xE9A887, 0x2E4E1 },
	{ 0xE9A888, 0x3D9EA },
	{ 0xE9A889, 0x2E4DB },
	{ 0xE9A88A, 0x2E4DF },
	{ 0xE9A88B, 0x2E4DA },
	{ 0xE9A88C, 0x3D9EB },
	{ 0xE9A88D, 0x2E4DC },
	{ 0xE9A88E, 0x1F7F7 },
	{ 0xE9A88F, 0x2E4D9 },
	{ 0xE9A890, 0x3D9ED },
	{ 0xE9A891, 0x2E4DE },
	{ 0xE9A894, 0x2E8AD },
	{ 0xE9A895, 0x2E8A2 },
	{ 0xE9A896, 0x1F9D1 },
	{ 0xE9A897, 0x3DBEF },
	{ 0xE9A898, 0x3DBED },
	{ 0xE9A899, 0x1F9D2 },
	{ 0xE9A89A, 0x2E8A1 },
	{ 0xE9A89B, 0x2E8A6 },
	{ 0xE9A89C, 0x2E8AC },
	{ 0xE9A89D, 0x2E8A4 },
	{ 0xE9A89E, 0x2E8AB },
	{ 0xE9A89F, 0x3DBEC },
	{ 0xE9A8A0, 0x2E8A8 },
	{ 0xE9A8A1, 0x3DBEE },
	{ 0xE9A8A2, 0x2E8A7 },
	{ 0xE9A8A3, 0x2E8AA },
	{ 0xE9A8A4, 0x2E8A5 },
	{ 0xE9A8A5, 0x2E8A3 },
	{ 0xE9A8A6, 0x3DBEB },
	{ 0xE9A8A7, 0x2E8A9 },
	{ 0xE9A8A9, 0x2EAEE },
	{ 0xE9A8AA, 0x2EAEC },
	{ 0xE9A8AB, 0x1FAD5 },
	{ 0xE9A8AC, 0x2EAEB },
	{ 0xE9A8AD, 0x2EAF1 },
	{ 0xE9A8AE, 0x2EAEF },
	{ 0xE9A8AF, 0x3DDDA },
	{ 0xE9A8B0, 0x1FAD6 },
	{ 0xE9A8B1, 0x2EAEA },
	{ 0xE9A8B2, 0x2EAE8 },
	{ 0xE9A8B3, 0x4E5C6 },
	{ 0xE9A8B4, 0x2EAE9 },
	{ 0xE9A8B5, 0x1FAD8 },
	{ 0xE9A8B6, 0x2EAED },
	{ 0xE9A8B7, 0x1FAD7 },
	{ 0xE9A8B8, 0x2EAF0 },
	{ 0xE9A8B9, 0x2ECE6 },
	{ 0xE9A8BA, 0x2ECEC },
	{ 0xE9A8BB, 0x3DFA4 },
	{ 0xE9A8BC, 0x3DFA2 },
	{ 0xE9A8BD, 0x2ECE7 },
	{ 0xE9A8BE, 0x1FBC7 },
	{ 0xE9A8BF, 0x2ECED },
	{ 0xE9A980, 0x1FBC6 },
	{ 0xE9A981, 0x2ECEB },
	{ 0xE9A982, 0x2ECEA },
	{ 0xE9A983, 0x1FBC5 },
	{ 0xE9A984, 0x2ECE9 },
	{ 0xE9A985, 0x1FBC4 },
	{ 0xE9A986, 0x2ECE8 },
	{ 0xE9A987, 0x7D6D1 },
	{ 0xE9A988, 0x2EECC },
	{ 0xE9A989, 0x2EECE },
	{ 0xE9A98A, 0x2EECD },
	{ 0xE9A98B, 0x4E9EA },
	{ 0xE9A98C, 0x2EECA },
	{ 0xE9A98D, 0x1FCA7 },
	{ 0xE9A98E, 0x2EEC7 },
	{ 0xE9A98F, 0x2EECB },
	{ 0xE9A990, 0x2EED0 },
	{ 0xE9A991, 0x3DFF9 },
	{ 0xE9A992, 0x2EECF },
	{ 0xE9A993, 0x2EEC8 },
	{ 0xE9A994, 0x2EEC9 },
	{ 0xE9A995, 0x1FCA6 },
	{ 0xE9A996, 0x2EFE0 },
	{ 0xE9A997, 0x1FCD3 },
	{ 0xE9A998, 0x3E0E2 },
	{ 0xE9A999, 0x2EFE1 },
	{ 0xE9A99A, 0x1FCD1 },
	{ 0xE9A99B, 0x1FCD2 },
	{ 0xE9A99C, 0x3E0E1 },
	{ 0xE9A99D, 0x4ECBD },
	{ 0xE9A99E, 0x2F0E1 },
	{ 0xE9A99F, 0x1FCF5 },
	{ 0xE9A9A0, 0x2F1E5 },
	{ 0xE9A9A1, 0x3E1F2 },
	{ 0xE9A9A2, 0x1FDB7 },
	{ 0xE9A9A3, 0x3E1F3 },
	{ 0xE9A9A4, 0x2F2A3 },
	{ 0xE9A9A5, 0x1FDB8 },
	{ 0xE9A9A6, 0x2F2A4 },
	{ 0xE9A9A7, 0x2F2A5 },
	{ 0xE9A9A8, 0x2F2B3 },
	{ 0xE9A9A9, 0x2F2B2 },
	{ 0xE9A9AA, 0x1FDC7 },
	{ 0xE9A9AB, 0x2F2BB },
	{ 0xE9AAA8, 0x1D8EC },
	{ 0xE9AAA9, 0x3C0AF },
	{ 0xE9AAAA, 0x4C2A1 },
	{ 0xE9AAAB, 0x2C8EF },
	{ 0xE9AAAC, 0x4C1FD },
	{ 0xE9AAAD, 0x2C8EE },
	{ 0xE9AAAE, 0x4C1FE },
	{ 0xE9AAAF, 0x1EBF3 },
	{ 0xE9AAB0, 0x1EBF4 },
	{ 0xE9AAB1, 0x2CFC2 },
	{ 0xE9AAB2, 0x4CEF4 },
	{ 0xE9AAB3, 0x2D5FB },
	{ 0xE9AAB4, 0x2DBF8 },
	{ 0xE9AAB5, 0x3CFF7 },
	{ 0xE9AAB6, 0x3CFF6 },
	{ 0xE9AAB7, 0x1EFFE },
	{ 0xE9AAB8, 0x1F3B0 },
	{ 0xE9AAB9, 0x2DBF6 },
	{ 0xE9AABA, 0x4D5B1 },
	{ 0xE9AABB, 0x2DBF9 },
	{ 0xE9AABC, 0x1F3B1 },
	{ 0xE9AABD, 0x3D7BA },
	{ 0xE9AABE, 0x2E0F0 },
	{ 0xE9AABF, 0x2DBF7 },
	{ 0xE9AB80, 0x2E4E3 },
	{ 0xE9AB81, 0x1F7F8 },
	{ 0xE9AB82, 0x2E8AE },
	{ 0xE9AB83, 0x4E2C9 },
	{ 0xE9AB84, 0x3DDE1 },
	{ 0xE9AB86, 0x2EAF4 },
	{ 0xE9AB87, 0x2EAF2 },
	{ 0xE9AB88, 0x3DDE0 },
	{ 0xE9AB89, 0x3DDDE },
	{ 0xE9AB8A, 0x2EAF3 },
	{ 0xE9AB8D, 0x2ECEE },
	{ 0xE9AB8E, 0x3DFA5 },
	{ 0xE9AB8F, 0x1FBC8 },
	{ 0xE9AB90, 0x2EED1 },
	{ 0xE9AB91, 0x1FCD6 },
	{ 0xE9AB92, 0x1FCA8 },
	{ 0xE9AB93, 0x1FCD4 },
	{ 0xE9AB94, 0x1FCD5 },
	{ 0xE9AB95, 0x2F0E2 },
	{ 0xE9AB96, 0x1FDAF },
	{ 0xE9AB97, 0x3E1F4 },
	{ 0xE9AB98, 0x1D8ED },
	{ 0xE9AB99, 0x4B6AD },
	{ 0xE9AB9A, 0x3CAEE },
	{ 0xE9AB9B, 0x4CEF9 },
	{ 0xE9AB9C, 0x2E4E4 },
	{ 0xE9AB9D, 0x3DFFB },
	{ 0xE9AB9E, 0x3E0E3 },
	{ 0xE9AB9F, 0x2B3CC },
	{ 0xE9ABA0, 0x3C0B2 },
	{ 0xE9ABA1, 0x1E7EC },
	{ 0xE9ABA2, 0x3C5E1 },
	{ 0xE9ABA3, 0x2CFC3 },
	{ 0xE9ABA4, 0x3CAEF },
	{ 0xE9ABA5, 0x3CAF3 },
	{ 0xE9ABA6, 0x1EBF5 },
	{ 0xE9ABA7, 0x2CFC4 },
	{ 0xE9ABA8, 0x3CAF1 },
	{ 0xE9ABA9, 0x3CAF0 },
	{ 0xE9ABAA, 0x3CAF2 },
	{ 0xE9ABAB, 0x2D5FD },
	{ 0xE9ABAC, 0x2D5FC },
	{ 0xE9ABAD, 0x1F3B3 },
	{ 0xE9ABAE, 0x1F0A1 },
	{ 0xE9ABAF, 0x1F0A2 },
	{ 0xE9ABB0, 0x4CFA1 },
	{ 0xE9ABB1, 0x2D6A2 },
	{ 0xE9ABB2, 0x2D6A1 },
	{ 0xE9ABB3, 0x2D5FE },
	{ 0xE9ABB4, 0x3CFF9 },
	{ 0xE9ABB5, 0x3D3F5 },
	{ 0xE9ABB6, 0x2DBFA },
	{ 0xE9ABB7, 0x2DBFD },
	{ 0xE9ABB8, 0x3D3F4 },
	{ 0xE9ABB9, 0x2DBFC },
	{ 0xE9ABBA, 0x2DBFB },
	{ 0xE9ABBB, 0x1F3B2 },
	{ 0xE9ABBC, 0x2E0F4 },
	{ 0xE9ABBD, 0x2E0F2 },
	{ 0xE9ABBE, 0x2E0F1 },
	{ 0xE9ABBF, 0x4DAB7 },
	{ 0xE9AC80, 0x3D7BB },
	{ 0xE9AC81, 0x2E0F3 },
	{ 0xE9AC82, 0x3D7BC },
	{ 0xE9AC83, 0x1F7F9 },
	{ 0xE9AC84, 0x2E4E6 },
	{ 0xE9AC85, 0x2E4E7 },
	{ 0xE9AC86, 0x1F7FA },
	{ 0xE9AC87, 0x3D9EF },
	{ 0xE9AC88, 0x2E4E5 },
	{ 0xE9AC89, 0x3DBF1 },
	{ 0xE9AC8A, 0x2E8B0 },
	{ 0xE9AC8B, 0x2E8AF },
	{ 0xE9AC8C, 0x2E8B2 },
	{ 0xE9AC8D, 0x1F9D3 },
	{ 0xE9AC8E, 0x2E8B1 },
	{ 0xE9AC8F, 0x4E2CF },
	{ 0xE9AC90, 0x2EAF5 },
	{ 0xE9AC91, 0x2EAF7 },
	{ 0xE9AC92, 0x2EAF6 },
	{ 0xE9AC94, 0x3DFA7 },
	{ 0xE9AC95, 0x2ECEF },
	{ 0xE9AC96, 0x2ECF2 },
	{ 0xE9AC97, 0x2ECF0 },
	{ 0xE9AC98, 0x2ECF1 },
	{ 0xE9AC99, 0x2EED2 },
	{ 0xE9AC9A, 0x1FCA9 },
	{ 0xE9AC9B, 0x4E9F4 },
	{ 0xE9AC9C, 0x4E9F1 },
	{ 0xE9AC9D, 0x3E6F2 },
	{ 0xE9AC9E, 0x2EFE2 },
	{ 0xE9AC9F, 0x2EFE3 },
	{ 0xE9ACA0, 0x2EFE4 },
	{ 0xE9ACA1, 0x3E1AC },
	{ 0xE9ACA2, 0x1FCF6 },
	{ 0xE9ACA3, 0x1FDB0 },
	{ 0xE9ACA4, 0x2F2A6 },
	{ 0xE9ACA5, 0x1D8EE },
	{ 0xE9ACA6, 0x3CAF5 },
	{ 0xE9ACA7, 0x1F0A3 },
	{ 0xE9ACA8, 0x1F3B4 },
	{ 0xE9ACA9, 0x2E4E8 },
	{ 0xE9ACAA, 0x3DDE2 },
	{ 0xE9ACAB, 0x2EED3 },
	{ 0xE9ACAC, 0x3E1AE },
	{ 0xE9ACAD, 0x4EDB7 },
	{ 0xE9ACAE, 0x2F1E6 },
	{ 0xE9ACAF, 0x2B3CD },
	{ 0xE9ACB0, 0x3E2A8 },
	{ 0xE9ACB1, 0x1FDC8 },
	{ 0xE9ACB2, 0x1D8EF },
	{ 0xE9ACB3, 0x2DBFE },
	{ 0xE9ACB4, 0x3D7BE },
	{ 0xE9ACB5, 0x2E4E9 },
	{ 0xE9ACB7, 0x2E8B3 },
	{ 0xE9ACB8, 0x3DDE3 },
	{ 0xE9ACB9, 0x4E8B6 },
	{ 0xE9ACBA, 0x2ECF3 },
	{ 0xE9ACBB, 0x2EED4 },
	{ 0xE9ACBC, 0x1D8F0 },
	{ 0xE9ACBD, 0x3C5E2 },
	{ 0xE9ACBE, 0x2CFC5 },
	{ 0xE9ACBF, 0x2CFC6 },
	{ 0xE9AD80, 0x3CAF8 },
	{ 0xE9AD81, 0x1EBF6 },
	{ 0xE9AD82, 0x1EBF7 },
	{ 0xE9AD83, 0x2D6A4 },
	{ 0xE9AD84, 0x1F0A5 },
	{ 0xE9AD85, 0x1F0A4 },
	{ 0xE9AD86, 0x2D6A3 },
	{ 0xE9AD88, 0x2E0F5 },
	{ 0xE9AD89, 0x3D7BF },
	{ 0xE9AD8A, 0x2E4EA },
	{ 0xE9AD8B, 0x2E4EC },
	{ 0xE9AD8C, 0x2E4EB },
	{ 0xE9AD8D, 0x1F7FD },
	{ 0xE9AD8E, 0x1F7FC },
	{ 0xE9AD8F, 0x1F7FB },
	{ 0xE9AD90, 0x3DDE4 },
	{ 0xE9AD91, 0x1FBCA },
	{ 0xE9AD92, 0x2ECF4 },
	{ 0xE9AD93, 0x3DFA8 },
	{ 0xE9AD94, 0x1FBC9 },
	{ 0xE9AD95, 0x2EED6 },
	{ 0xE9AD96, 0x2EED5 },
	{ 0xE9AD97, 0x3E1AF },
	{ 0xE9AD98, 0x1FCF7 },
	{ 0xE9AD99, 0x2F0E3 },
	{ 0xE9AD9A, 0x1DEA3 },
	{ 0xE9AD9B, 0x2C8F0 },
	{ 0xE9AD9C, 0x4C2A9 },
	{ 0xE9AD9D, 0x3C5E3 },
	{ 0xE9AD9F, 0x2CFC9 },
	{ 0xE9ADA0, 0x2CFC7 },
	{ 0xE9ADA1, 0x2CFC8 },
	{ 0xE9ADA2, 0x4C8EB },
	{ 0xE9ADA3, 0x3CFFE },
	{ 0xE9ADA4, 0x2D6AD },
	{ 0xE9ADA5, 0x4CFB0 },
	{ 0xE9ADA6, 0x2D6A8 },
	{ 0xE9ADA7, 0x2D6A5 },
	{ 0xE9ADA8, 0x2D6AC },
	{ 0xE9ADA9, 0x3CFFC },
	{ 0xE9ADAA, 0x4CFB5 },
	{ 0xE9ADAB, 0x3CFFB },
	{ 0xE9ADAC, 0x2D6AE },
	{ 0xE9ADAD, 0x4CFB7 },
	{ 0xE9ADAE, 0x4CFAC },
	{ 0xE9ADAF, 0x1F0A7 },
	{ 0xE9ADB0, 0x2D6AB },
	{ 0xE9ADB1, 0x2D6A7 },
	{ 0xE9ADB2, 0x3CFFD },
	{ 0xE9ADB3, 0x4CFAA },
	{ 0xE9ADB4, 0x2D6A6 },
	{ 0xE9ADB5, 0x2D6AA },
	{ 0xE9ADB6, 0x2D6A9 },
	{ 0xE9ADB7, 0x1F0A6 },
	{ 0xE9ADB9, 0xFD3BE },
	{ 0xE9ADBA, 0x2DCAB },
	{ 0xE9ADBB, 0x2DCA6 },
	{ 0xE9ADBC, 0x2DCA4 },
	{ 0xE9ADBD, 0x2DCAD },
	{ 0xE9ADBE, 0x2DCA5 },
	{ 0xE9ADBF, 0x4D5C7 },
	{ 0xE9AE80, 0x2DCA1 },
	{ 0xE9AE81, 0x4D5C3 },
	{ 0xE9AE82, 0x2DCA7 },
	{ 0xE9AE83, 0x3D3F8 },
	{ 0xE9AE84, 0x3D3FA },
	{ 0xE9AE85, 0x2DCA2 },
	{ 0xE9AE86, 0x2E0FE },
	{ 0xE9AE87, 0x2DCA3 },
	{ 0xE9AE88, 0x2DCAE },
	{ 0xE9AE89, 0x3D4A3 },
	{ 0xE9AE8A, 0x4D5C5 },
	{ 0xE9AE8B, 0x3D3FC },
	{ 0xE9AE8C, 0x3D4A1 },
	{ 0xE9AE8D, 0x5DACA },
	{ 0xE9AE8E, 0x3D4A5 },
	{ 0xE9AE8F, 0x3D3FD },
	{ 0xE9AE90, 0x2DCAA },
	{ 0xE9AE91, 0x1F3B5 },
	{ 0xE9AE92, 0x2DCA9 },
	{ 0xE9AE93, 0x2DCA8 },
	{ 0xE9AE94, 0x3D3F9 },
	{ 0xE9AE95, 0x2DCAC },
	{ 0xE9AE96, 0xFD9B8 },
	{ 0xE9AE98, 0x3E6F3 },
	{ 0xE9AE99, 0x3D7C4 },
	{ 0xE9AE9A, 0x2E0F6 },
	{ 0xE9AE9B, 0x2E0F9 },
	{ 0xE9AE9C, 0x4DAC9 },
	{ 0xE9AE9D, 0x3D7C5 },
	{ 0xE9AE9E, 0x2E0F8 },
	{ 0xE9AE9F, 0x3D7C0 },
	{ 0xE9AEA0, 0x2E1A2 },
	{ 0xE9AEA1, 0x2E0FB },
	{ 0xE9AEA2, 0x2E1A1 },
	{ 0xE9AEA3, 0x3D7C2 },
	{ 0xE9AEA4, 0x2E0FD },
	{ 0xE9AEA5, 0x2E0FC },
	{ 0xE9AEA6, 0x2E0FA },
	{ 0xE9AEA7, 0x4DAC1 },
	{ 0xE9AEA8, 0x2E0F7 },
	{ 0xE9AEA9, 0x4DABF },
	{ 0xE9AEAA, 0x1F6AF },
	{ 0xE9AEAB, 0x1F6AE },
	{ 0xE9AEAC, 0x4DAC4 },
	{ 0xE9AEAD, 0x1F6B0 },
	{ 0xE9AEAE, 0x1F6AD },
	{ 0xE9AEAF, 0x2E1A3 },
	{ 0xE9AEB0, 0x4DAC5 },
	{ 0xE9AEB1, 0xFDDF6 },
	{ 0xE9AEB3, 0x4DAC3 },
	{ 0xE9AEB5, 0x2E4F2 },
	{ 0xE9AEB6, 0x2E4F5 },
	{ 0xE9AEB7, 0x4DFA6 },
	{ 0xE9AEB8, 0x2E4F3 },
	{ 0xE9AEB9, 0x2E4F7 },
	{ 0xE9AEBA, 0x5E6F9 },
	{ 0xE9AEBB, 0x3D9F4 },
	{ 0xE9AEBC, 0x4DFA2 },
	{ 0xE9AEBD, 0x2E4F8 },
	{ 0xE9AEBE, 0x4DFAA },
	{ 0xE9AEBF, 0x2E4F0 },
	{ 0xE9AF80, 0x1F8A4 },
	{ 0xE9AF81, 0x2E4F1 },
	{ 0xE9AF82, 0x3D9F3 },
	{ 0xE9AF83, 0x2E4EF },
	{ 0xE9AF84, 0x2E4F6 },
	{ 0xE9AF85, 0x3DBF4 },
	{ 0xE9AF86, 0x2E4EE },
	{ 0xE9AF87, 0x2E4ED },
	{ 0xE9AF88, 0x1F8A3 },
	{ 0xE9AF89, 0x1F8A1 },
	{ 0xE9AF8A, 0x1F7FE },
	{ 0xE9AF8B, 0x3D9F6 },
	{ 0xE9AF8C, 0x3D9F5 },
	{ 0xE9AF8D, 0x3D7C3 },
	{ 0xE9AF8F, 0xFE1F2 },
	{ 0xE9AF92, 0x3D9F1 },
	{ 0xE9AF93, 0x2E4F4 },
	{ 0xE9AF94, 0x2E8BC },
	{ 0xE9AF95, 0x2E8C2 },
	{ 0xE9AF96, 0x1F9D6 },
	{ 0xE9AF97, 0x2E8BD },
	{ 0xE9AF98, 0x5EBB3 },
	{ 0xE9AF99, 0x2E8C0 },
	{ 0xE9AF9A, 0x2E8C4 },
	{ 0xE9AF9B, 0x1F9D7 },
	{ 0xE9AF9C, 0x2E8BF },
	{ 0xE9AF9D, 0x4E2DC },
	{ 0xE9AF9E, 0x2E8B7 },
	{ 0xE9AF9F, 0x3DBF5 },
	{ 0xE9AFA0, 0x2E8B6 },
	{ 0xE9AFA1, 0x2E8C3 },
	{ 0xE9AFA2, 0x2E8BA },
	{ 0xE9AFA3, 0x3DBF7 },
	{ 0xE9AFA4, 0x2E8B8 },
	{ 0xE9AFA5, 0x2E8C1 },
	{ 0xE9AFA6, 0x2E8B9 },
	{ 0xE9AFA7, 0x1F9D5 },
	{ 0xE9AFA8, 0x1F9D4 },
	{ 0xE9AFA9, 0x3DBF9 },
	{ 0xE9AFAA, 0x2E8B4 },
	{ 0xE9AFAB, 0x2E8B5 },
	{ 0xE9AFAC, 0x2E8BE },
	{ 0xE9AFAD, 0x4E2E6 },
	{ 0xE9AFAE, 0x3DBFA },
	{ 0xE9AFAF, 0x4E2E8 },
	{ 0xE9AFB0, 0x2E8BB },
	{ 0xE9AFB3, 0xFE4EB },
	{ 0xE9AFB4, 0x4E2D5 },
	{ 0xE9AFB6, 0x3DDEF },
	{ 0xE9AFB7, 0x2EAFA },
	{ 0xE9AFB8, 0x2EAFD },
	{ 0xE9AFB9, 0x3DDF1 },
	{ 0xE9AFBA, 0x4E2D6 },
	{ 0xE9AFBB, 0x3DDE7 },
	{ 0xE9AFBC, 0x3DDE9 },
	{ 0xE9AFBD, 0x1F8A2 },
	{ 0xE9AFBE, 0x3DDEA },
	{ 0xE9AFBF, 0x3DDF4 },
	{ 0xE9B080, 0x3DDF5 },
	{ 0xE9B081, 0x4E5DA },
	{ 0xE9B082, 0x3DDEE },
	{ 0xE9B083, 0x4E5D9 },
	{ 0xE9B084, 0x3DDE8 },
	{ 0xE9B085, 0x2EAFB },
	{ 0xE9B086, 0x2EBA3 },
	{ 0xE9B087, 0x2EBA1 },
	{ 0xE9B088, 0x2EAF9 },
	{ 0xE9B089, 0x2EBA6 },
	{ 0xE9B08A, 0x3DDE6 },
	{ 0xE9B08B, 0x2EAF8 },
	{ 0xE9B08C, 0x3DDF6 },
	{ 0xE9B08D, 0x1FADA },
	{ 0xE9B08E, 0x2EBA2 },
	{ 0xE9B08F, 0x4E5D4 },
	{ 0xE9B090, 0x3DDF3 },
	{ 0xE9B091, 0x4E5D7 },
	{ 0xE9B092, 0x2EAFC },
	{ 0xE9B093, 0x1FAD9 },
	{ 0xE9B094, 0x2EBA5 },
	{ 0xE9B095, 0x3DDF2 },
	{ 0xE9B096, 0x4E5DD },
	{ 0xE9B097, 0x2EBA4 },
	{ 0xE9B09B, 0x3DDF0 },
	{ 0xE9B09C, 0x2ECF7 },
	{ 0xE9B09D, 0x2ECF6 },
	{ 0xE9B09E, 0x5F2D1 },
	{ 0xE9B09F, 0x3DFAC },
	{ 0xE9B0A0, 0x5F2CB },
	{ 0xE9B0A1, 0x2ECFD },
	{ 0xE9B0A2, 0x5F2CE },
	{ 0xE9B0A3, 0x2ECF9 },
	{ 0xE9B0A4, 0x2ECFC },
	{ 0xE9B0A5, 0x1FBCC },
	{ 0xE9B0A6, 0x4E8BB },
	{ 0xE9B0A7, 0x4E8BE },
	{ 0xE9B0A8, 0x2ECFA },
	{ 0xE9B0A9, 0x2ECFB },
	{ 0xE9B0AA, 0x4E8B9 },
	{ 0xE9B0AB, 0x2ECF5 },
	{ 0xE9B0AC, 0x2ECF8 },
	{ 0xE9B0AD, 0x1FBCB },
	{ 0xE9B0AE, 0x3DFAA },
	{ 0xE9B0AF, 0xFE9AA },
	{ 0xE9B0B1, 0x1FCAB },
	{ 0xE9B0B2, 0x2EEE1 },
	{ 0xE9B0B3, 0x2EEDC },
	{ 0xE9B0B4, 0x2EEE0 },
	{ 0xE9B0B5, 0x3E0A5 },
	{ 0xE9B0B6, 0x2EEE3 },
	{ 0xE9B0B7, 0x2EEDF },
	{ 0xE9B0B8, 0x3DFFE },
	{ 0xE9B0B9, 0x2EEDB },
	{ 0xE9B0BA, 0x3E0A3 },
	{ 0xE9B0BB, 0x1FCAD },
	{ 0xE9B0BC, 0x2EEDE },
	{ 0xE9B0BD, 0x2EEE2 },
	{ 0xE9B0BE, 0x1FCAC },
	{ 0xE9B0BF, 0x2EED9 },
	{ 0xE9B180, 0x2EAFE },
	{ 0xE9B181, 0x2EEDD },
	{ 0xE9B182, 0x4EAA3 },
	{ 0xE9B183, 0x5F5AD },
	{ 0xE9B184, 0x2EEDA },
	{ 0xE9B185, 0x3E0A2 },
	{ 0xE9B186, 0x2EED7 },
	{ 0xE9B187, 0xFEABE },
	{ 0xE9B188, 0x2EED8 },
	{ 0xE9B189, 0x1FCAA },
	{ 0xE9B18A, 0x2EFE8 },
	{ 0xE9B18B, 0x2EFEA },
	{ 0xE9B18C, 0x2EFED },
	{ 0xE9B18D, 0x2EFE9 },
	{ 0xE9B18E, 0x2EFEE },
	{ 0xE9B18F, 0x3E0E5 },
	{ 0xE9B190, 0x2EFE7 },
	{ 0xE9B191, 0x3E0E6 },
	{ 0xE9B192, 0x2EFE5 },
	{ 0xE9B193, 0x3E0E8 },
	{ 0xE9B194, 0x1FCD7 },
	{ 0xE9B195, 0x2EFEB },
	{ 0xE9B196, 0x1FCD9 },
	{ 0xE9B197, 0x1FCD8 },
	{ 0xE9B198, 0x2EFE6 },
	{ 0xE9B199, 0x2EFEC },
	{ 0xE9B19D, 0x3E1B2 },
	{ 0xE9B19E, 0x2F0E8 },
	{ 0xE9B19F, 0x1FCF8 },
	{ 0xE9B1A0, 0x2F0E9 },
	{ 0xE9B1A1, 0x3E1B3 },
	{ 0xE9B1A2, 0x2F0E7 },
	{ 0xE9B1A3, 0x2F0E4 },
	{ 0xE9B1A4, 0x4ECCA },
	{ 0xE9B1A5, 0x3E1B4 },
	{ 0xE9B1A6, 0x2F0E6 },
	{ 0xE9B1A7, 0x2F0E5 },
	{ 0xE9B1A8, 0x2F1C9 },
	{ 0xE9B1AC, 0x3E1D9 },
	{ 0xE9B1AD, 0x2F1CB },
	{ 0xE9B1AE, 0x2F1CA },
	{ 0xE9B1AF, 0x3E1DB },
	{ 0xE9B1B1, 0x2F1E9 },
	{ 0xE9B1B2, 0x5FAD3 },
	{ 0xE9B1B3, 0x2F1E8 },
	{ 0xE9B1B4, 0x2F1E7 },
	{ 0xE9B1B5, 0x2F1EA },
	{ 0xE9B1B6, 0x3E1F5 },
	{ 0xE9B1B7, 0x1FDC0 },
	{ 0xE9B1B8, 0x1FDC1 },
	{ 0xE9B1B9, 0x2F2B8 },
	{ 0xE9B1BA, 0x2F2BC },
	{ 0xE9B1BB, 0x3E2C1 },
	{ 0xE9B3A5, 0x1DEA4 },
	{ 0xE9B3A6, 0x2C1D4 },
	{ 0xE9B3A7, 0x2C8F3 },
	{ 0xE9B3A8, 0x3C5E4 },
	{ 0xE9B3A9, 0x1E7ED },
	{ 0xE9B3AA, 0x2C8F1 },
	{ 0xE9B3AB, 0x3C5E6 },
	{ 0xE9B3AC, 0x3AFC2 },
	{ 0xE9B3AD, 0x2C8F2 },
	{ 0xE9B3AE, 0x3C5E8 },
	{ 0xE9B3AF, 0x3C5E7 },
	{ 0xE9B3B1, 0x2CFCA },
	{ 0xE9B3B2, 0x2CFCB },
	{ 0xE9B3B3, 0x1EBFA },
	{ 0xE9B3B4, 0x1EBF8 },
	{ 0xE9B3B5, 0x2CFCC },
	{ 0xE9B3B6, 0x1EBF9 },
	{ 0xE9B3B7, 0x2D6B3 },
	{ 0xE9B3B8, 0x3D0A7 },
	{ 0xE9B3B9, 0x2D6B6 },
	{ 0xE9B3BA, 0x2D6B0 },
	{ 0xE9B3BB, 0x2D6B7 },
	{ 0xE9B3BC, 0x2D6AF },
	{ 0xE9B3BD, 0x2D6B1 },
	{ 0xE9B3BE, 0x3D0AA },
	{ 0xE9B3BF, 0x2D6B2 },
	{ 0xE9B480, 0x2D6B5 },
	{ 0xE9B481, 0x3D0A4 },
	{ 0xE9B482, 0x3D0AB },
	{ 0xE9B483, 0x1F0AA },
	{ 0xE9B484, 0x2D6BA },
	{ 0xE9B485, 0x2D6B9 },
	{ 0xE9B486, 0x1F0A8 },
	{ 0xE9B487, 0x2D6B4 },
	{ 0xE9B488, 0x2D6B8 },
	{ 0xE9B489, 0x1F0A9 },
	{ 0xE9B48A, 0x3D4AD },
	{ 0xE9B48B, 0x4CFC2 },
	{ 0xE9B48C, 0x3D0A5 },
	{ 0xE9B48D, 0x3D0A2 },
	{ 0xE9B48F, 0x3D4AA },
	{ 0xE9B490, 0x2DCB8 },
	{ 0xE9B491, 0x4D5D2 },
	{ 0xE9B492, 0x1F3BA },
	{ 0xE9B493, 0x3D4AC },
	{ 0xE9B494, 0x2DCB3 },
	{ 0xE9B495, 0x1F3B6 },
	{ 0xE9B496, 0x3D4B6 },
	{ 0xE9B497, 0x2DCB0 },
	{ 0xE9B498, 0x2DCB6 },
	{ 0xE9B499, 0x2DCB9 },
	{ 0xE9B49A, 0x3D4B3 },
	{ 0xE9B49B, 0x1F3BB },
	{ 0xE9B49C, 0x4DACE },
	{ 0xE9B49D, 0x2DCB5 },
	{ 0xE9B49E, 0x2DCB2 },
	{ 0xE9B49F, 0x2DCBA },
	{ 0xE9B4A0, 0x2DCB1 },
	{ 0xE9B4A1, 0x3D4B7 },
	{ 0xE9B4A2, 0x2DCB7 },
	{ 0xE9B4A3, 0x1F3B7 },
	{ 0xE9B4A4, 0x3D4A9 },
	{ 0xE9B4A5, 0x2DCAF },
	{ 0xE9B4A6, 0x1F3B8 },
	{ 0xE9B4A7, 0x3D4B5 },
	{ 0xE9B4A8, 0x1F3B9 },
	{ 0xE9B4A9, 0x2DCB4 },
	{ 0xE9B4AA, 0x3D4B2 },
	{ 0xE9B4AD, 0x2E1B5 },
	{ 0xE9B4AE, 0x2E1A8 },
	{ 0xE9B4AF, 0x2E1A9 },
	{ 0xE9B4B0, 0x2E1AC },
	{ 0xE9B4B1, 0x2E1AA },
	{ 0xE9B4B2, 0x4DAD5 },
	{ 0xE9B4B3, 0x2E1A4 },
	{ 0xE9B4B4, 0x4DAD6 },
	{ 0xE9B4B5, 0x3D7CD },
	{ 0xE9B4B6, 0x2E1A7 },
	{ 0xE9B4B7, 0x2E1B1 },
	{ 0xE9B4B8, 0x2E1AB },
	{ 0xE9B4B9, 0x3D7C8 },
	{ 0xE9B4BA, 0x4DACF },
	{ 0xE9B4BB, 0x1F6B1 },
	{ 0xE9B4BC, 0x4DACD },
	{ 0xE9B4BD, 0x2E1B3 },
	{ 0xE9B4BE, 0x2E1B0 },
	{ 0xE9B4BF, 0x1F6B2 },
	{ 0xE9B580, 0x2E1B2 },
	{ 0xE9B581, 0x2E1A5 },
	{ 0xE9B582, 0x2E1AE },
	{ 0xE9B583, 0x2E1AF },
	{ 0xE9B584, 0x3D7CA },
	{ 0xE9B585, 0x2E1AD },
	{ 0xE9B587, 0xFDEA4 },
	{ 0xE9B589, 0x3E6F5 },
	{ 0xE9B58A, 0x2E4FC },
	{ 0xE9B58B, 0x2E4FE },
	{ 0xE9B58C, 0x2E5A3 },
	{ 0xE9B58D, 0x3D9F9 },
	{ 0xE9B58E, 0x3D9FB },
	{ 0xE9B58F, 0x2E4FB },
	{ 0xE9B590, 0x3D9FD },
	{ 0xE9B591, 0x1F8A5 },
	{ 0xE9B592, 0x2E5A5 },
	{ 0xE9B593, 0x2E4FA },
	{ 0xE9B594, 0x2E5A6 },
	{ 0xE9B595, 0x3D9FE },
	{ 0xE9B596, 0x2E5A2 },
	{ 0xE9B597, 0x2E5A4 },
	{ 0xE9B598, 0x2E5A8 },
	{ 0xE9B599, 0x2E5A1 },
	{ 0xE9B59A, 0x2E5A9 },
	{ 0xE9B59B, 0x2E4FD },
	{ 0xE9B59C, 0x2E4F9 },
	{ 0xE9B59D, 0x1F8A6 },
	{ 0xE9B59E, 0x3DAA2 },
	{ 0xE9B59F, 0x2E5A7 },
	{ 0xE9B5A0, 0x1F8A7 },
	{ 0xE9B5A1, 0x1F9D9 },
	{ 0xE9B5A2, 0x4DFB4 },
	{ 0xE9B5A3, 0x3D9FA },
	{ 0xE9B5A4, 0xFE1F7 },
	{ 0xE9B5A6, 0x3DBFD },
	{ 0xE9B5A7, 0x2E1A6 },
	{ 0xE9B5A8, 0x2E8DE },
	{ 0xE9B5A9, 0x2E8D5 },
	{ 0xE9B5AA, 0x1F9DB },
	{ 0xE9B5AB, 0x2E8D1 },
	{ 0xE9B5AC, 0x1F9DC },
	{ 0xE9B5AD, 0x3DCA7 },
	{ 0xE9B5AE, 0x3DCA2 },
	{ 0xE9B5AF, 0x2E8DA },
	{ 0xE9B5B0, 0x2E8D4 },
	{ 0xE9B5B1, 0x2E8CA },
	{ 0xE9B5B2, 0x1F9DA },
	{ 0xE9B5B3, 0x2E8D7 },
	{ 0xE9B5B4, 0x2E8D2 },
	{ 0xE9B5B5, 0x2E8D3 },
	{ 0xE9B5B6, 0x3DCA5 },
	{ 0xE9B5B7, 0x2E8C5 },
	{ 0xE9B5B8, 0x2E8CC },
	{ 0xE9B5B9, 0x2E8DB },
	{ 0xE9B5BA, 0x3DBFE },
	{ 0xE9B5BB, 0x2E8D8 },
	{ 0xE9B5BC, 0x5EBBF },
	{ 0xE9B5BD, 0x2E8D0 },
	{ 0xE9B5BE, 0x3DCA6 },
	{ 0xE9B5BF, 0x2E8DC },
	{ 0xE9B680, 0x2E8CB },
	{ 0xE9B681, 0x2E8C6 },
	{ 0xE9B682, 0x2E8D9 },
	{ 0xE9B683, 0x3DCA4 },
	{ 0xE9B684, 0x2E8C8 },
	{ 0xE9B685, 0x2E8D6 },
	{ 0xE9B686, 0x2E8CD },
	{ 0xE9B687, 0x2E8DD },
	{ 0xE9B688, 0x2E8C9 },
	{ 0xE9B689, 0x1F9D8 },
	{ 0xE9B68A, 0x2E8C7 },
	{ 0xE9B68B, 0x2E8CE },
	{ 0xE9B68C, 0x2E8CF },
	{ 0xE9B690, 0x2EBAD },
	{ 0xE9B691, 0x3DCA3 },
	{ 0xE9B692, 0x2EBAB },
	{ 0xE9B693, 0x4E5E9 },
	{ 0xE9B694, 0x2EBB0 },
	{ 0xE9B695, 0x3DDF9 },
	{ 0xE9B696, 0x2EBBC },
	{ 0xE9B697, 0x2EBB3 },
	{ 0xE9B698, 0x2EBAC },
	{ 0xE9B699, 0x2EBA8 },
	{ 0xE9B69A, 0x2EBB5 },
	{ 0xE9B69B, 0x2EBAE },
	{ 0xE9B69C, 0x2EBB1 },
	{ 0xE9B69D, 0x2EBAA },
	{ 0xE9B69E, 0x2EBB8 },
	{ 0xE9B69F, 0x2EBA7 },
	{ 0xE9B6A0, 0x2EBAF },
	{ 0xE9B6A1, 0x2EBB4 },
	{ 0xE9B6A2, 0x2EBB6 },
	{ 0xE9B6A3, 0x2EBB9 },
	{ 0xE9B6A4, 0x2EBA9 },
	{ 0xE9B6A5, 0x3DDFA },
	{ 0xE9B6A6, 0x2EBBD },
	{ 0xE9B6A7, 0x2EBBE },
	{ 0xE9B6A8, 0x2EBB7 },
	{ 0xE9B6A9, 0x2EBBB },
	{ 0xE9B6AA, 0x2EBB2 },
	{ 0xE9B6AC, 0x2EDAF },
	{ 0xE9B6AD, 0x2EDB2 },
	{ 0xE9B6AE, 0x3DFB5 },
	{ 0xE9B6AF, 0x1FBCD },
	{ 0xE9B6B0, 0x3DFB1 },
	{ 0xE9B6B1, 0x2EDB1 },
	{ 0xE9B6B2, 0x2EDB6 },
	{ 0xE9B6B3, 0x2EDB4 },
	{ 0xE9B6B4, 0x1FBCE },
	{ 0xE9B6B5, 0x2EDAB },
	{ 0xE9B6B6, 0x2EDA1 },
	{ 0xE9B6B7, 0x2ECFE },
	{ 0xE9B6B8, 0x1FBD0 },
	{ 0xE9B6B9, 0x2EDAD },
	{ 0xE9B6BA, 0x2EDAE },
	{ 0xE9B6BB, 0x2EDAA },
	{ 0xE9B6BC, 0x2EDA2 },
	{ 0xE9B6BD, 0x3DFB2 },
	{ 0xE9B6BE, 0x2EDA7 },
	{ 0xE9B6BF, 0x2EBBA },
	{ 0xE9B780, 0x4E8C3 },
	{ 0xE9B781, 0x2EDA3 },
	{ 0xE9B782, 0x1FBCF },
	{ 0xE9B783, 0x2EDA9 },
	{ 0xE9B784, 0x3DFB6 },
	{ 0xE9B785, 0x2EDA8 },
	{ 0xE9B787, 0x2EDA4 },
	{ 0xE9B788, 0x2EDB0 },
	{ 0xE9B789, 0x4E8C4 },
	{ 0xE9B78A, 0x2EDA5 },
	{ 0xE9B78B, 0x2EEE8 },
	{ 0xE9B78C, 0x2EDB3 },
	{ 0xE9B78D, 0x2EDB5 },
	{ 0xE9B78E, 0x2EDAC },
	{ 0xE9B78F, 0x2EDA6 },
	{ 0xE9B790, 0x2EEE9 },
	{ 0xE9B791, 0x2EEEB },
	{ 0xE9B792, 0x2EEE5 },
	{ 0xE9B793, 0x1FCAE },
	{ 0xE9B794, 0x4EAA5 },
	{ 0xE9B795, 0x2EEF2 },
	{ 0xE9B796, 0x2EEF0 },
	{ 0xE9B797, 0x1FCAF },
	{ 0xE9B798, 0x2EEEF },
	{ 0xE9B799, 0x2EEEE },
	{ 0xE9B79A, 0x2EEE7 },
	{ 0xE9B79B, 0x2EEE4 },
	{ 0xE9B79C, 0x2EEEA },
	{ 0xE9B79D, 0x2EEF3 },
	{ 0xE9B79E, 0x2EEE6 },
	{ 0xE9B79F, 0x2EEEC },
	{ 0xE9B7A0, 0x5F5C5 },
	{ 0xE9B7A1, 0x2EFF7 },
	{ 0xE9B7A2, 0x2EFFC },
	{ 0xE9B7A3, 0x2EFF2 },
	{ 0xE9B7A4, 0x2EFF5 },
	{ 0xE9B7A5, 0x1FCDA },
	{ 0xE9B7A6, 0x2EFF9 },
	{ 0xE9B7A7, 0x4EBC6 },
	{ 0xE9B7A8, 0x2F0A2 },
	{ 0xE9B7A9, 0x2EEED },
	{ 0xE9B7AA, 0x4EBCA },
	{ 0xE9B7AB, 0x2EFF3 },
	{ 0xE9B7AC, 0x2EFFD },
	{ 0xE9B7AD, 0x2F0A3 },
	{ 0xE9B7AE, 0x2EFF8 },
	{ 0xE9B7AF, 0x2EFF1 },
	{ 0xE9B7B0, 0x2EFFB },
	{ 0xE9B7B1, 0x4EBCB },
	{ 0xE9B7B2, 0x2EFFA },
	{ 0xE9B7B3, 0x2F0A1 },
	{ 0xE9B7B4, 0x2EFFE },
	{ 0xE9B7B5, 0x2EEF1 },
	{ 0xE9B7B6, 0x2EFF6 },
	{ 0xE9B7B7, 0x2EFF0 },
	{ 0xE9B7B8, 0x2EFF4 },
	{ 0xE9B7B9, 0x1FCF9 },
	{ 0xE9B7BA, 0x1FCFA },
	{ 0xE9B7BB, 0x2EFEF },
	{ 0xE9B7BC, 0x3E0EC },
	{ 0xE9B7BD, 0x2F0F4 },
	{ 0xE9B7BE, 0x2F0EB },
	{ 0xE9B7BF, 0x2F0F3 },
	{ 0xE9B880, 0x2F0F0 },
	{ 0xE9B881, 0x2F0F1 },
	{ 0xE9B882, 0x2F0EA },
	{ 0xE9B883, 0x2F0ED },
	{ 0xE9B884, 0x2F0F5 },
	{ 0xE9B885, 0x2F0EF },
	{ 0xE9B886, 0x2F0EE },
	{ 0xE9B887, 0x2F0EC },
	{ 0xE9B888, 0x3E1B5 },
	{ 0xE9B889, 0x2F0F2 },
	{ 0xE9B88A, 0x4ECD6 },
	{ 0xE9B88B, 0x2F1CC },
	{ 0xE9B88C, 0x4EDBA },
	{ 0xE9B88D, 0x2F1CD },
	{ 0xE9B88E, 0x3E1DD },
	{ 0xE9B88F, 0x2F1CF },
	{ 0xE9B890, 0x2F1CE },
	{ 0xE9B891, 0x2F1D1 },
	{ 0xE9B892, 0x2F1D0 },
	{ 0xE9B893, 0x2F1EC },
	{ 0xE9B894, 0x2F1EB },
	{ 0xE9B895, 0x2F2A7 },
	{ 0xE9B896, 0x3E2A9 },
	{ 0xE9B897, 0x2F2A8 },
	{ 0xE9B898, 0x3E2B0 },
	{ 0xE9B899, 0x2F2B4 },
	{ 0xE9B89A, 0x1FDC5 },
	{ 0xE9B89B, 0x1FDC9 },
	{ 0xE9B89C, 0x3E2B8 },
	{ 0xE9B89D, 0x2F2BD },
	{ 0xE9B89E, 0x1FDCA },
	{ 0xE9B9B5, 0x1DEA5 },
	{ 0xE9B9B6, 0x4CFC8 },
	{ 0xE9B9B7, 0x5DADB },
	{ 0xE9B9B9, 0x1FADB },
	{ 0xE9B9BA, 0x2EDB7 },
	{ 0xE9B9BB, 0x3DFB7 },
	{ 0xE9B9BC, 0x1FCFB },
	{ 0xE9B9BD, 0x1FCFC },
	{ 0xE9B9BF, 0x1DEA6 },
	{ 0xE9BA80, 0x2C8F4 },
	{ 0xE9BA81, 0x3C5E9 },
	{ 0xE9BA82, 0x1E7EE },
	{ 0xE9BA83, 0x2D6BB },
	{ 0xE9BA84, 0x3D0AC },
	{ 0xE9BA85, 0x3D4B9 },
	{ 0xE9BA86, 0x2DCBC },
	{ 0xE9BA87, 0x2DCBD },
	{ 0xE9BA88, 0x2DCBB },
	{ 0xE9BA89, 0x2E1B7 },
	{ 0xE9BA8A, 0x2E1B6 },
	{ 0xE9BA8B, 0x1F6B3 },
	{ 0xE9BA8C, 0x2E5AB },
	{ 0xE9BA8D, 0x2E1B8 },
	{ 0xE9BA8E, 0x2E5AA },
	{ 0xE9BA8F, 0x4DFBA },
	{ 0xE9BA90, 0x3DAA4 },
	{ 0xE9BA91, 0x2E8E0 },
	{ 0xE9BA92, 0x1F9DD },
	{ 0xE9BA93, 0x1F9DF },
	{ 0xE9BA94, 0x2E8DF },
	{ 0xE9BA95, 0x3DCA9 },
	{ 0xE9BA96, 0x4E2F5 },
	{ 0xE9BA97, 0x1F9DE },
	{ 0xE9BA98, 0x3DEA1 },
	{ 0xE9BA99, 0x2EBBF },
	{ 0xE9BA9A, 0x2EBC1 },
	{ 0xE9BA9B, 0x2EBC0 },
	{ 0xE9BA9C, 0x2EDB8 },
	{ 0xE9BA9D, 0x1FBD1 },
	{ 0xE9BA9E, 0x3DFBA },
	{ 0xE9BA9F, 0x1FCDB },
	{ 0xE9BAA0, 0x2F0F6 },
	{ 0xE9BAA1, 0x2F1D2 },
	{ 0xE9BAA2, 0x3E2B1 },
	{ 0xE9BAA3, 0x3E2BF },
	{ 0xE9BAA4, 0x2F2C1 },
	{ 0xE9BAA5, 0x1DEA7 },
	{ 0xE9BAA6, 0x3A5C7 },
	{ 0xE9BAA7, 0x2CFCD },
	{ 0xE9BAA8, 0x4CFCC },
	{ 0xE9BAA9, 0x1F0AB },
	{ 0xE9BAAA, 0x3D0AF },
	{ 0xE9BAAB, 0x3D0AE },
	{ 0xE9BAAC, 0x3D4BA },
	{ 0xE9BAAD, 0x2DCBF },
	{ 0xE9BAAE, 0x2DCBE },
	{ 0xE9BAAF, 0x3D7D0 },
	{ 0xE9BAB0, 0x2E1B9 },
	{ 0xE9BAB1, 0x3DAA6 },
	{ 0xE9BAB2, 0x3DAA5 },
	{ 0xE9BAB3, 0x4E2FE },
	{ 0xE9BAB4, 0x1F9E0 },
	{ 0xE9BAB5, 0x1FADC },
	{ 0xE9BAB6, 0x2EEF4 },
	{ 0xE9BAB7, 0x2F2B9 },
	{ 0xE9BABB, 0x1DEA8 },
	{ 0xE9BABC, 0x1EBFB },
	{ 0xE9BABD, 0x3CBA2 },
	{ 0xE9BABE, 0x1F0AC },
	{ 0xE9BABF, 0xFE1FC },
	{ 0xE9BB80, 0x2E8E1 },
	{ 0xE9BB81, 0x3DEA2 },
	{ 0xE9BB82, 0x2F0A4 },
	{ 0xE9BB83, 0x1E3A7 },
	{ 0xE9BB84, 0x3B9EA },
	{ 0xE9BB85, 0x3D4BC },
	{ 0xE9BB86, 0x3D4BB },
	{ 0xE9BB87, 0x4DADD },
	{ 0xE9BB88, 0x2E1BA },
	{ 0xE9BB8A, 0x3DAA8 },
	{ 0xE9BB8B, 0x4DFBE },
	{ 0xE9BB8C, 0x1FDB1 },
	{ 0xE9BB8D, 0x1E3A8 },
	{ 0xE9BB8E, 0x1F0AD },
	{ 0xE9BB8F, 0x1F6B4 },
	{ 0xE9BB90, 0x2F0A5 },
	{ 0xE9BB91, 0x1E3A9 },
	{ 0xE9BB92, 0x3B9EB },
	{ 0xE9BB93, 0x2D6BC },
	{ 0xE9BB94, 0x1F3BD },
	{ 0xE9BB95, 0x2DCC0 },
	{ 0xE9BB96, 0x2DCC1 },
	{ 0xE9BB97, 0x3D4BD },
	{ 0xE9BB98, 0x1F3BC },
	{ 0xE9BB99, 0x4D5E0 },
	{ 0xE9BB9A, 0x2E1BB },
	{ 0xE9BB9B, 0x1F6B8 },
	{ 0xE9BB9C, 0x1F6B6 },
	{ 0xE9BB9D, 0x1F6B7 },
	{ 0xE9BB9E, 0x1F6B5 },
	{ 0xE9BB9F, 0x2E5AC },
	{ 0xE9BBA0, 0x1F8A8 },
	{ 0xE9BBA2, 0x4E3A4 },
	{ 0xE9BBA3, 0x3DCAA },
	{ 0xE9BBA4, 0x2EBC3 },
	{ 0xE9BBA5, 0x2EBC2 },
	{ 0xE9BBA6, 0x2EBC5 },
	{ 0xE9BBA7, 0x2EBC4 },
	{ 0xE9BBA8, 0x1FADD },
	{ 0xE9BBAB, 0x2EDB9 },
	{ 0xE9BBAC, 0x4E8D6 },
	{ 0xE9BBAD, 0x2EDBB },
	{ 0xE9BBAE, 0x2EDBA },
	{ 0xE9BBAF, 0x1FBD2 },
	{ 0xE9BBB0, 0x2EEF5 },
	{ 0xE9BBB1, 0x3E0A9 },
	{ 0xE9BBB2, 0x2F0A6 },
	{ 0xE9BBB3, 0x2F0A7 },
	{ 0xE9BBB4, 0x1FCDC },
	{ 0xE9BBB5, 0x2F1D3 },
	{ 0xE9BBB6, 0x2F1ED },
	{ 0xE9BBB7, 0x1FDC2 },
	{ 0xE9BBB8, 0x4EEC3 },
	{ 0xE9BBB9, 0x2C1D5 },
	{ 0xE9BBBA, 0x2DCC2 },
	{ 0xE9BBBB, 0x2E1BC },
	{ 0xE9BBBC, 0x2E8E2 },
	{ 0xE9BBBD, 0x2C8F5 },
	{ 0xE9BBBE, 0x3A7F2 },
	{ 0xE9BBBF, 0x2E1BD },
	{ 0xE9BC80, 0x2E5AE },
	{ 0xE9BC81, 0x2E5AD },
	{ 0xE9BC82, 0x3DAA9 },
	{ 0xE9BC83, 0x3DCAD },
	{ 0xE9BC84, 0x3DCAE },
	{ 0xE9BC85, 0x3DFBC },
	{ 0xE9BC86, 0x2F0A8 },
	{ 0xE9BC87, 0x1FCFD },
	{ 0xE9BC88, 0x3E1DF },
	{ 0xE9BC89, 0x2F1D4 },
	{ 0xE9BC8A, 0x2F1EE },
	{ 0xE9BC8E, 0x1E7EF },
	{ 0xE9BC8F, 0x2D6BD },
	{ 0xE9BC90, 0x2D6BE },
	{ 0xE9BC91, 0x4CFD6 },
	{ 0xE9BC92, 0x2DCC3 },
	{ 0xE9BC93, 0x1E7F0 },
	{ 0xE9BC94, 0x3C5EA },
	{ 0xE9BC95, 0x1F8A9 },
	{ 0xE9BC96, 0x2E5AF },
	{ 0xE9BC97, 0x3DCB0 },
	{ 0xE9BC98, 0x2EDBD },
	{ 0xE9BC99, 0x1FBD3 },
	{ 0xE9BC9A, 0x2EDBE },
	{ 0xE9BC9B, 0x2EDBC },
	{ 0xE9BC9C, 0x2F0A9 },
	{ 0xE9BC9D, 0x3E1E0 },
	{ 0xE9BC9E, 0x2F0F7 },
	{ 0xE9BC9F, 0x4EDC8 },
	{ 0xE9BCA0, 0x1E7F1 },
	{ 0xE9BCA2, 0x2E1C0 },
	{ 0xE9BCA3, 0x2E1BF },
	{ 0xE9BCA4, 0x2E1BE },
	{ 0xE9BCA5, 0x2E5B0 },
	{ 0xE9BCA6, 0x3DAAB },
	{ 0xE9BCA7, 0x3DAAA },
	{ 0xE9BCA8, 0x2E5B4 },
	{ 0xE9BCA9, 0x2E5B3 },
	{ 0xE9BCAA, 0x2E5B2 },
	{ 0xE9BCAB, 0x2E5B1 },
	{ 0xE9BCAC, 0x1F8AA },
	{ 0xE9BCAD, 0x2E8E3 },
	{ 0xE9BCAE, 0x2EBC7 },
	{ 0xE9BCAF, 0x1FADE },
	{ 0xE9BCB0, 0x2EBC6 },
	{ 0xE9BCB1, 0x2EDBF },
	{ 0xE9BCB2, 0x2EEF8 },
	{ 0xE9BCB3, 0x2EEF7 },
	{ 0xE9BCB4, 0x1FCB0 },
	{ 0xE9BCB5, 0x2EEF6 },
	{ 0xE9BCB6, 0x2F0AC },
	{ 0xE9BCB7, 0x2F0AB },
	{ 0xE9BCB8, 0x2F0AA },
	{ 0xE9BCB9, 0x3E0ED },
	{ 0xE9BCBA, 0x4EEC4 },
	{ 0xE9BCBB, 0x1EBFC },
	{ 0xE9BCBC, 0x4D5E3 },
	{ 0xE9BCBD, 0x2DCC4 },
	{ 0xE9BCBE, 0x1F6B9 },
	{ 0xE9BCBF, 0x4DAE4 },
	{ 0xE9BD80, 0x2E8E4 },
	{ 0xE9BD81, 0x2E8E5 },
	{ 0xE9BD82, 0x2EEF9 },
	{ 0xE9BD83, 0x2F0AD },
	{ 0xE9BD84, 0x4EBDC },
	{ 0xE9BD85, 0x3E1BB },
	{ 0xE9BD86, 0x2F0F8 },
	{ 0xE9BD87, 0x2F1D5 },
	{ 0xE9BD88, 0x2F2A9 },
	{ 0xE9BD89, 0x2F2C3 },
	{ 0xE9BD8A, 0x1EBFD },
	{ 0xE9BD8B, 0x1F6BA },
	{ 0xE9BD8C, 0x2E5B5 },
	{ 0xE9BD8D, 0x2E8E6 },
	{ 0xE9BD8E, 0x2EDC0 },
	{ 0xE9BD8F, 0x2F0AE },
	{ 0xE9BD90, 0x3A3F0 },
	{ 0xE9BD92, 0x1F0AF },
	{ 0xE9BD93, 0x3D4BE },
	{ 0xE9BD94, 0x2E1C1 },
	{ 0xE9BD95, 0x2E5B6 },
	{ 0xE9BD96, 0x2E8E7 },
	{ 0xE9BD97, 0x2E8E8 },
	{ 0xE9BD98, 0x2E8E9 },
	{ 0xE9BD99, 0x2EBCC },
	{ 0xE9BD9A, 0x3DEA4 },
	{ 0xE9BD9B, 0x2EBC8 },
	{ 0xE9BD9C, 0x1FBD4 },
	{ 0xE9BD9D, 0x2EBCB },
	{ 0xE9BD9E, 0x2EBCA },
	{ 0xE9BD9F, 0x1FADF },
	{ 0xE9BDA0, 0x2EBC9 },
	{ 0xE9BDA1, 0x1FAE1 },
	{ 0xE9BDA3, 0x1FAE0 },
	{ 0xE9BDA4, 0x2EDC2 },
	{ 0xE9BDA5, 0x2EDC1 },
	{ 0xE9BDA6, 0x1FBD5 },
	{ 0xE9BDA7, 0x1FBD6 },
	{ 0xE9BDA8, 0x4E8E0 },
	{ 0xE9BDA9, 0x3DFBE },
	{ 0xE9BDAA, 0x1FCB2 },
	{ 0xE9BDAB, 0x2EEFA },
	{ 0xE9BDAC, 0x1FCB1 },
	{ 0xE9BDAD, 0x4EBE1 },
	{ 0xE9BDAE, 0x2F0B1 },
	{ 0xE9BDAF, 0x2F0B2 },
	{ 0xE9BDB0, 0x2F0B0 },
	{ 0xE9BDB1, 0x2F0AF },
	{ 0xE9BDB2, 0x1FDA1 },
	{ 0xE9BDB3, 0x4ECE4 },
	{ 0xE9BDB4, 0x2F0F9 },
	{ 0xE9BDB5, 0x2F0FA },
	{ 0xE9BDB6, 0x2F0FB },
	{ 0xE9BDB7, 0x1FCFE },
	{ 0xE9BDB8, 0x2F1D6 },
	{ 0xE9BDB9, 0x2F1D9 },
	{ 0xE9BDBA, 0x2F1D8 },
	{ 0xE9BDBB, 0x2F1D7 },
	{ 0xE9BDBC, 0x3E2B3 },
	{ 0xE9BDBD, 0x4EEC5 },
	{ 0xE9BDBE, 0x2F2C2 },
	{ 0xE9BE8D, 0x1F3BE },
	{ 0xE9BE8E, 0x3D7D5 },
	{ 0xE9BE8F, 0x4E3AD },
	{ 0xE9BE90, 0x1F8B2 },
	{ 0xE9BE91, 0x2EBCD },
	{ 0xE9BE92, 0x2EDC3 },
	{ 0xE9BE93, 0x3E0AB },
	{ 0xE9BE94, 0x1FCB3 },
	{ 0xE9BE95, 0x2EEFB },
	{ 0xE9BE96, 0x4EED5 },
	{ 0xE9BE97, 0x3E2C2 },
	{ 0xE9BE98, 0x2F2C4 },
	{ 0xE9BE99, 0xFA1D9 },
	{ 0xE9BE9C, 0x1F3BF },
	{ 0xE9BE9D, 0x3DEC7 },
	{ 0xE9BE9E, 0x4EEB3 },
	{ 0xE9BEA0, 0x2E1C2 },
	{ 0xE9BEA1, 0x3DFBF },
	{ 0xE9BEA2, 0x2EEFC },
	{ 0xE9BEA3, 0x3E1E1 },
	{ 0xE9BEA4, 0x2F1EF },
	{ 0xE9BEA5, 0x3E1F7 },
	{ 0xEFA8A8, 0xFD8CC },
	{ 0xEFB8B0, 0x1A1AB },
	{ 0xEFB8B1, 0x1A1B6 },
	{ 0xEFB8B2, 0x1A1B8 },
	{ 0xEFB8B5, 0x1A1C0 },
	{ 0xEFB8B6, 0x1A1C1 },
	{ 0xEFB8B7, 0x1A1C4 },
	{ 0xEFB8B8, 0x1A1C5 },
	{ 0xEFB8B9, 0x1A1C8 },
	{ 0xEFB8BA, 0x1A1C9 },
	{ 0xEFB8BB, 0x1A1CC },
	{ 0xEFB8BC, 0x1A1CD },
	{ 0xEFB8BD, 0x1A1D0 },
	{ 0xEFB8BE, 0x1A1D1 },
	{ 0xEFB8BF, 0x1A1D4 },
	{ 0xEFB980, 0x1A1D5 },
	{ 0xEFB981, 0x1A1D8 },
	{ 0xEFB982, 0x1A1D9 },
	{ 0xEFB983, 0x1A1DC },
	{ 0xEFB984, 0x1A1DD },
	{ 0xEFB989, 0x1A2A7 },
	{ 0xEFB98A, 0x1A2A8 },
	{ 0xEFB98B, 0x1A2AB },
	{ 0xEFB98C, 0x1A2AC },
	{ 0xEFB98D, 0x1A2A9 },
	{ 0xEFB98E, 0x1A2AA },
	{ 0xEFB990, 0x1A1AE },
	{ 0xEFB991, 0x1A1AF },
	{ 0xEFB992, 0x1A1B0 },
	{ 0xEFB994, 0x1A1B2 },
	{ 0xEFB995, 0x1A1B3 },
	{ 0xEFB996, 0x1A1B4 },
	{ 0xEFB997, 0x1A1B5 },
	{ 0xEFB999, 0x1A1DE },
	{ 0xEFB99A, 0x1A1DF },
	{ 0xEFB99B, 0x1A1E0 },
	{ 0xEFB99C, 0x1A1E1 },
	{ 0xEFB99D, 0x1A1E2 },
	{ 0xEFB99E, 0x1A1E3 },
	{ 0xEFB99F, 0x1A2AD },
	{ 0xEFB9A0, 0x1A2AE },
	{ 0xEFB9A1, 0x1A2AF },
	{ 0xEFB9A2, 0x1A2BF },
	{ 0xEFB9A3, 0x1A2C0 },
	{ 0xEFB9A4, 0x1A2C1 },
	{ 0xEFB9A5, 0x1A2C3 },
	{ 0xEFB9A6, 0x1A2C2 },
	{ 0xEFB9A8, 0x1A2E2 },
	{ 0xEFB9A9, 0x1A2EC },
	{ 0xEFB9AA, 0x1A2ED },
	{ 0xEFB9AB, 0x1A2EE },
	{ 0xEFBC81, 0x1A1AA },
	{ 0xEFBC83, 0x1A1EC },
	{ 0xEFBC84, 0x1A2E3 },
	{ 0xEFBC85, 0x1A2E8 },
	{ 0xEFBC86, 0x1A1ED },
	{ 0xEFBC88, 0x1A1BE },
	{ 0xEFBC89, 0x1A1BF },
	{ 0xEFBC8A, 0x1A1EE },
	{ 0xEFBC8B, 0x1A2B0 },
	{ 0xEFBC8C, 0x1A1A2 },
	{ 0xEFBC8D, 0x1A2B1 },
	{ 0xEFBC8E, 0x1A1A5 },
	{ 0xEFBC8F, 0x1A2DF },
	{ 0xEFBC90, 0x1A4A1 },
	{ 0xEFBC91, 0x1A4A2 },
	{ 0xEFBC92, 0x1A4A3 },
	{ 0xEFBC93, 0x1A4A4 },
	{ 0xEFBC94, 0x1A4A5 },
	{ 0xEFBC95, 0x1A4A6 },
	{ 0xEFBC96, 0x1A4A7 },
	{ 0xEFBC97, 0x1A4A8 },
	{ 0xEFBC98, 0x1A4A9 },
	{ 0xEFBC99, 0x1A4AA },
	{ 0xEFBC9A, 0x1A1A8 },
	{ 0xEFBC9B, 0x1A1A7 },
	{ 0xEFBC9C, 0x1A2B6 },
	{ 0xEFBC9D, 0x1A2B8 },
	{ 0xEFBC9E, 0x1A2B7 },
	{ 0xEFBC9F, 0x1A1A9 },
	{ 0xEFBCA0, 0x1A2E9 },
	{ 0xEFBCA1, 0x1A4C1 },
	{ 0xEFBCA2, 0x1A4C2 },
	{ 0xEFBCA3, 0x1A4C3 },
	{ 0xEFBCA4, 0x1A4C4 },
	{ 0xEFBCA5, 0x1A4C5 },
	{ 0xEFBCA6, 0x1A4C6 },
	{ 0xEFBCA7, 0x1A4C7 },
	{ 0xEFBCA8, 0x1A4C8 },
	{ 0xEFBCA9, 0x1A4C9 },
	{ 0xEFBCAA, 0x1A4CA },
	{ 0xEFBCAB, 0x1A4CB },
	{ 0xEFBCAC, 0x1A4CC },
	{ 0xEFBCAD, 0x1A4CD },
	{ 0xEFBCAE, 0x1A4CE },
	{ 0xEFBCAF, 0x1A4CF },
	{ 0xEFBCB0, 0x1A4D0 },
	{ 0xEFBCB1, 0x1A4D1 },
	{ 0xEFBCB2, 0x1A4D2 },
	{ 0xEFBCB3, 0x1A4D3 },
	{ 0xEFBCB4, 0x1A4D4 },
	{ 0xEFBCB5, 0x1A4D5 },
	{ 0xEFBCB6, 0x1A4D6 },
	{ 0xEFBCB7, 0x1A4D7 },
	{ 0xEFBCB8, 0x1A4D8 },
	{ 0xEFBCB9, 0x1A4D9 },
	{ 0xEFBCBA, 0x1A4DA },
	{ 0xEFBCBC, 0x1A2E0 },
	{ 0xEFBCBF, 0x1A2A5 },
	{ 0xEFBD81, 0x1A4DB },
	{ 0xEFBD82, 0x1A4DC },
	{ 0xEFBD83, 0x1A4DD },
	{ 0xEFBD84, 0x1A4DE },
	{ 0xEFBD85, 0x1A4DF },
	{ 0xEFBD86, 0x1A4E0 },
	{ 0xEFBD87, 0x1A4E1 },
	{ 0xEFBD88, 0x1A4E2 },
	{ 0xEFBD89, 0x1A4E3 },
	{ 0xEFBD8A, 0x1A4E4 },
	{ 0xEFBD8B, 0x1A4E5 },
	{ 0xEFBD8C, 0x1A4E6 },
	{ 0xEFBD8D, 0x1A4E7 },
	{ 0xEFBD8E, 0x1A4E8 },
	{ 0xEFBD8F, 0x1A4E9 },
	{ 0xEFBD90, 0x1A4EA },
	{ 0xEFBD91, 0x1A4EB },
	{ 0xEFBD92, 0x1A4EC },
	{ 0xEFBD93, 0x1A4ED },
	{ 0xEFBD94, 0x1A4EE },
	{ 0xEFBD95, 0x1A4EF },
	{ 0xEFBD96, 0x1A4F0 },
	{ 0xEFBD97, 0x1A4F1 },
	{ 0xEFBD98, 0x1A4F2 },
	{ 0xEFBD99, 0x1A4F3 },
	{ 0xEFBD9A, 0x1A4F4 },
	{ 0xEFBD9B, 0x1A1C2 },
	{ 0xEFBD9C, 0x1A2DE },
	{ 0xEFBD9D, 0x1A1C3 },
	{ 0xEFBFA0, 0x1A2E6 },
	{ 0xEFBFA1, 0x1A2E7 },
	{ 0xEFBFA5, 0x1A2E4 },
	{ 0xF0A08080, 0x5A1A5 },
	{ 0xF0A08082, 0xFA1A1 },
	{ 0xF0A08083, 0x6A1AF },
	{ 0xF0A08084, 0x6A1AD },
	{ 0xF0A08085, 0x6A1AE },
	{ 0xF0A08087, 0x6A1C2 },
	{ 0xF0A08088, 0x6A1C3 },
	{ 0xF0A08089, 0x5A1B3 },
	{ 0xF0A0808B, 0x3A1C4 },
	{ 0xF0A0808F, 0xFA1BE },
	{ 0xF0A08090, 0xFA1BF },
	{ 0xF0A08092, 0x6A2AB },
	{ 0xF0A08094, 0x5A1CD },
	{ 0xF0A08098, 0x6A3C0 },
	{ 0xF0A08099, 0x6A3BE },
	{ 0xF0A0809A, 0x6A3BF },
	{ 0xF0A080A0, 0x6A4E7 },
	{ 0xF0A080A1, 0x6A5DF },
	{ 0xF0A080A2, 0x5A3AF },
	{ 0xF0A080A3, 0xFA2F4 },
	{ 0xF0A080A5, 0x6A5E7 },
	{ 0xF0A080A9, 0x6A5E3 },
	{ 0xF0A080AC, 0x6A9B7 },
	{ 0xF0A080AD, 0x6A9BA },
	{ 0xF0A080AE, 0x6A9B8 },
	{ 0xF0A080B5, 0xFA9A2 },
	{ 0xF0A080B6, 0xFA9A3 },
	{ 0xF0A080BB, 0x6AEE6 },
	{ 0xF0A08181, 0x5B0F2 },
	{ 0xF0A08183, 0x5B3A3 },
	{ 0xF0A08186, 0xFB9B2 },
	{ 0xF0A08187, 0xFB9B3 },
	{ 0xF0A08188, 0x6C7AD },
	{ 0xF0A0818B, 0xFBBF3 },
	{ 0xF0A0818C, 0xFC0B5 },
	{ 0xF0A0818D, 0xFC0F5 },
	{ 0xF0A08192, 0xFC7C2 },
	{ 0xF0A08193, 0xFCDD6 },
	{ 0xF0A08195, 0x7A1A1 },
	{ 0xF0A08196, 0xFD9C7 },
	{ 0xF0A08197, 0x4CFFC },
	{ 0xF0A0819B, 0xFDABF },
	{ 0xF0A081A1, 0x6A1AC },
	{ 0xF0A081A2, 0x6A1A2 },
	{ 0xF0A081A4, 0x6A2DF },
	{ 0xF0A081A5, 0x4A1D6 },
	{ 0xF0A081A6, 0x6A3C1 },
	{ 0xF0A081A7, 0x6A5E0 },
	{ 0xF0A081A9, 0x6A9BB },
	{ 0xF0A081AB, 0x5A5A1 },
	{ 0xF0A081AD, 0x5A7FA },
	{ 0xF0A081AE, 0x6AECA },
	{ 0xF0A081AF, 0xFA9D0 },
	{ 0xF0A081B0, 0x6B5A5 },
	{ 0xF0A081B1, 0x6B5A6 },
	{ 0xF0A081B2, 0x6C5FD },
	{ 0xF0A081B4, 0x6C6BF },
	{ 0xF0A081B6, 0xFC6C0 },
	{ 0xF0A081B7, 0x5C4FE },
	{ 0xF0A081BD, 0x6A1B2 },
	{ 0xF0A081BE, 0x5A1AD },
	{ 0xF0A081BF, 0x6A2AD },
	{ 0xF0A08282, 0x6A3C2 },
	{ 0xF0A08283, 0xFADE1 },
	{ 0xF0A08284, 0x6D0D0 },
	{ 0xF0A08285, 0xFD3C4 },
	{ 0xF0A08286, 0x4A1A1 },
	{ 0xF0A08287, 0x5A1A6 },
	{ 0xF0A08288, 0x6A1A4 },
	{ 0xF0A0828C, 0xFA1A2 },
	{ 0xF0A0828D, 0x6A1B3 },
	{ 0xF0A0828F, 0x6A1C4 },
	{ 0xF0A08292, 0xFA1A5 },
	{ 0xF0A08293, 0xFA1A6 },
	{ 0xF0A08294, 0x5A1CE },
	{ 0xF0A08295, 0x6A2B0 },
	{ 0xF0A08297, 0xFA1C5 },
	{ 0xF0A08298, 0x6A2CE },
	{ 0xF0A08299, 0x6A2AF },
	{ 0xF0A0829A, 0xFA1C0 },
	{ 0xF0A0829B, 0xFA1C1 },
	{ 0xF0A0829C, 0x6A1C5 },
	{ 0xF0A0829E, 0x6A2B1 },
	{ 0xF0A082A0, 0x6A2AE },
	{ 0xF0A082A2, 0x4A2A6 },
	{ 0xF0A082A3, 0x4A2A5 },
	{ 0xF0A082A4, 0x5A2A4 },
	{ 0xF0A082A5, 0x5A2A5 },
	{ 0xF0A082A8, 0x6A3C3 },
	{ 0xF0A082A9, 0x6A9BE },
	{ 0xF0A082AC, 0x6A4DD },
	{ 0xF0A082AE, 0x6A5D6 },
	{ 0xF0A082AF, 0x6A5E1 },
	{ 0xF0A082B0, 0x6A5E2 },
	{ 0xF0A082B1, 0x6ACC3 },
	{ 0xF0A082B2, 0x6A9BC },
	{ 0xF0A082B3, 0x6BAE5 },
	{ 0xF0A082B4, 0xFA9A5 },
	{ 0xF0A082B5, 0x6ADAD },
	{ 0xF0A082B6, 0x6A9BD },
	{ 0xF0A082B7, 0x6AECB },
	{ 0xF0A082B9, 0x5ABE7 },
	{ 0xF0A082BA, 0x6B5AA },
	{ 0xF0A082BC, 0x6B5A7 },
	{ 0xF0A082BD, 0x6B9E4 },
	{ 0xF0A082BE, 0x6B5A9 },
	{ 0xF0A082BF, 0x6BCFB },
	{ 0xF0A08382, 0x6C5FE },
	{ 0xF0A08383, 0x6C6C0 },
	{ 0xF0A08384, 0x6C6C1 },
	{ 0xF0A08386, 0x5BDD6 },
	{ 0xF0A08389, 0x5A1A3 },
	{ 0xF0A0838B, 0x5A1A2 },
	{ 0xF0A0838F, 0x6A1A6 },
	{ 0xF0A08390, 0x6A1A5 },
	{ 0xF0A08391, 0x5A1A1 },
	{ 0xF0A08392, 0x5A1AB },
	{ 0xF0A08394, 0xFA1A3 },
	{ 0xF0A08395, 0x6A1C6 },
	{ 0xF0A08396, 0x5A1B4 },
	{ 0xF0A08398, 0xFA1A7 },
	{ 0xF0A08399, 0xFA1A8 },
	{ 0xF0A0839E, 0x6A2B3 },
	{ 0xF0A0839F, 0x6A2B2 },
	{ 0xF0A083A0, 0x6A2AA },
	{ 0xF0A083A1, 0x5A1CF },
	{ 0xF0A083A4, 0x6A3C6 },
	{ 0xF0A083A5, 0x6A3C4 },
	{ 0xF0A083A6, 0xFA1EE },
	{ 0xF0A083A7, 0x6A3C5 },
	{ 0xF0A083AA, 0xFA2F5 },
	{ 0xF0A083AD, 0x6A9BF },
	{ 0xF0A083B0, 0x6ADAC },
	{ 0xF0A083B1, 0x4A6A4 },
	{ 0xF0A083B2, 0x6AECD },
	{ 0xF0A083B3, 0x6AECE },
	{ 0xF0A083B4, 0xFA5C0 },
	{ 0xF0A083B6, 0x6AECC },
	{ 0xF0A083B8, 0x6B5AB },
	{ 0xF0A083BB, 0xFADE0 },
	{ 0xF0A083BC, 0x6BCFE },
	{ 0xF0A083BD, 0x5B0F3 },
	{ 0xF0A083BE, 0x6BCFD },
	{ 0xF0A08482, 0xFB9B4 },
	{ 0xF0A08484, 0x6D0D1 },
	{ 0xF0A08485, 0x5C4D5 },
	{ 0xF0A08486, 0xFC6C1 },
	{ 0xF0A08487, 0x6DAE3 },
	{ 0xF0A08488, 0x6DAE2 },
	{ 0xF0A08489, 0x7B6F3 },
	{ 0xF0A0848A, 0x7C6A7 },
	{ 0xF0A0848B, 0x7CDBA },
	{ 0xF0A0848C, 0x5A1A4 },
	{ 0xF0A0848D, 0x5A1A7 },
	{ 0xF0A0848E, 0x4A1A8 },
	{ 0xF0A0848F, 0x5A1A8 },
	{ 0xF0A08491, 0x5A1AC },
	{ 0xF0A08492, 0x6A1C7 },
	{ 0xF0A08493, 0x6A1C8 },
	{ 0xF0A08494, 0x6A1C9 },
	{ 0xF0A08495, 0x6A3C7 },
	{ 0xF0A08496, 0x5A3B0 },
	{ 0xF0A08497, 0x6A5E4 },
	{ 0xF0A08499, 0x6A9C0 },
	{ 0xF0A0849A, 0x5B0F4 },
	{ 0xF0A0849B, 0x6C6C2 },
	{ 0xF0A0849D, 0x7ACBC },
	{ 0xF0A0849E, 0x6A1A7 },
	{ 0xF0A0849F, 0x6A1A8 },
	{ 0xF0A084A0, 0x6A1A9 },
	{ 0xF0A084A1, 0x6A1CA },
	{ 0xF0A084A2, 0x6A5E5 },
	{ 0xF0A084A3, 0x6A3C8 },
	{ 0xF0A084A4, 0x6A3C9 },
	{ 0xF0A084A8, 0x6A5E8 },
	{ 0xF0A084AA, 0xFA2F6 },
	{ 0xF0A084AC, 0x4A5B3 },
	{ 0xF0A084AD, 0x5A5A2 },
	{ 0xF0A084AE, 0x4A5B2 },
	{ 0xF0A084B0, 0x6AED0 },
	{ 0xF0A084B1, 0x5A7FB },
	{ 0xF0A084B2, 0xFA9A7 },
	{ 0xF0A084B4, 0x6B0FC },
	{ 0xF0A084B5, 0x6B5AD },
	{ 0xF0A084B7, 0x6B5AC },
	{ 0xF0A084B8, 0xFADE2 },
	{ 0xF0A084B9, 0x6BDA1 },
	{ 0xF0A08580, 0xFCDEE },
	{ 0xF0A08583, 0x6A3CA },
	{ 0xF0A08584, 0xFA1EF },
	{ 0xF0A08585, 0xFA1F0 },
	{ 0xF0A08587, 0xFA2AB },
	{ 0xF0A08588, 0x5A3B1 },
	{ 0xF0A08589, 0xFA2F7 },
	{ 0xF0A0858A, 0xFA2F8 },
	{ 0xF0A0858B, 0xFA2F9 },
	{ 0xF0A0858C, 0x5A5A3 },
	{ 0xF0A0858F, 0x6A9C1 },
	{ 0xF0A08591, 0xFA5C3 },
	{ 0xF0A08593, 0x6AED2 },
	{ 0xF0A08594, 0x6AED1 },
	{ 0xF0A08595, 0xFA9A8 },
	{ 0xF0A08596, 0x6B5AF },
	{ 0xF0A08597, 0x5ACE6 },
	{ 0xF0A08598, 0x4ABDF },
	{ 0xF0A08599, 0x6B5B0 },
	{ 0xF0A0859D, 0xFADE3 },
	{ 0xF0A0859E, 0x6B5B1 },
	{ 0xF0A0859F, 0x6C6C3 },
	{ 0xF0A085A0, 0x6BDA3 },
	{ 0xF0A085A1, 0x6BDA2 },
	{ 0xF0A085A2, 0x4B0C4 },
	{ 0xF0A085A3, 0x5B0F5 },
	{ 0xF0A085A4, 0xFB2F4 },
	{ 0xF0A085A5, 0xFB2F5 },
	{ 0xF0A085A7, 0xFB2F2 },
	{ 0xF0A085A9, 0x6C6C5 },
	{ 0xF0A085AA, 0x6C6C4 },
	{ 0xF0A085AB, 0x6C6C6 },
	{ 0xF0A085AC, 0x4B6AF },
	{ 0xF0A085AD, 0xFB9B5 },
	{ 0xF0A085AE, 0xFB9B6 },
	{ 0xF0A085AF, 0xFB9B7 },
	{ 0xF0A085B0, 0x6CCAD },
	{ 0xF0A085B4, 0xFC0B6 },
	{ 0xF0A085B5, 0xFC0B7 },
	{ 0xF0A085B6, 0xFC0B8 },
	{ 0xF0A085BE, 0xFC6C2 },
	{ 0xF0A08680, 0x6D0D2 },
	{ 0xF0A08681, 0x5CBF1 },
	{ 0xF0A08682, 0x7A1A2 },
	{ 0xF0A08683, 0xFCDD7 },
	{ 0xF0A08684, 0xFCDD8 },
	{ 0xF0A08685, 0xFCDD9 },
	{ 0xF0A08686, 0x7A6F9 },
	{ 0xF0A08687, 0x7A1A4 },
	{ 0xF0A08689, 0x7A1A3 },
	{ 0xF0A0868A, 0x7A1C6 },
	{ 0xF0A0868C, 0x7ACBF },
	{ 0xF0A0868E, 0x5D3D3 },
	{ 0xF0A0868F, 0x7ACBE },
	{ 0xF0A08692, 0x7ACBD },
	{ 0xF0A0869C, 0x7C6A3 },
	{ 0xF0A0869D, 0x7C6A8 },
	{ 0xF0A086A3, 0x6A1B4 },
	{ 0xF0A086A4, 0x6A1B5 },
	{ 0xF0A086A5, 0xFA1A4 },
	{ 0xF0A086A6, 0x6A1CC },
	{ 0xF0A086A7, 0xFA1A9 },
	{ 0xF0A086A8, 0x6A1CB },
	{ 0xF0A086A9, 0x3A1EF },
	{ 0xF0A086AC, 0xFA1C3 },
	{ 0xF0A086AD, 0x6A2B5 },
	{ 0xF0A086AF, 0x6A2B4 },
	{ 0xF0A086B0, 0x6A2B6 },
	{ 0xF0A086B2, 0x4A1D8 },
	{ 0xF0A086B4, 0x4A2AC },
	{ 0xF0A086B5, 0x4A2AB },
	{ 0xF0A086B6, 0x4A2A9 },
	{ 0xF0A086B7, 0x6A3CF },
	{ 0xF0A086B8, 0x4A2B0 },
	{ 0xF0A086B9, 0x6A3D0 },
	{ 0xF0A086BA, 0x5A2A7 },
	{ 0xF0A086BB, 0x6A3CD },
	{ 0xF0A086BC, 0x6A3CC },
	{ 0xF0A08782, 0x4A2AF },
	{ 0xF0A08783, 0x6A3CB },
	{ 0xF0A08784, 0xFA1F3 },
	{ 0xF0A08785, 0xFA1F4 },
	{ 0xF0A08786, 0xFA1F5 },
	{ 0xF0A08787, 0xFA1F6 },
	{ 0xF0A08788, 0xFA1F7 },
	{ 0xF0A08789, 0xFA1F8 },
	{ 0xF0A0878A, 0xFA1F9 },
	{ 0xF0A0878B, 0x5A2A8 },
	{ 0xF0A0878F, 0x6A3D1 },
	{ 0xF0A08790, 0x5A2A6 },
	{ 0xF0A08794, 0xFA1FA },
	{ 0xF0A08798, 0x5A3B2 },
	{ 0xF0A08799, 0x6A5EA },
	{ 0xF0A0879A, 0x4A3BA },
	{ 0xF0A0879B, 0x6A5EB },
	{ 0xF0A0879C, 0x6A5F4 },
	{ 0xF0A0879D, 0x6A5F0 },
	{ 0xF0A0879E, 0x6A5EC },
	{ 0xF0A0879F, 0xFA2FA },
	{ 0xF0A087A0, 0xFA2FB },
	{ 0xF0A087A1, 0xFA2FC },
	{ 0xF0A087A2, 0xFA2FD },
	{ 0xF0A087A3, 0xFA3A1 },
	{ 0xF0A087A4, 0xFA3A2 },
	{ 0xF0A087A5, 0xFA3A3 },
	{ 0xF0A087A6, 0xFA3A5 },
	{ 0xF0A087A7, 0xFA3A8 },
	{ 0xF0A087A8, 0xFA3A9 },
	{ 0xF0A087A9, 0xFA3AA },
	{ 0xF0A087AA, 0xFA3AB },
	{ 0xF0A087AB, 0xFA3AC },
	{ 0xF0A087B1, 0x4A3B8 },
	{ 0xF0A087B2, 0x6A5ED },
	{ 0xF0A087B4, 0x6A5EF },
	{ 0xF0A087B7, 0xFA3A6 },
	{ 0xF0A087BE, 0x6A5EE },
	{ 0xF0A087BF, 0x6A5E9 },
	{ 0xF0A08880, 0x5A3B3 },
	{ 0xF0A08881, 0x6A5F3 },
	{ 0xF0A08883, 0x6A9C3 },
	{ 0xF0A08884, 0x6A9C5 },
	{ 0xF0A08885, 0x4A5BA },
	{ 0xF0A08886, 0x5A5A8 },
	{ 0xF0A08887, 0x6A9C6 },
	{ 0xF0A08888, 0x5A5A9 },
	{ 0xF0A08889, 0x3A7CE },
	{ 0xF0A0888A, 0x5A5AA },
	{ 0xF0A0888B, 0x4A5B7 },
	{ 0xF0A0888C, 0x4A5B5 },
	{ 0xF0A0888D, 0x6A9CA },
	{ 0xF0A0888E, 0x6A9C4 },
	{ 0xF0A0888F, 0x6A9CC },
	{ 0xF0A08890, 0x6A9C7 },
	{ 0xF0A08891, 0x6A9CE },
	{ 0xF0A08895, 0x5A5A6 },
	{ 0xF0A08896, 0x6A9C2 },
	{ 0xF0A08897, 0xFA5C5 },
	{ 0xF0A08898, 0xFA5C6 },
	{ 0xF0A08899, 0xFA5C8 },
	{ 0xF0A0889A, 0xFA5C9 },
	{ 0xF0A0889B, 0xFA5CB },
	{ 0xF0A0889C, 0xFA5CC },
	{ 0xF0A0889D, 0xFA5CD },
	{ 0xF0A0889E, 0xFA5CE },
	{ 0xF0A0889F, 0xFA5CF },
	{ 0xF0A088A0, 0xFA5D0 },
	{ 0xF0A088A1, 0xFA5D1 },
	{ 0xF0A088A2, 0x6A9CD },
	{ 0xF0A088A7, 0x6A9C8 },
	{ 0xF0A088A8, 0x6A9C9 },
	{ 0xF0A088A9, 0x6A9CB },
	{ 0xF0A088AA, 0x5A5A4 },
	{ 0xF0A088AC, 0x5A5A7 },
	{ 0xF0A088AD, 0x5A7FC },
	{ 0xF0A088AE, 0x6AEE4 },
	{ 0xF0A088AF, 0x6AED9 },
	{ 0xF0A088B0, 0x5ABF2 },
	{ 0xF0A088B1, 0x4A8B6 },
	{ 0xF0A088B2, 0x6AEE3 },
	{ 0xF0A088B3, 0x6AED7 },
	{ 0xF0A088B4, 0x6AED6 },
	{ 0xF0A088B5, 0x5A8A3 },
	{ 0xF0A088B6, 0x4A8BB },
	{ 0xF0A088B7, 0x6AEDD },
	{ 0xF0A088B8, 0x5A7FE },
	{ 0xF0A088B9, 0x5A7FD },
	{ 0xF0A088BA, 0x5A8A2 },
	{ 0xF0A088BB, 0x6AEE2 },
	{ 0xF0A088BC, 0x6AED5 },
	{ 0xF0A088BD, 0x6AED4 },
	{ 0xF0A088BE, 0x6AEE5 },
	{ 0xF0A088BF, 0x6AEDC },
	{ 0xF0A08984, 0xFA9A9 },
	{ 0xF0A08985, 0xFA9AA },
	{ 0xF0A08986, 0xFA9AB },
	{ 0xF0A08987, 0xFA9AC },
	{ 0xF0A08988, 0xFA9AE },
	{ 0xF0A08989, 0xFA9AF },
	{ 0xF0A0898A, 0xFA9B1 },
	{ 0xF0A0898B, 0xFA9B2 },
	{ 0xF0A0898C, 0xFA9B3 },
	{ 0xF0A0898D, 0xFA9B4 },
	{ 0xF0A0898E, 0xFA9B5 },
	{ 0xF0A0898F, 0xFA9B6 },
	{ 0xF0A08990, 0xFA9B7 },
	{ 0xF0A08991, 0xFA9B8 },
	{ 0xF0A08992, 0x6AED3 },
	{ 0xF0A08994, 0x6AED8 },
	{ 0xF0A08995, 0x6AEDB },
	{ 0xF0A08996, 0x6AEDE },
	{ 0xF0A08998, 0x6AEE0 },
	{ 0xF0A0899B, 0xFA5C7 },
	{ 0xF0A089A1, 0x6AEDF },
	{ 0xF0A089A2, 0x5A8A4 },
	{ 0xF0A089A3, 0x4ABE3 },
	{ 0xF0A089A4, 0x5ABF0 },
	{ 0xF0A089A5, 0x4ABE7 },
	{ 0xF0A089A6, 0x6B5B6 },
	{ 0xF0A089A7, 0x5ABEB },
	{ 0xF0A089A8, 0x6B5B5 },
	{ 0xF0A089A9, 0x5ABF4 },
	{ 0xF0A089AA, 0x4ABE6 },
	{ 0xF0A089AB, 0x4ABE8 },
	{ 0xF0A089AC, 0x5ABEF },
	{ 0xF0A089AD, 0x6B5B2 },
	{ 0xF0A089AE, 0x5ABE9 },
	{ 0xF0A089B1, 0xFADE4 },
	{ 0xF0A089B2, 0xFADEE },
	{ 0xF0A089B3, 0x6B5B7 },
	{ 0xF0A089B6, 0x5ABEE },
	{ 0xF0A089B7, 0xFADE6 },
	{ 0xF0A089B8, 0xFADE7 },
	{ 0xF0A089B9, 0xFADEA },
	{ 0xF0A089BA, 0xFADEB },
	{ 0xF0A089BB, 0xFADEC },
	{ 0xF0A089BC, 0xFADED },
	{ 0xF0A089BD, 0xFADEF },
	{ 0xF0A089BE, 0xFADF1 },
	{ 0xF0A089BF, 0xFADF2 },
	{ 0xF0A08A80, 0xFADF3 },
	{ 0xF0A08A81, 0xFADF4 },
	{ 0xF0A08A82, 0xFADF5 },
	{ 0xF0A08A83, 0xFADF6 },
	{ 0xF0A08A84, 0xFADF8 },
	{ 0xF0A08A85, 0xFADF9 },
	{ 0xF0A08A86, 0xFADFA },
	{ 0xF0A08A87, 0xFADFB },
	{ 0xF0A08A88, 0xFADFC },
	{ 0xF0A08A8A, 0x6B5A1 },
	{ 0xF0A08A8B, 0x6B5BA },
	{ 0xF0A08A8C, 0x6B5BB },
	{ 0xF0A08A91, 0x6B5B3 },
	{ 0xF0A08A92, 0x6B5B4 },
	{ 0xF0A08A94, 0x5ABE8 },
	{ 0xF0A08A96, 0x6B5B9 },
	{ 0xF0A08A9E, 0xFADF7 },
	{ 0xF0A08AA0, 0xFADF0 },
	{ 0xF0A08AA2, 0x5ABEA },
	{ 0xF0A08AA3, 0x5ABED },
	{ 0xF0A08AA4, 0x5ABF5 },
	{ 0xF0A08AA5, 0x5ABF1 },
	{ 0xF0A08AA6, 0x5ABF3 },
	{ 0xF0A08AA7, 0x4ABE0 },
	{ 0xF0A08AA8, 0x6BDAB },
	{ 0xF0A08AA9, 0x6BDAD },
	{ 0xF0A08AAA, 0x6BDAC },
	{ 0xF0A08AAB, 0x4B0C9 },
	{ 0xF0A08AAC, 0x4B0C8 },
	{ 0xF0A08AAD, 0x6BDB0 },
	{ 0xF0A08AAE, 0x6BDA8 },
	{ 0xF0A08AB0, 0x5B1A1 },
	{ 0xF0A08AB1, 0x6BDB3 },
	{ 0xF0A08AB2, 0x5B0F7 },
	{ 0xF0A08AB3, 0x6BDAE },
	{ 0xF0A08AB4, 0x6BDA7 },
	{ 0xF0A08AB5, 0x5B1A2 },
	{ 0xF0A08AB6, 0x5B0F6 },
	{ 0xF0A08AB7, 0x4B0C6 },
	{ 0xF0A08AB8, 0x6BDAA },
	{ 0xF0A08AB9, 0x6BDB1 },
	{ 0xF0A08ABA, 0x6BDB7 },
	{ 0xF0A08ABB, 0x6BDB2 },
	{ 0xF0A08ABE, 0x6BDA9 },
	{ 0xF0A08B81, 0x4B0CB },
	{ 0xF0A08B82, 0x6BDB4 },
	{ 0xF0A08B83, 0xFADE9 },
	{ 0xF0A08B84, 0xFB2F7 },
	{ 0xF0A08B85, 0xFB2F8 },
	{ 0xF0A08B86, 0xFB2F9 },
	{ 0xF0A08B87, 0xFB2FA },
	{ 0xF0A08B88, 0xFB2FB },
	{ 0xF0A08B89, 0xFB2FC },
	{ 0xF0A08B8A, 0xFB2FE },
	{ 0xF0A08B8B, 0xFB3A1 },
	{ 0xF0A08B8C, 0xFB3A3 },
	{ 0xF0A08B8D, 0xFB3A4 },
	{ 0xF0A08B8E, 0xFB3A5 },
	{ 0xF0A08B8F, 0xFB3A6 },
	{ 0xF0A08B90, 0xFB3A7 },
	{ 0xF0A08B91, 0x6C6B7 },
	{ 0xF0A08B92, 0x6BDB8 },
	{ 0xF0A08B93, 0x6BEE5 },
	{ 0xF0A08B94, 0x6BDB9 },
	{ 0xF0A08B95, 0x6BDAF },
	{ 0xF0A08B96, 0x5B0FA },
	{ 0xF0A08B9B, 0x6C3E3 },
	{ 0xF0A08B9D, 0x5B0FD },
	{ 0xF0A08BA1, 0x5B1A3 },
	{ 0xF0A08BA2, 0x6BDA4 },
	{ 0xF0A08BA3, 0x6BDA6 },
	{ 0xF0A08BA5, 0xFB2FD },
	{ 0xF0A08BA7, 0x5B0F9 },
	{ 0xF0A08BA8, 0x5B0FE },
	{ 0xF0A08BA9, 0x5B0F8 },
	{ 0xF0A08BAA, 0x6BDA5 },
	{ 0xF0A08BAB, 0x6BDB6 },
	{ 0xF0A08BAC, 0x5B0FC },
	{ 0xF0A08BAD, 0x6C6C9 },
	{ 0xF0A08BAE, 0x6C6CF },
	{ 0xF0A08BAF, 0x5B6D6 },
	{ 0xF0A08BB0, 0x5B6D1 },
	{ 0xF0A08BB1, 0x6C6CC },
	{ 0xF0A08BB2, 0x5B6CE },
	{ 0xF0A08BB3, 0x5B6D2 },
	{ 0xF0A08BB4, 0x5B6E3 },
	{ 0xF0A08BB5, 0x5B6D3 },
	{ 0xF0A08BB6, 0x6C6C8 },
	{ 0xF0A08BB7, 0x5B6D5 },
	{ 0xF0A08BB8, 0x5B6D0 },
	{ 0xF0A08BB9, 0x6C6D6 },
	{ 0xF0A08BBA, 0x4B6B5 },
	{ 0xF0A08BBB, 0x5B6D4 },
	{ 0xF0A08BBC, 0x6C6D2 },
	{ 0xF0A08BBD, 0x6C6D0 },
	{ 0xF0A08BBE, 0x6C6CB },
	{ 0xF0A08BBF, 0x6C6CE },
	{ 0xF0A08C80, 0x6C6D3 },
	{ 0xF0A08C87, 0xFB2F6 },
	{ 0xF0A08C88, 0x6C6D8 },
	{ 0xF0A08C89, 0x5B6CF },
	{ 0xF0A08C8B, 0x5B6D7 },
	{ 0xF0A08C8C, 0x6C6C7 },
	{ 0xF0A08C8D, 0xFB9B8 },
	{ 0xF0A08C8E, 0xFB9B9 },
	{ 0xF0A08C8F, 0xFB9BA },
	{ 0xF0A08C90, 0xFB9BB },
	{ 0xF0A08C91, 0xFB9BC },
	{ 0xF0A08C92, 0xFB9BD },
	{ 0xF0A08C93, 0xFB9BE },
	{ 0xF0A08C94, 0xFB9BF },
	{ 0xF0A08C97, 0x6C6CD },
	{ 0xF0A08C98, 0x4B6BB },
	{ 0xF0A08C9C, 0x6C6D1 },
	{ 0xF0A08CA0, 0x6C6D4 },
	{ 0xF0A08CA1, 0x5B6CD },
	{ 0xF0A08CA9, 0x6C6CA },
	{ 0xF0A08CAA, 0x5B4A1 },
	{ 0xF0A08CAB, 0x6D0DA },
	{ 0xF0A08CAC, 0x4C2B8 },
	{ 0xF0A08CAD, 0x5BDDA },
	{ 0xF0A08CAE, 0x5BDD8 },
	{ 0xF0A08CAF, 0x6D0D3 },
	{ 0xF0A08CB0, 0x5B0FB },
	{ 0xF0A08CB1, 0x5BDDE },
	{ 0xF0A08CB2, 0x5BDDC },
	{ 0xF0A08CB3, 0x6D0D8 },
	{ 0xF0A08CB4, 0x5BDDB },
	{ 0xF0A08CB5, 0x6D0DF },
	{ 0xF0A08CB6, 0x6D0DD },
	{ 0xF0A08CB7, 0x4BCAE },
	{ 0xF0A08CB9, 0x6D0DC },
	{ 0xF0A08CBA, 0x6D0E2 },
	{ 0xF0A08CBB, 0x6D0D5 },
	{ 0xF0A08CBC, 0x4BCAF },
	{ 0xF0A08CBE, 0x5BDE0 },
	{ 0xF0A08CBF, 0x6D0D4 },
	{ 0xF0A08D80, 0x5BDD7 },
	{ 0xF0A08D84, 0x6D0D7 },
	{ 0xF0A08D88, 0x6D0DE },
	{ 0xF0A08D89, 0xFC0B9 },
	{ 0xF0A08D8A, 0xFC0BA },
	{ 0xF0A08D8B, 0xFC0BB },
	{ 0xF0A08D8C, 0xFC0BC },
	{ 0xF0A08D8D, 0xFC0BD },
	{ 0xF0A08D8E, 0xFC0BE },
	{ 0xF0A08D8F, 0xFC0BF },
	{ 0xF0A08D90, 0xFC0C0 },
	{ 0xF0A08D91, 0xFC0C1 },
	{ 0xF0A08D92, 0xFC0C2 },
	{ 0xF0A08D93, 0xFC0C3 },
	{ 0xF0A08D94, 0xFC0C4 },
	{ 0xF0A08D95, 0xFC0C5 },
	{ 0xF0A08D96, 0xFC0C6 },
	{ 0xF0A08D98, 0x6D0E1 },
	{ 0xF0A08D9E, 0x6D6CE },
	{ 0xF0A08D9F, 0x6D0D9 },
	{ 0xF0A08DA2, 0x6D0D6 },
	{ 0xF0A08DA7, 0x6C6D7 },
	{ 0xF0A08DA8, 0x5BDD9 },
	{ 0xF0A08DA9, 0x5BDDD },
	{ 0xF0A08DAA, 0x5BDDF },
	{ 0xF0A08DAB, 0x4BCAB },
	{ 0xF0A08DAC, 0x6D0E0 },
	{ 0xF0A08DAE, 0x6DAF1 },
	{ 0xF0A08DAF, 0x5BDE1 },
	{ 0xF0A08DB0, 0x7A1AE },
	{ 0xF0A08DB1, 0x4C2B4 },
	{ 0xF0A08DB2, 0x5C4D6 },
	{ 0xF0A08DB3, 0x6DAE4 },
	{ 0xF0A08DB4, 0x6DAE9 },
	{ 0xF0A08DB5, 0x5BDE2 },
	{ 0xF0A08DB6, 0x6DAEB },
	{ 0xF0A08DB7, 0x4C2B9 },
	{ 0xF0A08DB8, 0x6DAF4 },
	{ 0xF0A08DB9, 0x4C2B1 },
	{ 0xF0A08DBA, 0x6DAF5 },
	{ 0xF0A08DBB, 0x6DAE8 },
	{ 0xF0A08E82, 0x6DAE7 },
	{ 0xF0A08E83, 0x6DAF6 },
	{ 0xF0A08E84, 0xFC6C3 },
	{ 0xF0A08E85, 0xFC6C4 },
	{ 0xF0A08E86, 0xFC6C5 },
	{ 0xF0A08E87, 0xFC6C6 },
	{ 0xF0A08E88, 0xFC6C7 },
	{ 0xF0A08E89, 0xFC6C9 },
	{ 0xF0A08E8A, 0xFC6CA },
	{ 0xF0A08E8B, 0xFC6CB },
	{ 0xF0A08E8C, 0xFC6CC },
	{ 0xF0A08E8D, 0xFC6CD },
	{ 0xF0A08E8E, 0xFC6CE },
	{ 0xF0A08E8F, 0xFC6CF },
	{ 0xF0A08E90, 0xFC6D1 },
	{ 0xF0A08E91, 0xFC6D2 },
	{ 0xF0A08E92, 0xFC6D3 },
	{ 0xF0A08E93, 0xFC6D4 },
	{ 0xF0A08E94, 0xFC6D6 },
	{ 0xF0A08E95, 0xFC6D7 },
	{ 0xF0A08E96, 0xFC6D8 },
	{ 0xF0A08E97, 0xFD3C5 },
	{ 0xF0A08E98, 0x7A6AD },
	{ 0xF0A08E99, 0x5C4D8 },
	{ 0xF0A08E9A, 0x6DAF7 },
	{ 0xF0A08E9B, 0x6DED7 },
	{ 0xF0A08E9E, 0x6DAED },
	{ 0xF0A08EA1, 0x6DAEF },
	{ 0xF0A08EA2, 0x6DAE5 },
	{ 0xF0A08EA3, 0xFC6D0 },
	{ 0xF0A08EA7, 0xFC6C8 },
	{ 0xF0A08EAC, 0xFC6D5 },
	{ 0xF0A08EAE, 0x4C2B0 },
	{ 0xF0A08EAF, 0x6DAE6 },
	{ 0xF0A08EB0, 0x6DAEA },
	{ 0xF0A08EB1, 0x6DAEE },
	{ 0xF0A08EB2, 0x6DAF0 },
	{ 0xF0A08EB3, 0x4C2B6 },
	{ 0xF0A08EB6, 0x5BFC6 },
	{ 0xF0A08EB7, 0x4C8FE },
	{ 0xF0A08EB8, 0x4C8FA },
	{ 0xF0A08EB9, 0x6DAEC },
	{ 0xF0A08EBA, 0x7A1AF },
	{ 0xF0A08EBB, 0x7A1B1 },
	{ 0xF0A08EBC, 0x7A1A9 },
	{ 0xF0A08EBD, 0x7A1A6 },
	{ 0xF0A08EBE, 0x7A1A5 },
	{ 0xF0A08EBF, 0x5CBF7 },
	{ 0xF0A08F80, 0x4C8FC },
	{ 0xF0A08F81, 0x7A1AB },
	{ 0xF0A08F82, 0x7A1AC },
	{ 0xF0A08F83, 0x5CBF3 },
	{ 0xF0A08F84, 0x7A1AA },
	{ 0xF0A08F87, 0x5CBF9 },
	{ 0xF0A08F88, 0x5CBF8 },
	{ 0xF0A08F8A, 0x7A1A7 },
	{ 0xF0A08F8C, 0xFCDDA },
	{ 0xF0A08F8D, 0xFCDDB },
	{ 0xF0A08F8E, 0xFCDDC },
	{ 0xF0A08F8F, 0xFCDDD },
	{ 0xF0A08F90, 0xFCDDE },
	{ 0xF0A08F91, 0xFCDE0 },
	{ 0xF0A08F92, 0xFCDE1 },
	{ 0xF0A08F94, 0x7A1A8 },
	{ 0xF0A08F96, 0x5CBF2 },
	{ 0xF0A08F97, 0x7A1AD },
	{ 0xF0A08F9A, 0xFCDE2 },
	{ 0xF0A08FA1, 0x4C9A1 },
	{ 0xF0A08FA2, 0x5CBF5 },
	{ 0xF0A08FA3, 0x7A1B0 },
	{ 0xF0A08FA4, 0x5CBF4 },
	{ 0xF0A08FA7, 0x5CCC5 },
	{ 0xF0A08FA8, 0x5D3D4 },
	{ 0xF0A08FA9, 0x5D3DA },
	{ 0xF0A08FAA, 0x7ACC0 },
	{ 0xF0A08FAB, 0x4CFD8 },
	{ 0xF0A08FAC, 0x4CFDF },
	{ 0xF0A08FAD, 0x5D3D8 },
	{ 0xF0A08FAE, 0x4CFDC },
	{ 0xF0A08FAF, 0x4CFDE },
	{ 0xF0A08FB0, 0x5D3D5 },
	{ 0xF0A08FB4, 0x5D3D6 },
	{ 0xF0A08FB6, 0xFD3C6 },
	{ 0xF0A08FB7, 0xFD3C7 },
	{ 0xF0A08FB8, 0xFD3C8 },
	{ 0xF0A08FBA, 0xFD3C9 },
	{ 0xF0A08FBB, 0xFD3CA },
	{ 0xF0A09080, 0x5D3DB },
	{ 0xF0A09086, 0x5D3D7 },
	{ 0xF0A09088, 0x7B6F8 },
	{ 0xF0A09089, 0x5CBF6 },
	{ 0xF0A0908A, 0x5DAEF },
	{ 0xF0A0908B, 0x5DAF0 },
	{ 0xF0A0908C, 0x4D5E7 },
	{ 0xF0A0908D, 0x4D5E6 },
	{ 0xF0A0908E, 0x7B6F6 },
	{ 0xF0A09092, 0xFD9C8 },
	{ 0xF0A09095, 0xFD9CA },
	{ 0xF0A09096, 0xFD9CB },
	{ 0xF0A09097, 0xFD9CC },
	{ 0xF0A09098, 0xFD9CE },
	{ 0xF0A0909A, 0x7B6F5 },
	{ 0xF0A0909B, 0x7B6F7 },
	{ 0xF0A0909F, 0xFD9C9 },
	{ 0xF0A090A1, 0x4D5E8 },
	{ 0xF0A090A2, 0x7B6F4 },
	{ 0xF0A090A3, 0x7BEF6 },
	{ 0xF0A090A4, 0x4DAEB },
	{ 0xF0A090A5, 0x4DAE9 },
	{ 0xF0A090A6, 0x4DAEA },
	{ 0xF0A090A7, 0x7BEF8 },
	{ 0xF0A090A8, 0x7BEF7 },
	{ 0xF0A090AA, 0xFDEB0 },
	{ 0xF0A090AB, 0xFDEB1 },
	{ 0xF0A090AE, 0xFDEAC },
	{ 0xF0A090AF, 0xFDEAE },
	{ 0xF0A090B0, 0xFDEAF },
	{ 0xF0A090B1, 0x7BEF5 },
	{ 0xF0A090B2, 0x5E1B1 },
	{ 0xF0A090B3, 0x4DAEC },
	{ 0xF0A090B5, 0x5E1AF },
	{ 0xF0A090B6, 0x5E1B0 },
	{ 0xF0A090BA, 0x5E1B2 },
	{ 0xF0A090BB, 0x5E7CA },
	{ 0xF0A090BC, 0x5E7CE },
	{ 0xF0A090BD, 0x4E3AE },
	{ 0xF0A090BE, 0x5E7CD },
	{ 0xF0A090BF, 0x5E7CF },
	{ 0xF0A09180, 0xFE1FE },
	{ 0xF0A09181, 0xFE2A1 },
	{ 0xF0A09182, 0x7C7EF },
	{ 0xF0A09184, 0x5E7CC },
	{ 0xF0A09185, 0x5E7CB },
	{ 0xF0A0918C, 0x5E9FC },
	{ 0xF0A0918D, 0x7D2F5 },
	{ 0xF0A0918E, 0x7CDBC },
	{ 0xF0A0918F, 0xFE4FA },
	{ 0xF0A09191, 0x5EBEB },
	{ 0xF0A09192, 0x7CDBB },
	{ 0xF0A09193, 0x7CDE8 },
	{ 0xF0A09197, 0x4E6AF },
	{ 0xF0A09198, 0x4E6AE },
	{ 0xF0A09199, 0x5EFE8 },
	{ 0xF0A0919A, 0x7D7CE },
	{ 0xF0A0919B, 0x5EBEC },
	{ 0xF0A0919C, 0xFE7BF },
	{ 0xF0A0919D, 0xFE7FE },
	{ 0xF0A0919F, 0x4E6AD },
	{ 0xF0A091A4, 0x7D7CD },
	{ 0xF0A091A6, 0xFE9B8 },
	{ 0xF0A091A7, 0xFE9BA },
	{ 0xF0A091A8, 0xFE9B9 },
	{ 0xF0A091A9, 0x5F3B1 },
	{ 0xF0A091AA, 0x4EAC0 },
	{ 0xF0A091AB, 0x7DBC5 },
	{ 0xF0A091AD, 0xFEACB },
	{ 0xF0A091AE, 0xFEBC1 },
	{ 0xF0A091AF, 0x5F5E2 },
	{ 0xF0A091B2, 0x4EDD2 },
	{ 0xF0A091B3, 0xFECC9 },
	{ 0xF0A091B6, 0x6A1CD },
	{ 0xF0A091B7, 0x4A1DC },
	{ 0xF0A091B9, 0x4A2B2 },
	{ 0xF0A091BA, 0x6A3D3 },
	{ 0xF0A091BB, 0x6A3D4 },
	{ 0xF0A091BD, 0x6A5F5 },
	{ 0xF0A091BE, 0x6A5F7 },
	{ 0xF0A091BF, 0x6A5F8 },
	{ 0xF0A09280, 0x5A3B5 },
	{ 0xF0A09281, 0x6A5F6 },
	{ 0xF0A09283, 0x6A9D1 },
	{ 0xF0A09284, 0x6A9D0 },
	{ 0xF0A09285, 0x6A9CF },
	{ 0xF0A09286, 0x6A9D3 },
	{ 0xF0A09288, 0xFA5D3 },
	{ 0xF0A0928A, 0x6A9D2 },
	{ 0xF0A0928B, 0xFA5D2 },
	{ 0xF0A0928C, 0x6AEE7 },
	{ 0xF0A0928D, 0x6AEE8 },
	{ 0xF0A09290, 0x5ABF6 },
	{ 0xF0A09293, 0xFADFD },
	{ 0xF0A09294, 0xFADFE },
	{ 0xF0A09295, 0xFAEA1 },
	{ 0xF0A09296, 0x6B5BC },
	{ 0xF0A09297, 0xFB3A8 },
	{ 0xF0A09298, 0x5B1A4 },
	{ 0xF0A09299, 0x5B1A5 },
	{ 0xF0A0929A, 0xFB3A9 },
	{ 0xF0A0929B, 0xFB3AA },
	{ 0xF0A0929E, 0x6C6D9 },
	{ 0xF0A0929F, 0xFB9C0 },
	{ 0xF0A092A0, 0xFB9C1 },
	{ 0xF0A092A1, 0xFB9C2 },
	{ 0xF0A092A2, 0x5B6D8 },
	{ 0xF0A092A3, 0xFB9C3 },
	{ 0xF0A092A4, 0xFC0C7 },
	{ 0xF0A092A8, 0x6D0E3 },
	{ 0xF0A092A9, 0xFC0C8 },
	{ 0xF0A092AA, 0xFC6D9 },
	{ 0xF0A092AB, 0xFC6DA },
	{ 0xF0A092AD, 0x5C4D9 },
	{ 0xF0A092B0, 0x7A1B4 },
	{ 0xF0A092B1, 0x7A1B2 },
	{ 0xF0A092B2, 0x5CBFB },
	{ 0xF0A092B3, 0xFCDE3 },
	{ 0xF0A092B4, 0xFCDE4 },
	{ 0xF0A092B5, 0x5CBFA },
	{ 0xF0A092B6, 0x7A1B3 },
	{ 0xF0A092B8, 0x5D3DC },
	{ 0xF0A092B9, 0x7ACC1 },
	{ 0xF0A092BA, 0xFD3CB },
	{ 0xF0A092BB, 0xFD3CC },
	{ 0xF0A092BC, 0xFD3CD },
	{ 0xF0A092BD, 0xFD3CE },
	{ 0xF0A092BF, 0x5DAF1 },
	{ 0xF0A09382, 0xFD9CF },
	{ 0xF0A09383, 0xFD9D0 },
	{ 0xF0A09384, 0xFD9D1 },
	{ 0xF0A09386, 0x7BEF9 },
	{ 0xF0A09388, 0x5E1B3 },
	{ 0xF0A09389, 0xFDEB2 },
	{ 0xF0A0938B, 0x7C6A9 },
	{ 0xF0A0938C, 0x5E7D0 },
	{ 0xF0A0938D, 0xFE4FB },
	{ 0xF0A0938E, 0x5E7D1 },
	{ 0xF0A0938F, 0x5EBED },
	{ 0xF0A09392, 0xFE7C1 },
	{ 0xF0A09393, 0xFE9BB },
	{ 0xF0A09395, 0xFEACC },
	{ 0xF0A09397, 0x5F7D3 },
	{ 0xF0A09398, 0xFEBC2 },
	{ 0xF0A0939B, 0x6A1B6 },
	{ 0xF0A0939C, 0x5A1B6 },
	{ 0xF0A0939D, 0x5A1B5 },
	{ 0xF0A0939F, 0x6A2B7 },
	{ 0xF0A093A0, 0x6A3D6 },
	{ 0xF0A093A1, 0x6A3D5 },
	{ 0xF0A093A4, 0x5A3B6 },
	{ 0xF0A093A5, 0x6A5F9 },
	{ 0xF0A093A7, 0x5A3B8 },
	{ 0xF0A093AA, 0x5A8A5 },
	{ 0xF0A093AB, 0x5A8A6 },
	{ 0xF0A093AD, 0x4ABEA },
	{ 0xF0A093AE, 0x6B5BD },
	{ 0xF0A093AF, 0xFAEA2 },
	{ 0xF0A093B0, 0xFAEA3 },
	{ 0xF0A093B1, 0x6BDBA },
	{ 0xF0A093B3, 0x6C6DA },
	{ 0xF0A093B4, 0x6D0E4 },
	{ 0xF0A093B6, 0x5BDE3 },
	{ 0xF0A093B7, 0x4BCB1 },
	{ 0xF0A093B8, 0x6DAF8 },
	{ 0xF0A093BD, 0x5DAF2 },
	{ 0xF0A09480, 0x6A1B7 },
	{ 0xF0A09481, 0x6A1CE },
	{ 0xF0A09482, 0x5A1B7 },
	{ 0xF0A09483, 0x6A1C1 },
	{ 0xF0A09484, 0x6A1D9 },
	{ 0xF0A09486, 0x5A1D0 },
	{ 0xF0A09487, 0x6A3BB },
	{ 0xF0A09488, 0x4A2B5 },
	{ 0xF0A09489, 0x6A3D7 },
	{ 0xF0A0948A, 0x6A5FC },
	{ 0xF0A0948B, 0x6A5FE },
	{ 0xF0A0948C, 0x5A3B9 },
	{ 0xF0A0948E, 0xFA3AD },
	{ 0xF0A0948F, 0x6A5FA },
	{ 0xF0A09490, 0x6A9D4 },
	{ 0xF0A09492, 0x6AEEB },
	{ 0xF0A09493, 0x6AEE9 },
	{ 0xF0A09495, 0x5A8A7 },
	{ 0xF0A09496, 0x6AEEA },
	{ 0xF0A09497, 0x6AECF },
	{ 0xF0A09498, 0x6B0FB },
	{ 0xF0A09499, 0x6B5C0 },
	{ 0xF0A0949A, 0x6B5BF },
	{ 0xF0A0949B, 0x6B5C1 },
	{ 0xF0A0949C, 0x6B5BE },
	{ 0xF0A0949D, 0x6BDBB },
	{ 0xF0A0949F, 0x6C6DD },
	{ 0xF0A094A0, 0x5BDE4 },
	{ 0xF0A094A1, 0xFB9C4 },
	{ 0xF0A094A2, 0xFB9C5 },
	{ 0xF0A094A5, 0x6C6DB },
	{ 0xF0A094A7, 0x6C6DC },
	{ 0xF0A094A8, 0x5BDE5 },
	{ 0xF0A094A9, 0x6D0E5 },
	{ 0xF0A094AA, 0xFC0C9 },
	{ 0xF0A094AB, 0xFC0CA },
	{ 0xF0A094AF, 0x4C2BA },
	{ 0xF0A094B1, 0x6DAF9 },
	{ 0xF0A094B3, 0xFD4C6 },
	{ 0xF0A094B4, 0xFD3CF },
	{ 0xF0A094B5, 0xFD3D0 },
	{ 0xF0A094B6, 0x5E1B4 },
	{ 0xF0A094B7, 0xFDEB3 },
	{ 0xF0A094B8, 0x7C6AA },
	{ 0xF0A094B9, 0x7C6AB },
	{ 0xF0A094BC, 0x4A1AD },
	{ 0xF0A094BD, 0x6A1CF },
	{ 0xF0A094BE, 0x6A1D1 },
	{ 0xF0A09581, 0x6A2B9 },
	{ 0xF0A09582, 0x4A1DD },
	{ 0xF0A09583, 0x6A2B8 },
	{ 0xF0A09584, 0x5A1D2 },
	{ 0xF0A09586, 0xFA1C6 },
	{ 0xF0A09588, 0x6A2BA },
	{ 0xF0A0958A, 0x5A1D1 },
	{ 0xF0A0958B, 0x6A3DA },
	{ 0xF0A0958D, 0x6A3D8 },
	{ 0xF0A0958E, 0x6A5C7 },
	{ 0xF0A09590, 0x6A6A3 },
	{ 0xF0A09591, 0x6A6A1 },
	{ 0xF0A09592, 0x6A6A2 },
	{ 0xF0A09593, 0x5A3BA },
	{ 0xF0A09594, 0x6A8FA },
	{ 0xF0A09596, 0x5A5AC },
	{ 0xF0A09598, 0x6A9D5 },
	{ 0xF0A0959A, 0x6A9D6 },
	{ 0xF0A0959B, 0x6AEEC },
	{ 0xF0A0959D, 0x6B5C2 },
	{ 0xF0A0959E, 0x6B5C3 },
	{ 0xF0A0959F, 0x5ABF7 },
	{ 0xF0A095A0, 0x5ABF8 },
	{ 0xF0A095A2, 0x6BDBD },
	{ 0xF0A095A3, 0x6C6DF },
	{ 0xF0A095A4, 0x3B9F7 },
	{ 0xF0A095A5, 0x6C6DE },
	{ 0xF0A095A6, 0x4BCB3 },
	{ 0xF0A095A7, 0x5BDE6 },
	{ 0xF0A095A8, 0x6DAFB },
	{ 0xF0A095A9, 0x6DAFA },
	{ 0xF0A095AC, 0x7A1B5 },
	{ 0xF0A095AD, 0x5D3DD },
	{ 0xF0A095AE, 0x7ACC2 },
	{ 0xF0A095AF, 0xFD5F6 },
	{ 0xF0A095B0, 0x4DAED },
	{ 0xF0A095B1, 0xFE7C2 },
	{ 0xF0A095B2, 0x7D7CF },
	{ 0xF0A095B3, 0x5A1B8 },
	{ 0xF0A095B5, 0x6A2BB },
	{ 0xF0A095B6, 0xFA1C8 },
	{ 0xF0A095B7, 0xFA1C9 },
	{ 0xF0A095B9, 0x6A3DB },
	{ 0xF0A095BA, 0x4A2B7 },
	{ 0xF0A095BB, 0x5A2A9 },
	{ 0xF0A095BD, 0xFA1FB },
	{ 0xF0A09680, 0xFA3AE },
	{ 0xF0A09681, 0xFA3AF },
	{ 0xF0A09684, 0x5A5AD },
	{ 0xF0A09685, 0xFA5D5 },
	{ 0xF0A0968A, 0x6AEED },
	{ 0xF0A0968C, 0x6BDBE },
	{ 0xF0A0968D, 0xFAEA5 },
	{ 0xF0A0968F, 0xFAEA6 },
	{ 0xF0A09690, 0xFAEA7 },
	{ 0xF0A09691, 0xFAEA8 },
	{ 0xF0A09692, 0xFAEA9 },
	{ 0xF0A09693, 0x5B1A7 },
	{ 0xF0A09694, 0x6C6E0 },
	{ 0xF0A09695, 0xFB9C7 },
	{ 0xF0A09696, 0xFB9C8 },
	{ 0xF0A09697, 0x6C6E1 },
	{ 0xF0A09699, 0xFBADD },
	{ 0xF0A0969A, 0x6D0E6 },
	{ 0xF0A0969C, 0x6DAFC },
	{ 0xF0A0969E, 0xFC6DB },
	{ 0xF0A0969F, 0x5CEF7 },
	{ 0xF0A096A0, 0x7ACC3 },
	{ 0xF0A096A1, 0xFD9D2 },
	{ 0xF0A096A2, 0xFD3D1 },
	{ 0xF0A096A3, 0x7BEFA },
	{ 0xF0A096A6, 0x7C6AC },
	{ 0xF0A096A7, 0x7CDBF },
	{ 0xF0A096A9, 0x5EFE9 },
	{ 0xF0A096AB, 0x5F5E3 },
	{ 0xF0A096AE, 0xFA1CA },
	{ 0xF0A096B1, 0x6A3DC },
	{ 0xF0A096B2, 0xFA1FD },
	{ 0xF0A096B4, 0xFA1FE },
	{ 0xF0A096B6, 0x4A2B8 },
	{ 0xF0A096B7, 0x5A3BB },
	{ 0xF0A096B8, 0x6A6A4 },
	{ 0xF0A096B9, 0x4A3BC },
	{ 0xF0A096BA, 0xFA3B0 },
	{ 0xF0A096BB, 0xFA3B1 },
	{ 0xF0A096BC, 0xFA3B2 },
	{ 0xF0A096BD, 0xFA3B3 },
	{ 0xF0A09780, 0xFA3A4 },
	{ 0xF0A09781, 0xFA2FE },
	{ 0xF0A09782, 0x4A5C1 },
	{ 0xF0A09783, 0x4A5C2 },
	{ 0xF0A09784, 0x6A9D8 },
	{ 0xF0A09785, 0x6A9D9 },
	{ 0xF0A09786, 0x5A5AF },
	{ 0xF0A09787, 0xFA5D7 },
	{ 0xF0A09788, 0x5A8A9 },
	{ 0xF0A09789, 0x4A8C1 },
	{ 0xF0A0978A, 0x4A8C2 },
	{ 0xF0A0978B, 0x5A8AC },
	{ 0xF0A0978C, 0x5A8A8 },
	{ 0xF0A0978D, 0x5A8AA },
	{ 0xF0A0978E, 0x6AEEF },
	{ 0xF0A09791, 0xFA9BA },
	{ 0xF0A09792, 0xFA9BC },
	{ 0xF0A09793, 0xFA9BD },
	{ 0xF0A09794, 0xFA9BE },
	{ 0xF0A09795, 0xFA9BF },
	{ 0xF0A09797, 0x6AEEE },
	{ 0xF0A09798, 0x5ABFA },
	{ 0xF0A09799, 0x4ABEB },
	{ 0xF0A0979A, 0x5ABF9 },
	{ 0xF0A0979B, 0x5A8AB },
	{ 0xF0A0979C, 0x6B5C5 },
	{ 0xF0A0979D, 0x5ABFB },
	{ 0xF0A0979E, 0xFAEAA },
	{ 0xF0A097A1, 0xFAEAB },
	{ 0xF0A097A2, 0x6B5C6 },
	{ 0xF0A097A5, 0x5B1A8 },
	{ 0xF0A097A6, 0x6BDBF },
	{ 0xF0A097A7, 0x6BDC0 },
	{ 0xF0A097A8, 0x4B0CE },
	{ 0xF0A097AA, 0xFB3AB },
	{ 0xF0A097AC, 0xFB3AC },
	{ 0xF0A097AD, 0xFB3AD },
	{ 0xF0A097AE, 0xFB3AF },
	{ 0xF0A097AF, 0xFB3B0 },
	{ 0xF0A097B1, 0x6C6E2 },
	{ 0xF0A097B2, 0x5B6DC },
	{ 0xF0A097B3, 0x5B6DA },
	{ 0xF0A097B4, 0x5B6DB },
	{ 0xF0A097B5, 0x5B6D9 },
	{ 0xF0A097B6, 0x4B6BE },
	{ 0xF0A097B7, 0xFB3AE },
	{ 0xF0A097BA, 0x5BDEC },
	{ 0xF0A097BB, 0x5BDE7 },
	{ 0xF0A097BC, 0x5BDE9 },
	{ 0xF0A097BD, 0x5BDEA },
	{ 0xF0A097BE, 0x5BDE8 },
	{ 0xF0A097BF, 0x5BDEB },
	{ 0xF0A09880, 0x6D0E7 },
	{ 0xF0A09884, 0x6DAFD },
	{ 0xF0A09885, 0x5CCA1 },
	{ 0xF0A09886, 0x5C4DA },
	{ 0xF0A09887, 0x7A1B7 },
	{ 0xF0A09888, 0xFC6DD },
	{ 0xF0A09889, 0xFC6DE },
	{ 0xF0A0988A, 0x5CBFE },
	{ 0xF0A0988B, 0x5CBFD },
	{ 0xF0A0988C, 0x5CBFC },
	{ 0xF0A0988D, 0x7A1B6 },
	{ 0xF0A0988E, 0xFCDE7 },
	{ 0xF0A09891, 0xFD3D3 },
	{ 0xF0A09892, 0x7ACC5 },
	{ 0xF0A09893, 0xFCDE6 },
	{ 0xF0A09894, 0xFD3D2 },
	{ 0xF0A09896, 0x4D5EA },
	{ 0xF0A09897, 0x7ACC6 },
	{ 0xF0A09898, 0x5DAF3 },
	{ 0xF0A0989B, 0xFD9D3 },
	{ 0xF0A0989C, 0xFD9D4 },
	{ 0xF0A0989D, 0x5E1B6 },
	{ 0xF0A0989E, 0x5E1B5 },
	{ 0xF0A0989F, 0x5E1B7 },
	{ 0xF0A098A0, 0xFDEB4 },
	{ 0xF0A098A1, 0x7BEFB },
	{ 0xF0A098A2, 0x5E7D2 },
	{ 0xF0A098A3, 0x5E7D3 },
	{ 0xF0A098A4, 0x7D2F6 },
	{ 0xF0A098A5, 0x5F3B2 },
	{ 0xF0A098A7, 0x4A1A9 },
	{ 0xF0A098A9, 0x6A1D2 },
	{ 0xF0A098AB, 0xFA1AA },
	{ 0xF0A098AC, 0xFA1AB },
	{ 0xF0A098AD, 0xFA1AC },
	{ 0xF0A098AE, 0xFA1AE },
	{ 0xF0A098AF, 0x6A1DC },
	{ 0xF0A098B0, 0xFA1AD },
	{ 0xF0A098B1, 0x5A1D3 },
	{ 0xF0A098B2, 0x6A2BD },
	{ 0xF0A098B3, 0x4A1DF },
	{ 0xF0A098B5, 0x6A3DE },
	{ 0xF0A098B6, 0x6A3DD },
	{ 0xF0A098B7, 0x6A3DF },
	{ 0xF0A098B8, 0x6A3E0 },
	{ 0xF0A098BA, 0xFA1CB },
	{ 0xF0A098BC, 0x6A6A7 },
	{ 0xF0A098BD, 0x6A6A5 },
	{ 0xF0A098BE, 0x6A6A6 },
	{ 0xF0A098BF, 0xFA3B4 },
	{ 0xF0A09980, 0xFA3B5 },
	{ 0xF0A09986, 0x4A5C6 },
	{ 0xF0A09987, 0x6A9DA },
	{ 0xF0A09988, 0x4A5C4 },
	{ 0xF0A09989, 0x6A9DB },
	{ 0xF0A0998A, 0x6A9DC },
	{ 0xF0A0998B, 0x6A9DD },
	{ 0xF0A0998C, 0xFA5D8 },
	{ 0xF0A0998D, 0xFA5D9 },
	{ 0xF0A0998F, 0x6AEF2 },
	{ 0xF0A09990, 0x6AEF0 },
	{ 0xF0A09991, 0x6AEF1 },
	{ 0xF0A09992, 0x6B5C7 },
	{ 0xF0A09993, 0xFAEAC },
	{ 0xF0A09997, 0x6B7A7 },
	{ 0xF0A09998, 0x6BDC2 },
	{ 0xF0A09999, 0x6BDC3 },
	{ 0xF0A0999A, 0x6BDC1 },
	{ 0xF0A0999B, 0xFB3B1 },
	{ 0xF0A0999C, 0xFB3B2 },
	{ 0xF0A0999D, 0xFB3B3 },
	{ 0xF0A0999F, 0x6C6E3 },
	{ 0xF0A099A0, 0x6C6E6 },
	{ 0xF0A099A1, 0xFB9C9 },
	{ 0xF0A099A2, 0x6C6E4 },
	{ 0xF0A099A7, 0xFB9CA },
	{ 0xF0A099A8, 0xFC6DF },
	{ 0xF0A099A9, 0xFC6E0 },
	{ 0xF0A099AA, 0xFC6E1 },
	{ 0xF0A099AB, 0xFCDE8 },
	{ 0xF0A099AD, 0x7ACC7 },
	{ 0xF0A099AE, 0xFD3D4 },
	{ 0xF0A099AF, 0xFD3D5 },
	{ 0xF0A099B0, 0xFD3C3 },
	{ 0xF0A099B1, 0xFD9D5 },
	{ 0xF0A099B2, 0xFDEB5 },
	{ 0xF0A099B3, 0xFE7C3 },
	{ 0xF0A099B5, 0x4A1AE },
	{ 0xF0A099B6, 0x5A1B9 },
	{ 0xF0A099B7, 0x6A1D3 },
	{ 0xF0A099B8, 0x6A1D4 },
	{ 0xF0A099B9, 0x6A2BF },
	{ 0xF0A099BA, 0x5A1D4 },
	{ 0xF0A099BB, 0x6A2BE },
	{ 0xF0A099BD, 0xFA1CC },
	{ 0xF0A099BE, 0x6A3E5 },
	{ 0xF0A099BF, 0x6A3E1 },
	{ 0xF0A09A80, 0x6A3E2 },
	{ 0xF0A09A81, 0x6A3E3 },
	{ 0xF0A09A82, 0xFA2A1 },
	{ 0xF0A09A86, 0x5A2AA },
	{ 0xF0A09A87, 0x6A6A8 },
	{ 0xF0A09A88, 0xFA3B6 },
	{ 0xF0A09A8B, 0x6A9E0 },
	{ 0xF0A09A8D, 0x6A9DF },
	{ 0xF0A09A8E, 0x6AEF3 },
	{ 0xF0A09A8F, 0x6AEF4 },
	{ 0xF0A09A91, 0x6B4FA },
	{ 0xF0A09A92, 0x6B5C8 },
	{ 0xF0A09A96, 0x6BDC4 },
	{ 0xF0A09A97, 0x6BDC5 },
	{ 0xF0A09A98, 0x5B6DD },
	{ 0xF0A09A99, 0x6DAFE },
	{ 0xF0A09A9A, 0xFC6E2 },
	{ 0xF0A09A9B, 0x7A1F0 },
	{ 0xF0A09A9D, 0x7B6FB },
	{ 0xF0A09A9E, 0x5DAF6 },
	{ 0xF0A09A9F, 0x5E7D4 },
	{ 0xF0A09AA1, 0x7CEBE },
	{ 0xF0A09AA3, 0x6A1B9 },
	{ 0xF0A09AA5, 0x4A1C0 },
	{ 0xF0A09AA6, 0x6A1D5 },
	{ 0xF0A09AA7, 0x5A1BA },
	{ 0xF0A09AA8, 0x5A1BB },
	{ 0xF0A09AA9, 0x6A1D6 },
	{ 0xF0A09AAA, 0x4A1C1 },
	{ 0xF0A09AAB, 0xFA1AF },
	{ 0xF0A09AAC, 0x6A1D7 },
	{ 0xF0A09AAD, 0x5A1D5 },
	{ 0xF0A09AAE, 0x5A1D6 },
	{ 0xF0A09AAF, 0x4A1E2 },
	{ 0xF0A09AB0, 0x6A2C4 },
	{ 0xF0A09AB1, 0x5A1D7 },
	{ 0xF0A09AB2, 0x6A2C3 },
	{ 0xF0A09AB3, 0x6A2C0 },
	{ 0xF0A09AB4, 0x6A2C5 },
	{ 0xF0A09AB7, 0x4A2BA },
	{ 0xF0A09AB8, 0x6A3EA },
	{ 0xF0A09AB9, 0x5A2AE },
	{ 0xF0A09ABA, 0x5A2AC },
	{ 0xF0A09ABB, 0x5A2AB },
	{ 0xF0A09ABC, 0x4A2BB },
	{ 0xF0A09ABD, 0x4A2B9 },
	{ 0xF0A09ABE, 0x6A3E8 },
	{ 0xF0A09ABF, 0x6A3E7 },
	{ 0xF0A09B80, 0x5A2AF },
	{ 0xF0A09B81, 0x6A3EB },
	{ 0xF0A09B82, 0x6A3E9 },
	{ 0xF0A09B83, 0x5A2AD },
	{ 0xF0A09B84, 0x4A2BD },
	{ 0xF0A09B87, 0xFA2A2 },
	{ 0xF0A09B88, 0xFA2A3 },
	{ 0xF0A09B89, 0x4A2BE },
	{ 0xF0A09B8D, 0x6A3E6 },
	{ 0xF0A09B8E, 0x4A3C1 },
	{ 0xF0A09B8F, 0x6A6AB },
	{ 0xF0A09B90, 0x4A3C3 },
	{ 0xF0A09B91, 0x5A3BD },
	{ 0xF0A09B92, 0x4A3C2 },
	{ 0xF0A09B93, 0x5A3C6 },
	{ 0xF0A09B94, 0x5A3C5 },
	{ 0xF0A09B95, 0x5A3C3 },
	{ 0xF0A09B96, 0x5A3C0 },
	{ 0xF0A09B97, 0x6A6A9 },
	{ 0xF0A09B98, 0x5A3BF },
	{ 0xF0A09B99, 0x5A3C2 },
	{ 0xF0A09B9A, 0x5A3C1 },
	{ 0xF0A09B9B, 0x6A6AA },
	{ 0xF0A09BA0, 0x6A6AC },
	{ 0xF0A09BA5, 0x5A3BE },
	{ 0xF0A09BA6, 0x5A3C4 },
	{ 0xF0A09BA7, 0x6A9E9 },
	{ 0xF0A09BA8, 0x5A5B3 },
	{ 0xF0A09BA9, 0x5A5B5 },
	{ 0xF0A09BAA, 0x4A5C9 },
	{ 0xF0A09BAB, 0x4A5CB },
	{ 0xF0A09BAC, 0x3A7DC },
	{ 0xF0A09BAD, 0x6A9E6 },
	{ 0xF0A09BAE, 0x4A5CD },
	{ 0xF0A09BAF, 0x6A9E4 },
	{ 0xF0A09BB0, 0x6A9E5 },
	{ 0xF0A09BB1, 0x6A9EC },
	{ 0xF0A09BB2, 0x6AEF5 },
	{ 0xF0A09BB4, 0x6A9EA },
	{ 0xF0A09BB5, 0x5A5B0 },
	{ 0xF0A09BB6, 0x5A5B6 },
	{ 0xF0A09BB7, 0x6A9EB },
	{ 0xF0A09BB8, 0x5A5B2 },
	{ 0xF0A09BB9, 0x6A9E7 },
	{ 0xF0A09BBB, 0x5A5B4 },
	{ 0xF0A09BBC, 0xFA5DA },
	{ 0xF0A09BBD, 0xFA5DB },
	{ 0xF0A09BBE, 0xFA5DC },
	{ 0xF0A09BBF, 0xFA5DD },
	{ 0xF0A09C82, 0x6A9E8 },
	{ 0xF0A09C86, 0x6A9E2 },
	{ 0xF0A09C87, 0x6A9E1 },
	{ 0xF0A09C89, 0x5A5B1 },
	{ 0xF0A09C8C, 0x6A9D7 },
	{ 0xF0A09C90, 0x4A8C7 },
	{ 0xF0A09C91, 0x5A8AD },
	{ 0xF0A09C92, 0x4A8C5 },
	{ 0xF0A09C93, 0x6AFA4 },
	{ 0xF0A09C94, 0x6AEFB },
	{ 0xF0A09C95, 0x6AFA2 },
	{ 0xF0A09C96, 0x4A8C8 },
	{ 0xF0A09C97, 0x6AFA1 },
	{ 0xF0A09C98, 0x4A8C4 },
	{ 0xF0A09C99, 0x4A8C6 },
	{ 0xF0A09C9A, 0x6AEF8 },
	{ 0xF0A09C9B, 0x6AEFE },
	{ 0xF0A09C9C, 0x6AFA3 },
	{ 0xF0A09C9D, 0x6AEFA },
	{ 0xF0A09C9F, 0x6AEFD },
	{ 0xF0A09CA0, 0x6AEFC },
	{ 0xF0A09CA1, 0xFA9C0 },
	{ 0xF0A09CA2, 0xFA9C1 },
	{ 0xF0A09CA3, 0xFA9C2 },
	{ 0xF0A09CA5, 0x6AEF9 },
	{ 0xF0A09CA6, 0x5A8AE },
	{ 0xF0A09CA8, 0x6AEF7 },
	{ 0xF0A09CB0, 0x6B5C9 },
	{ 0xF0A09CB1, 0x4ABF0 },
	{ 0xF0A09CB2, 0x4ABED },
	{ 0xF0A09CB3, 0x5ACA5 },
	{ 0xF0A09CB4, 0x5ACA3 },
	{ 0xF0A09CB5, 0x4ABEF },
	{ 0xF0A09CB6, 0x4ABF3 },
	{ 0xF0A09CB7, 0x6B5CE },
	{ 0xF0A09CB8, 0x6B5D2 },
	{ 0xF0A09CB9, 0x5ACA2 },
	{ 0xF0A09CBA, 0x6B5D3 },
	{ 0xF0A09CBB, 0x4ABEC },
	{ 0xF0A09CBC, 0x5ACA6 },
	{ 0xF0A09CBD, 0x6B5D1 },
	{ 0xF0A09CBE, 0x4ABF1 },
	{ 0xF0A09CBF, 0x6B5D0 },
	{ 0xF0A09D80, 0x6B5CF },
	{ 0xF0A09D81, 0x6B5CC },
	{ 0xF0A09D82, 0x6B5CB },
	{ 0xF0A09D83, 0x4ABF2 },
	{ 0xF0A09D84, 0x5ACA4 },
	{ 0xF0A09D85, 0x6B5CD },
	{ 0xF0A09D88, 0xFAEB3 },
	{ 0xF0A09D89, 0x6B5D4 },
	{ 0xF0A09D8A, 0xFAEAE },
	{ 0xF0A09D8B, 0xFAEAF },
	{ 0xF0A09D8C, 0xFAEB0 },
	{ 0xF0A09D8D, 0xFAEB2 },
	{ 0xF0A09D91, 0xFAEB1 },
	{ 0xF0A09D92, 0x6B5CA },
	{ 0xF0A09D98, 0x5ACA7 },
	{ 0xF0A09D99, 0x5ABFD },
	{ 0xF0A09D9A, 0x5ACA1 },
	{ 0xF0A09D9B, 0x5ABFE },
	{ 0xF0A09D9D, 0x4B0D0 },
	{ 0xF0A09D9E, 0x5B1AB },
	{ 0xF0A09D9F, 0x4B0D1 },
	{ 0xF0A09DA0, 0x5B1AA },
	{ 0xF0A09DA1, 0x6BDC6 },
	{ 0xF0A09DA2, 0x4B0D6 },
	{ 0xF0A09DA3, 0x4B6C9 },
	{ 0xF0A09DA4, 0x4B0D5 },
	{ 0xF0A09DA5, 0x6BDC9 },
	{ 0xF0A09DA7, 0x6BDC7 },
	{ 0xF0A09DA8, 0x5B6DE },
	{ 0xF0A09DA9, 0x4B0CF },
	{ 0xF0A09DAA, 0x5ACA8 },
	{ 0xF0A09DAD, 0xFB3B4 },
	{ 0xF0A09DAE, 0xFB3B5 },
	{ 0xF0A09DAF, 0xFB3B7 },
	{ 0xF0A09DB1, 0x6BDC8 },
	{ 0xF0A09DBD, 0x6BDCA },
	{ 0xF0A09DBE, 0x6BDCB },
	{ 0xF0A09DBF, 0x4B6C3 },
	{ 0xF0A09E80, 0x5B6DF },
	{ 0xF0A09E81, 0x6C6ED },
	{ 0xF0A09E82, 0x6C6E9 },
	{ 0xF0A09E83, 0x4B6C6 },
	{ 0xF0A09E84, 0x4B6C7 },
	{ 0xF0A09E85, 0x5B6E0 },
	{ 0xF0A09E86, 0x5B6E4 },
	{ 0xF0A09E87, 0x4B6CA },
	{ 0xF0A09E88, 0x4B6C4 },
	{ 0xF0A09E89, 0x4B6C1 },
	{ 0xF0A09E8A, 0x4B6C0 },
	{ 0xF0A09E8B, 0x6C6EB },
	{ 0xF0A09E8C, 0x6C6E8 },
	{ 0xF0A09E8D, 0x6C6EC },
	{ 0xF0A09E8E, 0x5B6E1 },
	{ 0xF0A09E8F, 0x5B6E2 },
	{ 0xF0A09E90, 0x6C6EA },
	{ 0xF0A09E91, 0xFB9CB },
	{ 0xF0A09E92, 0xFB9CC },
	{ 0xF0A09E93, 0xFB9CD },
	{ 0xF0A09E94, 0xFB9CE },
	{ 0xF0A09E98, 0x4B6C8 },
	{ 0xF0A09E9C, 0x6CCC6 },
	{ 0xF0A09E9D, 0x6C6EE },
	{ 0xF0A09EA4, 0x5B6E5 },
	{ 0xF0A09EA5, 0x4BCB9 },
	{ 0xF0A09EA6, 0x6D0EF },
	{ 0xF0A09EA7, 0x5BDF3 },
	{ 0xF0A09EA8, 0x6D0ED },
	{ 0xF0A09EA9, 0x4BCB5 },
	{ 0xF0A09EAA, 0x5BDF4 },
	{ 0xF0A09EAB, 0x6D0EE },
	{ 0xF0A09EAC, 0x5BDED },
	{ 0xF0A09EAD, 0x4BCB7 },
	{ 0xF0A09EAE, 0x4BCB6 },
	{ 0xF0A09EAF, 0x5BDEE },
	{ 0xF0A09EB0, 0x4BCBA },
	{ 0xF0A09EB1, 0x5BDEF },
	{ 0xF0A09EB2, 0x6D0EB },
	{ 0xF0A09EB3, 0xFC0CB },
	{ 0xF0A09EB7, 0x6D0EA },
	{ 0xF0A09EBB, 0x6D0E8 },
	{ 0xF0A09EBC, 0x6D0F0 },
	{ 0xF0A09EBD, 0x6D0E9 },
	{ 0xF0A09EBE, 0x5BDF2 },
	{ 0xF0A09EBF, 0x5BDF1 },
	{ 0xF0A09F81, 0xFC0CC },
	{ 0xF0A09F82, 0x5C4DB },
	{ 0xF0A09F83, 0x4C2BB },
	{ 0xF0A09F84, 0x6DBA4 },
	{ 0xF0A09F85, 0x5C4E1 },
	{ 0xF0A09F86, 0x6DBA2 },
	{ 0xF0A09F87, 0x6DBA1 },
	{ 0xF0A09F88, 0x4BCB8 },
	{ 0xF0A09F89, 0x4C2C0 },
	{ 0xF0A09F8A, 0x5C4E2 },
	{ 0xF0A09F8B, 0x5C4DC },
	{ 0xF0A09F8C, 0x5C4DF },
	{ 0xF0A09F8D, 0x4C2BD },
	{ 0xF0A09F8E, 0x4C2C4 },
	{ 0xF0A09F8F, 0x6DBAB },
	{ 0xF0A09F90, 0x6DBA9 },
	{ 0xF0A09F91, 0x6DBA8 },
	{ 0xF0A09F92, 0x5C4DE },
	{ 0xF0A09F93, 0x5CCA2 },
	{ 0xF0A09F94, 0x6DBA6 },
	{ 0xF0A09F95, 0x5C4DD },
	{ 0xF0A09F96, 0x6DBAA },
	{ 0xF0A09F97, 0x5C4E0 },
	{ 0xF0A09F98, 0x6DBA5 },
	{ 0xF0A09F99, 0xFC6E3 },
	{ 0xF0A09F9A, 0xFC6E4 },
	{ 0xF0A09F9B, 0xFC6E5 },
	{ 0xF0A09F9C, 0x6DBA3 },
	{ 0xF0A09F9F, 0x6DBA7 },
	{ 0xF0A09FA6, 0x5CCA3 },
	{ 0xF0A09FA7, 0x5CCA7 },
	{ 0xF0A09FA8, 0x4C9A4 },
	{ 0xF0A09FA9, 0x5CCA4 },
	{ 0xF0A09FAA, 0x5CCA6 },
	{ 0xF0A09FAB, 0x7A1BC },
	{ 0xF0A09FAC, 0x7A1BD },
	{ 0xF0A09FAD, 0x7A1BA },
	{ 0xF0A09FAE, 0x7A1BE },
	{ 0xF0A09FAF, 0x7A1BB },
	{ 0xF0A09FB0, 0x5CCA5 },
	{ 0xF0A09FB1, 0x7A1B8 },
	{ 0xF0A09FB3, 0x7A2DA },
	{ 0xF0A09FB5, 0x7A1B9 },
	{ 0xF0A09FBA, 0x4CFE0 },
	{ 0xF0A09FBB, 0x7ACC9 },
	{ 0xF0A09FBC, 0x5DAF7 },
	{ 0xF0A09FBD, 0x7ACCA },
	{ 0xF0A09FBE, 0x7ACCE },
	{ 0xF0A09FBF, 0x7ACCD },
	{ 0xF0A0A080, 0x7ACCC },
	{ 0xF0A0A081, 0x5D3DF },
	{ 0xF0A0A082, 0x5D3E1 },
	{ 0xF0A0A083, 0x5D3E0 },
	{ 0xF0A0A084, 0x5D3DE },
	{ 0xF0A0A085, 0x7ACC8 },
	{ 0xF0A0A086, 0x7ACCB },
	{ 0xF0A0A087, 0x7A1BF },
	{ 0xF0A0A088, 0xFD3D6 },
	{ 0xF0A0A08B, 0x5D8D1 },
	{ 0xF0A0A08D, 0x5DAFA },
	{ 0xF0A0A08E, 0x4D5EB },
	{ 0xF0A0A08F, 0x5DAF9 },
	{ 0xF0A0A090, 0x5DAF8 },
	{ 0xF0A0A092, 0x7B6FC },
	{ 0xF0A0A093, 0xFD9D6 },
	{ 0xF0A0A097, 0x4D5EE },
	{ 0xF0A0A09B, 0x7BEFC },
	{ 0xF0A0A09C, 0x5E1B8 },
	{ 0xF0A0A09D, 0x5E1B9 },
	{ 0xF0A0A09E, 0x7B6FD },
	{ 0xF0A0A09F, 0xFDEB6 },
	{ 0xF0A0A0A0, 0x5E1BA },
	{ 0xF0A0A0A1, 0x7C6AF },
	{ 0xF0A0A0A2, 0x7C6AE },
	{ 0xF0A0A0A3, 0x7C6AD },
	{ 0xF0A0A0A6, 0x7CDC0 },
	{ 0xF0A0A0A7, 0x7CDC1 },
	{ 0xF0A0A0AA, 0x5EFEA },
	{ 0xF0A0A0AB, 0x7D2F7 },
	{ 0xF0A0A0AC, 0xFE7C4 },
	{ 0xF0A0A0AE, 0x5F5E4 },
	{ 0xF0A0A0AF, 0x4EBE5 },
	{ 0xF0A0A0B0, 0x7E2AD },
	{ 0xF0A0A0B1, 0x7E2AC },
	{ 0xF0A0A0B2, 0x6A1BA },
	{ 0xF0A0A0B3, 0x5A1BC },
	{ 0xF0A0A0B4, 0x6A1D8 },
	{ 0xF0A0A0B6, 0x4A1E3 },
	{ 0xF0A0A0B7, 0x5A1D9 },
	{ 0xF0A0A0B8, 0x5A1D8 },
	{ 0xF0A0A0B9, 0x5A2B1 },
	{ 0xF0A0A0BB, 0x5A2B2 },
	{ 0xF0A0A0BC, 0xFA2A5 },
	{ 0xF0A0A0BD, 0xFA2A6 },
	{ 0xF0A0A0BE, 0xFA2A7 },
	{ 0xF0A0A0BF, 0xFA2A8 },
	{ 0xF0A0A181, 0x5A2B3 },
	{ 0xF0A0A182, 0x6A6AE },
	{ 0xF0A0A183, 0x4A3C5 },
	{ 0xF0A0A184, 0x5A3C7 },
	{ 0xF0A0A186, 0xFA3B8 },
	{ 0xF0A0A187, 0xFA3BA },
	{ 0xF0A0A188, 0xFA3BB },
	{ 0xF0A0A18C, 0x6A6AD },
	{ 0xF0A0A18D, 0x4A3C9 },
	{ 0xF0A0A191, 0x5A5BD },
	{ 0xF0A0A192, 0x5A5B9 },
	{ 0xF0A0A193, 0x6A9ED },
	{ 0xF0A0A194, 0x5A5BC },
	{ 0xF0A0A195, 0x6A9EE },
	{ 0xF0A0A196, 0xFA5E0 },
	{ 0xF0A0A197, 0xFA5E1 },
	{ 0xF0A0A198, 0xFA5E2 },
	{ 0xF0A0A199, 0xFA5E3 },
	{ 0xF0A0A19E, 0x5A8B0 },
	{ 0xF0A0A19F, 0x4A8CA },
	{ 0xF0A0A1A0, 0x6AFA6 },
	{ 0xF0A0A1A1, 0x5A8B1 },
	{ 0xF0A0A1A2, 0x5A8AF },
	{ 0xF0A0A1A6, 0x6AFA8 },
	{ 0xF0A0A1A8, 0xFA9C3 },
	{ 0xF0A0A1A9, 0xFA9C4 },
	{ 0xF0A0A1AA, 0xFA9C5 },
	{ 0xF0A0A1AB, 0x6B5D5 },
	{ 0xF0A0A1AC, 0x6B5D9 },
	{ 0xF0A0A1AD, 0x4ABF4 },
	{ 0xF0A0A1AE, 0x5ACAD },
	{ 0xF0A0A1AF, 0x5ACA9 },
	{ 0xF0A0A1B0, 0x5ACAB },
	{ 0xF0A0A1B1, 0x5ACAC },
	{ 0xF0A0A1B2, 0x5ACAA },
	{ 0xF0A0A1B4, 0xFAEB4 },
	{ 0xF0A0A1B5, 0xFAEB5 },
	{ 0xF0A0A1B8, 0x6B5D6 },
	{ 0xF0A0A1B9, 0x6B5D7 },
	{ 0xF0A0A1BB, 0x5B1AD },
	{ 0xF0A0A1BC, 0x6BDCE },
	{ 0xF0A0A1BD, 0x6BDCC },
	{ 0xF0A0A1BE, 0x6BDCF },
	{ 0xF0A0A1BF, 0x6BDD0 },
	{ 0xF0A0A280, 0x6BDD1 },
	{ 0xF0A0A281, 0xFB3B8 },
	{ 0xF0A0A282, 0xFB3B9 },
	{ 0xF0A0A284, 0x6BDCD },
	{ 0xF0A0A285, 0x5B6E9 },
	{ 0xF0A0A286, 0x5B6E6 },
	{ 0xF0A0A287, 0x5B6E8 },
	{ 0xF0A0A288, 0x5B6EB },
	{ 0xF0A0A289, 0x5B6E7 },
	{ 0xF0A0A28A, 0xFB9CF },
	{ 0xF0A0A28B, 0xFB9D0 },
	{ 0xF0A0A28E, 0x6C6EF },
	{ 0xF0A0A28F, 0x6C6F0 },
	{ 0xF0A0A292, 0x6C6F1 },
	{ 0xF0A0A293, 0x5BDF6 },
	{ 0xF0A0A294, 0x5BDF5 },
	{ 0xF0A0A295, 0x4BCBB },
	{ 0xF0A0A296, 0x6D0F2 },
	{ 0xF0A0A297, 0x6D0F1 },
	{ 0xF0A0A298, 0xFC0CD },
	{ 0xF0A0A299, 0x5BDF7 },
	{ 0xF0A0A2A0, 0x4C2C6 },
	{ 0xF0A0A2A1, 0x5C4E6 },
	{ 0xF0A0A2A2, 0x5C4E4 },
	{ 0xF0A0A2A3, 0x5C4E5 },
	{ 0xF0A0A2A4, 0x5C4E9 },
	{ 0xF0A0A2A5, 0x4C2C5 },
	{ 0xF0A0A2A6, 0x5C4E8 },
	{ 0xF0A0A2A7, 0x6DBAE },
	{ 0xF0A0A2A8, 0xFC6E6 },
	{ 0xF0A0A2AD, 0x6DBAC },
	{ 0xF0A0A2AF, 0x6DBAD },
	{ 0xF0A0A2B0, 0x5CCAB },
	{ 0xF0A0A2B1, 0x5CCA8 },
	{ 0xF0A0A2B2, 0x4C9A6 },
	{ 0xF0A0A2B3, 0x5CCA9 },
	{ 0xF0A0A2B4, 0x5CCAA },
	{ 0xF0A0A2B6, 0x7ACCF },
	{ 0xF0A0A2B7, 0x5DAFC },
	{ 0xF0A0A2B8, 0xFD3D7 },
	{ 0xF0A0A2B9, 0x5DAFB },
	{ 0xF0A0A2BA, 0x5DAFD },
	{ 0xF0A0A2BB, 0x7B6FE },
	{ 0xF0A0A2BC, 0x7B7A2 },
	{ 0xF0A0A2BF, 0x7B7A1 },
	{ 0xF0A0A380, 0x5E1BC },
	{ 0xF0A0A381, 0x7BEFE },
	{ 0xF0A0A383, 0x7BFA1 },
	{ 0xF0A0A384, 0x5E7D6 },
	{ 0xF0A0A385, 0x5E7D5 },
	{ 0xF0A0A386, 0x7CDC2 },
	{ 0xF0A0A387, 0x5EFEB },
	{ 0xF0A0A388, 0x7DBC6 },
	{ 0xF0A0A389, 0x5F5E5 },
	{ 0xF0A0A38A, 0x4ECEB },
	{ 0xF0A0A38B, 0x7E6BB },
	{ 0xF0A0A38C, 0x5A1BD },
	{ 0xF0A0A38D, 0x6A2C7 },
	{ 0xF0A0A38E, 0x6A2C8 },
	{ 0xF0A0A38F, 0x5A2B5 },
	{ 0xF0A0A391, 0x5A2B4 },
	{ 0xF0A0A392, 0x5A2B6 },
	{ 0xF0A0A393, 0xFA2AA },
	{ 0xF0A0A394, 0x6A6AF },
	{ 0xF0A0A396, 0x5A3C8 },
	{ 0xF0A0A397, 0x5A3C9 },
	{ 0xF0A0A398, 0x4A5D2 },
	{ 0xF0A0A399, 0x6A9F1 },
	{ 0xF0A0A39A, 0x6A9F0 },
	{ 0xF0A0A39C, 0xFA5E4 },
	{ 0xF0A0A39D, 0xFA5E5 },
	{ 0xF0A0A39E, 0x6AFAA },
	{ 0xF0A0A39F, 0x4A8CC },
	{ 0xF0A0A3A0, 0x6AFAB },
	{ 0xF0A0A3A1, 0x6AFAC },
	{ 0xF0A0A3A2, 0xFA9C6 },
	{ 0xF0A0A3A3, 0x6AFA9 },
	{ 0xF0A0A3A4, 0x4ABF6 },
	{ 0xF0A0A3A5, 0x6B5DC },
	{ 0xF0A0A3A6, 0x6B5DB },
	{ 0xF0A0A3A7, 0x6B5DE },
	{ 0xF0A0A3A8, 0x6B5DF },
	{ 0xF0A0A3A9, 0x6B5DA },
	{ 0xF0A0A3AA, 0x6B5DD },
	{ 0xF0A0A3AB, 0x5ACAF },
	{ 0xF0A0A3AE, 0x4B0DD },
	{ 0xF0A0A3AF, 0x6BDD2 },
	{ 0xF0A0A3B0, 0x5ACAE },
	{ 0xF0A0A3B1, 0x5B1AE },
	{ 0xF0A0A3B3, 0x5B1AF },
	{ 0xF0A0A3B4, 0x6BDD3 },
	{ 0xF0A0A3B5, 0x4B6CE },
	{ 0xF0A0A3B7, 0xFB9D1 },
	{ 0xF0A0A3B8, 0x6D0F3 },
	{ 0xF0A0A3B9, 0x4B0DB },
	{ 0xF0A0A3BA, 0x5BDF9 },
	{ 0xF0A0A3BB, 0xFC0CE },
	{ 0xF0A0A3BC, 0xFC0CF },
	{ 0xF0A0A3BD, 0x6DBAF },
	{ 0xF0A0A3BE, 0x4C2C7 },
	{ 0xF0A0A3BF, 0x5C4EA },
	{ 0xF0A0A480, 0x5C4EB },
	{ 0xF0A0A481, 0xFC6E7 },
	{ 0xF0A0A483, 0xFCDE9 },
	{ 0xF0A0A484, 0x4CFE5 },
	{ 0xF0A0A485, 0x7ACD0 },
	{ 0xF0A0A487, 0x7ACD1 },
	{ 0xF0A0A488, 0x7B7A3 },
	{ 0xF0A0A489, 0x7B7A4 },
	{ 0xF0A0A48A, 0x5DAFE },
	{ 0xF0A0A48B, 0x7CDC3 },
	{ 0xF0A0A48E, 0x6A1AA },
	{ 0xF0A0A48F, 0x4A1C2 },
	{ 0xF0A0A490, 0x6A2CA },
	{ 0xF0A0A491, 0x6A6B0 },
	{ 0xF0A0A492, 0x6A6B3 },
	{ 0xF0A0A493, 0x5A3CA },
	{ 0xF0A0A494, 0x6A6B1 },
	{ 0xF0A0A495, 0x6A6B2 },
	{ 0xF0A0A497, 0x4A8CD },
	{ 0xF0A0A498, 0x6AFAF },
	{ 0xF0A0A499, 0x6AFB1 },
	{ 0xF0A0A49A, 0x6AFAD },
	{ 0xF0A0A49B, 0x6AFAE },
	{ 0xF0A0A49C, 0x6AFB0 },
	{ 0xF0A0A49E, 0x6BDD4 },
	{ 0xF0A0A49F, 0x6B5E0 },
	{ 0xF0A0A4A0, 0xFAEB6 },
	{ 0xF0A0A4A1, 0xFAEB7 },
	{ 0xF0A0A4A2, 0x6B5A4 },
	{ 0xF0A0A4A3, 0x6C6F2 },
	{ 0xF0A0A4A4, 0xFB9D2 },
	{ 0xF0A0A4A5, 0x4BCBD },
	{ 0xF0A0A4A8, 0xFC6E8 },
	{ 0xF0A0A4AA, 0x7BFA2 },
	{ 0xF0A0A4AB, 0x5EDB2 },
	{ 0xF0A0A4AC, 0x6A1AB },
	{ 0xF0A0A4AD, 0xFA1B1 },
	{ 0xF0A0A4AE, 0x5A2B7 },
	{ 0xF0A0A4AF, 0x6A3EE },
	{ 0xF0A0A4B0, 0x4A2C3 },
	{ 0xF0A0A4B1, 0x6A3ED },
	{ 0xF0A0A4B3, 0x6A6B4 },
	{ 0xF0A0A4B4, 0x4A3CA },
	{ 0xF0A0A4B5, 0x6A6B5 },
	{ 0xF0A0A4B6, 0xFA3BC },
	{ 0xF0A0A4B8, 0x6A9F3 },
	{ 0xF0A0A4B9, 0x5A5BE },
	{ 0xF0A0A4BA, 0x5A5BF },
	{ 0xF0A0A4BC, 0x4A8CF },
	{ 0xF0A0A4BE, 0x6AFB4 },
	{ 0xF0A0A4BF, 0x5A8B3 },
	{ 0xF0A0A580, 0x6AFB3 },
	{ 0xF0A0A581, 0x5A8B2 },
	{ 0xF0A0A582, 0x6AFB2 },
	{ 0xF0A0A583, 0x6AFB7 },
	{ 0xF0A0A584, 0x6AFB5 },
	{ 0xF0A0A585, 0xFA9C7 },
	{ 0xF0A0A589, 0x5ACB0 },
	{ 0xF0A0A58A, 0x6B5E2 },
	{ 0xF0A0A58B, 0x6B5E1 },
	{ 0xF0A0A58C, 0x5ACB1 },
	{ 0xF0A0A58E, 0x6BDD5 },
	{ 0xF0A0A58F, 0xFB3BA },
	{ 0xF0A0A590, 0x4B6CF },
	{ 0xF0A0A591, 0x6D0F5 },
	{ 0xF0A0A592, 0x6C6F3 },
	{ 0xF0A0A593, 0x6B5E3 },
	{ 0xF0A0A596, 0x5BDFA },
	{ 0xF0A0A599, 0x4C2C8 },
	{ 0xF0A0A59A, 0x6DBB1 },
	{ 0xF0A0A59B, 0x6DBB0 },
	{ 0xF0A0A59C, 0x5CCAC },
	{ 0xF0A0A59D, 0x5CCAD },
	{ 0xF0A0A59E, 0x5CCAE },
	{ 0xF0A0A5A1, 0xFCDEA },
	{ 0xF0A0A5A2, 0x5D3E4 },
	{ 0xF0A0A5A3, 0x7B7A5 },
	{ 0xF0A0A5A5, 0xFDEB7 },
	{ 0xF0A0A5A6, 0x4DFCB },
	{ 0xF0A0A5A9, 0x7BFA3 },
	{ 0xF0A0A5AA, 0x7CDC4 },
	{ 0xF0A0A5AB, 0x7E0E9 },
	{ 0xF0A0A5AC, 0x7E4C3 },
	{ 0xF0A0A5AD, 0xFA1B2 },
	{ 0xF0A0A5AE, 0x5A2B8 },
	{ 0xF0A0A5AF, 0x6A3EF },
	{ 0xF0A0A5B0, 0x5A3CC },
	{ 0xF0A0A5B1, 0x6A6B7 },
	{ 0xF0A0A5B2, 0xFA3BD },
	{ 0xF0A0A5B3, 0xFA5E6 },
	{ 0xF0A0A5B4, 0x6AFB6 },
	{ 0xF0A0A5B5, 0x5A8B4 },
	{ 0xF0A0A5B6, 0x6B5E4 },
	{ 0xF0A0A5B7, 0xFC6E9 },
	{ 0xF0A0A5B8, 0x7CDC5 },
	{ 0xF0A0A5BA, 0x7D7D0 },
	{ 0xF0A0A5BB, 0x6A1DA },
	{ 0xF0A0A5BD, 0x5A1DA },
	{ 0xF0A0A5BE, 0x5A1DB },
	{ 0xF0A0A680, 0x6A2CB },
	{ 0xF0A0A682, 0x6A3F0 },
	{ 0xF0A0A683, 0x4A2C4 },
	{ 0xF0A0A685, 0x4A2C5 },
	{ 0xF0A0A686, 0x6A3F3 },
	{ 0xF0A0A687, 0x6A3F2 },
	{ 0xF0A0A688, 0x5A2BA },
	{ 0xF0A0A68C, 0x5A2B9 },
	{ 0xF0A0A68D, 0x6A3F4 },
	{ 0xF0A0A691, 0x6A6B9 },
	{ 0xF0A0A692, 0x5A3CD },
	{ 0xF0A0A693, 0x6A6BA },
	{ 0xF0A0A694, 0x6A3F5 },
	{ 0xF0A0A695, 0x6A6BB },
	{ 0xF0A0A696, 0xFA3BE },
	{ 0xF0A0A698, 0x5A5C0 },
	{ 0xF0A0A699, 0x6A9F4 },
	{ 0xF0A0A69A, 0x6A9F7 },
	{ 0xF0A0A69B, 0x6A9F8 },
	{ 0xF0A0A69C, 0x6A9F6 },
	{ 0xF0A0A69D, 0xFA5E7 },
	{ 0xF0A0A69E, 0xFA5E9 },
	{ 0xF0A0A69F, 0xFA5EA },
	{ 0xF0A0A6A0, 0xFA5EB },
	{ 0xF0A0A6A1, 0xFA5E8 },
	{ 0xF0A0A6A2, 0x6A9F5 },
	{ 0xF0A0A6A3, 0x6B5E5 },
	{ 0xF0A0A6A4, 0x6B5E6 },
	{ 0xF0A0A6A5, 0xFAEB8 },
	{ 0xF0A0A6A6, 0xFAEB9 },
	{ 0xF0A0A6AA, 0x4B0E3 },
	{ 0xF0A0A6AB, 0x4B0E1 },
	{ 0xF0A0A6AC, 0x4B0E2 },
	{ 0xF0A0A6AD, 0xFB3BB },
	{ 0xF0A0A6B0, 0xFB9D3 },
	{ 0xF0A0A6B1, 0xFB9D4 },
	{ 0xF0A0A6B4, 0x6D0F8 },
	{ 0xF0A0A6B5, 0x6D0F7 },
	{ 0xF0A0A6B6, 0x6D0F9 },
	{ 0xF0A0A6B7, 0x6D0FB },
	{ 0xF0A0A6BC, 0xFC0D0 },
	{ 0xF0A0A6BD, 0xFC6EA },
	{ 0xF0A0A6BE, 0xFC6EB },
	{ 0xF0A0A780, 0x5CCAF },
	{ 0xF0A0A781, 0xFCDEB },
	{ 0xF0A0A782, 0xFCDEC },
	{ 0xF0A0A784, 0x7A1C0 },
	{ 0xF0A0A788, 0x7B7A6 },
	{ 0xF0A0A78A, 0xFDEB8 },
	{ 0xF0A0A78E, 0x7C6B0 },
	{ 0xF0A0A78F, 0x7D2F8 },
	{ 0xF0A0A790, 0x7E0EA },
	{ 0xF0A0A791, 0x7E2AE },
	{ 0xF0A0A793, 0x6A2CC },
	{ 0xF0A0A794, 0x6A3F7 },
	{ 0xF0A0A797, 0x6A3F6 },
	{ 0xF0A0A798, 0x6A3F8 },
	{ 0xF0A0A799, 0x4A3CC },
	{ 0xF0A0A79A, 0x5A3CF },
	{ 0xF0A0A79B, 0x5A3CE },
	{ 0xF0A0A79C, 0x6A6BC },
	{ 0xF0A0A79E, 0x4A5D5 },
	{ 0xF0A0A79F, 0x4A5D4 },
	{ 0xF0A0A7A0, 0x6A9FC },
	{ 0xF0A0A7A1, 0x6A9FB },
	{ 0xF0A0A7A2, 0x6A9FD },
	{ 0xF0A0A7A3, 0x6A9FA },
	{ 0xF0A0A7A4, 0x6A9FE },
	{ 0xF0A0A7A5, 0x6A9F9 },
	{ 0xF0A0A7A6, 0xFA5EC },
	{ 0xF0A0A7A8, 0x6AAA2 },
	{ 0xF0A0A7A9, 0x4A8D2 },
	{ 0xF0A0A7AA, 0x4A8D1 },
	{ 0xF0A0A7AB, 0x5A8B7 },
	{ 0xF0A0A7AC, 0xFA9C8 },
	{ 0xF0A0A7AD, 0xFA9C9 },
	{ 0xF0A0A7AE, 0xFA9CA },
	{ 0xF0A0A7AF, 0xFA9CB },
	{ 0xF0A0A7B2, 0x6AFB9 },
	{ 0xF0A0A7B3, 0x6B5E8 },
	{ 0xF0A0A7B4, 0x4ABF9 },
	{ 0xF0A0A7B5, 0x5ACB2 },
	{ 0xF0A0A7B6, 0x6B5E7 },
	{ 0xF0A0A7B7, 0x6B5EA },
	{ 0xF0A0A7B8, 0x6BCFA },
	{ 0xF0A0A7B9, 0x6B5E9 },
	{ 0xF0A0A7BA, 0x6BDD7 },
	{ 0xF0A0A7BB, 0x6BDD6 },
	{ 0xF0A0A7BC, 0x6B5EB },
	{ 0xF0A0A7BD, 0x6BDD8 },
	{ 0xF0A0A880, 0x6C6F5 },
	{ 0xF0A0A881, 0x6C6F6 },
	{ 0xF0A0A882, 0x6C6F7 },
	{ 0xF0A0A883, 0x5B7BF },
	{ 0xF0A0A885, 0x6D0FC },
	{ 0xF0A0A886, 0x5C4ED },
	{ 0xF0A0A887, 0x6DBB2 },
	{ 0xF0A0A888, 0x7A1C1 },
	{ 0xF0A0A889, 0xFD3D8 },
	{ 0xF0A0A88B, 0x7E3CB },
	{ 0xF0A0A88D, 0x5A1BE },
	{ 0xF0A0A88E, 0x4A1C3 },
	{ 0xF0A0A88F, 0xFA1B4 },
	{ 0xF0A0A890, 0x6A1DB },
	{ 0xF0A0A892, 0x4A2C6 },
	{ 0xF0A0A893, 0x6AAA4 },
	{ 0xF0A0A894, 0x6A3FA },
	{ 0xF0A0A896, 0x6A3F9 },
	{ 0xF0A0A898, 0x4A3CE },
	{ 0xF0A0A899, 0x6AFBB },
	{ 0xF0A0A89A, 0x5A8B8 },
	{ 0xF0A0A89B, 0x6AFBA },
	{ 0xF0A0A89C, 0x4A8D3 },
	{ 0xF0A0A89D, 0x6B5EC },
	{ 0xF0A0A89E, 0x6AFBC },
	{ 0xF0A0A89F, 0x6C6F8 },
	{ 0xF0A0A8A0, 0x5ACB3 },
	{ 0xF0A0A8A2, 0x5BDFB },
	{ 0xF0A0A8A3, 0x6D0FD },
	{ 0xF0A0A8A5, 0x5C4EE },
	{ 0xF0A0A8A7, 0x7BFA4 },
	{ 0xF0A0A8AC, 0x5A1BF },
	{ 0xF0A0A8AD, 0x5A1DC },
	{ 0xF0A0A8AE, 0x6A3FB },
	{ 0xF0A0A8AF, 0x6A2CF },
	{ 0xF0A0A8B0, 0x6A2CD },
	{ 0xF0A0A8B1, 0x6A2D0 },
	{ 0xF0A0A8B2, 0x5A1DD },
	{ 0xF0A0A8B4, 0x4A2C7 },
	{ 0xF0A0A8B5, 0x5A2BB },
	{ 0xF0A0A8B6, 0x6A3FC },
	{ 0xF0A0A8B7, 0x6A3FD },
	{ 0xF0A0A8B8, 0x5A2BF },
	{ 0xF0A0A8B9, 0x5A2C0 },
	{ 0xF0A0A8BA, 0x5A2BD },
	{ 0xF0A0A8BB, 0x5A2BE },
	{ 0xF0A0A8BD, 0xFA2AD },
	{ 0xF0A0A980, 0x6A6BE },
	{ 0xF0A0A981, 0x5A3D0 },
	{ 0xF0A0A982, 0x6A6BD },
	{ 0xF0A0A983, 0x5A3D1 },
	{ 0xF0A0A984, 0x6A5DE },
	{ 0xF0A0A987, 0xFA3BF },
	{ 0xF0A0A98A, 0x6AAA7 },
	{ 0xF0A0A98B, 0x6AAA6 },
	{ 0xF0A0A98C, 0x6AAA9 },
	{ 0xF0A0A98D, 0x6AAA8 },
	{ 0xF0A0A98E, 0x5A5C1 },
	{ 0xF0A0A98F, 0x4A5D8 },
	{ 0xF0A0A991, 0xFA5ED },
	{ 0xF0A0A992, 0xFA5EE },
	{ 0xF0A0A996, 0x6AAA5 },
	{ 0xF0A0A997, 0x5A8B9 },
	{ 0xF0A0A998, 0x4A8D4 },
	{ 0xF0A0A999, 0x6AFC6 },
	{ 0xF0A0A99A, 0x6AFC1 },
	{ 0xF0A0A99B, 0x6AFC4 },
	{ 0xF0A0A99C, 0x6AFC5 },
	{ 0xF0A0A99D, 0x6AFC0 },
	{ 0xF0A0A99E, 0x6AFBE },
	{ 0xF0A0A99F, 0x6AFC2 },
	{ 0xF0A0A9A0, 0x6AFC3 },
	{ 0xF0A0A9A2, 0xFA9CD },
	{ 0xF0A0A9A3, 0xFA9CE },
	{ 0xF0A0A9A4, 0x4A8D5 },
	{ 0xF0A0A9A6, 0x6AFBF },
	{ 0xF0A0A9A7, 0x6B5F3 },
	{ 0xF0A0A9A8, 0x6B5F4 },
	{ 0xF0A0A9A9, 0x4ABFB },
	{ 0xF0A0A9AA, 0x5ACB4 },
	{ 0xF0A0A9AB, 0x4ABFC },
	{ 0xF0A0A9AC, 0x6B5EF },
	{ 0xF0A0A9AD, 0x6B5ED },
	{ 0xF0A0A9AE, 0x6B5F0 },
	{ 0xF0A0A9AF, 0x6B5F2 },
	{ 0xF0A0A9B0, 0x6B5F1 },
	{ 0xF0A0A9B1, 0x6B5EE },
	{ 0xF0A0A9B2, 0x5ACB5 },
	{ 0xF0A0A9B3, 0xFAEBA },
	{ 0xF0A0A9B4, 0xFAEBB },
	{ 0xF0A0A9B8, 0x6BDE0 },
	{ 0xF0A0A9B9, 0x6BDDB },
	{ 0xF0A0A9BA, 0x4B0E7 },
	{ 0xF0A0A9BB, 0x6BDDF },
	{ 0xF0A0A9BC, 0x6BDDC },
	{ 0xF0A0A9BD, 0x6BDDD },
	{ 0xF0A0A9BE, 0xFB3BD },
	{ 0xF0A0A9BF, 0x5B1B0 },
	{ 0xF0A0AA84, 0x6BDDE },
	{ 0xF0A0AA86, 0x4B0E6 },
	{ 0xF0A0AA87, 0x4B6D2 },
	{ 0xF0A0AA88, 0x6C6FC },
	{ 0xF0A0AA89, 0x6C6FA },
	{ 0xF0A0AA8A, 0x4B6D3 },
	{ 0xF0A0AA8B, 0x6C6FB },
	{ 0xF0A0AA8C, 0x6C6F9 },
	{ 0xF0A0AA8D, 0x6C6FD },
	{ 0xF0A0AA8E, 0xFB9D5 },
	{ 0xF0A0AA8F, 0x6C6FE },
	{ 0xF0A0AA91, 0x5BDFC },
	{ 0xF0A0AA92, 0x5BDFD },
	{ 0xF0A0AA93, 0x6D1A4 },
	{ 0xF0A0AA94, 0x6D1A3 },
	{ 0xF0A0AA95, 0x6D0FE },
	{ 0xF0A0AA96, 0xFC0D1 },
	{ 0xF0A0AA98, 0x6D1A1 },
	{ 0xF0A0AA99, 0x4BCBF },
	{ 0xF0A0AA9A, 0x4C2C9 },
	{ 0xF0A0AA9B, 0x6DBB4 },
	{ 0xF0A0AA9C, 0x6DBB7 },
	{ 0xF0A0AA9D, 0x6DBB3 },
	{ 0xF0A0AA9E, 0x6DBB8 },
	{ 0xF0A0AA9F, 0x5C4EF },
	{ 0xF0A0AAA0, 0xFC6ED },
	{ 0xF0A0AAA2, 0xFC6EE },
	{ 0xF0A0AAA4, 0x6DBB6 },
	{ 0xF0A0AAA5, 0x6DBB9 },
	{ 0xF0A0AAA6, 0x6DBBB },
	{ 0xF0A0AAAA, 0x6DBBA },
	{ 0xF0A0AAAB, 0x6DBB5 },
	{ 0xF0A0AAAD, 0x7A1C3 },
	{ 0xF0A0AAAE, 0x4C9A8 },
	{ 0xF0A0AAAF, 0x5CCB0 },
	{ 0xF0A0AAB0, 0x7A1C4 },
	{ 0xF0A0AAB3, 0x7A1C2 },
	{ 0xF0A0AAB5, 0xFCDED },
	{ 0xF0A0AAB9, 0x7A5C8 },
	{ 0xF0A0AABA, 0x5D3E5 },
	{ 0xF0A0AABB, 0x7ACD3 },
	{ 0xF0A0AABC, 0x7ACD2 },
	{ 0xF0A0AABD, 0xFD3D9 },
	{ 0xF0A0AABE, 0xFD3DA },
	{ 0xF0A0AABF, 0x7BBCD },
	{ 0xF0A0AB80, 0xFDEB9 },
	{ 0xF0A0AB81, 0xFDEBA },
	{ 0xF0A0AB82, 0xFDEBB },
	{ 0xF0A0AB87, 0xFE4FC },
	{ 0xF0A0AB88, 0x7CEA7 },
	{ 0xF0A0AB89, 0x7D2F9 },
	{ 0xF0A0AB8C, 0x5F7D4 },
	{ 0xF0A0AB8E, 0x7DED0 },
	{ 0xF0A0AB90, 0x7E5B3 },
	{ 0xF0A0AB92, 0x7E6B3 },
	{ 0xF0A0AB93, 0x5A1AE },
	{ 0xF0A0AB94, 0x6A1BC },
	{ 0xF0A0AB95, 0x6A1BD },
	{ 0xF0A0AB97, 0x6A1DD },
	{ 0xF0A0AB99, 0x6A2D2 },
	{ 0xF0A0AB9A, 0x6A2D1 },
	{ 0xF0A0AB9E, 0x4A2CA },
	{ 0xF0A0AB9F, 0x6A4A3 },
	{ 0xF0A0ABA0, 0x6A4A1 },
	{ 0xF0A0ABA2, 0xFA2AE },
	{ 0xF0A0ABA4, 0x4A2C9 },
	{ 0xF0A0ABA5, 0x6A4A2 },
	{ 0xF0A0ABA6, 0x6A6C0 },
	{ 0xF0A0ABA7, 0xFA3C0 },
	{ 0xF0A0ABA8, 0x5A3BC },
	{ 0xF0A0ABA9, 0x6AAAC },
	{ 0xF0A0ABAA, 0x6AAAB },
	{ 0xF0A0ABAB, 0x6AAAD },
	{ 0xF0A0ABAC, 0x6AAAE },
	{ 0xF0A0ABB0, 0x6AFC7 },
	{ 0xF0A0ABB1, 0x6AFC8 },
	{ 0xF0A0ABB3, 0x4A8D6 },
	{ 0xF0A0ABB4, 0xFA9CF },
	{ 0xF0A0ABB9, 0x6B5F6 },
	{ 0xF0A0ABBA, 0x6B5F5 },
	{ 0xF0A0ABBB, 0x6B6C9 },
	{ 0xF0A0ABBC, 0x6B5AE },
	{ 0xF0A0ABBF, 0x5B6EC },
	{ 0xF0A0AC80, 0x6C7A2 },
	{ 0xF0A0AC81, 0x6C7A4 },
	{ 0xF0A0AC82, 0x6CDE2 },
	{ 0xF0A0AC84, 0xFB9D6 },
	{ 0xF0A0AC85, 0x6C7A3 },
	{ 0xF0A0AC86, 0x5BEA1 },
	{ 0xF0A0AC87, 0x6D1A5 },
	{ 0xF0A0AC88, 0x5BDFE },
	{ 0xF0A0AC8A, 0xFC0D2 },
	{ 0xF0A0AC8E, 0x6DBBC },
	{ 0xF0A0AC8F, 0xFC6EF },
	{ 0xF0A0AC90, 0x6E0F2 },
	{ 0xF0A0AC91, 0x7A1C5 },
	{ 0xF0A0AC93, 0x5D3E6 },
	{ 0xF0A0AC97, 0xFD9D7 },
	{ 0xF0A0AC98, 0x7CBEA },
	{ 0xF0A0AC9A, 0x6A1E0 },
	{ 0xF0A0AC9B, 0x5A1C0 },
	{ 0xF0A0AC9C, 0x6A1DE },
	{ 0xF0A0AC9D, 0x5A1C2 },
	{ 0xF0A0AC9E, 0x6A1E2 },
	{ 0xF0A0AC9F, 0x6A1DF },
	{ 0xF0A0ACA1, 0x6A2D5 },
	{ 0xF0A0ACA2, 0x4A1E8 },
	{ 0xF0A0ACA3, 0x5A1DE },
	{ 0xF0A0ACA5, 0x6A2D6 },
	{ 0xF0A0ACA6, 0x5A1DF },
	{ 0xF0A0ACA7, 0x6A2D3 },
	{ 0xF0A0ACA8, 0x6A2D4 },
	{ 0xF0A0ACA9, 0x6A4A5 },
	{ 0xF0A0ACAA, 0x4A2CB },
	{ 0xF0A0ACAB, 0x6A4A4 },
	{ 0xF0A0ACAC, 0x5A2C2 },
	{ 0xF0A0ACAD, 0x6A4A6 },
	{ 0xF0A0ACAE, 0x5A2C1 },
	{ 0xF0A0ACAF, 0x6A4A7 },
	{ 0xF0A0ACB1, 0x6A6C4 },
	{ 0xF0A0ACB2, 0x6A6C2 },
	{ 0xF0A0ACB3, 0x5A3D2 },
	{ 0xF0A0ACB4, 0xFA3C1 },
	{ 0xF0A0ACB5, 0xFA3C2 },
	{ 0xF0A0ACB6, 0xFA3C3 },
	{ 0xF0A0ACB7, 0xFA3C4 },
	{ 0xF0A0ACB8, 0x4A3D0 },
	{ 0xF0A0ACB9, 0x6AAB1 },
	{ 0xF0A0ACBA, 0x6AAAF },
	{ 0xF0A0ACBB, 0x6AAB2 },
	{ 0xF0A0ACBC, 0x6AAB0 },
	{ 0xF0A0ACBD, 0xFA5EF },
	{ 0xF0A0ACBF, 0x6AFCD },
	{ 0xF0A0AD80, 0x6AFCA },
	{ 0xF0A0AD81, 0x6AFCC },
	{ 0xF0A0AD82, 0x6AFCB },
	{ 0xF0A0AD83, 0x6AFC9 },
	{ 0xF0A0AD84, 0xFA9D1 },
	{ 0xF0A0AD85, 0xFA9D2 },
	{ 0xF0A0AD87, 0x6B2F2 },
	{ 0xF0A0AD89, 0x5A8B6 },
	{ 0xF0A0AD8A, 0x6B5FB },
	{ 0xF0A0AD8B, 0x5ACB6 },
	{ 0xF0A0AD8C, 0x6B5FC },
	{ 0xF0A0AD8D, 0x6B5F9 },
	{ 0xF0A0AD8E, 0x6B5F7 },
	{ 0xF0A0AD8F, 0x6B5FA },
	{ 0xF0A0AD90, 0xFAEBC },
	{ 0xF0A0AD91, 0xFAEBD },
	{ 0xF0A0AD92, 0xFAEBE },
	{ 0xF0A0AD93, 0xFAEBF },
	{ 0xF0A0AD94, 0x6BCE7 },
	{ 0xF0A0AD95, 0x6BDE6 },
	{ 0xF0A0AD96, 0x6BDE8 },
	{ 0xF0A0AD97, 0x5B1B2 },
	{ 0xF0A0AD98, 0x5B1B3 },
	{ 0xF0A0AD99, 0x6BDE5 },
	{ 0xF0A0AD9A, 0x6BDE3 },
	{ 0xF0A0AD9B, 0x6BDEB },
	{ 0xF0A0AD9C, 0x6BDE4 },
	{ 0xF0A0AD9D, 0x5ACB7 },
	{ 0xF0A0AD9E, 0x6BDE2 },
	{ 0xF0A0AD9F, 0x6BDE9 },
	{ 0xF0A0ADA0, 0x6BDEA },
	{ 0xF0A0ADA1, 0x6BCFC },
	{ 0xF0A0ADA3, 0x6BDE7 },
	{ 0xF0A0ADA5, 0x4B6D4 },
	{ 0xF0A0ADA6, 0x5B6ED },
	{ 0xF0A0ADA7, 0x6C7A7 },
	{ 0xF0A0ADA8, 0x6C7A5 },
	{ 0xF0A0ADA9, 0xFB3BE },
	{ 0xF0A0ADAA, 0xFB9D7 },
	{ 0xF0A0ADAB, 0xFB9D8 },
	{ 0xF0A0ADAC, 0xFB9D9 },
	{ 0xF0A0ADAD, 0xFB9DA },
	{ 0xF0A0ADAE, 0x6C7A6 },
	{ 0xF0A0ADAF, 0x4BCC3 },
	{ 0xF0A0ADB0, 0x4BCC2 },
	{ 0xF0A0ADB1, 0x6D1A7 },
	{ 0xF0A0ADB2, 0x6D1A8 },
	{ 0xF0A0ADB3, 0x6D1A6 },
	{ 0xF0A0ADB4, 0x4BCC1 },
	{ 0xF0A0ADB5, 0x6C7A8 },
	{ 0xF0A0ADB6, 0x6D1DB },
	{ 0xF0A0ADB8, 0x6D1A9 },
	{ 0xF0A0ADBB, 0x6DFA1 },
	{ 0xF0A0ADBC, 0x6DBBE },
	{ 0xF0A0ADBE, 0x6DBBD },
	{ 0xF0A0ADBF, 0x5C4F0 },
	{ 0xF0A0AE81, 0x6D3FB },
	{ 0xF0A0AE82, 0xFCDD5 },
	{ 0xF0A0AE83, 0x5CCB3 },
	{ 0xF0A0AE84, 0x5CCB4 },
	{ 0xF0A0AE85, 0xFC6F0 },
	{ 0xF0A0AE86, 0x5CCB2 },
	{ 0xF0A0AE87, 0x7ACD5 },
	{ 0xF0A0AE88, 0xFD3DB },
	{ 0xF0A0AE89, 0x3D0B9 },
	{ 0xF0A0AE8A, 0x5D4AE },
	{ 0xF0A0AE8B, 0x7ACD4 },
	{ 0xF0A0AE8D, 0x7B7A9 },
	{ 0xF0A0AE8E, 0x7B7A8 },
	{ 0xF0A0AE8F, 0xFD9D8 },
	{ 0xF0A0AE90, 0x4DAEF },
	{ 0xF0A0AE91, 0x7C6B2 },
	{ 0xF0A0AE92, 0x7C6B1 },
	{ 0xF0A0AE93, 0x4E6B1 },
	{ 0xF0A0AE94, 0xFE7C5 },
	{ 0xF0A0AE95, 0x7D7D1 },
	{ 0xF0A0AE96, 0x5F5E6 },
	{ 0xF0A0AE97, 0x7DED1 },
	{ 0xF0A0AE98, 0x7DED2 },
	{ 0xF0A0AE99, 0x5A1C3 },
	{ 0xF0A0AE9A, 0x6A1E4 },
	{ 0xF0A0AE9B, 0x4A1C7 },
	{ 0xF0A0AE9C, 0x4A1C6 },
	{ 0xF0A0AE9D, 0xFA1B6 },
	{ 0xF0A0AE9E, 0x6A1E3 },
	{ 0xF0A0AEA0, 0x5A1E1 },
	{ 0xF0A0AEA1, 0x6A2D9 },
	{ 0xF0A0AEA2, 0x6A2D8 },
	{ 0xF0A0AEA3, 0x6A2DE },
	{ 0xF0A0AEA4, 0x6A2DA },
	{ 0xF0A0AEA5, 0x6A2DD },
	{ 0xF0A0AEA6, 0x6A2D7 },
	{ 0xF0A0AEA7, 0x6A2C2 },
	{ 0xF0A0AEA8, 0xFA1CE },
	{ 0xF0A0AEAA, 0x6A2DC },
	{ 0xF0A0AEAB, 0x5A2C7 },
	{ 0xF0A0AEAC, 0x6A4AD },
	{ 0xF0A0AEAD, 0x5A2C5 },
	{ 0xF0A0AEAE, 0x6A4AE },
	{ 0xF0A0AEAF, 0x4A2CD },
	{ 0xF0A0AEB0, 0x5A2C6 },
	{ 0xF0A0AEB1, 0x4A2D0 },
	{ 0xF0A0AEB2, 0x6A4AC },
	{ 0xF0A0AEB3, 0x4A2CF },
	{ 0xF0A0AEB4, 0x4A2CE },
	{ 0xF0A0AEB5, 0x5A2C4 },
	{ 0xF0A0AEB7, 0x6A4A8 },
	{ 0xF0A0AEB8, 0xFA2AF },
	{ 0xF0A0AEB9, 0xFA2B0 },
	{ 0xF0A0AEBA, 0xFA2B2 },
	{ 0xF0A0AEBB, 0xFA2B4 },
	{ 0xF0A0AF81, 0x6A4AA },
	{ 0xF0A0AF82, 0xFA2B1 },
	{ 0xF0A0AF86, 0xFA2B3 },
	{ 0xF0A0AF88, 0x5A2C3 },
	{ 0xF0A0AF89, 0x6A4A9 },
	{ 0xF0A0AF8A, 0x6A4AB },
	{ 0xF0A0AF8B, 0x4A3D6 },
	{ 0xF0A0AF8C, 0x6A6CF },
	{ 0xF0A0AF8D, 0x6A6C6 },
	{ 0xF0A0AF8E, 0x6A6CD },
	{ 0xF0A0AF8F, 0x6A6CC },
	{ 0xF0A0AF90, 0x5A3D6 },
	{ 0xF0A0AF91, 0x4A3DA },
	{ 0xF0A0AF92, 0x4A3DD },
	{ 0xF0A0AF93, 0x5A3DB },
	{ 0xF0A0AF94, 0x5A3D4 },
	{ 0xF0A0AF95, 0x6A6C8 },
	{ 0xF0A0AF96, 0x4A3D7 },
	{ 0xF0A0AF97, 0x4A3D2 },
	{ 0xF0A0AF98, 0x4A3D8 },
	{ 0xF0A0AF99, 0x5A3D8 },
	{ 0xF0A0AF9A, 0x6A6C9 },
	{ 0xF0A0AF9B, 0x5A3D9 },
	{ 0xF0A0AF9C, 0x4A3D5 },
	{ 0xF0A0AF9D, 0x5A3D5 },
	{ 0xF0A0AF9E, 0x6A6C7 },
	{ 0xF0A0AFA1, 0x5A3DC },
	{ 0xF0A0AFA3, 0xFA3C5 },
	{ 0xF0A0AFA4, 0xFA3C6 },
	{ 0xF0A0AFA5, 0xFA3C7 },
	{ 0xF0A0AFA6, 0xFA3CA },
	{ 0xF0A0AFA7, 0xFA3CB },
	{ 0xF0A0AFA8, 0xFA3CC },
	{ 0xF0A0AFAB, 0xFA3C8 },
	{ 0xF0A0AFAC, 0x6A6CB },
	{ 0xF0A0AFAE, 0x6A6CA },
	{ 0xF0A0AFB3, 0x6A6D0 },
	{ 0xF0A0AFB5, 0x6A6C5 },
	{ 0xF0A0AFB6, 0x5A3D3 },
	{ 0xF0A0B084, 0x5A3D7 },
	{ 0xF0A0B085, 0x5A3DA },
	{ 0xF0A0B088, 0x4A5DC },
	{ 0xF0A0B089, 0x4A5DE },
	{ 0xF0A0B08A, 0x6AAB6 },
	{ 0xF0A0B08B, 0x5A5CC },
	{ 0xF0A0B08C, 0x5A5C4 },
	{ 0xF0A0B08D, 0x4A5DB },
	{ 0xF0A0B08E, 0x6AAB4 },
	{ 0xF0A0B08F, 0x5A5CD },
	{ 0xF0A0B090, 0x5A5C5 },
	{ 0xF0A0B091, 0x5A5C7 },
	{ 0xF0A0B092, 0x4A5E1 },
	{ 0xF0A0B093, 0x5A5D0 },
	{ 0xF0A0B094, 0x6AAB3 },
	{ 0xF0A0B095, 0x5A5D2 },
	{ 0xF0A0B096, 0x5A8C7 },
	{ 0xF0A0B097, 0x6AABB },
	{ 0xF0A0B098, 0x5A5C8 },
	{ 0xF0A0B099, 0x5A5CB },
	{ 0xF0A0B09A, 0x5A5CA },
	{ 0xF0A0B09B, 0x5A5D1 },
	{ 0xF0A0B09C, 0x5A5C9 },
	{ 0xF0A0B09D, 0x5A5CE },
	{ 0xF0A0B09E, 0x6AABD },
	{ 0xF0A0B0A1, 0x5A5CF },
	{ 0xF0A0B0A2, 0xFA5F0 },
	{ 0xF0A0B0A3, 0xFA5F2 },
	{ 0xF0A0B0A4, 0xFA5F3 },
	{ 0xF0A0B0A5, 0xFA5F4 },
	{ 0xF0A0B0A6, 0xFA5F5 },
	{ 0xF0A0B0A7, 0xFA5F6 },
	{ 0xF0A0B0A8, 0xFA5F7 },
	{ 0xF0A0B0A9, 0xFA5F8 },
	{ 0xF0A0B0AA, 0xFA5F9 },
	{ 0xF0A0B0AB, 0xFA5FA },
	{ 0xF0A0B0AC, 0xFA5FD },
	{ 0xF0A0B0AD, 0xFA5FE },
	{ 0xF0A0B0AE, 0xFA6A1 },
	{ 0xF0A0B0AF, 0xFA6A2 },
	{ 0xF0A0B0B0, 0xFA6A3 },
	{ 0xF0A0B0B2, 0x5A5C6 },
	{ 0xF0A0B0B5, 0x6AAB5 },
	{ 0xF0A0B0B6, 0x5A5C3 },
	{ 0xF0A0B0B8, 0x6AAB8 },
	{ 0xF0A0B0BF, 0x6AAB7 },
	{ 0xF0A0B180, 0xFA5FC },
	{ 0xF0A0B18E, 0x6AABA },
	{ 0xF0A0B190, 0x5ACB8 },
	{ 0xF0A0B191, 0x5A8C6 },
	{ 0xF0A0B192, 0x5A8D2 },
	{ 0xF0A0B193, 0x5A8CD },
	{ 0xF0A0B194, 0x5A8BC },
	{ 0xF0A0B195, 0x5A8D1 },
	{ 0xF0A0B196, 0x6AFD4 },
	{ 0xF0A0B197, 0x6AFCE },
	{ 0xF0A0B198, 0x5A8BF },
	{ 0xF0A0B199, 0x4A8DB },
	{ 0xF0A0B19A, 0x4A8DA },
	{ 0xF0A0B19B, 0x5A8CF },
	{ 0xF0A0B19C, 0x5A8C5 },
	{ 0xF0A0B19D, 0x5A8CB },
	{ 0xF0A0B19E, 0x5A8CA },
	{ 0xF0A0B19F, 0x5A8CE },
	{ 0xF0A0B1A0, 0x5A8C8 },
	{ 0xF0A0B1A1, 0x5A8C9 },
	{ 0xF0A0B1A2, 0x5A8BD },
	{ 0xF0A0B1A3, 0x5A8C1 },
	{ 0xF0A0B1A4, 0x5A8CC },
	{ 0xF0A0B1A5, 0x4A5E2 },
	{ 0xF0A0B1A6, 0x6AFD9 },
	{ 0xF0A0B1A7, 0x6AFDA },
	{ 0xF0A0B1A8, 0x5A8D3 },
	{ 0xF0A0B1A9, 0x6AFCF },
	{ 0xF0A0B1AB, 0x5A8BA },
	{ 0xF0A0B1AC, 0x6AFD7 },
	{ 0xF0A0B1AD, 0x6AFD6 },
	{ 0xF0A0B1AE, 0x5A8D0 },
	{ 0xF0A0B1AF, 0x6AFD0 },
	{ 0xF0A0B1B0, 0x6AFD8 },
	{ 0xF0A0B1B1, 0x6AFD2 },
	{ 0xF0A0B1B2, 0x5A8C0 },
	{ 0xF0A0B1B3, 0x5A8C2 },
	{ 0xF0A0B1B5, 0xFABB3 },
	{ 0xF0A0B1B9, 0xFA9D3 },
	{ 0xF0A0B1BA, 0xFA9D5 },
	{ 0xF0A0B1BB, 0xFA9D6 },
	{ 0xF0A0B1BC, 0xFA9D7 },
	{ 0xF0A0B1BD, 0xFA9D8 },
	{ 0xF0A0B1BE, 0xFA9D9 },
	{ 0xF0A0B1BF, 0xFA9DA },
	{ 0xF0A0B280, 0xFA9DB },
	{ 0xF0A0B281, 0xFA9DE },
	{ 0xF0A0B282, 0xFA9DF },
	{ 0xF0A0B283, 0xFA9E0 },
	{ 0xF0A0B284, 0xFA9E1 },
	{ 0xF0A0B285, 0xFA9E2 },
	{ 0xF0A0B286, 0xFA9E3 },
	{ 0xF0A0B287, 0xFA9E4 },
	{ 0xF0A0B288, 0xFA9E6 },
	{ 0xF0A0B289, 0xFA9E7 },
	{ 0xF0A0B28B, 0x5A8C3 },
	{ 0xF0A0B28C, 0x5A8C4 },
	{ 0xF0A0B28E, 0x4A8DD },
	{ 0xF0A0B28F, 0xFA9E5 },
	{ 0xF0A0B290, 0x6AFD5 },
	{ 0xF0A0B293, 0x6AFD3 },
	{ 0xF0A0B297, 0x4A8D8 },
	{ 0xF0A0B2A9, 0x5A8BB },
	{ 0xF0A0B2AA, 0x5A8BE },
	{ 0xF0A0B2AB, 0x6AFD1 },
	{ 0xF0A0B2AD, 0x6B6A9 },
	{ 0xF0A0B2AE, 0x4ACA4 },
	{ 0xF0A0B2AF, 0x4ACAB },
	{ 0xF0A0B2B0, 0x4ACAC },
	{ 0xF0A0B2B1, 0x4ACA7 },
	{ 0xF0A0B2B2, 0x6B6A2 },
	{ 0xF0A0B2B3, 0x5ACCE },
	{ 0xF0A0B2B4, 0x5ACC1 },
	{ 0xF0A0B2B5, 0x5ACBF },
	{ 0xF0A0B2B6, 0x5ACCC },
	{ 0xF0A0B2B7, 0x5ACBD },
	{ 0xF0A0B2B8, 0x5ACC6 },
	{ 0xF0A0B2B9, 0x5ACD6 },
	{ 0xF0A0B2BA, 0x5ACC9 },
	{ 0xF0A0B2BB, 0x4ACAA },
	{ 0xF0A0B2BC, 0x5ACCD },
	{ 0xF0A0B2BD, 0x5ACD4 },
	{ 0xF0A0B2BE, 0x5ACD2 },
	{ 0xF0A0B2BF, 0x4ACA2 },
	{ 0xF0A0B380, 0x6B6A3 },
	{ 0xF0A0B381, 0x6B6A4 },
	{ 0xF0A0B382, 0x5ACD1 },
	{ 0xF0A0B383, 0x4ACA3 },
	{ 0xF0A0B384, 0x5ACC0 },
	{ 0xF0A0B385, 0x6B6A7 },
	{ 0xF0A0B386, 0x6B6A8 },
	{ 0xF0A0B387, 0x5ACD7 },
	{ 0xF0A0B388, 0x6B6A6 },
	{ 0xF0A0B389, 0x5ACD3 },
	{ 0xF0A0B38A, 0x5ACD8 },
	{ 0xF0A0B38B, 0x5ACC7 },
	{ 0xF0A0B38C, 0x5ACD9 },
	{ 0xF0A0B38D, 0x5ACC4 },
	{ 0xF0A0B38E, 0x5ACD5 },
	{ 0xF0A0B39B, 0xFAEC0 },
	{ 0xF0A0B39C, 0xFAEC1 },
	{ 0xF0A0B39D, 0xFAEC3 },
	{ 0xF0A0B39E, 0xFAEC4 },
	{ 0xF0A0B39F, 0xFAEC8 },
	{ 0xF0A0B3A0, 0xFAEC9 },
	{ 0xF0A0B3A1, 0xFAECB },
	{ 0xF0A0B3A2, 0xFAECC },
	{ 0xF0A0B3A3, 0xFAECD },
	{ 0xF0A0B3A4, 0xFAECE },
	{ 0xF0A0B3A5, 0xFAECF },
	{ 0xF0A0B3A6, 0xFAED0 },
	{ 0xF0A0B3A7, 0xFAED1 },
	{ 0xF0A0B3A8, 0xFAED2 },
	{ 0xF0A0B3A9, 0xFAED3 },
	{ 0xF0A0B3AA, 0xFAED4 },
	{ 0xF0A0B3AB, 0x6B9DE },
	{ 0xF0A0B3AE, 0x6B6A1 },
	{ 0xF0A0B3AF, 0x5ACC2 },
	{ 0xF0A0B3B0, 0x5ACC5 },
	{ 0xF0A0B3B1, 0x5ACC8 },
	{ 0xF0A0B3B4, 0x6B6A5 },
	{ 0xF0A0B3B7, 0x5ACD0 },
	{ 0xF0A0B3B8, 0x5ACCB },
	{ 0xF0A0B3B9, 0x5ACB9 },
	{ 0xF0A0B3BA, 0x5ACBA },
	{ 0xF0A0B3BB, 0x5ACBB },
	{ 0xF0A0B3BF, 0xFAEC5 },
	{ 0xF0A0B483, 0x5ACCA },
	{ 0xF0A0B4A1, 0x5ACCF },
	{ 0xF0A0B4A2, 0x5ACBE },
	{ 0xF0A0B4A3, 0x5ACBC },
	{ 0xF0A0B4A6, 0x5ACDA },
	{ 0xF0A0B4A7, 0x5B1C6 },
	{ 0xF0A0B4A8, 0x4B0E9 },
	{ 0xF0A0B4A9, 0x6BDF7 },
	{ 0xF0A0B4AA, 0x6BDF4 },
	{ 0xF0A0B4AB, 0x4B0F8 },
	{ 0xF0A0B4AC, 0x6BDEF },
	{ 0xF0A0B4AD, 0x4B0F5 },
	{ 0xF0A0B4AE, 0x5B1D1 },
	{ 0xF0A0B4AF, 0x5B1C9 },
	{ 0xF0A0B4B0, 0x5B1CC },
	{ 0xF0A0B4B1, 0x4B0EE },
	{ 0xF0A0B4B2, 0x4B0F9 },
	{ 0xF0A0B4B3, 0x5B1C4 },
	{ 0xF0A0B4B4, 0x6BDF6 },
	{ 0xF0A0B4B5, 0x5B1B6 },
	{ 0xF0A0B4B6, 0x5B1CA },
	{ 0xF0A0B4B7, 0x5B1C5 },
	{ 0xF0A0B4B8, 0x5B1CE },
	{ 0xF0A0B4B9, 0x5B1B4 },
	{ 0xF0A0B4BA, 0x5B1CD },
	{ 0xF0A0B4BB, 0x5B1C2 },
	{ 0xF0A0B4BC, 0x5B1BB },
	{ 0xF0A0B4BD, 0x6BDF1 },
	{ 0xF0A0B4BE, 0x6BDF5 },
	{ 0xF0A0B4BF, 0x6BDFD },
	{ 0xF0A0B580, 0x6BDFA },
	{ 0xF0A0B581, 0x6BDFE },
	{ 0xF0A0B582, 0x5B1BA },
	{ 0xF0A0B583, 0x5B1BC },
	{ 0xF0A0B58A, 0x6BDEC },
	{ 0xF0A0B591, 0x5B1B8 },
	{ 0xF0A0B592, 0x6BDF2 },
	{ 0xF0A0B593, 0x6BDFB },
	{ 0xF0A0B594, 0xFB3BF },
	{ 0xF0A0B595, 0xFB3C0 },
	{ 0xF0A0B596, 0xFB3C1 },
	{ 0xF0A0B597, 0xFB3C2 },
	{ 0xF0A0B598, 0xFB3C4 },
	{ 0xF0A0B599, 0xFB3C5 },
	{ 0xF0A0B59A, 0xFB3C6 },
	{ 0xF0A0B59B, 0xFB3C7 },
	{ 0xF0A0B59C, 0xFB3C8 },
	{ 0xF0A0B59D, 0xFB3C9 },
	{ 0xF0A0B59E, 0xFB3CC },
	{ 0xF0A0B59F, 0xFB3CD },
	{ 0xF0A0B5A0, 0x5B1B7 },
	{ 0xF0A0B5A1, 0x6BDF3 },
	{ 0xF0A0B5A2, 0x5B1B9 },
	{ 0xF0A0B5A5, 0x6BDED },
	{ 0xF0A0B5AA, 0x5B1C1 },
	{ 0xF0A0B5B0, 0x5B1C8 },
	{ 0xF0A0B5B2, 0x6BEA1 },
	{ 0xF0A0B5B5, 0x5B1D2 },
	{ 0xF0A0B5B7, 0x6BDF0 },
	{ 0xF0A0B5B9, 0x5B1C0 },
	{ 0xF0A0B6A7, 0x5B1B5 },
	{ 0xF0A0B6A8, 0x5B1C7 },
	{ 0xF0A0B6A9, 0x5B1BE },
	{ 0xF0A0B6AA, 0x5B1C3 },
	{ 0xF0A0B6AB, 0x5B1BD },
	{ 0xF0A0B6AC, 0x5B1D0 },
	{ 0xF0A0B6AD, 0x6BDF9 },
	{ 0xF0A0B6AE, 0x3B4E0 },
	{ 0xF0A0B6B0, 0x5B1D3 },
	{ 0xF0A0B6B1, 0x5B1CF },
	{ 0xF0A0B6B2, 0x6BDF8 },
	{ 0xF0A0B6B3, 0x6BDEE },
	{ 0xF0A0B6B4, 0x5B1BF },
	{ 0xF0A0B6B5, 0x5B1CB },
	{ 0xF0A0B6B7, 0x4B6D5 },
	{ 0xF0A0B6B8, 0x4B6E1 },
	{ 0xF0A0B6BA, 0x6C7B2 },
	{ 0xF0A0B6BB, 0x5B7A4 },
	{ 0xF0A0B6BC, 0x6C7B7 },
	{ 0xF0A0B6BD, 0x6C7BE },
	{ 0xF0A0B6BE, 0x5B6F7 },
	{ 0xF0A0B6BF, 0x6C7B5 },
	{ 0xF0A0B780, 0x5B6FC },
	{ 0xF0A0B781, 0x4B6D6 },
	{ 0xF0A0B782, 0x5B7A8 },
	{ 0xF0A0B783, 0x5B6EF },
	{ 0xF0A0B784, 0x5B6F1 },
	{ 0xF0A0B785, 0x4B6DA },
	{ 0xF0A0B786, 0x5B6F8 },
	{ 0xF0A0B787, 0x4B6D7 },
	{ 0xF0A0B788, 0x5B7A9 },
	{ 0xF0A0B789, 0x5B6FE },
	{ 0xF0A0B78A, 0x4B6E2 },
	{ 0xF0A0B78B, 0x4B6DB },
	{ 0xF0A0B78C, 0x5B7A3 },
	{ 0xF0A0B78D, 0x5B7A7 },
	{ 0xF0A0B78E, 0x4B6E6 },
	{ 0xF0A0B78F, 0x5B7B0 },
	{ 0xF0A0B791, 0x4B6DD },
	{ 0xF0A0B792, 0x5B7AC },
	{ 0xF0A0B793, 0x5B7AE },
	{ 0xF0A0B794, 0x6C7AE },
	{ 0xF0A0B795, 0x6C7BC },
	{ 0xF0A0B796, 0x5BEA2 },
	{ 0xF0A0B797, 0x6C7AB },
	{ 0xF0A0B798, 0x6C7AF },
	{ 0xF0A0B799, 0x6C7B8 },
	{ 0xF0A0B79A, 0x5B7A2 },
	{ 0xF0A0B79B, 0x6C7B4 },
	{ 0xF0A0B79C, 0x6C7BF },
	{ 0xF0A0B79D, 0x6C7BA },
	{ 0xF0A0B79E, 0x4B6E4 },
	{ 0xF0A0B79F, 0x5B7A6 },
	{ 0xF0A0B7A7, 0x5B6F3 },
	{ 0xF0A0B7A8, 0xFB9DB },
	{ 0xF0A0B7A9, 0xFB9DD },
	{ 0xF0A0B7AA, 0xFB9DE },
	{ 0xF0A0B7AB, 0xFB9E1 },
	{ 0xF0A0B7AC, 0xFB9E2 },
	{ 0xF0A0B7AD, 0xFB9E3 },
	{ 0xF0A0B7AE, 0xFB9E4 },
	{ 0xF0A0B7AF, 0xFB9E5 },
	{ 0xF0A0B7B0, 0xFB9E6 },
	{ 0xF0A0B7B1, 0xFB9E7 },
	{ 0xF0A0B7B2, 0xFB9E8 },
	{ 0xF0A0B7B3, 0xFB9EA },
	{ 0xF0A0B7B4, 0xFB9ED },
	{ 0xF0A0B7B5, 0xFB9EE },
	{ 0xF0A0B7B6, 0xFB9EF },
	{ 0xF0A0B7B7, 0xFB9F0 },
	{ 0xF0A0B7B8, 0x5B6F4 },
	{ 0xF0A0B7BB, 0x5B6F5 },
	{ 0xF0A0B7BC, 0x5B6FB },
	{ 0xF0A0B7BD, 0x5B7A5 },
	{ 0xF0A0B7BE, 0x5B7A1 },
	{ 0xF0A0B880, 0x6C7BB },
	{ 0xF0A0B884, 0xFB9EB },
	{ 0xF0A0B88C, 0xFB9DC },
	{ 0xF0A0B88D, 0xFB9DF },
	{ 0xF0A0B896, 0xFB9E9 },
	{ 0xF0A0B89D, 0xFB9EC },
	{ 0xF0A0B8AD, 0x5B7AB },
	{ 0xF0A0B8AE, 0x5B7AF },
	{ 0xF0A0B8B0, 0x6C7BD },
	{ 0xF0A0B8B1, 0x5B7AD },
	{ 0xF0A0B8B2, 0x5B7AA },
	{ 0xF0A0B8B3, 0x5B6FD },
	{ 0xF0A0B8B5, 0x6C7B6 },
	{ 0xF0A0B8B6, 0x6D1B9 },
	{ 0xF0A0B8B7, 0x5BEA3 },
	{ 0xF0A0B8B8, 0x4BCC9 },
	{ 0xF0A0B8B9, 0x5BEA7 },
	{ 0xF0A0B8BA, 0x4BCCE },
	{ 0xF0A0B8BB, 0x5B6F2 },
	{ 0xF0A0B8BF, 0x6D1C1 },
	{ 0xF0A0B980, 0x4BCC8 },
	{ 0xF0A0B981, 0x4BCC4 },
	{ 0xF0A0B982, 0x6DBC2 },
	{ 0xF0A0B983, 0x5BEAD },
	{ 0xF0A0B984, 0x6D1B3 },
	{ 0xF0A0B985, 0x6D1B5 },
	{ 0xF0A0B986, 0x5BEAA },
	{ 0xF0A0B987, 0x5BEB8 },
	{ 0xF0A0B988, 0x6D1BA },
	{ 0xF0A0B989, 0x6D1B0 },
	{ 0xF0A0B98A, 0x5BEAE },
	{ 0xF0A0B98B, 0x5BEA4 },
	{ 0xF0A0B98C, 0x5BEB5 },
	{ 0xF0A0B98D, 0x5BEBF },
	{ 0xF0A0B98E, 0x6D1BF },
	{ 0xF0A0B98F, 0x6D1B7 },
	{ 0xF0A0B990, 0x5BEB4 },
	{ 0xF0A0B991, 0x5BEB7 },
	{ 0xF0A0B992, 0x4BCCD },
	{ 0xF0A0B993, 0x5BEBA },
	{ 0xF0A0B994, 0x4BCC5 },
	{ 0xF0A0B995, 0x5BEB3 },
	{ 0xF0A0B996, 0x5BEAC },
	{ 0xF0A0B997, 0x4BCCF },
	{ 0xF0A0B998, 0x5BEAF },
	{ 0xF0A0B999, 0x4BCD1 },
	{ 0xF0A0B99A, 0x5BEB1 },
	{ 0xF0A0B99B, 0x5BEB2 },
	{ 0xF0A0B99C, 0x6D1BB },
	{ 0xF0A0B99E, 0x6D1C0 },
	{ 0xF0A0B99F, 0x6D1AA },
	{ 0xF0A0B9A0, 0x6D1BE },
	{ 0xF0A0B9A1, 0x6D1BD },
	{ 0xF0A0B9A2, 0x5BEBB },
	{ 0xF0A0B9A3, 0x6D1B8 },
	{ 0xF0A0B9A4, 0x5BEA8 },
	{ 0xF0A0B9A5, 0x5BEB0 },
	{ 0xF0A0B9A6, 0x5BEAB },
	{ 0xF0A0B9A7, 0x6D1AC },
	{ 0xF0A0B9A8, 0x6D1C4 },
	{ 0xF0A0B9A9, 0x6D1AE },
	{ 0xF0A0B9AA, 0x6D1AB },
	{ 0xF0A0B9AB, 0x6D1AD },
	{ 0xF0A0B9AE, 0xFC7A6 },
	{ 0xF0A0B9BF, 0x5BEBE },
	{ 0xF0A0BA80, 0x6D1B1 },
	{ 0xF0A0BA81, 0xFC0D6 },
	{ 0xF0A0BA82, 0xFC0D7 },
	{ 0xF0A0BA83, 0xFC0D8 },
	{ 0xF0A0BA84, 0xFC0D9 },
	{ 0xF0A0BA85, 0xFC0DA },
	{ 0xF0A0BA86, 0xFC0DB },
	{ 0xF0A0BA87, 0xFC0DC },
	{ 0xF0A0BA88, 0xFC0DD },
	{ 0xF0A0BA89, 0xFC0DE },
	{ 0xF0A0BA8A, 0xFC0DF },
	{ 0xF0A0BA8B, 0xFC0E0 },
	{ 0xF0A0BA8C, 0xFC0E1 },
	{ 0xF0A0BA8D, 0xFC0E3 },
	{ 0xF0A0BA8E, 0x6D1AF },
	{ 0xF0A0BA8F, 0x6D1B4 },
	{ 0xF0A0BA93, 0x6D1BC },
	{ 0xF0A0BAA2, 0xFC0D4 },
	{ 0xF0A0BAA4, 0x6D1C2 },
	{ 0xF0A0BB8C, 0x5BEBC },
	{ 0xF0A0BB8D, 0x5BEB6 },
	{ 0xF0A0BB8E, 0x5BEA5 },
	{ 0xF0A0BB8F, 0x5BEA9 },
	{ 0xF0A0BB90, 0x5BEA6 },
	{ 0xF0A0BB91, 0xFC0E4 },
	{ 0xF0A0BB94, 0x6DBC6 },
	{ 0xF0A0BB95, 0x6DBC0 },
	{ 0xF0A0BB96, 0x6DBCB },
	{ 0xF0A0BB97, 0x4C2CD },
	{ 0xF0A0BB98, 0x6DBCF },
	{ 0xF0A0BB99, 0x6DBC5 },
	{ 0xF0A0BB9A, 0x6DBD1 },
	{ 0xF0A0BB9B, 0x6DBD0 },
	{ 0xF0A0BB9C, 0x4C2CE },
	{ 0xF0A0BB9D, 0x6DBCC },
	{ 0xF0A0BB9E, 0x5C4F3 },
	{ 0xF0A0BB9F, 0x5C4F7 },
	{ 0xF0A0BBA0, 0x5C4F5 },
	{ 0xF0A0BBA1, 0x5C4FC },
	{ 0xF0A0BBA2, 0x6DBC3 },
	{ 0xF0A0BBA3, 0x6DBC7 },
	{ 0xF0A0BBA4, 0x4C2CC },
	{ 0xF0A0BBA5, 0x4C2D4 },
	{ 0xF0A0BBA6, 0x5C4FB },
	{ 0xF0A0BBA7, 0x4C2D0 },
	{ 0xF0A0BBA8, 0x5C4F6 },
	{ 0xF0A0BBA9, 0x6DBC1 },
	{ 0xF0A0BBAA, 0x5C4F1 },
	{ 0xF0A0BBAB, 0x5C4F2 },
	{ 0xF0A0BBAC, 0x5C4F9 },
	{ 0xF0A0BBAD, 0x6DBD2 },
	{ 0xF0A0BBAE, 0x6DBBF },
	{ 0xF0A0BBAF, 0x6DBC9 },
	{ 0xF0A0BBB0, 0x6DBCA },
	{ 0xF0A0BBB1, 0x5C4F8 },
	{ 0xF0A0BBB6, 0x6DBCD },
	{ 0xF0A0BBBE, 0xFC6F1 },
	{ 0xF0A0BBBF, 0xFC6F2 },
	{ 0xF0A0BC80, 0xFC6F3 },
	{ 0xF0A0BC81, 0xFC6F4 },
	{ 0xF0A0BC82, 0xFC6F6 },
	{ 0xF0A0BC83, 0xFC6F7 },
	{ 0xF0A0BC84, 0xFC6F8 },
	{ 0xF0A0BC85, 0xFC6F9 },
	{ 0xF0A0BC86, 0xFC6FA },
	{ 0xF0A0BC87, 0xFC6FB },
	{ 0xF0A0BC88, 0xFC6FC },
	{ 0xF0A0BC89, 0xFC6FE },
	{ 0xF0A0BC8A, 0xFC7A1 },
	{ 0xF0A0BC8B, 0xFC7A2 },
	{ 0xF0A0BC8C, 0xFC7A3 },
	{ 0xF0A0BC8D, 0xFC7A7 },
	{ 0xF0A0BC8E, 0xFC7A8 },
	{ 0xF0A0BC8F, 0xFC7A9 },
	{ 0xF0A0BC90, 0xFC7AA },
	{ 0xF0A0BC91, 0xFC7AB },
	{ 0xF0A0BC92, 0xFC7AC },
	{ 0xF0A0BC93, 0xFC7AD },
	{ 0xF0A0BC94, 0xFC7A4 },
	{ 0xF0A0BC95, 0x6DBC8 },
	{ 0xF0A0BC96, 0xFC6F5 },
	{ 0xF0A0BC98, 0x5C4F4 },
	{ 0xF0A0BC9A, 0x5C4FA },
	{ 0xF0A0BC9C, 0x6DBCE },
	{ 0xF0A0BC9E, 0x5C5A1 },
	{ 0xF0A0BCA2, 0xFC6FD },
	{ 0xF0A0BCA3, 0x6DBC4 },
	{ 0xF0A0BCA9, 0xFC7A5 },
	{ 0xF0A0BD9C, 0x5CCB5 },
	{ 0xF0A0BD9D, 0x5C4FD },
	{ 0xF0A0BDA0, 0xFC6EC },
	{ 0xF0A0BDA2, 0x7A1D1 },
	{ 0xF0A0BDA3, 0x5CCBB },
	{ 0xF0A0BDA4, 0x7A1D5 },
	{ 0xF0A0BDA5, 0x7A1D2 },
	{ 0xF0A0BDA6, 0x5CCB9 },
	{ 0xF0A0BDA7, 0x7A1D8 },
	{ 0xF0A0BDA8, 0x7A1CA },
	{ 0xF0A0BDA9, 0x5CCC0 },
	{ 0xF0A0BDAA, 0x5CCC6 },
	{ 0xF0A0BDAB, 0x5CCBD },
	{ 0xF0A0BDAC, 0x7A1CF },
	{ 0xF0A0BDAD, 0x5CCBE },
	{ 0xF0A0BDAE, 0x7A1D7 },
	{ 0xF0A0BDAF, 0x7A1D0 },
	{ 0xF0A0BDB0, 0x5CCB6 },
	{ 0xF0A0BDB1, 0x7A1CB },
	{ 0xF0A0BDB2, 0x5CCBF },
	{ 0xF0A0BDB3, 0x7A1D6 },
	{ 0xF0A0BDB4, 0x7A1D9 },
	{ 0xF0A0BDB5, 0x5CCC1 },
	{ 0xF0A0BDB6, 0x4C9AF },
	{ 0xF0A0BDB8, 0x7A1DB },
	{ 0xF0A0BDB9, 0x5CCBA },
	{ 0xF0A0BDBA, 0x7A1C8 },
	{ 0xF0A0BDBB, 0x5CCB8 },
	{ 0xF0A0BDBC, 0x5DBA7 },
	{ 0xF0A0BDBD, 0x7A1DA },
	{ 0xF0A0BDBE, 0x4C9AB },
	{ 0xF0A0BDBF, 0x7A1D4 },
	{ 0xF0A0BE80, 0x5C5A3 },
	{ 0xF0A0BE81, 0x7A1D3 },
	{ 0xF0A0BE82, 0x7A1C9 },
	{ 0xF0A0BE83, 0x7A1C7 },
	{ 0xF0A0BE84, 0x7A1E2 },
	{ 0xF0A0BE85, 0x7A1DC },
	{ 0xF0A0BE86, 0xFCDFA },
	{ 0xF0A0BE88, 0x7A1DE },
	{ 0xF0A0BE89, 0x5CCC2 },
	{ 0xF0A0BE8A, 0x7A1E1 },
	{ 0xF0A0BE8B, 0x7ACE1 },
	{ 0xF0A0BE8C, 0x5CCB7 },
	{ 0xF0A0BE96, 0x4C9B2 },
	{ 0xF0A0BE97, 0x5CCC7 },
	{ 0xF0A0BE98, 0xFCDEF },
	{ 0xF0A0BE99, 0xFCDF0 },
	{ 0xF0A0BE9A, 0xFCDF1 },
	{ 0xF0A0BE9B, 0xFCDF2 },
	{ 0xF0A0BE9C, 0xFCDF3 },
	{ 0xF0A0BE9D, 0xFCDF4 },
	{ 0xF0A0BE9E, 0xFCDF5 },
	{ 0xF0A0BE9F, 0xFCDF6 },
	{ 0xF0A0BEA0, 0xFCDF8 },
	{ 0xF0A0BEA1, 0xFCDF9 },
	{ 0xF0A0BEA5, 0x5CCC4 },
	{ 0xF0A0BEA6, 0x7A1DF },
	{ 0xF0A0BEA7, 0x7A6AB },
	{ 0xF0A0BEAA, 0x7A1DD },
	{ 0xF0A0BEAF, 0x7A1CD },
	{ 0xF0A0BEB0, 0x7A1CC },
	{ 0xF0A0BF85, 0x5CCBC },
	{ 0xF0A0BF86, 0x5CCC3 },
	{ 0xF0A0BF87, 0x7ACEA },
	{ 0xF0A0BF88, 0x4CFEE },
	{ 0xF0A0BF89, 0x5D3F4 },
	{ 0xF0A0BF8A, 0x7ACDC },
	{ 0xF0A0BF8B, 0x5D3F2 },
	{ 0xF0A0BF8C, 0x7ACE8 },
	{ 0xF0A0BF8D, 0x4CFF2 },
	{ 0xF0A0BF8E, 0x5D3EA },
	{ 0xF0A0BF8F, 0x5D3F8 },
	{ 0xF0A0BF90, 0x7ACE0 },
	{ 0xF0A0BF91, 0x4CFE8 },
	{ 0xF0A0BF92, 0x4CFF3 },
	{ 0xF0A0BF93, 0x4CFE6 },
	{ 0xF0A0BF94, 0x5D3F1 },
	{ 0xF0A0BF95, 0x4CFF0 },
	{ 0xF0A0BF96, 0x5D3EF },
	{ 0xF0A0BF97, 0x5D3E8 },
	{ 0xF0A0BF98, 0x7ACEB },
	{ 0xF0A0BF99, 0x7ACDB },
	{ 0xF0A0BF9A, 0x7ACE4 },
	{ 0xF0A0BF9B, 0x5D3EE },
	{ 0xF0A0BF9C, 0x7ACDF },
	{ 0xF0A0BF9D, 0x5D3EC },
	{ 0xF0A0BF9E, 0x5D3E7 },
	{ 0xF0A0BF9F, 0x5D3F5 },
	{ 0xF0A0BFA0, 0x5D3F0 },
	{ 0xF0A0BFA1, 0x5D3F3 },
	{ 0xF0A0BFA2, 0x7ACD9 },
	{ 0xF0A0BFA3, 0x5D3EB },
	{ 0xF0A0BFA4, 0x5D3E9 },
	{ 0xF0A0BFA5, 0x7ACE7 },
	{ 0xF0A0BFA6, 0x7ACD8 },
	{ 0xF0A0BFA7, 0x7ACD7 },
	{ 0xF0A0BFAE, 0xFCDF7 },
	{ 0xF0A0BFBA, 0x4CFE9 },
	{ 0xF0A0BFBB, 0x4CFF4 },
	{ 0xF0A0BFBC, 0x5D3F7 },
	{ 0xF0A0BFBD, 0x7ACE6 },
	{ 0xF0A0BFBE, 0xFD3DC },
	{ 0xF0A0BFBF, 0xFD3DE },
	{ 0xF0A18080, 0xFD3DF },
	{ 0xF0A18081, 0xFD3E0 },
	{ 0xF0A18082, 0xFD3E1 },
	{ 0xF0A18083, 0xFD3E2 },
	{ 0xF0A18084, 0xFD3E3 },
	{ 0xF0A18085, 0xFD3E4 },
	{ 0xF0A18086, 0xFD3E5 },
	{ 0xF0A18087, 0xFD3E7 },
	{ 0xF0A18088, 0xFD3E8 },
	{ 0xF0A18089, 0xFD3E9 },
	{ 0xF0A1808A, 0xFD3EA },
	{ 0xF0A1808B, 0xFD3EB },
	{ 0xF0A1808C, 0xFD3EC },
	{ 0xF0A1808D, 0xFD3ED },
	{ 0xF0A1808E, 0xFD3EE },
	{ 0xF0A1808F, 0xFD3EF },
	{ 0xF0A18090, 0x7ACDE },
	{ 0xF0A18092, 0x7ACDD },
	{ 0xF0A18093, 0x7ACE2 },
	{ 0xF0A180B9, 0x7ACE9 },
	{ 0xF0A180BA, 0x5D3ED },
	{ 0xF0A180BB, 0xFD5F4 },
	{ 0xF0A180BC, 0x5D3F6 },
	{ 0xF0A180BD, 0x4D5FA },
	{ 0xF0A180BF, 0x5DBA6 },
	{ 0xF0A18181, 0x5DBA1 },
	{ 0xF0A18182, 0x7B7AD },
	{ 0xF0A18183, 0x7B7AA },
	{ 0xF0A18184, 0x7B7B4 },
	{ 0xF0A18185, 0x7B7B5 },
	{ 0xF0A18186, 0x5DBA3 },
	{ 0xF0A18187, 0x5DBAB },
	{ 0xF0A18188, 0x4D5F1 },
	{ 0xF0A18189, 0x4D5F6 },
	{ 0xF0A1818B, 0x5DBA8 },
	{ 0xF0A1818C, 0x4D5F7 },
	{ 0xF0A1818D, 0x7B7AB },
	{ 0xF0A1818E, 0x5DBA9 },
	{ 0xF0A1818F, 0x4D5F9 },
	{ 0xF0A18190, 0x7B7B1 },
	{ 0xF0A18191, 0x7B7AF },
	{ 0xF0A18192, 0x7B7AE },
	{ 0xF0A18193, 0x5DBA4 },
	{ 0xF0A18195, 0x4D5F5 },
	{ 0xF0A18196, 0x7B7B2 },
	{ 0xF0A18197, 0x7B7B9 },
	{ 0xF0A1819F, 0xFD9D9 },
	{ 0xF0A181A0, 0xFD9DA },
	{ 0xF0A181A1, 0xFD9DE },
	{ 0xF0A181A2, 0xFD9DF },
	{ 0xF0A181A3, 0xFD9E0 },
	{ 0xF0A181A4, 0xFD9E1 },
	{ 0xF0A181A5, 0xFD9E2 },
	{ 0xF0A181A8, 0x7B7B8 },
	{ 0xF0A181A9, 0x7B7B0 },
	{ 0xF0A181AB, 0x7B7B6 },
	{ 0xF0A181AC, 0x7B7B3 },
	{ 0xF0A181AD, 0x7B7AC },
	{ 0xF0A1828A, 0x5DBAA },
	{ 0xF0A1828B, 0x5DBA2 },
	{ 0xF0A1828F, 0x4DAF4 },
	{ 0xF0A18290, 0x7BFA9 },
	{ 0xF0A18291, 0x7BFAF },
	{ 0xF0A18292, 0x4DAF3 },
	{ 0xF0A18293, 0x5E1BE },
	{ 0xF0A18294, 0x7BFAB },
	{ 0xF0A18295, 0x4DAF1 },
	{ 0xF0A18296, 0x4DAF6 },
	{ 0xF0A18297, 0x5E1C6 },
	{ 0xF0A18298, 0x4DAF7 },
	{ 0xF0A18299, 0x5E7D8 },
	{ 0xF0A1829A, 0x5E1BD },
	{ 0xF0A1829B, 0x5E1C4 },
	{ 0xF0A1829C, 0x5E1C3 },
	{ 0xF0A1829D, 0x4DAF8 },
	{ 0xF0A1829E, 0x7BFAA },
	{ 0xF0A1829F, 0x4DAF5 },
	{ 0xF0A182A0, 0x4DAF9 },
	{ 0xF0A182A1, 0x4DAF2 },
	{ 0xF0A182A2, 0x7BFAE },
	{ 0xF0A182A3, 0x5E1C1 },
	{ 0xF0A182A4, 0x7BFA7 },
	{ 0xF0A182A5, 0x7BFAD },
	{ 0xF0A182A6, 0x7BFA8 },
	{ 0xF0A182A7, 0x7BFA6 },
	{ 0xF0A182A8, 0x7BFAC },
	{ 0xF0A182A9, 0x5E1C2 },
	{ 0xF0A182AC, 0xFD9DB },
	{ 0xF0A182B6, 0x7BFA5 },
	{ 0xF0A182B7, 0xFDEBC },
	{ 0xF0A182B8, 0xFDEBD },
	{ 0xF0A182B9, 0xFDEBE },
	{ 0xF0A182BA, 0xFDEBF },
	{ 0xF0A182BB, 0xFDEC0 },
	{ 0xF0A182BC, 0xFDEC3 },
	{ 0xF0A182BD, 0xFDEC4 },
	{ 0xF0A182BE, 0xFDEC5 },
	{ 0xF0A1839D, 0x5E1BF },
	{ 0xF0A1839F, 0xFDECA },
	{ 0xF0A183A0, 0x7C6B4 },
	{ 0xF0A183A1, 0x4DFCE },
	{ 0xF0A183A2, 0x5DBA5 },
	{ 0xF0A183A3, 0x7C6BB },
	{ 0xF0A183A4, 0x7C6B9 },
	{ 0xF0A183A5, 0x7C6B7 },
	{ 0xF0A183A6, 0x5E7DA },
	{ 0xF0A183A7, 0x5E7DB },
	{ 0xF0A183A8, 0x4DFD0 },
	{ 0xF0A183A9, 0x5E7D7 },
	{ 0xF0A183AA, 0x7C6BC },
	{ 0xF0A183AB, 0x7C6BA },
	{ 0xF0A183AC, 0x7C6B3 },
	{ 0xF0A183AD, 0x7C6B5 },
	{ 0xF0A183AE, 0x7C6B8 },
	{ 0xF0A183AF, 0x4DFCF },
	{ 0xF0A183B2, 0xFDEC6 },
	{ 0xF0A183B7, 0x5E7DC },
	{ 0xF0A18482, 0xFE2A2 },
	{ 0xF0A18483, 0xFE2A3 },
	{ 0xF0A18484, 0xFE2A4 },
	{ 0xF0A18485, 0xFE2A5 },
	{ 0xF0A18486, 0xFE2A6 },
	{ 0xF0A18488, 0x7C6B6 },
	{ 0xF0A18489, 0x7C7EE },
	{ 0xF0A1848A, 0x7C6BD },
	{ 0xF0A18491, 0x5EBF4 },
	{ 0xF0A18492, 0x5EBF5 },
	{ 0xF0A18493, 0x5EBEF },
	{ 0xF0A18494, 0x5EBF1 },
	{ 0xF0A18495, 0x5EBF0 },
	{ 0xF0A18496, 0x7CDC7 },
	{ 0xF0A18497, 0x7CDC9 },
	{ 0xF0A18498, 0x7CDCB },
	{ 0xF0A18499, 0x7CDC8 },
	{ 0xF0A1849A, 0x7CDC6 },
	{ 0xF0A1849B, 0x7CDCA },
	{ 0xF0A1849C, 0xFE4FD },
	{ 0xF0A1849D, 0xFE4FE },
	{ 0xF0A1849E, 0xFE5A1 },
	{ 0xF0A184A0, 0x7CDCC },
	{ 0xF0A184A3, 0x5EBF2 },
	{ 0xF0A184B1, 0x7D2FB },
	{ 0xF0A184B2, 0x5EFF1 },
	{ 0xF0A184B3, 0x5EFEF },
	{ 0xF0A184B4, 0x4E6B5 },
	{ 0xF0A184B5, 0x5EFEE },
	{ 0xF0A184B6, 0x7D2FA },
	{ 0xF0A184B7, 0x5EFED },
	{ 0xF0A184B8, 0x7D2FE },
	{ 0xF0A184B9, 0x5EFF0 },
	{ 0xF0A184BA, 0x7D2FD },
	{ 0xF0A184BB, 0x4E6B3 },
	{ 0xF0A184BF, 0xFE7C7 },
	{ 0xF0A18580, 0xFE7C8 },
	{ 0xF0A18581, 0x5EFEC },
	{ 0xF0A18594, 0x7D2FC },
	{ 0xF0A18597, 0x7D7D9 },
	{ 0xF0A18598, 0x7D7DA },
	{ 0xF0A18599, 0x5F3B3 },
	{ 0xF0A1859A, 0x7D7D5 },
	{ 0xF0A1859C, 0x7D7D6 },
	{ 0xF0A1859D, 0x7D7D7 },
	{ 0xF0A1859E, 0x7D7D4 },
	{ 0xF0A1859F, 0x7D7D2 },
	{ 0xF0A185A1, 0x7D7D3 },
	{ 0xF0A185A3, 0xFE9BC },
	{ 0xF0A185AD, 0x4E8E4 },
	{ 0xF0A185AE, 0x7D7D8 },
	{ 0xF0A185B0, 0x7DBC9 },
	{ 0xF0A185B1, 0x7DBCA },
	{ 0xF0A185B2, 0xFEACD },
	{ 0xF0A185B6, 0x7DBC8 },
	{ 0xF0A185B8, 0x7DBC7 },
	{ 0xF0A185B9, 0x5F7D5 },
	{ 0xF0A185BA, 0x5F7D6 },
	{ 0xF0A185BB, 0x4EBE6 },
	{ 0xF0A185BC, 0x7DED3 },
	{ 0xF0A185BD, 0x7DED5 },
	{ 0xF0A185BE, 0x7DED4 },
	{ 0xF0A185BF, 0x7DED6 },
	{ 0xF0A18683, 0xFEBC3 },
	{ 0xF0A18685, 0x5F5E7 },
	{ 0xF0A18686, 0x5F9A3 },
	{ 0xF0A18689, 0x4ECED },
	{ 0xF0A1868A, 0xFECA2 },
	{ 0xF0A1868B, 0xFECA3 },
	{ 0xF0A1868E, 0x7E0EB },
	{ 0xF0A1868F, 0x7E2B2 },
	{ 0xF0A18690, 0x7E2B1 },
	{ 0xF0A18691, 0x7E2B4 },
	{ 0xF0A18692, 0x7E2B0 },
	{ 0xF0A18693, 0x7E2B3 },
	{ 0xF0A1869B, 0xFECF9 },
	{ 0xF0A1869C, 0xFECFA },
	{ 0xF0A186A0, 0x6A1E5 },
	{ 0xF0A186A1, 0x6A1E6 },
	{ 0xF0A186A2, 0xFA1B7 },
	{ 0xF0A186A3, 0x4A1EE },
	{ 0xF0A186A7, 0x6A4B2 },
	{ 0xF0A186A8, 0x6A4B0 },
	{ 0xF0A186A9, 0x5A2C9 },
	{ 0xF0A186AD, 0xFA2B5 },
	{ 0xF0A186B0, 0x6A4B1 },
	{ 0xF0A186B2, 0x6A4AF },
	{ 0xF0A186B3, 0x5A2C8 },
	{ 0xF0A186B4, 0x6A6D4 },
	{ 0xF0A186B5, 0x6AFDC },
	{ 0xF0A186B6, 0x6AABE },
	{ 0xF0A186B7, 0x6A6D8 },
	{ 0xF0A186B8, 0x6A6D6 },
	{ 0xF0A186B9, 0xFA3CF },
	{ 0xF0A186BA, 0xFA3D1 },
	{ 0xF0A186BB, 0x6A6D7 },
	{ 0xF0A186BC, 0x6A6D9 },
	{ 0xF0A186BE, 0x6A6DC },
	{ 0xF0A186BF, 0x6A6DA },
	{ 0xF0A18781, 0x6A6D1 },
	{ 0xF0A18783, 0x6A6D5 },
	{ 0xF0A18784, 0x6A6D2 },
	{ 0xF0A18786, 0x6A6D3 },
	{ 0xF0A18787, 0x6A6DB },
	{ 0xF0A18788, 0x5A5D5 },
	{ 0xF0A18789, 0x6AAC3 },
	{ 0xF0A1878A, 0x6AAC0 },
	{ 0xF0A1878B, 0x6AAC1 },
	{ 0xF0A1878C, 0x6AAC2 },
	{ 0xF0A1878D, 0x6ADB4 },
	{ 0xF0A1878E, 0x6AABF },
	{ 0xF0A18790, 0xFA6A4 },
	{ 0xF0A18791, 0x5A5D4 },
	{ 0xF0A18792, 0x5A8D4 },
	{ 0xF0A18793, 0x5A8D6 },
	{ 0xF0A18794, 0x6AFE0 },
	{ 0xF0A18795, 0x6AFDF },
	{ 0xF0A18796, 0x5A8D5 },
	{ 0xF0A18797, 0x6AFDB },
	{ 0xF0A18798, 0x6AFDE },
	{ 0xF0A1879B, 0x6AFDD },
	{ 0xF0A187A0, 0x5ACDC },
	{ 0xF0A187A1, 0x6B6AD },
	{ 0xF0A187A2, 0x6B6AA },
	{ 0xF0A187A3, 0x6B6AC },
	{ 0xF0A187A4, 0x5ACDB },
	{ 0xF0A187AA, 0x6B6AB },
	{ 0xF0A187B0, 0x5ACDD },
	{ 0xF0A187B1, 0x5B1D6 },
	{ 0xF0A187B2, 0x6BEA5 },
	{ 0xF0A187B3, 0x5B1D7 },
	{ 0xF0A187B4, 0x6BEA4 },
	{ 0xF0A187B5, 0x6BEA3 },
	{ 0xF0A187B6, 0x6BEA2 },
	{ 0xF0A187B7, 0x5B1D4 },
	{ 0xF0A187B9, 0x6BEA6 },
	{ 0xF0A187BC, 0x5B7B3 },
	{ 0xF0A187BD, 0x6C7C0 },
	{ 0xF0A187BE, 0x6C7C1 },
	{ 0xF0A187BF, 0x5B7B1 },
	{ 0xF0A18880, 0x5B1D5 },
	{ 0xF0A18882, 0xFB9F2 },
	{ 0xF0A18883, 0xFB9F3 },
	{ 0xF0A18884, 0xFB9F4 },
	{ 0xF0A18887, 0x6C7C2 },
	{ 0xF0A18889, 0x5B7B2 },
	{ 0xF0A1888A, 0x5BEC0 },
	{ 0xF0A1888B, 0x6D1C5 },
	{ 0xF0A1888C, 0x5BEC1 },
	{ 0xF0A1888D, 0x6D1C7 },
	{ 0xF0A1888E, 0x6D1C8 },
	{ 0xF0A1888F, 0x5BEC2 },
	{ 0xF0A18891, 0x6D1C6 },
	{ 0xF0A18894, 0xFC0E5 },
	{ 0xF0A18895, 0x6DBD4 },
	{ 0xF0A18896, 0x6DBD8 },
	{ 0xF0A18897, 0x5C5A4 },
	{ 0xF0A18898, 0x6DBD5 },
	{ 0xF0A18899, 0x6DBDA },
	{ 0xF0A1889A, 0x6DBD6 },
	{ 0xF0A1889B, 0xFC7AE },
	{ 0xF0A1889C, 0xFC7AF },
	{ 0xF0A1889D, 0xFC7B0 },
	{ 0xF0A1889F, 0x6DBD7 },
	{ 0xF0A188A2, 0x7A1E5 },
	{ 0xF0A188A3, 0x7A1E6 },
	{ 0xF0A188A4, 0x7A1E4 },
	{ 0xF0A188A5, 0xFCDFB },
	{ 0xF0A188AA, 0x4CFF5 },
	{ 0xF0A188AC, 0xFD3F3 },
	{ 0xF0A188AD, 0x7B7BC },
	{ 0xF0A188AE, 0x7B7BA },
	{ 0xF0A188B1, 0x7B7BB },
	{ 0xF0A188B3, 0x4DFD1 },
	{ 0xF0A188B7, 0x7CDCD },
	{ 0xF0A188B8, 0x7D3A2 },
	{ 0xF0A188B9, 0x7D3A1 },
	{ 0xF0A188BC, 0x4A1C8 },
	{ 0xF0A188BE, 0x5A1C4 },
	{ 0xF0A188BF, 0x6A2E0 },
	{ 0xF0A18981, 0xFA1D1 },
	{ 0xF0A18982, 0xFA1D2 },
	{ 0xF0A18984, 0x6A2E1 },
	{ 0xF0A1898A, 0x6A4B5 },
	{ 0xF0A1898C, 0xFA2B6 },
	{ 0xF0A1898D, 0xFA2B7 },
	{ 0xF0A18992, 0x6A4B4 },
	{ 0xF0A18998, 0x6A6EA },
	{ 0xF0A18999, 0x4A3E0 },
	{ 0xF0A1899A, 0x6A6E6 },
	{ 0xF0A1899B, 0x6A6E2 },
	{ 0xF0A1899D, 0x6A6DE },
	{ 0xF0A1899F, 0x6A6E9 },
	{ 0xF0A189A0, 0x6A6DD },
	{ 0xF0A189A1, 0x6A6E5 },
	{ 0xF0A189A2, 0x6A6E7 },
	{ 0xF0A189A3, 0xFA3D3 },
	{ 0xF0A189A4, 0xFA3D4 },
	{ 0xF0A189A5, 0xFA3D6 },
	{ 0xF0A189A6, 0xFA3D8 },
	{ 0xF0A189A7, 0xFA3DA },
	{ 0xF0A189AC, 0x6A6E0 },
	{ 0xF0A189B1, 0x6A6E3 },
	{ 0xF0A189B2, 0x6A6E8 },
	{ 0xF0A189B3, 0x6A6E4 },
	{ 0xF0A189B5, 0x6A6E1 },
	{ 0xF0A189B6, 0x6A6DF },
	{ 0xF0A189B7, 0x5A3DE },
	{ 0xF0A189BC, 0xFA3D9 },
	{ 0xF0A18A80, 0x5A3DD },
	{ 0xF0A18A81, 0x5A3DF },
	{ 0xF0A18A82, 0x5A3E0 },
	{ 0xF0A18A83, 0x5A3E1 },
	{ 0xF0A18A84, 0x4A5EA },
	{ 0xF0A18A85, 0x6AACF },
	{ 0xF0A18A86, 0x6AAC7 },
	{ 0xF0A18A87, 0x6AACC },
	{ 0xF0A18A88, 0x6AAC6 },
	{ 0xF0A18A89, 0x4A5E7 },
	{ 0xF0A18A8A, 0x6AACA },
	{ 0xF0A18A8B, 0x4A5EC },
	{ 0xF0A18A8C, 0x6AAC8 },
	{ 0xF0A18A8D, 0x5A5D6 },
	{ 0xF0A18A8E, 0x6AAD1 },
	{ 0xF0A18A8F, 0x6A6C1 },
	{ 0xF0A18A93, 0x6AAC9 },
	{ 0xF0A18A94, 0xFA6A6 },
	{ 0xF0A18A95, 0xFA6A7 },
	{ 0xF0A18A96, 0xFA6A8 },
	{ 0xF0A18A97, 0xFA6A9 },
	{ 0xF0A18A98, 0xFA6AA },
	{ 0xF0A18A99, 0xFA6B0 },
	{ 0xF0A18A9A, 0xFA6B1 },
	{ 0xF0A18A9B, 0xFA6AC },
	{ 0xF0A18A9C, 0xFA6AB },
	{ 0xF0A18A9E, 0x4A5EB },
	{ 0xF0A18AA0, 0xFA6AF },
	{ 0xF0A18AA1, 0xFA6AE },
	{ 0xF0A18AA3, 0x6AAD0 },
	{ 0xF0A18AA4, 0x6AACB },
	{ 0xF0A18AA5, 0x6AACD },
	{ 0xF0A18AA6, 0x6AACE },
	{ 0xF0A18AA7, 0xFA6B2 },
	{ 0xF0A18AA8, 0xFA6A5 },
	{ 0xF0A18AAC, 0x6AAC5 },
	{ 0xF0A18AB4, 0x6AAC4 },
	{ 0xF0A18AB5, 0x5A5D7 },
	{ 0xF0A18AB6, 0x5A8DB },
	{ 0xF0A18AB7, 0x6AFE2 },
	{ 0xF0A18AB8, 0x5A8D7 },
	{ 0xF0A18AB9, 0x6AFE4 },
	{ 0xF0A18ABA, 0x6AFE1 },
	{ 0xF0A18ABB, 0x5A8D8 },
	{ 0xF0A18ABC, 0x4A8DF },
	{ 0xF0A18ABD, 0x6AFEB },
	{ 0xF0A18ABE, 0x6AFE3 },
	{ 0xF0A18B84, 0xFA9FA },
	{ 0xF0A18B85, 0xFA9E8 },
	{ 0xF0A18B86, 0xFA9E9 },
	{ 0xF0A18B87, 0xFA9EB },
	{ 0xF0A18B88, 0xFA9EC },
	{ 0xF0A18B89, 0xFA9ED },
	{ 0xF0A18B8A, 0xFA9EE },
	{ 0xF0A18B8B, 0xFA9EF },
	{ 0xF0A18B8C, 0xFA9F0 },
	{ 0xF0A18B8D, 0xFA9F2 },
	{ 0xF0A18B8E, 0xFA9F3 },
	{ 0xF0A18B8F, 0xFA9F5 },
	{ 0xF0A18B90, 0xFA9F6 },
	{ 0xF0A18B91, 0xFA9F7 },
	{ 0xF0A18B92, 0xFA9F8 },
	{ 0xF0A18B93, 0xFA9F9 },
	{ 0xF0A18B94, 0xFA9FB },
	{ 0xF0A18B95, 0xFA9FC },
	{ 0xF0A18B96, 0xFA9FD },
	{ 0xF0A18B98, 0x6AFEA },
	{ 0xF0A18B9B, 0x6AFEC },
	{ 0xF0A18B9C, 0x6B4B1 },
	{ 0xF0A18B9D, 0x6AFE7 },
	{ 0xF0A18B9E, 0x6AFE8 },
	{ 0xF0A18BA0, 0x6AFE6 },
	{ 0xF0A18BA3, 0xFA9F4 },
	{ 0xF0A18BA7, 0x5A8DD },
	{ 0xF0A18BA8, 0x5A8DA },
	{ 0xF0A18BA9, 0x5A8DE },
	{ 0xF0A18BAA, 0x5A8DC },
	{ 0xF0A18BAB, 0x5A8D9 },
	{ 0xF0A18BAC, 0x5ACDE },
	{ 0xF0A18BAD, 0x4ACB2 },
	{ 0xF0A18BAE, 0x6B6B4 },
	{ 0xF0A18BAF, 0x4ACB0 },
	{ 0xF0A18BB0, 0x4ACB4 },
	{ 0xF0A18BB1, 0x6B6B2 },
	{ 0xF0A18BB2, 0x6B6BC },
	{ 0xF0A18BB3, 0x6B6B6 },
	{ 0xF0A18BB4, 0x6B6BD },
	{ 0xF0A18BB5, 0x6B6BE },
	{ 0xF0A18BB6, 0x6B6B1 },
	{ 0xF0A18BB7, 0x6B6AE },
	{ 0xF0A18BB8, 0x6B6BA },
	{ 0xF0A18C81, 0x6B6AF },
	{ 0xF0A18C86, 0x6B6C0 },
	{ 0xF0A18C87, 0xFAED5 },
	{ 0xF0A18C88, 0xFAED6 },
	{ 0xF0A18C89, 0xFAED7 },
	{ 0xF0A18C8A, 0xFAED8 },
	{ 0xF0A18C8B, 0xFAED9 },
	{ 0xF0A18C8C, 0xFAEDA },
	{ 0xF0A18C8D, 0xFAEDB },
	{ 0xF0A18C8E, 0xFAEDE },
	{ 0xF0A18C8F, 0xFAEDF },
	{ 0xF0A18C90, 0xFAEE0 },
	{ 0xF0A18C92, 0x6B6B0 },
	{ 0xF0A18C93, 0x6B6BF },
	{ 0xF0A18C95, 0x6B6B7 },
	{ 0xF0A18C96, 0x6B6B8 },
	{ 0xF0A18C97, 0x6B6B9 },
	{ 0xF0A18C98, 0x5ACE0 },
	{ 0xF0A18C99, 0x6B6BB },
	{ 0xF0A18C9A, 0xFAEDD },
	{ 0xF0A18C9C, 0xFAEE1 },
	{ 0xF0A18C9F, 0x6B6B3 },
	{ 0xF0A18CA4, 0x5ACDF },
	{ 0xF0A18CA5, 0x5ACE2 },
	{ 0xF0A18CA6, 0x4B0FD },
	{ 0xF0A18CA7, 0x6BEA7 },
	{ 0xF0A18CA9, 0x4B0FC },
	{ 0xF0A18CAA, 0x5B1DD },
	{ 0xF0A18CAB, 0x6BEB4 },
	{ 0xF0A18CAC, 0x6BEAD },
	{ 0xF0A18CAD, 0x5B1DB },
	{ 0xF0A18CAE, 0x6BEAA },
	{ 0xF0A18CAF, 0x5ACE1 },
	{ 0xF0A18CB0, 0x6BEB3 },
	{ 0xF0A18CB1, 0x6BEB0 },
	{ 0xF0A18CB2, 0x5B1DA },
	{ 0xF0A18CB3, 0x4B1A2 },
	{ 0xF0A18CB4, 0x4B1A3 },
	{ 0xF0A18CB6, 0xFB3CF },
	{ 0xF0A18CB7, 0xFB3DB },
	{ 0xF0A18CB8, 0x6BEAE },
	{ 0xF0A18CB9, 0x6BEAF },
	{ 0xF0A18CBB, 0xFB3CE },
	{ 0xF0A18CBC, 0xFB3D0 },
	{ 0xF0A18CBD, 0xFB3D1 },
	{ 0xF0A18CBE, 0xFB3D2 },
	{ 0xF0A18CBF, 0xFB3D3 },
	{ 0xF0A18D80, 0xFB3D4 },
	{ 0xF0A18D81, 0xFB3D5 },
	{ 0xF0A18D82, 0xFB3D6 },
	{ 0xF0A18D83, 0xFB3D8 },
	{ 0xF0A18D84, 0xFB3D9 },
	{ 0xF0A18D85, 0xFB3DA },
	{ 0xF0A18D86, 0xFB3DE },
	{ 0xF0A18D87, 0xFB3DF },
	{ 0xF0A18D88, 0xFB3E0 },
	{ 0xF0A18D89, 0xFB3E1 },
	{ 0xF0A18D8A, 0x5B1DC },
	{ 0xF0A18D8F, 0x6BEB1 },
	{ 0xF0A18D91, 0x6BEB5 },
	{ 0xF0A18D93, 0x4B0FE },
	{ 0xF0A18D94, 0x6BEA8 },
	{ 0xF0A18D95, 0x6BEA9 },
	{ 0xF0A18DA0, 0x5B1D8 },
	{ 0xF0A18DA1, 0x5B1D9 },
	{ 0xF0A18DA4, 0x3BACF },
	{ 0xF0A18DA5, 0x6D1CE },
	{ 0xF0A18DA6, 0x4B6F2 },
	{ 0xF0A18DA7, 0x6C7C7 },
	{ 0xF0A18DA8, 0x4B6EA },
	{ 0xF0A18DA9, 0x6C7C5 },
	{ 0xF0A18DAA, 0x4B6F0 },
	{ 0xF0A18DAB, 0x4B6EC },
	{ 0xF0A18DAC, 0x6C7CB },
	{ 0xF0A18DAD, 0x6C7D0 },
	{ 0xF0A18DAE, 0x4B6F5 },
	{ 0xF0A18DAF, 0x6C7C4 },
	{ 0xF0A18DB0, 0x6C7C6 },
	{ 0xF0A18DB1, 0x6C7CD },
	{ 0xF0A18DB2, 0x5B7B4 },
	{ 0xF0A18DB3, 0x6BEB2 },
	{ 0xF0A18DB4, 0x6C7CF },
	{ 0xF0A18DB5, 0x4BCDA },
	{ 0xF0A18DB6, 0x5B7B9 },
	{ 0xF0A18DB7, 0x4B6F3 },
	{ 0xF0A18DBA, 0x6CFED },
	{ 0xF0A18DBB, 0x5B7B8 },
	{ 0xF0A18DBC, 0xFB9F6 },
	{ 0xF0A18DBD, 0xFB9F8 },
	{ 0xF0A18DBE, 0xFB9F9 },
	{ 0xF0A18DBF, 0xFB9FA },
	{ 0xF0A18E80, 0xFB9FB },
	{ 0xF0A18E81, 0xFB9FC },
	{ 0xF0A18E82, 0xFBAA1 },
	{ 0xF0A18E83, 0xFBAA2 },
	{ 0xF0A18E84, 0xFBAA3 },
	{ 0xF0A18E85, 0xFBAA4 },
	{ 0xF0A18E86, 0xFBAA5 },
	{ 0xF0A18E87, 0xFBAA6 },
	{ 0xF0A18E8E, 0x6C7D1 },
	{ 0xF0A18E90, 0x6C7CA },
	{ 0xF0A18E95, 0x6C7C9 },
	{ 0xF0A18E96, 0x4B6F4 },
	{ 0xF0A18E97, 0x6C7CC },
	{ 0xF0A18E9A, 0xFB9F5 },
	{ 0xF0A18EA7, 0x5B7B7 },
	{ 0xF0A18EA8, 0x5B7BA },
	{ 0xF0A18EA9, 0x6C7C8 },
	{ 0xF0A18EAA, 0x5B7B5 },
	{ 0xF0A18EAB, 0x5B7B6 },
	{ 0xF0A18EAC, 0x5B7BB },
	{ 0xF0A18EAE, 0x5BEC6 },
	{ 0xF0A18EAF, 0x6D1D6 },
	{ 0xF0A18EB0, 0x6D1CB },
	{ 0xF0A18EB1, 0x6D1D5 },
	{ 0xF0A18EB3, 0x5BECD },
	{ 0xF0A18EB4, 0x4BCD4 },
	{ 0xF0A18EB5, 0x6DBE2 },
	{ 0xF0A18EB6, 0x6D1D2 },
	{ 0xF0A18EB7, 0x5BECC },
	{ 0xF0A18EB8, 0x6D1D1 },
	{ 0xF0A18EB9, 0x5BEC4 },
	{ 0xF0A18EBA, 0x5BECB },
	{ 0xF0A18EBB, 0x5BEC3 },
	{ 0xF0A18EBC, 0x6D1D4 },
	{ 0xF0A18EBD, 0x6D1D0 },
	{ 0xF0A18EBE, 0x5BEC9 },
	{ 0xF0A18EBF, 0x5BECA },
	{ 0xF0A18F80, 0x4BCD5 },
	{ 0xF0A18F81, 0x5BEC7 },
	{ 0xF0A18F82, 0x6D1C9 },
	{ 0xF0A18F83, 0x6D1CC },
	{ 0xF0A18F85, 0xFB9F7 },
	{ 0xF0A18F87, 0x6D1D3 },
	{ 0xF0A18F88, 0x6D1CD },
	{ 0xF0A18F89, 0xFC0E6 },
	{ 0xF0A18F8A, 0xFC0E7 },
	{ 0xF0A18F8B, 0xFC0E8 },
	{ 0xF0A18F8C, 0xFC0EA },
	{ 0xF0A18F8D, 0xFC0EB },
	{ 0xF0A18F8E, 0xFC0EC },
	{ 0xF0A18F8F, 0xFC0ED },
	{ 0xF0A18F90, 0xFC0EE },
	{ 0xF0A18F91, 0xFC0EF },
	{ 0xF0A18F92, 0xFC0F0 },
	{ 0xF0A18F93, 0xFC0F1 },
	{ 0xF0A18F94, 0xFC0F2 },
	{ 0xF0A18F95, 0xFC0F3 },
	{ 0xF0A18F97, 0x6D1CF },
	{ 0xF0A18FA9, 0x5BECE },
	{ 0xF0A18FAA, 0x5BEC8 },
	{ 0xF0A18FAB, 0x5BEC5 },
	{ 0xF0A18FAD, 0x5C5A9 },
	{ 0xF0A18FAE, 0x5C5A8 },
	{ 0xF0A18FAF, 0x5C5A7 },
	{ 0xF0A18FB0, 0x6DBDC },
	{ 0xF0A18FB1, 0x4C2DC },
	{ 0xF0A18FB2, 0x6DBE4 },
	{ 0xF0A18FB3, 0x6DBE6 },
	{ 0xF0A18FB4, 0x6DBE1 },
	{ 0xF0A18FB5, 0x5C5AA },
	{ 0xF0A18FB6, 0x6DBE0 },
	{ 0xF0A18FB7, 0x5C5A6 },
	{ 0xF0A18FB8, 0x6DBE7 },
	{ 0xF0A18FBF, 0xFC7B2 },
	{ 0xF0A19080, 0xFC7B3 },
	{ 0xF0A19081, 0xFC7B4 },
	{ 0xF0A19082, 0xFC7B5 },
	{ 0xF0A19083, 0xFC7B6 },
	{ 0xF0A19084, 0xFC7B7 },
	{ 0xF0A19085, 0xFC7B9 },
	{ 0xF0A19086, 0xFC7BA },
	{ 0xF0A19087, 0xFC7BB },
	{ 0xF0A19088, 0xFC7BC },
	{ 0xF0A19089, 0x6DBDD },
	{ 0xF0A1908A, 0xFC7B8 },
	{ 0xF0A1908E, 0x6DBEB },
	{ 0xF0A19090, 0x6DBE3 },
	{ 0xF0A19091, 0x6DBD3 },
	{ 0xF0A19093, 0xFC7B1 },
	{ 0xF0A19094, 0x4C2DA },
	{ 0xF0A19095, 0x6DBE5 },
	{ 0xF0A1909B, 0x6DBDE },
	{ 0xF0A1909D, 0x5C5A5 },
	{ 0xF0A1909E, 0x5C5AB },
	{ 0xF0A1909F, 0x7A1F2 },
	{ 0xF0A190A0, 0x4C9B4 },
	{ 0xF0A190A1, 0x4C9B5 },
	{ 0xF0A190A2, 0x7A1EF },
	{ 0xF0A190A3, 0x4C9B6 },
	{ 0xF0A190A4, 0x5CCCB },
	{ 0xF0A190A5, 0x5CCCC },
	{ 0xF0A190A6, 0x7A1EB },
	{ 0xF0A190A8, 0x7A1F8 },
	{ 0xF0A190A9, 0x4C9B7 },
	{ 0xF0A190AA, 0x7A1F7 },
	{ 0xF0A190AB, 0x7A1F4 },
	{ 0xF0A190AD, 0xFCEA1 },
	{ 0xF0A190B0, 0x5CCCD },
	{ 0xF0A190B1, 0x5CCCF },
	{ 0xF0A190B2, 0x7A1E7 },
	{ 0xF0A190B3, 0x7A1F5 },
	{ 0xF0A190B4, 0xFCDFC },
	{ 0xF0A190B5, 0xFCDFD },
	{ 0xF0A190B6, 0xFCEA6 },
	{ 0xF0A190B7, 0xFCEA7 },
	{ 0xF0A190B8, 0xFCEA8 },
	{ 0xF0A190B9, 0xFCEA9 },
	{ 0xF0A190BA, 0xFCEAA },
	{ 0xF0A190BB, 0xFCEAB },
	{ 0xF0A190BC, 0xFCEAD },
	{ 0xF0A190BE, 0x7A1EC },
	{ 0xF0A19182, 0x7A1ED },
	{ 0xF0A19187, 0x7A1EE },
	{ 0xF0A19188, 0x5CCF1 },
	{ 0xF0A19189, 0x7A1F3 },
	{ 0xF0A1918A, 0x7A1F1 },
	{ 0xF0A1918F, 0x7A1E9 },
	{ 0xF0A19191, 0xFCDFE },
	{ 0xF0A19192, 0xFCEA4 },
	{ 0xF0A19194, 0xFCEA3 },
	{ 0xF0A19198, 0x5CCCE },
	{ 0xF0A19199, 0x5CCCA },
	{ 0xF0A1919A, 0x5CCC8 },
	{ 0xF0A1919B, 0x7A1E8 },
	{ 0xF0A1919C, 0x5CCC9 },
	{ 0xF0A1919E, 0x7ACEF },
	{ 0xF0A1919F, 0x7ACF1 },
	{ 0xF0A191A0, 0x7ACEC },
	{ 0xF0A191A1, 0x4CFF7 },
	{ 0xF0A191A2, 0x4CFFA },
	{ 0xF0A191A3, 0x4CFF9 },
	{ 0xF0A191A4, 0x7ACED },
	{ 0xF0A191A6, 0x7ACF0 },
	{ 0xF0A191A8, 0xFCEAC },
	{ 0xF0A191AB, 0xFD3F4 },
	{ 0xF0A191AC, 0xFD3F6 },
	{ 0xF0A191AD, 0xFD3F8 },
	{ 0xF0A191B6, 0x5D3FA },
	{ 0xF0A191B7, 0x7ACF2 },
	{ 0xF0A191B8, 0x5D3FB },
	{ 0xF0A191B9, 0x5D3F9 },
	{ 0xF0A191BA, 0x7B4EF },
	{ 0xF0A19282, 0x7ACF3 },
	{ 0xF0A19286, 0x7ACEE },
	{ 0xF0A19287, 0xFD3F7 },
	{ 0xF0A19288, 0x4CFF6 },
	{ 0xF0A19289, 0x7B7C3 },
	{ 0xF0A1928A, 0x4D5FD },
	{ 0xF0A1928B, 0x7B7BD },
	{ 0xF0A1928C, 0x5DBAE },
	{ 0xF0A1928D, 0x7B7BF },
	{ 0xF0A1928E, 0x7B7C4 },
	{ 0xF0A19290, 0x7B7C2 },
	{ 0xF0A19292, 0x7B7C5 },
	{ 0xF0A19293, 0x5DBAC },
	{ 0xF0A19296, 0x7ACF4 },
	{ 0xF0A19299, 0xFD9E4 },
	{ 0xF0A1929A, 0xFD9E5 },
	{ 0xF0A1929B, 0xFD9E6 },
	{ 0xF0A1929C, 0xFD9E7 },
	{ 0xF0A1929D, 0xFD9E8 },
	{ 0xF0A1929E, 0xFD9E9 },
	{ 0xF0A1929F, 0xFD9EA },
	{ 0xF0A192A0, 0xFD9EB },
	{ 0xF0A192A1, 0x7BEEC },
	{ 0xF0A192A3, 0x7B7C0 },
	{ 0xF0A192A4, 0x7B7C1 },
	{ 0xF0A192A8, 0x4D5FE },
	{ 0xF0A192AF, 0x5DBAF },
	{ 0xF0A192B0, 0x7BFB4 },
	{ 0xF0A192B1, 0x5E1C7 },
	{ 0xF0A192B2, 0x7B7BE },
	{ 0xF0A192B3, 0x5E1C9 },
	{ 0xF0A192B4, 0x7BFB3 },
	{ 0xF0A192B5, 0xFDEC7 },
	{ 0xF0A192B7, 0xFDEC8 },
	{ 0xF0A192B8, 0xFDEC9 },
	{ 0xF0A192B9, 0xFDECB },
	{ 0xF0A192BA, 0xFDECD },
	{ 0xF0A192BB, 0xFDECE },
	{ 0xF0A192BC, 0x7BFB1 },
	{ 0xF0A192BD, 0x7BFB2 },
	{ 0xF0A19389, 0x5DBB0 },
	{ 0xF0A1938A, 0x5E1C8 },
	{ 0xF0A1938C, 0xFE2A8 },
	{ 0xF0A1938D, 0x5E1CA },
	{ 0xF0A19390, 0x7C6C2 },
	{ 0xF0A19391, 0x7C6BF },
	{ 0xF0A19392, 0x5E7DD },
	{ 0xF0A19393, 0x7C6C7 },
	{ 0xF0A19394, 0x7C6C1 },
	{ 0xF0A19395, 0xFDECC },
	{ 0xF0A19397, 0xFE2A7 },
	{ 0xF0A19399, 0x7C6C3 },
	{ 0xF0A1939A, 0x7C6C6 },
	{ 0xF0A1939B, 0x7CABB },
	{ 0xF0A193A3, 0x7C6C0 },
	{ 0xF0A193A4, 0x7BFB5 },
	{ 0xF0A193A6, 0x4E3B3 },
	{ 0xF0A193A7, 0xFE5A2 },
	{ 0xF0A193A9, 0xFE5A3 },
	{ 0xF0A193AA, 0xFE5A4 },
	{ 0xF0A193AB, 0xFE5A5 },
	{ 0xF0A193AC, 0x7CDCE },
	{ 0xF0A193B0, 0x5EBF7 },
	{ 0xF0A193B1, 0x7D3A8 },
	{ 0xF0A193B2, 0x4E6B6 },
	{ 0xF0A193B3, 0x7D3A4 },
	{ 0xF0A193B4, 0x7D3A3 },
	{ 0xF0A193B5, 0x7D3A7 },
	{ 0xF0A193B6, 0x7D3A5 },
	{ 0xF0A193B8, 0x5EFF4 },
	{ 0xF0A193B9, 0xFE7C9 },
	{ 0xF0A193BA, 0xFE7CA },
	{ 0xF0A193BB, 0xFE7CC },
	{ 0xF0A193BC, 0x7D3A6 },
	{ 0xF0A193BD, 0xFE7CB },
	{ 0xF0A193BF, 0x5EFF2 },
	{ 0xF0A19481, 0x5EFF3 },
	{ 0xF0A19482, 0x7D7DB },
	{ 0xF0A19484, 0xFE9BD },
	{ 0xF0A19487, 0x5F3B4 },
	{ 0xF0A19488, 0x7D7DD },
	{ 0xF0A19489, 0x5F3B5 },
	{ 0xF0A1948A, 0x7DBCB },
	{ 0xF0A1948B, 0x7D7DC },
	{ 0xF0A1948F, 0x7DED7 },
	{ 0xF0A19495, 0x5F7D7 },
	{ 0xF0A19497, 0x5FBDF },
	{ 0xF0A19498, 0x7E5DA },
	{ 0xF0A19499, 0x7E6C2 },
	{ 0xF0A1949A, 0x7E6CF },
	{ 0xF0A1949B, 0x6A2E2 },
	{ 0xF0A1949D, 0x6AFED },
	{ 0xF0A1949E, 0x6A6EB },
	{ 0xF0A1949F, 0x6AAD2 },
	{ 0xF0A194A0, 0xFA9FE },
	{ 0xF0A194A1, 0xFAAA1 },
	{ 0xF0A194A2, 0x5ACE4 },
	{ 0xF0A194A4, 0x6B6C2 },
	{ 0xF0A194A5, 0x6AFEE },
	{ 0xF0A194A6, 0x6B6C1 },
	{ 0xF0A194A7, 0xFAEE2 },
	{ 0xF0A194A8, 0x5ACE3 },
	{ 0xF0A194AC, 0x6BEB6 },
	{ 0xF0A194AD, 0xFB3E2 },
	{ 0xF0A194AF, 0x6C7D2 },
	{ 0xF0A194B0, 0x6D1D9 },
	{ 0xF0A194B5, 0x6D1D8 },
	{ 0xF0A194B6, 0x6DBEA },
	{ 0xF0A194B7, 0x6E4FA },
	{ 0xF0A194B9, 0x6DBE8 },
	{ 0xF0A194BA, 0xFC7BD },
	{ 0xF0A194BB, 0x6DBE9 },
	{ 0xF0A194BC, 0x7A1FA },
	{ 0xF0A194BD, 0x7A1F9 },
	{ 0xF0A194BE, 0x7ACF5 },
	{ 0xF0A19585, 0x7BFB6 },
	{ 0xF0A19586, 0x7C3BF },
	{ 0xF0A1958A, 0xFDECF },
	{ 0xF0A1958B, 0x7BFB7 },
	{ 0xF0A1958C, 0x7C6C8 },
	{ 0xF0A1958D, 0x7C6C9 },
	{ 0xF0A1958E, 0x7C8BB },
	{ 0xF0A19591, 0x7D7DE },
	{ 0xF0A19592, 0x5A1AF },
	{ 0xF0A19593, 0x6A2E3 },
	{ 0xF0A19595, 0x6A4B7 },
	{ 0xF0A19596, 0x6A4B6 },
	{ 0xF0A19598, 0x6A6EC },
	{ 0xF0A19599, 0xFA3DC },
	{ 0xF0A1959A, 0x6B6C3 },
	{ 0xF0A1959B, 0x6BEB7 },
	{ 0xF0A1959C, 0x6BEB8 },
	{ 0xF0A1959D, 0x6D1DA },
	{ 0xF0A1959E, 0x6A4B9 },
	{ 0xF0A1959F, 0x6A4B8 },
	{ 0xF0A195A0, 0x5A3E4 },
	{ 0xF0A195A1, 0x5A3E3 },
	{ 0xF0A195A2, 0x4A5EF },
	{ 0xF0A195A3, 0x6AAD3 },
	{ 0xF0A195A4, 0xFA6B4 },
	{ 0xF0A195A6, 0xFAEE3 },
	{ 0xF0A195A7, 0x5B1DE },
	{ 0xF0A195A8, 0x6BEB9 },
	{ 0xF0A195A9, 0x6BEBC },
	{ 0xF0A195AA, 0x5ACE5 },
	{ 0xF0A195AB, 0x6BEBB },
	{ 0xF0A195AC, 0x6BEBA },
	{ 0xF0A195AE, 0x5BECF },
	{ 0xF0A195AF, 0x6D1DC },
	{ 0xF0A195B1, 0xFC0F4 },
	{ 0xF0A195B2, 0x6DBEC },
	{ 0xF0A195B3, 0xFC7BE },
	{ 0xF0A195B4, 0x6DBED },
	{ 0xF0A195B6, 0x5CCD0 },
	{ 0xF0A195B7, 0xFCEAF },
	{ 0xF0A195B8, 0xFD3F9 },
	{ 0xF0A195B9, 0x7ACF6 },
	{ 0xF0A195BA, 0x7ACF7 },
	{ 0xF0A195BB, 0x7B7C6 },
	{ 0xF0A195BC, 0x7C6CA },
	{ 0xF0A195BD, 0x7BFBA },
	{ 0xF0A195BE, 0x7BFB8 },
	{ 0xF0A195BF, 0x7BFB9 },
	{ 0xF0A19680, 0x7C6CB },
	{ 0xF0A19681, 0x7CDCF },
	{ 0xF0A19684, 0x6A2E4 },
	{ 0xF0A19686, 0x6A2E5 },
	{ 0xF0A19688, 0x6A4BA },
	{ 0xF0A1968A, 0x6A6EE },
	{ 0xF0A1968B, 0x6A6ED },
	{ 0xF0A1968D, 0x6AAD4 },
	{ 0xF0A1968F, 0xFA5C2 },
	{ 0xF0A19691, 0x5A8DF },
	{ 0xF0A19692, 0x5ACE8 },
	{ 0xF0A19693, 0x4ACB5 },
	{ 0xF0A19694, 0x5ACE7 },
	{ 0xF0A19695, 0x6B6C6 },
	{ 0xF0A19697, 0x6B6C5 },
	{ 0xF0A19698, 0xFAEE4 },
	{ 0xF0A19699, 0xFAEE5 },
	{ 0xF0A1969A, 0x6B6C7 },
	{ 0xF0A1969C, 0x5ACE9 },
	{ 0xF0A1969D, 0x4B1A4 },
	{ 0xF0A1969E, 0x5B1E1 },
	{ 0xF0A1969F, 0x6BEBD },
	{ 0xF0A196A2, 0x5B1DF },
	{ 0xF0A196A3, 0x5B1E0 },
	{ 0xF0A196A4, 0x5B1E2 },
	{ 0xF0A196A5, 0xFB3E3 },
	{ 0xF0A196A9, 0x6C7D4 },
	{ 0xF0A196AA, 0x5B7BE },
	{ 0xF0A196AB, 0x5B7C2 },
	{ 0xF0A196AC, 0x5B7C0 },
	{ 0xF0A196AD, 0x5B7C1 },
	{ 0xF0A196AE, 0xFBAA7 },
	{ 0xF0A196AF, 0x5BED0 },
	{ 0xF0A196B0, 0x6D1DD },
	{ 0xF0A196B2, 0x5BED2 },
	{ 0xF0A196B3, 0x5BED1 },
	{ 0xF0A196B4, 0x6D1DF },
	{ 0xF0A196B6, 0x4C2E1 },
	{ 0xF0A196B7, 0x6DBEF },
	{ 0xF0A196B8, 0x6DBF0 },
	{ 0xF0A196B9, 0x6DBEE },
	{ 0xF0A196BD, 0x5C5AC },
	{ 0xF0A196BE, 0x5C5AE },
	{ 0xF0A196BF, 0x7A1FB },
	{ 0xF0A19781, 0x5CCD1 },
	{ 0xF0A19783, 0x7BFBB },
	{ 0xF0A19786, 0x5DBB1 },
	{ 0xF0A19788, 0x5DBB2 },
	{ 0xF0A1978C, 0x7C6CC },
	{ 0xF0A19792, 0x6A1E7 },
	{ 0xF0A19793, 0x6A1E8 },
	{ 0xF0A19794, 0xFA1B8 },
	{ 0xF0A19795, 0x6A2E6 },
	{ 0xF0A19798, 0xFA1D3 },
	{ 0xF0A19799, 0xFA1D4 },
	{ 0xF0A1979C, 0x5A1F6 },
	{ 0xF0A1979D, 0x6A4BC },
	{ 0xF0A1979E, 0x4A2D4 },
	{ 0xF0A1979F, 0x6A4BF },
	{ 0xF0A197A0, 0x6A4C0 },
	{ 0xF0A197A1, 0x6A4BE },
	{ 0xF0A197A2, 0x6A4BD },
	{ 0xF0A197A3, 0xFA1EB },
	{ 0xF0A197A5, 0x4A3E3 },
	{ 0xF0A197A6, 0x4A3E4 },
	{ 0xF0A197A8, 0x4A3E6 },
	{ 0xF0A197A9, 0xFA3DD },
	{ 0xF0A197AA, 0xFA3DE },
	{ 0xF0A197AB, 0xFA3DF },
	{ 0xF0A197AC, 0xFA3E0 },
	{ 0xF0A197AD, 0xFA3E1 },
	{ 0xF0A197AE, 0xFA3E2 },
	{ 0xF0A197AF, 0xFA3E3 },
	{ 0xF0A197B0, 0x6A6F0 },
	{ 0xF0A197B4, 0x6A6EF },
	{ 0xF0A197B7, 0x4A5F6 },
	{ 0xF0A197B8, 0x5A5DA },
	{ 0xF0A197B9, 0x4A5F4 },
	{ 0xF0A197BA, 0x6AAD5 },
	{ 0xF0A197BB, 0x6AAD6 },
	{ 0xF0A197BC, 0x4A8E3 },
	{ 0xF0A197BD, 0x6AADC },
	{ 0xF0A197BE, 0x6AAD8 },
	{ 0xF0A197BF, 0x6AAD9 },
	{ 0xF0A19880, 0xFA6B6 },
	{ 0xF0A19881, 0xFA6B7 },
	{ 0xF0A19882, 0x6AADA },
	{ 0xF0A19884, 0x6AADB },
	{ 0xF0A19885, 0x6AADD },
	{ 0xF0A19886, 0x4A5F9 },
	{ 0xF0A19889, 0x6AAD7 },
	{ 0xF0A1988B, 0x6A9B9 },
	{ 0xF0A1988C, 0x4A8E4 },
	{ 0xF0A1988D, 0x4A8E2 },
	{ 0xF0A1988E, 0x5A8E1 },
	{ 0xF0A1988F, 0x5A8E2 },
	{ 0xF0A19890, 0x5A8E0 },
	{ 0xF0A19892, 0xFAAA3 },
	{ 0xF0A19894, 0xFAAA4 },
	{ 0xF0A19895, 0xFAAA5 },
	{ 0xF0A19896, 0xFAAA6 },
	{ 0xF0A19897, 0xFAAA8 },
	{ 0xF0A19898, 0xFAAA9 },
	{ 0xF0A19899, 0xFAAA7 },
	{ 0xF0A1989A, 0xFAAA2 },
	{ 0xF0A1989D, 0x5ACEC },
	{ 0xF0A1989F, 0x6B6C8 },
	{ 0xF0A198A0, 0x6B6CB },
	{ 0xF0A198A2, 0x5ACEA },
	{ 0xF0A198A3, 0x5ACED },
	{ 0xF0A198A4, 0xFAEE7 },
	{ 0xF0A198A5, 0xFAEE8 },
	{ 0xF0A198A6, 0xFAEE9 },
	{ 0xF0A198A9, 0x6B6CA },
	{ 0xF0A198AB, 0x4ACB7 },
	{ 0xF0A198B0, 0x5ACEB },
	{ 0xF0A198B2, 0x5B1E4 },
	{ 0xF0A198B3, 0xFAEE6 },
	{ 0xF0A198B4, 0x4ACB6 },
	{ 0xF0A198B5, 0x6BEC1 },
	{ 0xF0A198B6, 0x6BEC4 },
	{ 0xF0A198B7, 0x3B4FE },
	{ 0xF0A198B8, 0x6BEBE },
	{ 0xF0A198B9, 0x6BEC3 },
	{ 0xF0A198BA, 0x6BEC0 },
	{ 0xF0A198BB, 0x6BEC5 },
	{ 0xF0A198BC, 0x6BEBF },
	{ 0xF0A198BD, 0xFB3E4 },
	{ 0xF0A198BF, 0xFB3E5 },
	{ 0xF0A19981, 0x4B1A7 },
	{ 0xF0A19984, 0x5B1E3 },
	{ 0xF0A19987, 0x4BCDE },
	{ 0xF0A19988, 0x6C7D8 },
	{ 0xF0A19989, 0x6C7DB },
	{ 0xF0A1998A, 0x6C7DD },
	{ 0xF0A1998C, 0x6C7DA },
	{ 0xF0A1998D, 0xFBAA8 },
	{ 0xF0A1998E, 0x6C7D5 },
	{ 0xF0A1998F, 0x6C7DC },
	{ 0xF0A19990, 0x5B7C3 },
	{ 0xF0A19995, 0x6C7D9 },
	{ 0xF0A19996, 0x4B6FA },
	{ 0xF0A19997, 0x4B6F8 },
	{ 0xF0A19998, 0x5B7C4 },
	{ 0xF0A1999A, 0x6C7D7 },
	{ 0xF0A1999C, 0x6D1E0 },
	{ 0xF0A1999D, 0x6D1E1 },
	{ 0xF0A199A0, 0x4BCDD },
	{ 0xF0A199A2, 0xFC0F6 },
	{ 0xF0A199A8, 0x5BED3 },
	{ 0xF0A199A9, 0x5BED4 },
	{ 0xF0A199AA, 0x5BED5 },
	{ 0xF0A199AB, 0x6DBF2 },
	{ 0xF0A199AC, 0x4C2E3 },
	{ 0xF0A199AD, 0x5C5AF },
	{ 0xF0A199AE, 0x4C2E2 },
	{ 0xF0A199AF, 0xFC7BF },
	{ 0xF0A199B0, 0xFC7C0 },
	{ 0xF0A199B1, 0xFC7C1 },
	{ 0xF0A199B2, 0x6DBF1 },
	{ 0xF0A199B6, 0x5C5B0 },
	{ 0xF0A199B7, 0x4C9B8 },
	{ 0xF0A199B8, 0x7A2A2 },
	{ 0xF0A199B9, 0x7A1FC },
	{ 0xF0A199BA, 0x7A2A1 },
	{ 0xF0A199BB, 0x7ACFC },
	{ 0xF0A199BC, 0x7A1FE },
	{ 0xF0A199BD, 0x5CCD3 },
	{ 0xF0A199BE, 0xFCEB1 },
	{ 0xF0A199BF, 0xFCEB2 },
	{ 0xF0A19A80, 0x7A1FD },
	{ 0xF0A19A81, 0x4C2E4 },
	{ 0xF0A19A85, 0x5CCD2 },
	{ 0xF0A19A86, 0x7ACFD },
	{ 0xF0A19A87, 0x5D3FC },
	{ 0xF0A19A88, 0x7ACF8 },
	{ 0xF0A19A89, 0x7ACF9 },
	{ 0xF0A19A8A, 0x4D6A1 },
	{ 0xF0A19A8B, 0xFD3FA },
	{ 0xF0A19A8C, 0x7ACFA },
	{ 0xF0A19A8F, 0x7B7C8 },
	{ 0xF0A19A90, 0x7B7C7 },
	{ 0xF0A19A91, 0x5DBB3 },
	{ 0xF0A19A96, 0x4D6AE },
	{ 0xF0A19A97, 0x4DAFB },
	{ 0xF0A19A98, 0xFE2A9 },
	{ 0xF0A19A9B, 0x5EBF8 },
	{ 0xF0A19A9C, 0x7D3A9 },
	{ 0xF0A19A9E, 0xFE9BE },
	{ 0xF0A19AA0, 0x5F5E8 },
	{ 0xF0A19AA3, 0xFEBC4 },
	{ 0xF0A19AA4, 0x7DED8 },
	{ 0xF0A19AA5, 0xFECDF },
	{ 0xF0A19AA8, 0x5A1E2 },
	{ 0xF0A19AAA, 0xFA1D5 },
	{ 0xF0A19AAB, 0xFA1D6 },
	{ 0xF0A19AAF, 0x6A4C1 },
	{ 0xF0A19AB0, 0x4A2D8 },
	{ 0xF0A19AB1, 0x6A4C2 },
	{ 0xF0A19AB2, 0xFA2B9 },
	{ 0xF0A19AB3, 0xFA2BA },
	{ 0xF0A19AB4, 0xFA2BB },
	{ 0xF0A19AB5, 0xFA2BC },
	{ 0xF0A19AB8, 0x4A2D7 },
	{ 0xF0A19AB9, 0x5A2CB },
	{ 0xF0A19ABA, 0x6A4C3 },
	{ 0xF0A19ABB, 0x5A2CA },
	{ 0xF0A19ABC, 0x6A6F4 },
	{ 0xF0A19ABD, 0x4A3E8 },
	{ 0xF0A19ABE, 0x4A3EB },
	{ 0xF0A19ABF, 0xFA3E4 },
	{ 0xF0A19B83, 0xFA3E6 },
	{ 0xF0A19B84, 0xFA3E8 },
	{ 0xF0A19B85, 0xFA3E9 },
	{ 0xF0A19B86, 0xFA3EB },
	{ 0xF0A19B87, 0xFA3EC },
	{ 0xF0A19B88, 0xFA3ED },
	{ 0xF0A19B89, 0xFA3EE },
	{ 0xF0A19B8A, 0xFA3EF },
	{ 0xF0A19B8B, 0xFA3E5 },
	{ 0xF0A19B8D, 0x6A6F2 },
	{ 0xF0A19B8E, 0x6A6F3 },
	{ 0xF0A19B90, 0x6A6F5 },
	{ 0xF0A19B92, 0x6A6F1 },
	{ 0xF0A19B93, 0xFA3EA },
	{ 0xF0A19B95, 0xFA3E7 },
	{ 0xF0A19B96, 0x5A3E6 },
	{ 0xF0A19B97, 0x5A3E7 },
	{ 0xF0A19B98, 0x5A3E5 },
	{ 0xF0A19B99, 0x4A5FC },
	{ 0xF0A19B9A, 0x6AAE1 },
	{ 0xF0A19B9B, 0x6AAE0 },
	{ 0xF0A19B9C, 0x5A5E0 },
	{ 0xF0A19B9D, 0x4A5FA },
	{ 0xF0A19B9E, 0x5A5DE },
	{ 0xF0A19B9F, 0x4A5FD },
	{ 0xF0A19BA0, 0x5A5DB },
	{ 0xF0A19BA1, 0x5A5DC },
	{ 0xF0A19BA2, 0x4A5FE },
	{ 0xF0A19BA5, 0xFA6BA },
	{ 0xF0A19BA9, 0xFA6BB },
	{ 0xF0A19BAA, 0xFA6BE },
	{ 0xF0A19BAB, 0xFA6BF },
	{ 0xF0A19BAC, 0xFA6C0 },
	{ 0xF0A19BAD, 0xFA6C1 },
	{ 0xF0A19BAE, 0xFA6C2 },
	{ 0xF0A19BAF, 0xFA6C3 },
	{ 0xF0A19BB0, 0xFA6C5 },
	{ 0xF0A19BB1, 0xFA6C6 },
	{ 0xF0A19BB2, 0xFA6C7 },
	{ 0xF0A19BB3, 0xFA6C8 },
	{ 0xF0A19BB4, 0xFA6C9 },
	{ 0xF0A19BB7, 0x6AADF },
	{ 0xF0A19BB9, 0x6AADE },
	{ 0xF0A19BBA, 0xFA6C4 },
	{ 0xF0A19BBB, 0xFA6BC },
	{ 0xF0A19BBC, 0xFA6BD },
	{ 0xF0A19BBD, 0x5A5E2 },
	{ 0xF0A19BBE, 0x5A5DF },
	{ 0xF0A19C80, 0x5A5E3 },
	{ 0xF0A19C81, 0x5A5E1 },
	{ 0xF0A19C82, 0x4A8E8 },
	{ 0xF0A19C83, 0x5A8E4 },
	{ 0xF0A19C84, 0x6AFF6 },
	{ 0xF0A19C85, 0x6AFF8 },
	{ 0xF0A19C86, 0x6AFF9 },
	{ 0xF0A19C87, 0x4A8E5 },
	{ 0xF0A19C88, 0x4A8EB },
	{ 0xF0A19C89, 0x5A8E6 },
	{ 0xF0A19C8A, 0x4A8E6 },
	{ 0xF0A19C8B, 0x5A8E3 },
	{ 0xF0A19C8C, 0x6AFF0 },
	{ 0xF0A19C8D, 0x6AFFB },
	{ 0xF0A19C8E, 0x6AFF4 },
	{ 0xF0A19C8F, 0x5A8EB },
	{ 0xF0A19C91, 0x6AFFE },
	{ 0xF0A19C92, 0xFAAAD },
	{ 0xF0A19C93, 0xFAAAE },
	{ 0xF0A19C94, 0xFAAAF },
	{ 0xF0A19C95, 0xFAAB0 },
	{ 0xF0A19C96, 0xFAAB1 },
	{ 0xF0A19C97, 0xFAAB2 },
	{ 0xF0A19C98, 0xFAAB3 },
	{ 0xF0A19C99, 0xFAAB4 },
	{ 0xF0A19C9B, 0x6AFF3 },
	{ 0xF0A19C9C, 0x6AFF7 },
	{ 0xF0A19C9D, 0x4A8EC },
	{ 0xF0A19C9F, 0x6AFF5 },
	{ 0xF0A19CA0, 0x6AFFA },
	{ 0xF0A19CA1, 0x6AFEF },
	{ 0xF0A19CA3, 0x6AFFD },
	{ 0xF0A19CA5, 0x5A8E9 },
	{ 0xF0A19CA6, 0x4A8EA },
	{ 0xF0A19CA7, 0x5A8EA },
	{ 0xF0A19CA8, 0x5A8E7 },
	{ 0xF0A19CA9, 0x6AFF1 },
	{ 0xF0A19CAA, 0x6AFFC },
	{ 0xF0A19CAB, 0x5A8E5 },
	{ 0xF0A19CAC, 0x5A8E8 },
	{ 0xF0A19CAD, 0x6AFF2 },
	{ 0xF0A19CAE, 0x3B0D3 },
	{ 0xF0A19CAF, 0x5ACF0 },
	{ 0xF0A19CB0, 0x6B6CF },
	{ 0xF0A19CB1, 0x5ACF2 },
	{ 0xF0A19CB2, 0x5ACF5 },
	{ 0xF0A19CB3, 0x5ACEF },
	{ 0xF0A19CB4, 0x6B6D5 },
	{ 0xF0A19CB5, 0x5ACEE },
	{ 0xF0A19CB6, 0x6B6D6 },
	{ 0xF0A19CB8, 0x6B6D0 },
	{ 0xF0A19CBD, 0x6B6D1 },
	{ 0xF0A19CBE, 0xFAEEC },
	{ 0xF0A19CBF, 0xFAEEE },
	{ 0xF0A19D80, 0xFAEF0 },
	{ 0xF0A19D81, 0xFAEF1 },
	{ 0xF0A19D82, 0xFAEF3 },
	{ 0xF0A19D83, 0xFAEF4 },
	{ 0xF0A19D84, 0xFAEF5 },
	{ 0xF0A19D85, 0xFAEF6 },
	{ 0xF0A19D86, 0xFAEF7 },
	{ 0xF0A19D87, 0xFAEF9 },
	{ 0xF0A19D8A, 0x6B6D4 },
	{ 0xF0A19D8C, 0x6B6CE },
	{ 0xF0A19D8D, 0x5ACF1 },
	{ 0xF0A19D8F, 0x6B6D3 },
	{ 0xF0A19D91, 0x6B6D2 },
	{ 0xF0A19D97, 0xFAEEF },
	{ 0xF0A19D98, 0xFAEF2 },
	{ 0xF0A19D99, 0x5ACF7 },
	{ 0xF0A19D9A, 0x5ACF4 },
	{ 0xF0A19D9B, 0x5ACF3 },
	{ 0xF0A19D9C, 0x5ACF6 },
	{ 0xF0A19D9D, 0x5ACF8 },
	{ 0xF0A19D9E, 0x6BECC },
	{ 0xF0A19D9F, 0x6BED2 },
	{ 0xF0A19DA0, 0x6BEC6 },
	{ 0xF0A19DA1, 0x6BEC7 },
	{ 0xF0A19DA2, 0x5B1EA },
	{ 0xF0A19DA3, 0x6BEC8 },
	{ 0xF0A19DA4, 0x6BEC9 },
	{ 0xF0A19DA5, 0x6BECF },
	{ 0xF0A19DA6, 0x5B1E9 },
	{ 0xF0A19DA7, 0x5B1ED },
	{ 0xF0A19DA8, 0x6BECD },
	{ 0xF0A19DA9, 0x4B1AB },
	{ 0xF0A19DAA, 0x6BECE },
	{ 0xF0A19DAB, 0x5B1EB },
	{ 0xF0A19DB2, 0x6BED3 },
	{ 0xF0A19DB5, 0xFB3E8 },
	{ 0xF0A19DB6, 0xFB3E9 },
	{ 0xF0A19DB7, 0xFB3EA },
	{ 0xF0A19DB8, 0xFB3EB },
	{ 0xF0A19DB9, 0xFB3EC },
	{ 0xF0A19DBA, 0xFB3ED },
	{ 0xF0A19DBB, 0xFB3EE },
	{ 0xF0A19DBC, 0xFB3EF },
	{ 0xF0A19DBD, 0xFB3F1 },
	{ 0xF0A19DBE, 0xFB3F2 },
	{ 0xF0A19DBF, 0xFB3F4 },
	{ 0xF0A19E80, 0xFB3F5 },
	{ 0xF0A19E81, 0xFB3F6 },
	{ 0xF0A19E82, 0xFB3F7 },
	{ 0xF0A19E83, 0xFB3F8 },
	{ 0xF0A19E84, 0xFB3F9 },
	{ 0xF0A19E85, 0xFB3FA },
	{ 0xF0A19E86, 0xFB3FB },
	{ 0xF0A19E87, 0xFB3FC },
	{ 0xF0A19E88, 0xFB3FD },
	{ 0xF0A19E89, 0xFB3FE },
	{ 0xF0A19E8A, 0xFB4A1 },
	{ 0xF0A19E8B, 0xFB4A2 },
	{ 0xF0A19E8C, 0xFB4A3 },
	{ 0xF0A19E8E, 0xFB3F0 },
	{ 0xF0A19E90, 0x6BED1 },
	{ 0xF0A19E91, 0x4B1AA },
	{ 0xF0A19E93, 0x6BECB },
	{ 0xF0A19E94, 0x6BECA },
	{ 0xF0A19E98, 0x5B1E6 },
	{ 0xF0A19E99, 0x5B1E7 },
	{ 0xF0A19E9A, 0x5B1E8 },
	{ 0xF0A19E9B, 0x5B1E5 },
	{ 0xF0A19E9C, 0x4B6FB },
	{ 0xF0A19E9D, 0x6C7E2 },
	{ 0xF0A19E9E, 0x4B6FC },
	{ 0xF0A19E9F, 0x5B7DA },
	{ 0xF0A19EA0, 0x6C7DF },
	{ 0xF0A19EA1, 0x4B7A1 },
	{ 0xF0A19EA2, 0x5B7C8 },
	{ 0xF0A19EA3, 0x5B7D9 },
	{ 0xF0A19EA4, 0x6C7E4 },
	{ 0xF0A19EA6, 0x6C7E6 },
	{ 0xF0A19EA7, 0x5B7CF },
	{ 0xF0A19EA8, 0x6C7E5 },
	{ 0xF0A19EA9, 0x6C7E0 },
	{ 0xF0A19EAA, 0x5B7D0 },
	{ 0xF0A19EAB, 0x5B7C9 },
	{ 0xF0A19EAC, 0x5B7D7 },
	{ 0xF0A19EAD, 0x5B7D4 },
	{ 0xF0A19EAE, 0x5B7C7 },
	{ 0xF0A19EAF, 0x5B7CB },
	{ 0xF0A19EB0, 0xFBAA9 },
	{ 0xF0A19EB6, 0xFBAAB },
	{ 0xF0A19EB7, 0xFBAAC },
	{ 0xF0A19EB8, 0xFBAAD },
	{ 0xF0A19EB9, 0xFBAAE },
	{ 0xF0A19EBA, 0xFBAAF },
	{ 0xF0A19EBB, 0xFBAB0 },
	{ 0xF0A19EBC, 0xFBAB2 },
	{ 0xF0A19EBD, 0xFBAB3 },
	{ 0xF0A19EBE, 0xFBAB4 },
	{ 0xF0A19EBF, 0xFBAB6 },
	{ 0xF0A19F80, 0xFBAB7 },
	{ 0xF0A19F81, 0xFBAB8 },
	{ 0xF0A19F82, 0xFBAB9 },
	{ 0xF0A19F83, 0xFBABA },
	{ 0xF0A19F84, 0xFBABE },
	{ 0xF0A19F85, 0xFBABF },
	{ 0xF0A19F86, 0xFBAC1 },
	{ 0xF0A19F87, 0xFBAC2 },
	{ 0xF0A19F88, 0xFBAC3 },
	{ 0xF0A19F89, 0xFBAC4 },
	{ 0xF0A19F8A, 0xFBAC5 },
	{ 0xF0A19F8E, 0xFBABB },
	{ 0xF0A19F91, 0x5B7D6 },
	{ 0xF0A19F94, 0x6C7E3 },
	{ 0xF0A19F95, 0x5B7D8 },
	{ 0xF0A19F96, 0x6C7DE },
	{ 0xF0A19F99, 0xFBABD },
	{ 0xF0A19F9A, 0xFBAC0 },
	{ 0xF0A19F9B, 0xFBAB1 },
	{ 0xF0A19F9C, 0xFBAAA },
	{ 0xF0A19F9D, 0x5B7C5 },
	{ 0xF0A19F9E, 0x5BED6 },
	{ 0xF0A19F9F, 0x5B7D3 },
	{ 0xF0A19FA0, 0x5B7CC },
	{ 0xF0A19FA1, 0x5B7D2 },
	{ 0xF0A19FA2, 0x5B7D1 },
	{ 0xF0A19FA3, 0x5B7CA },
	{ 0xF0A19FA4, 0x5B7CD },
	{ 0xF0A19FA5, 0x5B7D5 },
	{ 0xF0A19FA6, 0x6C7E7 },
	{ 0xF0A19FA7, 0xFB3E7 },
	{ 0xF0A19FA8, 0x5BEDF },
	{ 0xF0A19FA9, 0x5BEDA },
	{ 0xF0A19FAA, 0x5BEDD },
	{ 0xF0A19FAB, 0x5BED7 },
	{ 0xF0A19FAC, 0x4BCE5 },
	{ 0xF0A19FAD, 0x5BED9 },
	{ 0xF0A19FAE, 0x6D1E3 },
	{ 0xF0A19FAF, 0x4BCE2 },
	{ 0xF0A19FB0, 0x4BCE0 },
	{ 0xF0A19FB1, 0x6D1E7 },
	{ 0xF0A19FB2, 0x6D1E5 },
	{ 0xF0A19FB3, 0x6DBFC },
	{ 0xF0A19FB4, 0x5BEDC },
	{ 0xF0A19FB7, 0x5BEDB },
	{ 0xF0A19FBD, 0x6D1E6 },
	{ 0xF0A19FBE, 0xFC0F8 },
	{ 0xF0A19FBF, 0xFC0F9 },
	{ 0xF0A1A080, 0xFC0FA },
	{ 0xF0A1A081, 0xFC0FC },
	{ 0xF0A1A082, 0xFC0FD },
	{ 0xF0A1A083, 0xFC0FE },
	{ 0xF0A1A084, 0xFC1A2 },
	{ 0xF0A1A085, 0xFC1A3 },
	{ 0xF0A1A088, 0x6D1E2 },
	{ 0xF0A1A08B, 0x6D1E4 },
	{ 0xF0A1A08E, 0xFC0F7 },
	{ 0xF0A1A090, 0x6D1E8 },
	{ 0xF0A1A091, 0x5BED8 },
	{ 0xF0A1A092, 0x5BEDE },
	{ 0xF0A1A093, 0x5BEE0 },
	{ 0xF0A1A094, 0x6D1EA },
	{ 0xF0A1A095, 0xFC1A1 },
	{ 0xF0A1A097, 0x4C2F0 },
	{ 0xF0A1A099, 0x5C5B2 },
	{ 0xF0A1A09A, 0x4C2EA },
	{ 0xF0A1A09B, 0x6DBFB },
	{ 0xF0A1A09C, 0x4C2F1 },
	{ 0xF0A1A09D, 0x6DBF3 },
	{ 0xF0A1A09E, 0x5C5B4 },
	{ 0xF0A1A09F, 0x7A2A9 },
	{ 0xF0A1A0A0, 0x4C2F3 },
	{ 0xF0A1A0A2, 0x6DBF5 },
	{ 0xF0A1A0A4, 0xFC7C8 },
	{ 0xF0A1A0A5, 0x4C2EF },
	{ 0xF0A1A0A6, 0x5C5B7 },
	{ 0xF0A1A0A7, 0x4C2EE },
	{ 0xF0A1A0AB, 0xFC7C7 },
	{ 0xF0A1A0AC, 0xFC7C9 },
	{ 0xF0A1A0AD, 0xFC7CA },
	{ 0xF0A1A0AE, 0xFC7CB },
	{ 0xF0A1A0AF, 0xFC7CC },
	{ 0xF0A1A0B0, 0xFC7CD },
	{ 0xF0A1A0B1, 0xFC7CE },
	{ 0xF0A1A0B2, 0xFC7CF },
	{ 0xF0A1A0B3, 0xFC7D0 },
	{ 0xF0A1A0B4, 0xFC7D1 },
	{ 0xF0A1A0B5, 0xFC7D2 },
	{ 0xF0A1A0B6, 0xFC7D4 },
	{ 0xF0A1A0B7, 0x6DBF4 },
	{ 0xF0A1A0B8, 0x6DBF8 },
	{ 0xF0A1A0BD, 0x4C2F2 },
	{ 0xF0A1A182, 0x4C2E5 },
	{ 0xF0A1A183, 0x6DBF6 },
	{ 0xF0A1A185, 0xFC7D3 },
	{ 0xF0A1A188, 0x5C5B3 },
	{ 0xF0A1A189, 0x5C5B6 },
	{ 0xF0A1A18A, 0x5C5B5 },
	{ 0xF0A1A18B, 0x7A2A6 },
	{ 0xF0A1A18C, 0x5C5B1 },
	{ 0xF0A1A18D, 0x6DBF7 },
	{ 0xF0A1A18F, 0x5CCDB },
	{ 0xF0A1A190, 0x5CCD9 },
	{ 0xF0A1A191, 0x4C9B9 },
	{ 0xF0A1A192, 0x5CCD6 },
	{ 0xF0A1A193, 0x7A2AF },
	{ 0xF0A1A194, 0x5CCD7 },
	{ 0xF0A1A195, 0x4C9BF },
	{ 0xF0A1A196, 0x4C9BB },
	{ 0xF0A1A197, 0x7A2AC },
	{ 0xF0A1A199, 0x4C9BE },
	{ 0xF0A1A19A, 0x7A2A5 },
	{ 0xF0A1A19B, 0x6DBF9 },
	{ 0xF0A1A19C, 0x7A2A4 },
	{ 0xF0A1A19D, 0xFCEBA },
	{ 0xF0A1A19F, 0x7B7D1 },
	{ 0xF0A1A1A0, 0xFC7C5 },
	{ 0xF0A1A1A5, 0x5CCD4 },
	{ 0xF0A1A1A8, 0x5CCDC },
	{ 0xF0A1A1A9, 0xFCEB3 },
	{ 0xF0A1A1AA, 0xFCEB4 },
	{ 0xF0A1A1AB, 0xFCEB5 },
	{ 0xF0A1A1AC, 0xFCEB6 },
	{ 0xF0A1A1AD, 0xFCEB7 },
	{ 0xF0A1A1AE, 0xFCEB8 },
	{ 0xF0A1A1AF, 0xFCEB9 },
	{ 0xF0A1A1B0, 0xFCEBB },
	{ 0xF0A1A1B1, 0xFCEBD },
	{ 0xF0A1A1B2, 0xFCEBE },
	{ 0xF0A1A1B3, 0xFCEBF },
	{ 0xF0A1A1B4, 0xFCEC0 },
	{ 0xF0A1A1B5, 0xFCEC1 },
	{ 0xF0A1A1B6, 0xFCEC2 },
	{ 0xF0A1A1B7, 0xFCEC4 },
	{ 0xF0A1A1B9, 0x6DBFA },
	{ 0xF0A1A1BC, 0x7A2A7 },
	{ 0xF0A1A1BD, 0x7A2AE },
	{ 0xF0A1A1BE, 0x7A2AD },
	{ 0xF0A1A1BF, 0x7A2A8 },
	{ 0xF0A1A282, 0x7A2A3 },
	{ 0xF0A1A283, 0xFCEC5 },
	{ 0xF0A1A284, 0xFCEC3 },
	{ 0xF0A1A285, 0xFCEBC },
	{ 0xF0A1A286, 0x5CCDA },
	{ 0xF0A1A287, 0x5CCD5 },
	{ 0xF0A1A288, 0x4C9BD },
	{ 0xF0A1A289, 0x7A2AA },
	{ 0xF0A1A28A, 0x5CCD8 },
	{ 0xF0A1A28B, 0x7A2AB },
	{ 0xF0A1A28D, 0xFD4A5 },
	{ 0xF0A1A291, 0x5D4A8 },
	{ 0xF0A1A292, 0x5D4A3 },
	{ 0xF0A1A293, 0x7ADA5 },
	{ 0xF0A1A294, 0x7ACFE },
	{ 0xF0A1A295, 0x5D4A9 },
	{ 0xF0A1A296, 0x5D4A6 },
	{ 0xF0A1A297, 0x7ADA1 },
	{ 0xF0A1A298, 0x4CFFE },
	{ 0xF0A1A299, 0x7ADA8 },
	{ 0xF0A1A29A, 0x5D4A2 },
	{ 0xF0A1A29B, 0x7ADAB },
	{ 0xF0A1A29C, 0x5D3FD },
	{ 0xF0A1A29D, 0x7ADAA },
	{ 0xF0A1A2A3, 0x7ADAC },
	{ 0xF0A1A2A4, 0xFD3FB },
	{ 0xF0A1A2A5, 0xFD3FC },
	{ 0xF0A1A2A6, 0xFD3FD },
	{ 0xF0A1A2A7, 0xFD3FE },
	{ 0xF0A1A2A8, 0xFD4A2 },
	{ 0xF0A1A2A9, 0xFD4A3 },
	{ 0xF0A1A2AA, 0xFD4A4 },
	{ 0xF0A1A2AB, 0xFD4A6 },
	{ 0xF0A1A2AC, 0xFD4A7 },
	{ 0xF0A1A2AD, 0xFD4AB },
	{ 0xF0A1A2AE, 0xFD4AC },
	{ 0xF0A1A2B1, 0x5D3FE },
	{ 0xF0A1A2B2, 0x7ADA6 },
	{ 0xF0A1A2B4, 0x7ADA7 },
	{ 0xF0A1A2B5, 0x7ADA3 },
	{ 0xF0A1A2B7, 0x7ADA2 },
	{ 0xF0A1A2B8, 0x7ADA4 },
	{ 0xF0A1A2BE, 0xFD4A1 },
	{ 0xF0A1A2BF, 0xFD4A8 },
	{ 0xF0A1A380, 0x5D4A7 },
	{ 0xF0A1A381, 0x5D4A1 },
	{ 0xF0A1A382, 0x5D4A5 },
	{ 0xF0A1A383, 0x7ADA9 },
	{ 0xF0A1A385, 0x7B7CB },
	{ 0xF0A1A386, 0x7B7D4 },
	{ 0xF0A1A387, 0x7B7CF },
	{ 0xF0A1A388, 0x4CFFD },
	{ 0xF0A1A389, 0x7B7CD },
	{ 0xF0A1A38B, 0x4D6A3 },
	{ 0xF0A1A38C, 0x7B7D3 },
	{ 0xF0A1A38D, 0x7B7CA },
	{ 0xF0A1A38E, 0x5DBB6 },
	{ 0xF0A1A38F, 0x5DBB4 },
	{ 0xF0A1A390, 0x7B7CC },
	{ 0xF0A1A391, 0x7B7CE },
	{ 0xF0A1A392, 0x7B7D0 },
	{ 0xF0A1A394, 0x5DBB5 },
	{ 0xF0A1A395, 0x4D6A5 },
	{ 0xF0A1A39A, 0xFD9EC },
	{ 0xF0A1A39B, 0xFD9ED },
	{ 0xF0A1A39C, 0xFD9EE },
	{ 0xF0A1A39D, 0xFD9EF },
	{ 0xF0A1A39E, 0xFD9F0 },
	{ 0xF0A1A39F, 0xFD9F1 },
	{ 0xF0A1A3A1, 0x7B7D2 },
	{ 0xF0A1A3A4, 0x7B7D5 },
	{ 0xF0A1A3A9, 0x7B7C9 },
	{ 0xF0A1A3AA, 0x5E1CB },
	{ 0xF0A1A3AB, 0x4DAFC },
	{ 0xF0A1A3AD, 0x7BFBF },
	{ 0xF0A1A3AE, 0x5E1CC },
	{ 0xF0A1A3AF, 0x5E1CD },
	{ 0xF0A1A3B0, 0x7BFBE },
	{ 0xF0A1A3B1, 0x7BFC0 },
	{ 0xF0A1A3B2, 0xFDED0 },
	{ 0xF0A1A3B3, 0xFDED1 },
	{ 0xF0A1A3B4, 0xFDED2 },
	{ 0xF0A1A3B5, 0xFDED4 },
	{ 0xF0A1A3B7, 0x7BFBD },
	{ 0xF0A1A3B8, 0x7BFC1 },
	{ 0xF0A1A3BA, 0xFDED3 },
	{ 0xF0A1A3BC, 0x7BFBC },
	{ 0xF0A1A3BD, 0x5E7DF },
	{ 0xF0A1A3BE, 0x4DFD3 },
	{ 0xF0A1A3BF, 0x7C6CD },
	{ 0xF0A1A480, 0x7C6D2 },
	{ 0xF0A1A481, 0x7C6D0 },
	{ 0xF0A1A482, 0xFDED5 },
	{ 0xF0A1A486, 0xFE2AA },
	{ 0xF0A1A487, 0xFE2AB },
	{ 0xF0A1A488, 0x7C6CE },
	{ 0xF0A1A48B, 0x5E7E1 },
	{ 0xF0A1A48C, 0x5E7E0 },
	{ 0xF0A1A48D, 0xFDFF3 },
	{ 0xF0A1A48F, 0x7CDD1 },
	{ 0xF0A1A492, 0x5EBF9 },
	{ 0xF0A1A495, 0xFE5A6 },
	{ 0xF0A1A496, 0x5EBFA },
	{ 0xF0A1A497, 0x5EBFB },
	{ 0xF0A1A498, 0x7D3AA },
	{ 0xF0A1A499, 0x5EFF6 },
	{ 0xF0A1A49A, 0x7D3AB },
	{ 0xF0A1A49B, 0x5EFF5 },
	{ 0xF0A1A49C, 0xFE7CD },
	{ 0xF0A1A49D, 0xFE7CE },
	{ 0xF0A1A4A1, 0x7D7E2 },
	{ 0xF0A1A4A2, 0x5F3B6 },
	{ 0xF0A1A4A3, 0x7D7E1 },
	{ 0xF0A1A4A4, 0x7D7E3 },
	{ 0xF0A1A4A5, 0x7D7DF },
	{ 0xF0A1A4A6, 0xFE9BF },
	{ 0xF0A1A4A8, 0x7D7E0 },
	{ 0xF0A1A4A9, 0x7D7E4 },
	{ 0xF0A1A4AA, 0xFE9C0 },
	{ 0xF0A1A4AB, 0x5F5E9 },
	{ 0xF0A1A4AC, 0x7DBCC },
	{ 0xF0A1A4AE, 0x7DEDA },
	{ 0xF0A1A4AF, 0x7DEDB },
	{ 0xF0A1A4B0, 0xFEBC5 },
	{ 0xF0A1A4B1, 0x7DED9 },
	{ 0xF0A1A4B2, 0x7DEDC },
	{ 0xF0A1A4B4, 0xFECA4 },
	{ 0xF0A1A4B6, 0x5F9A4 },
	{ 0xF0A1A4B7, 0xFECCA },
	{ 0xF0A1A4B9, 0x7E3CD },
	{ 0xF0A1A4BA, 0x5FAE5 },
	{ 0xF0A1A4BC, 0x4A1B3 },
	{ 0xF0A1A4BE, 0x6A2E8 },
	{ 0xF0A1A4BF, 0x5A1E3 },
	{ 0xF0A1A580, 0x6A2E9 },
	{ 0xF0A1A581, 0xFA1D8 },
	{ 0xF0A1A582, 0xFA1D7 },
	{ 0xF0A1A583, 0x6A4C5 },
	{ 0xF0A1A585, 0x6A4C4 },
	{ 0xF0A1A586, 0x6A6F6 },
	{ 0xF0A1A587, 0x6A6F7 },
	{ 0xF0A1A588, 0x5A3EA },
	{ 0xF0A1A589, 0x4A3EC },
	{ 0xF0A1A58A, 0xFA3F0 },
	{ 0xF0A1A58D, 0x5A3E9 },
	{ 0xF0A1A58E, 0x4A8EF },
	{ 0xF0A1A58F, 0x6B0A4 },
	{ 0xF0A1A590, 0x6AAE3 },
	{ 0xF0A1A591, 0x6AAE2 },
	{ 0xF0A1A592, 0xFA6CA },
	{ 0xF0A1A593, 0xFA6CB },
	{ 0xF0A1A594, 0xFA6CC },
	{ 0xF0A1A595, 0xFA6CD },
	{ 0xF0A1A596, 0xFA6CF },
	{ 0xF0A1A597, 0x6AAE4 },
	{ 0xF0A1A598, 0xFA6CE },
	{ 0xF0A1A59B, 0x6B0A3 },
	{ 0xF0A1A59C, 0x6B0A1 },
	{ 0xF0A1A59D, 0x6B0A6 },
	{ 0xF0A1A59E, 0x6B0A5 },
	{ 0xF0A1A5A1, 0xFAAB5 },
	{ 0xF0A1A5A2, 0xFAAB6 },
	{ 0xF0A1A5A3, 0xFAAB7 },
	{ 0xF0A1A5A6, 0x6B0A2 },
	{ 0xF0A1A5A8, 0x6B6D9 },
	{ 0xF0A1A5A9, 0x5ACF9 },
	{ 0xF0A1A5AA, 0x6B6D8 },
	{ 0xF0A1A5AB, 0xFAEFA },
	{ 0xF0A1A5AC, 0xFAEFB },
	{ 0xF0A1A5AD, 0x5ACFA },
	{ 0xF0A1A5AE, 0xFB3E6 },
	{ 0xF0A1A5AF, 0xFB4A4 },
	{ 0xF0A1A5B0, 0xFB4A5 },
	{ 0xF0A1A5B1, 0xFB4A6 },
	{ 0xF0A1A5B2, 0xFB4A7 },
	{ 0xF0A1A5B6, 0x5B7DC },
	{ 0xF0A1A5B7, 0x6C7E9 },
	{ 0xF0A1A5B9, 0x5B7DB },
	{ 0xF0A1A5BA, 0x6C7EA },
	{ 0xF0A1A5BB, 0xFBAC7 },
	{ 0xF0A1A5BD, 0x6C7E8 },
	{ 0xF0A1A5BE, 0xFBAC6 },
	{ 0xF0A1A683, 0x4BCE6 },
	{ 0xF0A1A684, 0x4BCE8 },
	{ 0xF0A1A685, 0x6D1ED },
	{ 0xF0A1A686, 0x5BEE2 },
	{ 0xF0A1A687, 0xFC1A5 },
	{ 0xF0A1A689, 0xFC1A6 },
	{ 0xF0A1A68B, 0x6D1EB },
	{ 0xF0A1A68C, 0x6D1EC },
	{ 0xF0A1A68E, 0x5BEE1 },
	{ 0xF0A1A68F, 0x4BCE9 },
	{ 0xF0A1A691, 0x6DBFD },
	{ 0xF0A1A692, 0xFC7D5 },
	{ 0xF0A1A693, 0xFC7D6 },
	{ 0xF0A1A695, 0x5C5B8 },
	{ 0xF0A1A697, 0x4C9C1 },
	{ 0xF0A1A698, 0x4C9C2 },
	{ 0xF0A1A69A, 0xFCEC6 },
	{ 0xF0A1A69D, 0x5CCDD },
	{ 0xF0A1A69E, 0x7ADAF },
	{ 0xF0A1A69F, 0x7ADAE },
	{ 0xF0A1A6A0, 0x7ADB1 },
	{ 0xF0A1A6A1, 0x7ADB2 },
	{ 0xF0A1A6A2, 0x5D4AA },
	{ 0xF0A1A6A3, 0x7ADB0 },
	{ 0xF0A1A6A4, 0xFD4AD },
	{ 0xF0A1A6A5, 0xFD4AE },
	{ 0xF0A1A6A9, 0x7B7D6 },
	{ 0xF0A1A6AD, 0x7CDD2 },
	{ 0xF0A1A6AF, 0xFE2AC },
	{ 0xF0A1A6B0, 0xFE2AD },
	{ 0xF0A1A6B5, 0x5EBFC },
	{ 0xF0A1A6B8, 0xFECE0 },
	{ 0xF0A1A6B9, 0x6A1E9 },
	{ 0xF0A1A6BC, 0x5A1E4 },
	{ 0xF0A1A6BD, 0x6A4C6 },
	{ 0xF0A1A6BE, 0x6A4C9 },
	{ 0xF0A1A6BF, 0x6A4CA },
	{ 0xF0A1A782, 0x4A2DA },
	{ 0xF0A1A783, 0xFA2BD },
	{ 0xF0A1A784, 0xFA2BE },
	{ 0xF0A1A785, 0xFA2BF },
	{ 0xF0A1A786, 0xFA2C0 },
	{ 0xF0A1A787, 0xFA2C1 },
	{ 0xF0A1A788, 0x6A4C7 },
	{ 0xF0A1A78B, 0x6A6FE },
	{ 0xF0A1A78C, 0x6A6FD },
	{ 0xF0A1A78D, 0x4A3EE },
	{ 0xF0A1A78E, 0x6A6FB },
	{ 0xF0A1A78F, 0x6A6FC },
	{ 0xF0A1A791, 0xFA3F2 },
	{ 0xF0A1A796, 0x5A5E5 },
	{ 0xF0A1A797, 0x5A5E4 },
	{ 0xF0A1A798, 0x6AAE6 },
	{ 0xF0A1A799, 0x5A5E6 },
	{ 0xF0A1A79A, 0x6AAE7 },
	{ 0xF0A1A79C, 0x6AAE8 },
	{ 0xF0A1A79D, 0xFA6D1 },
	{ 0xF0A1A79E, 0xFA6D2 },
	{ 0xF0A1A79F, 0xFA6D4 },
	{ 0xF0A1A7A0, 0xFA6D5 },
	{ 0xF0A1A7A2, 0x6AAE5 },
	{ 0xF0A1A7A3, 0xFA6D3 },
	{ 0xF0A1A7A9, 0x5A8EC },
	{ 0xF0A1A7AA, 0x6B0A8 },
	{ 0xF0A1A7AB, 0x6B0AA },
	{ 0xF0A1A7AC, 0x5A8ED },
	{ 0xF0A1A7AD, 0x4A8F1 },
	{ 0xF0A1A7AE, 0x4A8F2 },
	{ 0xF0A1A7AF, 0x4A8F3 },
	{ 0xF0A1A7B0, 0x6B0AB },
	{ 0xF0A1A7B1, 0x6B0A7 },
	{ 0xF0A1A7B4, 0x6B0A9 },
	{ 0xF0A1A7B5, 0xFAAB8 },
	{ 0xF0A1A7B6, 0xFAABA },
	{ 0xF0A1A7B7, 0xFAABB },
	{ 0xF0A1A7B8, 0xFAABC },
	{ 0xF0A1A7BA, 0x6B0AC },
	{ 0xF0A1A7BB, 0x6B0AD },
	{ 0xF0A1A880, 0x4ACCA },
	{ 0xF0A1A881, 0x6B6E1 },
	{ 0xF0A1A882, 0x4ACC5 },
	{ 0xF0A1A883, 0x4ACC4 },
	{ 0xF0A1A884, 0x4ACC3 },
	{ 0xF0A1A885, 0x4ACC7 },
	{ 0xF0A1A886, 0x6B6E4 },
	{ 0xF0A1A887, 0x6B6E5 },
	{ 0xF0A1A888, 0x6B6DF },
	{ 0xF0A1A889, 0x6B6DE },
	{ 0xF0A1A88A, 0x5ACFD },
	{ 0xF0A1A88D, 0x5ADA2 },
	{ 0xF0A1A88E, 0x6B6DB },
	{ 0xF0A1A88F, 0x6B6E2 },
	{ 0xF0A1A890, 0xFAEFC },
	{ 0xF0A1A891, 0xFAEFD },
	{ 0xF0A1A893, 0x6B6E0 },
	{ 0xF0A1A894, 0x6B6E3 },
	{ 0xF0A1A89C, 0x6B6DA },
	{ 0xF0A1A89E, 0x6B6DC },
	{ 0xF0A1A89F, 0x5ADA1 },
	{ 0xF0A1A8A0, 0x5ACFE },
	{ 0xF0A1A8A2, 0x4B1AD },
	{ 0xF0A1A8A3, 0x5B1EF },
	{ 0xF0A1A8A4, 0x6BED7 },
	{ 0xF0A1A8A5, 0x6BED9 },
	{ 0xF0A1A8A6, 0x6BED8 },
	{ 0xF0A1A8A7, 0x6BED6 },
	{ 0xF0A1A8A8, 0x6BEDB },
	{ 0xF0A1A8A9, 0x5B1F0 },
	{ 0xF0A1A8AA, 0xFB4A8 },
	{ 0xF0A1A8AB, 0xFB4A9 },
	{ 0xF0A1A8AC, 0xFB4AA },
	{ 0xF0A1A8AD, 0xFB4AB },
	{ 0xF0A1A8AE, 0xFB4AC },
	{ 0xF0A1A8AF, 0xFB4AD },
	{ 0xF0A1A8B0, 0xFB4AE },
	{ 0xF0A1A8B1, 0xFB4AF },
	{ 0xF0A1A8B4, 0x4B1AF },
	{ 0xF0A1A8B6, 0x6BEDC },
	{ 0xF0A1A8BB, 0x5B1EE },
	{ 0xF0A1A8BC, 0x6BED5 },
	{ 0xF0A1A8BD, 0x5B7DE },
	{ 0xF0A1A8BE, 0x4B7A6 },
	{ 0xF0A1A8BF, 0x5B7E1 },
	{ 0xF0A1A980, 0x6C7F0 },
	{ 0xF0A1A981, 0x6C7EB },
	{ 0xF0A1A982, 0x4B7A3 },
	{ 0xF0A1A983, 0x5B7DD },
	{ 0xF0A1A984, 0x5B7E0 },
	{ 0xF0A1A985, 0x6C7EE },
	{ 0xF0A1A986, 0x4B7A5 },
	{ 0xF0A1A987, 0x5B7DF },
	{ 0xF0A1A988, 0x6C7EF },
	{ 0xF0A1A989, 0x6C7EC },
	{ 0xF0A1A98E, 0xFBAC8 },
	{ 0xF0A1A98F, 0xFBAC9 },
	{ 0xF0A1A990, 0xFBACA },
	{ 0xF0A1A991, 0xFBACB },
	{ 0xF0A1A992, 0xFBACC },
	{ 0xF0A1A993, 0xFBACD },
	{ 0xF0A1A994, 0xFBACE },
	{ 0xF0A1A995, 0xFBACF },
	{ 0xF0A1A999, 0x6C7ED },
	{ 0xF0A1A99B, 0x5B7E2 },
	{ 0xF0A1A99E, 0xFBDEC },
	{ 0xF0A1A99F, 0x6D1F4 },
	{ 0xF0A1A9A0, 0x6D1F0 },
	{ 0xF0A1A9A1, 0x4BCEB },
	{ 0xF0A1A9A2, 0x4BCF0 },
	{ 0xF0A1A9A3, 0x5BEE3 },
	{ 0xF0A1A9A4, 0x6D1F7 },
	{ 0xF0A1A9A5, 0x5BEE4 },
	{ 0xF0A1A9A6, 0x6D1F2 },
	{ 0xF0A1A9A7, 0x6D1F1 },
	{ 0xF0A1A9A8, 0x6D1F6 },
	{ 0xF0A1A9A9, 0x4BCED },
	{ 0xF0A1A9AA, 0x6D1F3 },
	{ 0xF0A1A9AC, 0x6D1EF },
	{ 0xF0A1A9AD, 0x6D1F5 },
	{ 0xF0A1A9AE, 0xFC1A7 },
	{ 0xF0A1A9AF, 0xFC1A8 },
	{ 0xF0A1A9B0, 0xFC1A9 },
	{ 0xF0A1A9B1, 0xFC1AA },
	{ 0xF0A1A9B2, 0xFC1AC },
	{ 0xF0A1A9B3, 0xFC1AD },
	{ 0xF0A1A9B4, 0xFC1AE },
	{ 0xF0A1A9BA, 0x6D1EE },
	{ 0xF0A1A9BB, 0x6DBFE },
	{ 0xF0A1A9BC, 0x6DCA7 },
	{ 0xF0A1A9BD, 0x5C5BC },
	{ 0xF0A1A9BE, 0x5C5BA },
	{ 0xF0A1A9BF, 0x6DCA4 },
	{ 0xF0A1AA80, 0x6DCAC },
	{ 0xF0A1AA81, 0x4C2F6 },
	{ 0xF0A1AA82, 0x6DCAE },
	{ 0xF0A1AA83, 0x6DCAB },
	{ 0xF0A1AA84, 0x6DCA6 },
	{ 0xF0A1AA85, 0x5C5B9 },
	{ 0xF0A1AA86, 0x7A2B3 },
	{ 0xF0A1AA88, 0xFC7D7 },
	{ 0xF0A1AA89, 0xFC7D8 },
	{ 0xF0A1AA8A, 0xFC7D9 },
	{ 0xF0A1AA8B, 0xFC7DA },
	{ 0xF0A1AA8E, 0x6DCA8 },
	{ 0xF0A1AA8F, 0x6DCA5 },
	{ 0xF0A1AA90, 0x6DCA9 },
	{ 0xF0A1AA93, 0x6DCAD },
	{ 0xF0A1AA94, 0x6DCA1 },
	{ 0xF0A1AA96, 0x6DCA3 },
	{ 0xF0A1AA97, 0x5C5BB },
	{ 0xF0A1AA98, 0x6DCAA },
	{ 0xF0A1AA9A, 0xFC7C4 },
	{ 0xF0A1AA9B, 0x6E2E7 },
	{ 0xF0A1AA9F, 0x7A2B0 },
	{ 0xF0A1AAA0, 0x5CCDE },
	{ 0xF0A1AAA1, 0x4C9C7 },
	{ 0xF0A1AAA2, 0x7A2B7 },
	{ 0xF0A1AAA3, 0x4C9C8 },
	{ 0xF0A1AAA4, 0x7A2B5 },
	{ 0xF0A1AAA5, 0x7A2B2 },
	{ 0xF0A1AAA7, 0xFCEC7 },
	{ 0xF0A1AAA8, 0xFCEC8 },
	{ 0xF0A1AAA9, 0xFCEC9 },
	{ 0xF0A1AAAA, 0xFCECA },
	{ 0xF0A1AAAB, 0xFCECB },
	{ 0xF0A1AAAC, 0xFCECC },
	{ 0xF0A1AAAD, 0xFCECE },
	{ 0xF0A1AAAE, 0xFCECF },
	{ 0xF0A1AAB4, 0x7A2B8 },
	{ 0xF0A1AAB6, 0x7A2B6 },
	{ 0xF0A1AAB7, 0xFCECD },
	{ 0xF0A1AAB8, 0x5CCE1 },
	{ 0xF0A1AABA, 0x5CCDF },
	{ 0xF0A1AABC, 0x7A2B1 },
	{ 0xF0A1AABD, 0x5CCE0 },
	{ 0xF0A1AABE, 0x7ADB5 },
	{ 0xF0A1AABF, 0x7ADB7 },
	{ 0xF0A1AB80, 0x5D4AC },
	{ 0xF0A1AB81, 0x4D0A2 },
	{ 0xF0A1AB82, 0x5D4AD },
	{ 0xF0A1AB83, 0x5D4AB },
	{ 0xF0A1AB84, 0x7ADB6 },
	{ 0xF0A1AB85, 0x7ADB3 },
	{ 0xF0A1AB86, 0x7ADB4 },
	{ 0xF0A1AB87, 0xFD4AF },
	{ 0xF0A1AB88, 0xFD4B0 },
	{ 0xF0A1AB89, 0xFD4B1 },
	{ 0xF0A1AB8A, 0xFD4B3 },
	{ 0xF0A1AB8B, 0xFD4B4 },
	{ 0xF0A1AB8C, 0xFD4B5 },
	{ 0xF0A1AB8D, 0xFD4B6 },
	{ 0xF0A1AB8E, 0xFD4B7 },
	{ 0xF0A1AB92, 0x7B7D9 },
	{ 0xF0A1AB93, 0x7B7D7 },
	{ 0xF0A1AB94, 0x5DBB8 },
	{ 0xF0A1AB95, 0xFD9F2 },
	{ 0xF0A1AB96, 0xFD9F3 },
	{ 0xF0A1AB97, 0xFD9F4 },
	{ 0xF0A1AB98, 0xFD9F5 },
	{ 0xF0A1AB9A, 0x7B7D8 },
	{ 0xF0A1AB9B, 0x7B7DA },
	{ 0xF0A1AB9C, 0x7A2B4 },
	{ 0xF0A1AB9D, 0x5DBB7 },
	{ 0xF0A1AB9E, 0x7C6D8 },
	{ 0xF0A1AB9F, 0x5E1CE },
	{ 0xF0A1ABA0, 0xFD9F6 },
	{ 0xF0A1ABA2, 0xFDED6 },
	{ 0xF0A1ABA3, 0xFDED7 },
	{ 0xF0A1ABA9, 0x7BFC2 },
	{ 0xF0A1ABAA, 0xFE2AE },
	{ 0xF0A1ABAC, 0x4DFD7 },
	{ 0xF0A1ABAD, 0x7C6D3 },
	{ 0xF0A1ABAE, 0x7C6D5 },
	{ 0xF0A1ABAF, 0x4DFD6 },
	{ 0xF0A1ABB0, 0x7C6D7 },
	{ 0xF0A1ABB1, 0x7C6D6 },
	{ 0xF0A1ABB2, 0xFE2AF },
	{ 0xF0A1ABB3, 0x7C6D4 },
	{ 0xF0A1ABB7, 0x4E3B6 },
	{ 0xF0A1ABBB, 0x7CDD3 },
	{ 0xF0A1ABBC, 0x7D3AC },
	{ 0xF0A1ABBD, 0x4E6B8 },
	{ 0xF0A1ABBE, 0x7D3AD },
	{ 0xF0A1ABBF, 0xFE7CF },
	{ 0xF0A1AC80, 0xFE7D0 },
	{ 0xF0A1AC83, 0x7D3AE },
	{ 0xF0A1AC84, 0x5F3B8 },
	{ 0xF0A1AC85, 0x4E8E6 },
	{ 0xF0A1AC86, 0x7D7E5 },
	{ 0xF0A1AC87, 0x5F3B7 },
	{ 0xF0A1AC8A, 0x7D7E6 },
	{ 0xF0A1AC8C, 0x4EAC5 },
	{ 0xF0A1AC8D, 0x4EBE7 },
	{ 0xF0A1AC8F, 0xFEBC6 },
	{ 0xF0A1AC91, 0x7E0EC },
	{ 0xF0A1AC92, 0x7E4C5 },
	{ 0xF0A1AC93, 0x5F9A5 },
	{ 0xF0A1AC94, 0xFECA5 },
	{ 0xF0A1AC96, 0x4EDD4 },
	{ 0xF0A1AC98, 0x5FAA7 },
	{ 0xF0A1AC99, 0x4EDF1 },
	{ 0xF0A1AC9A, 0x7E3CE },
	{ 0xF0A1AC9B, 0x7E5B4 },
	{ 0xF0A1AC9D, 0x6A1EA },
	{ 0xF0A1AC9F, 0x6AAEA },
	{ 0xF0A1ACA0, 0x6AAE9 },
	{ 0xF0A1ACA2, 0xFA6D6 },
	{ 0xF0A1ACA3, 0xFA6D7 },
	{ 0xF0A1ACA7, 0x5A8EF },
	{ 0xF0A1ACA8, 0x6B0AE },
	{ 0xF0A1ACA9, 0xFAABD },
	{ 0xF0A1ACAA, 0x6B0B1 },
	{ 0xF0A1ACAC, 0x6B0AF },
	{ 0xF0A1ACAE, 0x4B1B1 },
	{ 0xF0A1ACAF, 0x6C3E7 },
	{ 0xF0A1ACB0, 0x6BEDE },
	{ 0xF0A1ACB1, 0x6BEDD },
	{ 0xF0A1ACB3, 0x4B7A7 },
	{ 0xF0A1ACB4, 0x6BEDF },
	{ 0xF0A1ACB9, 0x6D1FA },
	{ 0xF0A1ACBA, 0x6D1F8 },
	{ 0xF0A1ACBB, 0x6D1F9 },
	{ 0xF0A1ACBD, 0x6DCB0 },
	{ 0xF0A1ACBE, 0x4C4A6 },
	{ 0xF0A1ACBF, 0xFC7DB },
	{ 0xF0A1AD81, 0x6DCB1 },
	{ 0xF0A1AD82, 0x5C5BD },
	{ 0xF0A1AD85, 0xFCED1 },
	{ 0xF0A1AD86, 0x7A2BA },
	{ 0xF0A1AD88, 0x7A2B9 },
	{ 0xF0A1AD8A, 0x7ADB9 },
	{ 0xF0A1AD8B, 0x5D3D2 },
	{ 0xF0A1AD8C, 0x7ADB8 },
	{ 0xF0A1AD8D, 0x7B7DB },
	{ 0xF0A1AD8E, 0x7B7DC },
	{ 0xF0A1AD90, 0x5E1CF },
	{ 0xF0A1AD91, 0x7C6D9 },
	{ 0xF0A1AD92, 0x7CDD4 },
	{ 0xF0A1AD93, 0x7D3AF },
	{ 0xF0A1AD95, 0x6A1EB },
	{ 0xF0A1AD96, 0xFA1B9 },
	{ 0xF0A1AD99, 0x6A4CC },
	{ 0xF0A1AD9A, 0x5A2CC },
	{ 0xF0A1AD9D, 0x6A7A4 },
	{ 0xF0A1AD9E, 0x4A3F2 },
	{ 0xF0A1AD9F, 0x6A7A3 },
	{ 0xF0A1ADA0, 0x6A7A2 },
	{ 0xF0A1ADA1, 0xFA3F3 },
	{ 0xF0A1ADA5, 0x5A5E7 },
	{ 0xF0A1ADA8, 0xFA6D8 },
	{ 0xF0A1ADA9, 0x6AAEB },
	{ 0xF0A1ADAA, 0x6B0B2 },
	{ 0xF0A1ADAB, 0x6B0B0 },
	{ 0xF0A1ADAF, 0x6B0B3 },
	{ 0xF0A1ADB3, 0x5A8F0 },
	{ 0xF0A1ADB4, 0x4ACCB },
	{ 0xF0A1ADB5, 0xFAFA1 },
	{ 0xF0A1ADB9, 0x6B6E9 },
	{ 0xF0A1ADBD, 0x6BEE1 },
	{ 0xF0A1ADBE, 0x5B1F1 },
	{ 0xF0A1ADBF, 0x5B7E3 },
	{ 0xF0A1AE80, 0x6BEE3 },
	{ 0xF0A1AE81, 0x6BEE0 },
	{ 0xF0A1AE82, 0x6BEE2 },
	{ 0xF0A1AE83, 0xFB4B0 },
	{ 0xF0A1AE8E, 0x6C7F1 },
	{ 0xF0A1AE8F, 0xFBAD0 },
	{ 0xF0A1AE90, 0x6C7F3 },
	{ 0xF0A1AE95, 0x6C7F2 },
	{ 0xF0A1AE99, 0x5BEE5 },
	{ 0xF0A1AE9D, 0xFC1AF },
	{ 0xF0A1AE9E, 0x5C5BE },
	{ 0xF0A1AE9F, 0x6DCB3 },
	{ 0xF0A1AEA1, 0x6DCB2 },
	{ 0xF0A1AEA6, 0x5CCE2 },
	{ 0xF0A1AEA7, 0x7A2BB },
	{ 0xF0A1AEB0, 0x5D4AF },
	{ 0xF0A1AEB1, 0x7ADBA },
	{ 0xF0A1AEB4, 0xFD9F7 },
	{ 0xF0A1AEBB, 0x5E1D0 },
	{ 0xF0A1AEBF, 0x5EFF7 },
	{ 0xF0A1AF82, 0x4A1CA },
	{ 0xF0A1AF83, 0xFA1BA },
	{ 0xF0A1AF84, 0x5A1E5 },
	{ 0xF0A1AF85, 0xFA1CD },
	{ 0xF0A1AF86, 0xFA1DA },
	{ 0xF0A1AF89, 0x6A2EB },
	{ 0xF0A1AF8A, 0x6A2EA },
	{ 0xF0A1AF8D, 0x5A2CD },
	{ 0xF0A1AF8E, 0xFA2C3 },
	{ 0xF0A1AF8F, 0x5A3EC },
	{ 0xF0A1AF90, 0x4A3F3 },
	{ 0xF0A1AF92, 0x5A5E8 },
	{ 0xF0A1AF94, 0x6A7A5 },
	{ 0xF0A1AF96, 0x5A3EB },
	{ 0xF0A1AF98, 0x5A3EE },
	{ 0xF0A1AF99, 0x5A3ED },
	{ 0xF0A1AF9B, 0x6B0B4 },
	{ 0xF0A1AF9C, 0x5A5E9 },
	{ 0xF0A1AF9D, 0x6AAEC },
	{ 0xF0A1AF9E, 0x5A5EB },
	{ 0xF0A1AF9F, 0xFA6D9 },
	{ 0xF0A1AFA0, 0x6B0B5 },
	{ 0xF0A1AFA1, 0x5A5EA },
	{ 0xF0A1AFA2, 0x5A8F1 },
	{ 0xF0A1AFA3, 0x6B0B7 },
	{ 0xF0A1AFA5, 0x6B0B8 },
	{ 0xF0A1AFA6, 0x5A8F2 },
	{ 0xF0A1AFA7, 0x6B0B9 },
	{ 0xF0A1AFA8, 0x5ADA3 },
	{ 0xF0A1AFA9, 0x6B6EC },
	{ 0xF0A1AFAA, 0x6B6EA },
	{ 0xF0A1AFAC, 0x5ADA4 },
	{ 0xF0A1AFAD, 0x6B6EB },
	{ 0xF0A1AFAE, 0x6B6ED },
	{ 0xF0A1AFAF, 0xFAFA2 },
	{ 0xF0A1AFB2, 0x6BEE6 },
	{ 0xF0A1AFB3, 0x5B1F2 },
	{ 0xF0A1AFB4, 0x4B1B4 },
	{ 0xF0A1AFB5, 0x5B1F4 },
	{ 0xF0A1AFB6, 0x6C7F6 },
	{ 0xF0A1AFB7, 0x6C7F4 },
	{ 0xF0A1AFB8, 0x6C7F5 },
	{ 0xF0A1AFBA, 0x4B7AA },
	{ 0xF0A1AFBB, 0x6C7F7 },
	{ 0xF0A1AFBC, 0xFBAD1 },
	{ 0xF0A1B082, 0x6D1FB },
	{ 0xF0A1B083, 0x6D1FD },
	{ 0xF0A1B084, 0x6D1FC },
	{ 0xF0A1B087, 0x5C8A6 },
	{ 0xF0A1B089, 0x4C2FA },
	{ 0xF0A1B08A, 0x6DCB4 },
	{ 0xF0A1B08B, 0x5C5C0 },
	{ 0xF0A1B08C, 0x5C5BF },
	{ 0xF0A1B08D, 0x6DCB5 },
	{ 0xF0A1B08E, 0x5C5C1 },
	{ 0xF0A1B090, 0x7ADBD },
	{ 0xF0A1B091, 0x7A2BE },
	{ 0xF0A1B092, 0x7A2BD },
	{ 0xF0A1B094, 0x7A2BC },
	{ 0xF0A1B095, 0x7ADBB },
	{ 0xF0A1B096, 0x5D4B0 },
	{ 0xF0A1B097, 0x7ADBC },
	{ 0xF0A1B098, 0x7ADBE },
	{ 0xF0A1B099, 0xFD4B8 },
	{ 0xF0A1B09C, 0x7B7DD },
	{ 0xF0A1B09D, 0x4E6B9 },
	{ 0xF0A1B0A0, 0x4E8E7 },
	{ 0xF0A1B0A2, 0x5F9A6 },
	{ 0xF0A1B0A3, 0x6A1BE },
	{ 0xF0A1B0A4, 0x4A1F5 },
	{ 0xF0A1B0A5, 0x4A1F4 },
	{ 0xF0A1B0A6, 0x6A2EC },
	{ 0xF0A1B0A9, 0x6A4CD },
	{ 0xF0A1B0AA, 0x4A2DE },
	{ 0xF0A1B0AB, 0x5A2CE },
	{ 0xF0A1B0AC, 0x6A4CE },
	{ 0xF0A1B0AD, 0x6A4D0 },
	{ 0xF0A1B0AE, 0x6A4D1 },
	{ 0xF0A1B0AF, 0x6A4CF },
	{ 0xF0A1B0B0, 0xFA2C4 },
	{ 0xF0A1B0B6, 0x6A7A9 },
	{ 0xF0A1B0B7, 0xFA3F4 },
	{ 0xF0A1B0B8, 0x6A7A7 },
	{ 0xF0A1B0BA, 0x6A7A6 },
	{ 0xF0A1B0BC, 0x6A7A8 },
	{ 0xF0A1B0BD, 0x5A3EF },
	{ 0xF0A1B0BE, 0x4A6AC },
	{ 0xF0A1B0BF, 0x4A6AB },
	{ 0xF0A1B180, 0x6AAED },
	{ 0xF0A1B181, 0x6AAEE },
	{ 0xF0A1B182, 0x5A5EC },
	{ 0xF0A1B183, 0x6AAEF },
	{ 0xF0A1B184, 0xFA6DB },
	{ 0xF0A1B18B, 0x5A5ED },
	{ 0xF0A1B18C, 0x4A8F7 },
	{ 0xF0A1B18D, 0x6B0BA },
	{ 0xF0A1B18E, 0x6B0BF },
	{ 0xF0A1B18F, 0x4A8FA },
	{ 0xF0A1B190, 0x4A8F6 },
	{ 0xF0A1B191, 0x5A8F5 },
	{ 0xF0A1B192, 0x6B0BE },
	{ 0xF0A1B193, 0x6B0BD },
	{ 0xF0A1B194, 0x6B0BC },
	{ 0xF0A1B195, 0x6B0BB },
	{ 0xF0A1B197, 0xFAAC0 },
	{ 0xF0A1B198, 0xFAAC1 },
	{ 0xF0A1B199, 0xFAAC2 },
	{ 0xF0A1B19A, 0xFAAC3 },
	{ 0xF0A1B19B, 0xFAAC4 },
	{ 0xF0A1B19D, 0xFAABF },
	{ 0xF0A1B1A0, 0x6B0C0 },
	{ 0xF0A1B1A1, 0x5A8F4 },
	{ 0xF0A1B1A2, 0x6B6F2 },
	{ 0xF0A1B1A3, 0x4ACD0 },
	{ 0xF0A1B1A4, 0x6B6EF },
	{ 0xF0A1B1A5, 0x4ACCF },
	{ 0xF0A1B1A6, 0x6BEE7 },
	{ 0xF0A1B1A7, 0x6B6F0 },
	{ 0xF0A1B1A8, 0x6B6EE },
	{ 0xF0A1B1AA, 0xFAFA3 },
	{ 0xF0A1B1AB, 0xFAFA4 },
	{ 0xF0A1B1AC, 0xFAFA6 },
	{ 0xF0A1B1AD, 0xFAFA7 },
	{ 0xF0A1B1AE, 0xFAFA8 },
	{ 0xF0A1B1B0, 0x5ADA6 },
	{ 0xF0A1B1B1, 0x5ADA7 },
	{ 0xF0A1B1B2, 0x6B6F1 },
	{ 0xF0A1B1B4, 0x6B6F3 },
	{ 0xF0A1B1B7, 0x5ADA5 },
	{ 0xF0A1B1B9, 0x6B6F4 },
	{ 0xF0A1B1BA, 0x6BEED },
	{ 0xF0A1B1BB, 0x6BEE9 },
	{ 0xF0A1B1BC, 0x5B1F8 },
	{ 0xF0A1B1BD, 0x5B1FA },
	{ 0xF0A1B1BE, 0x5B1F7 },
	{ 0xF0A1B1BF, 0x5B1F9 },
	{ 0xF0A1B280, 0x5B1F6 },
	{ 0xF0A1B281, 0x5B1FB },
	{ 0xF0A1B282, 0x6BEF0 },
	{ 0xF0A1B283, 0x6BEEA },
	{ 0xF0A1B284, 0xFB4B1 },
	{ 0xF0A1B285, 0xFB4B2 },
	{ 0xF0A1B286, 0xFB4B5 },
	{ 0xF0A1B287, 0xFB4B6 },
	{ 0xF0A1B288, 0xFB4B7 },
	{ 0xF0A1B289, 0xFB4B8 },
	{ 0xF0A1B28A, 0xFB4B9 },
	{ 0xF0A1B28B, 0xFB4BA },
	{ 0xF0A1B28C, 0x6BEE8 },
	{ 0xF0A1B28E, 0x6BEEC },
	{ 0xF0A1B291, 0x6BEEF },
	{ 0xF0A1B292, 0x6BEEE },
	{ 0xF0A1B293, 0xFB4B3 },
	{ 0xF0A1B294, 0x6C8A3 },
	{ 0xF0A1B295, 0x6C8A4 },
	{ 0xF0A1B296, 0x6C8A2 },
	{ 0xF0A1B297, 0x4B7AC },
	{ 0xF0A1B298, 0x6C7FE },
	{ 0xF0A1B299, 0x6C7FA },
	{ 0xF0A1B29A, 0x5B7E4 },
	{ 0xF0A1B29B, 0x4B7AD },
	{ 0xF0A1B29C, 0x5B7E5 },
	{ 0xF0A1B29D, 0x6C7F9 },
	{ 0xF0A1B29E, 0x6C7F8 },
	{ 0xF0A1B29F, 0x6C8A5 },
	{ 0xF0A1B2A0, 0x6C8A1 },
	{ 0xF0A1B2A1, 0x6C8A6 },
	{ 0xF0A1B2A3, 0x6C7FC },
	{ 0xF0A1B2A6, 0xFBAD2 },
	{ 0xF0A1B2A7, 0xFBAD3 },
	{ 0xF0A1B2A8, 0xFBAD4 },
	{ 0xF0A1B2A9, 0x6C7FD },
	{ 0xF0A1B2AA, 0x4B7AE },
	{ 0xF0A1B2AC, 0x6D2A3 },
	{ 0xF0A1B2AD, 0x5BEE9 },
	{ 0xF0A1B2AE, 0x5BEE7 },
	{ 0xF0A1B2AF, 0x6D2A6 },
	{ 0xF0A1B2B0, 0x5BEE8 },
	{ 0xF0A1B2B1, 0x6D2A5 },
	{ 0xF0A1B2B2, 0x6D2A9 },
	{ 0xF0A1B2B3, 0x6D2A1 },
	{ 0xF0A1B2B4, 0x6D1FE },
	{ 0xF0A1B2B5, 0x6D2A7 },
	{ 0xF0A1B2B6, 0x6D2A4 },
	{ 0xF0A1B2B8, 0xFC1B0 },
	{ 0xF0A1B2B9, 0xFC1B1 },
	{ 0xF0A1B2BA, 0xFC1B2 },
	{ 0xF0A1B2BB, 0x6D2A2 },
	{ 0xF0A1B2BE, 0x6D2A8 },
	{ 0xF0A1B382, 0x5BEE6 },
	{ 0xF0A1B384, 0x4C2FC },
	{ 0xF0A1B385, 0x4C2FE },
	{ 0xF0A1B386, 0x4C2FB },
	{ 0xF0A1B387, 0x6DCB8 },
	{ 0xF0A1B388, 0x6DCB6 },
	{ 0xF0A1B389, 0x6DCB7 },
	{ 0xF0A1B38A, 0xFC7DD },
	{ 0xF0A1B38D, 0x6DCB9 },
	{ 0xF0A1B38F, 0x5C5C2 },
	{ 0xF0A1B390, 0x7A2C0 },
	{ 0xF0A1B391, 0x5CCE6 },
	{ 0xF0A1B393, 0xFCED2 },
	{ 0xF0A1B394, 0xFCED3 },
	{ 0xF0A1B395, 0xFCED4 },
	{ 0xF0A1B396, 0xFCED5 },
	{ 0xF0A1B397, 0xFCED6 },
	{ 0xF0A1B398, 0x5CCE5 },
	{ 0xF0A1B39E, 0x5CCE4 },
	{ 0xF0A1B39F, 0x7ADC0 },
	{ 0xF0A1B3A0, 0x7ADBF },
	{ 0xF0A1B3A1, 0x7A2BF },
	{ 0xF0A1B3A6, 0xFD4B9 },
	{ 0xF0A1B3A7, 0x7B0AD },
	{ 0xF0A1B3A8, 0x7B7DE },
	{ 0xF0A1B3AB, 0x7BFC3 },
	{ 0xF0A1B3AC, 0x4DFD8 },
	{ 0xF0A1B3AD, 0x5E7E2 },
	{ 0xF0A1B3B1, 0xFE5A7 },
	{ 0xF0A1B3B2, 0xFE5A8 },
	{ 0xF0A1B3B4, 0x5EBFD },
	{ 0xF0A1B3B7, 0xFE7D1 },
	{ 0xF0A1B3B8, 0x5F3BA },
	{ 0xF0A1B3BE, 0x5A1B0 },
	{ 0xF0A1B3BF, 0x6A1EC },
	{ 0xF0A1B480, 0x6A2ED },
	{ 0xF0A1B481, 0x6A4D4 },
	{ 0xF0A1B482, 0x6A4D3 },
	{ 0xF0A1B484, 0x6A4D2 },
	{ 0xF0A1B485, 0x5A2CF },
	{ 0xF0A1B486, 0x4A3F5 },
	{ 0xF0A1B488, 0x6A7AA },
	{ 0xF0A1B48B, 0x4A6AD },
	{ 0xF0A1B48C, 0x6AAF1 },
	{ 0xF0A1B48D, 0x6AAF0 },
	{ 0xF0A1B48E, 0x5A8F7 },
	{ 0xF0A1B48F, 0x6B0C2 },
	{ 0xF0A1B491, 0x6B0C3 },
	{ 0xF0A1B492, 0x5A8F6 },
	{ 0xF0A1B493, 0x6B0C4 },
	{ 0xF0A1B495, 0x6B6F7 },
	{ 0xF0A1B496, 0x6B6F8 },
	{ 0xF0A1B497, 0x6B6F6 },
	{ 0xF0A1B498, 0x6B5A8 },
	{ 0xF0A1B499, 0x6B6F5 },
	{ 0xF0A1B49B, 0x6BEF1 },
	{ 0xF0A1B49C, 0x6BEF2 },
	{ 0xF0A1B49D, 0x6C8A8 },
	{ 0xF0A1B49E, 0x5B7E7 },
	{ 0xF0A1B49F, 0x6C8A9 },
	{ 0xF0A1B4A1, 0x6C8A7 },
	{ 0xF0A1B4A3, 0xFBAD5 },
	{ 0xF0A1B4A4, 0x6D2AA },
	{ 0xF0A1B4A5, 0x6DCBA },
	{ 0xF0A1B4A6, 0x7A2C1 },
	{ 0xF0A1B4A7, 0x7ADC1 },
	{ 0xF0A1B4A8, 0x7A2C2 },
	{ 0xF0A1B4A9, 0x7A2C3 },
	{ 0xF0A1B4AB, 0x7D3B0 },
	{ 0xF0A1B4AC, 0x7DEDD },
	{ 0xF0A1B4AD, 0x5A1C5 },
	{ 0xF0A1B4AF, 0x5A1C6 },
	{ 0xF0A1B4B0, 0x6A2F0 },
	{ 0xF0A1B4B1, 0x6A2EE },
	{ 0xF0A1B4B2, 0x6A2F2 },
	{ 0xF0A1B4B3, 0x6A2F1 },
	{ 0xF0A1B4B5, 0xFA1DC },
	{ 0xF0A1B4B6, 0xFA1DD },
	{ 0xF0A1B4B7, 0xFA1DE },
	{ 0xF0A1B4B8, 0x6A2F3 },
	{ 0xF0A1B4BB, 0x5A1E6 },
	{ 0xF0A1B4BC, 0x6A2EF },
	{ 0xF0A1B4BF, 0x6A4D7 },
	{ 0xF0A1B580, 0x6A4D5 },
	{ 0xF0A1B581, 0x6A4D9 },
	{ 0xF0A1B586, 0x3A3D9 },
	{ 0xF0A1B587, 0xFA2C5 },
	{ 0xF0A1B588, 0xFA2C6 },
	{ 0xF0A1B58A, 0x6A4D6 },
	{ 0xF0A1B58B, 0x5A2D3 },
	{ 0xF0A1B58E, 0x6A4DA },
	{ 0xF0A1B58F, 0x6A4D8 },
	{ 0xF0A1B591, 0x5A2D2 },
	{ 0xF0A1B593, 0x6A7AE },
	{ 0xF0A1B594, 0x5A3F1 },
	{ 0xF0A1B595, 0x5A3F8 },
	{ 0xF0A1B596, 0x5A3F9 },
	{ 0xF0A1B597, 0x6A7B0 },
	{ 0xF0A1B598, 0x5A3F6 },
	{ 0xF0A1B599, 0x5A3F5 },
	{ 0xF0A1B59A, 0x5A3F7 },
	{ 0xF0A1B59B, 0x5A3F2 },
	{ 0xF0A1B59C, 0x5A3F3 },
	{ 0xF0A1B59D, 0x6A7B1 },
	{ 0xF0A1B59E, 0x6A7AC },
	{ 0xF0A1B5A3, 0x6A7B2 },
	{ 0xF0A1B5A4, 0xFA3F6 },
	{ 0xF0A1B5A6, 0xFA3F7 },
	{ 0xF0A1B5A7, 0xFA3F9 },
	{ 0xF0A1B5A8, 0xFA3FA },
	{ 0xF0A1B5A9, 0xFA3FB },
	{ 0xF0A1B5AA, 0xFA3FE },
	{ 0xF0A1B5AB, 0xFA4A1 },
	{ 0xF0A1B5AE, 0x6A7AD },
	{ 0xF0A1B5B0, 0x6A7AF },
	{ 0xF0A1B5B1, 0x4A3FD },
	{ 0xF0A1B5B3, 0xFA3FD },
	{ 0xF0A1B5B9, 0x6A7B4 },
	{ 0xF0A1B5BA, 0x6A7B3 },
	{ 0xF0A1B5BC, 0x4A3FC },
	{ 0xF0A1B5BE, 0x6A7AB },
	{ 0xF0A1B682, 0x5A3FA },
	{ 0xF0A1B683, 0x4A6B0 },
	{ 0xF0A1B684, 0x5A5F5 },
	{ 0xF0A1B685, 0x6AAF5 },
	{ 0xF0A1B686, 0x4A6B3 },
	{ 0xF0A1B687, 0x6AAF2 },
	{ 0xF0A1B688, 0x5A5F3 },
	{ 0xF0A1B689, 0x5A5F4 },
	{ 0xF0A1B68A, 0x6AAFA },
	{ 0xF0A1B68B, 0x5A5F1 },
	{ 0xF0A1B68C, 0x6AAF7 },
	{ 0xF0A1B68D, 0x6AAFC },
	{ 0xF0A1B68E, 0x5A5EF },
	{ 0xF0A1B68F, 0x6AAF9 },
	{ 0xF0A1B690, 0x5A5F2 },
	{ 0xF0A1B691, 0x5A5F0 },
	{ 0xF0A1B692, 0x6AAF4 },
	{ 0xF0A1B693, 0x6A7B5 },
	{ 0xF0A1B694, 0xFA6DC },
	{ 0xF0A1B695, 0xFA6DD },
	{ 0xF0A1B696, 0xFA6DE },
	{ 0xF0A1B697, 0xFA6DF },
	{ 0xF0A1B698, 0xFA6E0 },
	{ 0xF0A1B699, 0xFA6E1 },
	{ 0xF0A1B69A, 0xFA6E3 },
	{ 0xF0A1B69B, 0xFA6E4 },
	{ 0xF0A1B69D, 0xFA6E5 },
	{ 0xF0A1B69E, 0xFA6E6 },
	{ 0xF0A1B69F, 0xFA6E7 },
	{ 0xF0A1B6A0, 0xFA6E8 },
	{ 0xF0A1B6A2, 0x6AAF8 },
	{ 0xF0A1B6A4, 0x6ADAB },
	{ 0xF0A1B6A9, 0x6AAF3 },
	{ 0xF0A1B6AA, 0x5A5F6 },
	{ 0xF0A1B6AB, 0x6B0D0 },
	{ 0xF0A1B6AC, 0x6B0CA },
	{ 0xF0A1B6AD, 0x5A8F8 },
	{ 0xF0A1B6AE, 0x6B0CB },
	{ 0xF0A1B6AF, 0x5A8F9 },
	{ 0xF0A1B6B0, 0x4A8FE },
	{ 0xF0A1B6B1, 0x5A8FA },
	{ 0xF0A1B6B3, 0x6B0C6 },
	{ 0xF0A1B6B8, 0x6B0C9 },
	{ 0xF0A1B6B9, 0x6B0D2 },
	{ 0xF0A1B6BB, 0xFAAC5 },
	{ 0xF0A1B6BC, 0xFAAC7 },
	{ 0xF0A1B6BD, 0xFAAC8 },
	{ 0xF0A1B6BE, 0xFAACB },
	{ 0xF0A1B6BF, 0xFAACC },
	{ 0xF0A1B780, 0xFAACD },
	{ 0xF0A1B781, 0xFAACE },
	{ 0xF0A1B782, 0xFAACF },
	{ 0xF0A1B783, 0xFAAD0 },
	{ 0xF0A1B784, 0xFAAD1 },
	{ 0xF0A1B785, 0x6B0CD },
	{ 0xF0A1B786, 0x6B0C5 },
	{ 0xF0A1B787, 0x6B0C7 },
	{ 0xF0A1B789, 0x6B0D1 },
	{ 0xF0A1B78C, 0x6B0CF },
	{ 0xF0A1B78F, 0x6B0CC },
	{ 0xF0A1B790, 0xFAACA },
	{ 0xF0A1B791, 0xFAAC6 },
	{ 0xF0A1B792, 0x6B0C8 },
	{ 0xF0A1B793, 0x5A8FB },
	{ 0xF0A1B794, 0x4A8FC },
	{ 0xF0A1B795, 0x5ADAC },
	{ 0xF0A1B796, 0x5ADA9 },
	{ 0xF0A1B797, 0x4ACD2 },
	{ 0xF0A1B798, 0x4ACD9 },
	{ 0xF0A1B799, 0x5ADAA },
	{ 0xF0A1B79A, 0x6B7A1 },
	{ 0xF0A1B79B, 0x4ACD8 },
	{ 0xF0A1B79C, 0x5ADB4 },
	{ 0xF0A1B79D, 0x5ADB0 },
	{ 0xF0A1B79E, 0x5ADAB },
	{ 0xF0A1B79F, 0x6B6FD },
	{ 0xF0A1B7A0, 0x5ADB1 },
	{ 0xF0A1B7A1, 0x5ADAD },
	{ 0xF0A1B7A2, 0x5ADAF },
	{ 0xF0A1B7A3, 0x6B7A4 },
	{ 0xF0A1B7A4, 0x6B6FE },
	{ 0xF0A1B7A5, 0x4ACE2 },
	{ 0xF0A1B7A6, 0x6B6F9 },
	{ 0xF0A1B7A7, 0x4ACE3 },
	{ 0xF0A1B7A8, 0x4ACD6 },
	{ 0xF0A1B7A9, 0x6B7A5 },
	{ 0xF0A1B7AA, 0x6B7A2 },
	{ 0xF0A1B7AD, 0x6B7A3 },
	{ 0xF0A1B7AE, 0x6B6FB },
	{ 0xF0A1B7AF, 0xFAFA9 },
	{ 0xF0A1B7B0, 0xFAFAA },
	{ 0xF0A1B7B1, 0xFAFAB },
	{ 0xF0A1B7B2, 0xFAFAC },
	{ 0xF0A1B7B3, 0xFAFAD },
	{ 0xF0A1B7B4, 0xFAFAE },
	{ 0xF0A1B7B5, 0xFAFAF },
	{ 0xF0A1B7B6, 0xFAFB1 },
	{ 0xF0A1B7B7, 0xFAFB3 },
	{ 0xF0A1B7B8, 0x5ADA8 },
	{ 0xF0A1B7BF, 0xFAFB0 },
	{ 0xF0A1B882, 0xFAFB2 },
	{ 0xF0A1B888, 0x5ADB3 },
	{ 0xF0A1B889, 0x4ACDD },
	{ 0xF0A1B88A, 0x5ADB5 },
	{ 0xF0A1B88C, 0x5ADB6 },
	{ 0xF0A1B88E, 0x5ADB2 },
	{ 0xF0A1B890, 0x6BBCE },
	{ 0xF0A1B891, 0x4B1BA },
	{ 0xF0A1B892, 0x6BFAB },
	{ 0xF0A1B893, 0x6BFA4 },
	{ 0xF0A1B894, 0x6BFA6 },
	{ 0xF0A1B895, 0x4B1BC },
	{ 0xF0A1B896, 0x4B1BE },
	{ 0xF0A1B897, 0x5B1FE },
	{ 0xF0A1B898, 0x6BEF9 },
	{ 0xF0A1B899, 0x6BFA2 },
	{ 0xF0A1B89A, 0x6BEFB },
	{ 0xF0A1B89B, 0x5B2A8 },
	{ 0xF0A1B89C, 0x4B1B8 },
	{ 0xF0A1B89E, 0x6BFA7 },
	{ 0xF0A1B89F, 0x6BFAC },
	{ 0xF0A1B8A0, 0x6BFA9 },
	{ 0xF0A1B8A1, 0x6BEF4 },
	{ 0xF0A1B8A2, 0x6BFAA },
	{ 0xF0A1B8A3, 0x4B1C0 },
	{ 0xF0A1B8A4, 0x4B1BB },
	{ 0xF0A1B8A5, 0x5B1FC },
	{ 0xF0A1B8A6, 0x5B2A6 },
	{ 0xF0A1B8A7, 0x6BEF3 },
	{ 0xF0A1B8A8, 0x4B1B6 },
	{ 0xF0A1B8A9, 0x5B1FD },
	{ 0xF0A1B8AA, 0x5B2A4 },
	{ 0xF0A1B8AC, 0x6BFA8 },
	{ 0xF0A1B8B5, 0x6BFA3 },
	{ 0xF0A1B8B6, 0xFB4BB },
	{ 0xF0A1B8B8, 0xFB4BC },
	{ 0xF0A1B8B9, 0xFB4BD },
	{ 0xF0A1B8BA, 0xFB4BE },
	{ 0xF0A1B8BB, 0xFB4C0 },
	{ 0xF0A1B8BC, 0xFB4C1 },
	{ 0xF0A1B8BD, 0xFB4C2 },
	{ 0xF0A1B8BE, 0xFB4C3 },
	{ 0xF0A1B8BF, 0xFB4C4 },
	{ 0xF0A1B980, 0xFB4C6 },
	{ 0xF0A1B981, 0xFB4C7 },
	{ 0xF0A1B982, 0xFB4C8 },
	{ 0xF0A1B983, 0x6BEF7 },
	{ 0xF0A1B986, 0x6B2AA },
	{ 0xF0A1B98A, 0x6BEFD },
	{ 0xF0A1B98B, 0x6BEFC },
	{ 0xF0A1B98D, 0x6BEFE },
	{ 0xF0A1B98F, 0x6BFA1 },
	{ 0xF0A1B992, 0x6BFA5 },
	{ 0xF0A1B994, 0x4B1BF },
	{ 0xF0A1B9A2, 0x5B2A9 },
	{ 0xF0A1B9A3, 0x5B2A1 },
	{ 0xF0A1B9A4, 0x5B2A7 },
	{ 0xF0A1B9A5, 0x5B2A3 },
	{ 0xF0A1B9A7, 0x5B2A2 },
	{ 0xF0A1B9A8, 0x5B2A5 },
	{ 0xF0A1B9A9, 0x5B2AA },
	{ 0xF0A1B9AA, 0x5B7E9 },
	{ 0xF0A1B9AB, 0x6C8B3 },
	{ 0xF0A1B9AC, 0x5B7EE },
	{ 0xF0A1B9AD, 0x6C8AA },
	{ 0xF0A1B9AE, 0x6C8B4 },
	{ 0xF0A1B9AF, 0x5B7EF },
	{ 0xF0A1B9B0, 0x5B7EC },
	{ 0xF0A1B9B2, 0x5B7EB },
	{ 0xF0A1B9B3, 0x4B7B0 },
	{ 0xF0A1B9B5, 0x5B7F0 },
	{ 0xF0A1B9B6, 0x5B7EA },
	{ 0xF0A1B9B7, 0x5B7F1 },
	{ 0xF0A1B9B8, 0x5B7F2 },
	{ 0xF0A1B9B9, 0x5B7F4 },
	{ 0xF0A1B9BA, 0x6C8AE },
	{ 0xF0A1B9BB, 0x6BEFA },
	{ 0xF0A1B9BC, 0x4B7B1 },
	{ 0xF0A1B9BD, 0x6C8AF },
	{ 0xF0A1B9BE, 0x5B7ED },
	{ 0xF0A1BA86, 0x4B7B3 },
	{ 0xF0A1BA88, 0x5B7E8 },
	{ 0xF0A1BA8A, 0x5B7F3 },
	{ 0xF0A1BA8B, 0xFBAD6 },
	{ 0xF0A1BA8C, 0xFBAD8 },
	{ 0xF0A1BA8D, 0xFBAD9 },
	{ 0xF0A1BA8E, 0xFBADA },
	{ 0xF0A1BA8F, 0xFBADB },
	{ 0xF0A1BA92, 0x6C8AD },
	{ 0xF0A1BA94, 0x5B7F5 },
	{ 0xF0A1BA99, 0x6C8B2 },
	{ 0xF0A1BA9A, 0x6C8AC },
	{ 0xF0A1BA9D, 0x6C8B1 },
	{ 0xF0A1BAA1, 0x6C8B0 },
	{ 0xF0A1BAA4, 0xFBADC },
	{ 0xF0A1BAAB, 0x5BEF0 },
	{ 0xF0A1BAAC, 0x6D2AD },
	{ 0xF0A1BAAD, 0x5BEEC },
	{ 0xF0A1BAAE, 0x4BCFA },
	{ 0xF0A1BAAF, 0x5BEF1 },
	{ 0xF0A1BAB0, 0x6D2AE },
	{ 0xF0A1BAB1, 0x6DCBB },
	{ 0xF0A1BAB2, 0x4BCFD },
	{ 0xF0A1BAB3, 0x6D2B5 },
	{ 0xF0A1BAB4, 0x5BEEA },
	{ 0xF0A1BAB5, 0x5BEF3 },
	{ 0xF0A1BAB6, 0x6D2AB },
	{ 0xF0A1BAB7, 0x5BEEF },
	{ 0xF0A1BAB9, 0x6D2AC },
	{ 0xF0A1BABA, 0x6D2B9 },
	{ 0xF0A1BABB, 0x6D2B0 },
	{ 0xF0A1BABC, 0x6D2B8 },
	{ 0xF0A1BABD, 0x5BEEE },
	{ 0xF0A1BABE, 0x6D2B6 },
	{ 0xF0A1BABF, 0x6DCC0 },
	{ 0xF0A1BB80, 0xFC1B7 },
	{ 0xF0A1BB81, 0x5BEF2 },
	{ 0xF0A1BB82, 0xFC1B3 },
	{ 0xF0A1BB83, 0xFC1B4 },
	{ 0xF0A1BB84, 0xFC1B6 },
	{ 0xF0A1BB85, 0xFC1B8 },
	{ 0xF0A1BB86, 0xFC1B9 },
	{ 0xF0A1BB87, 0x6D2BA },
	{ 0xF0A1BB8B, 0x6D2B2 },
	{ 0xF0A1BB8D, 0x6D2B7 },
	{ 0xF0A1BB91, 0x5BEEB },
	{ 0xF0A1BB95, 0xFC1B5 },
	{ 0xF0A1BB97, 0x6D2AF },
	{ 0xF0A1BB98, 0x5C5C3 },
	{ 0xF0A1BB99, 0x5C5CB },
	{ 0xF0A1BB9A, 0x5C5C9 },
	{ 0xF0A1BB9B, 0x6DCC1 },
	{ 0xF0A1BB9C, 0x6DCBC },
	{ 0xF0A1BB9D, 0x4C3AB },
	{ 0xF0A1BB9E, 0x4C3A6 },
	{ 0xF0A1BB9F, 0x4C3A5 },
	{ 0xF0A1BBA0, 0x5C5C4 },
	{ 0xF0A1BBA1, 0x5C5C8 },
	{ 0xF0A1BBA2, 0x5C5C7 },
	{ 0xF0A1BBA3, 0x5C5CA },
	{ 0xF0A1BBA4, 0x5C5CE },
	{ 0xF0A1BBA5, 0x6DCBE },
	{ 0xF0A1BBA6, 0x6DCC7 },
	{ 0xF0A1BBA7, 0x5C5CD },
	{ 0xF0A1BBA8, 0x5C5C5 },
	{ 0xF0A1BBA9, 0x5C5C6 },
	{ 0xF0A1BBAA, 0x6DCC2 },
	{ 0xF0A1BBAC, 0x4C3A9 },
	{ 0xF0A1BBAD, 0x6DCC6 },
	{ 0xF0A1BBAE, 0x4C3A7 },
	{ 0xF0A1BBAF, 0x4C3A3 },
	{ 0xF0A1BBB0, 0x5C5CC },
	{ 0xF0A1BBB1, 0x6DCC5 },
	{ 0xF0A1BBB2, 0x6DCC3 },
	{ 0xF0A1BBB4, 0x6DCBF },
	{ 0xF0A1BBB5, 0x4C3A8 },
	{ 0xF0A1BBB6, 0xFC7DE },
	{ 0xF0A1BBB7, 0xFC7DF },
	{ 0xF0A1BBB8, 0xFC7E0 },
	{ 0xF0A1BBB9, 0xFC7E1 },
	{ 0xF0A1BBBE, 0x6D2B1 },
	{ 0xF0A1BC8A, 0x4C9CE },
	{ 0xF0A1BC8B, 0x7A2C9 },
	{ 0xF0A1BC8C, 0x4C9D2 },
	{ 0xF0A1BC8D, 0x7A2C5 },
	{ 0xF0A1BC8E, 0x5CCE9 },
	{ 0xF0A1BC90, 0x7A2D0 },
	{ 0xF0A1BC91, 0x7A2CA },
	{ 0xF0A1BC92, 0x5CCEE },
	{ 0xF0A1BC93, 0x5CCE7 },
	{ 0xF0A1BC94, 0x7A2C7 },
	{ 0xF0A1BC95, 0x7A2D1 },
	{ 0xF0A1BC96, 0x5CCEF },
	{ 0xF0A1BC97, 0x7A2CF },
	{ 0xF0A1BC98, 0x7A2CC },
	{ 0xF0A1BC99, 0x7A2CD },
	{ 0xF0A1BC9A, 0x5CCF0 },
	{ 0xF0A1BC9B, 0x5CCEA },
	{ 0xF0A1BC9C, 0x5CCED },
	{ 0xF0A1BC9D, 0x7ADC4 },
	{ 0xF0A1BCA5, 0x7A2C6 },
	{ 0xF0A1BCA6, 0xFCED7 },
	{ 0xF0A1BCA7, 0xFCED8 },
	{ 0xF0A1BCA8, 0xFCED9 },
	{ 0xF0A1BCA9, 0xFCEDB },
	{ 0xF0A1BCAA, 0xFCEDC },
	{ 0xF0A1BCAF, 0x7A2C4 },
	{ 0xF0A1BCB0, 0x7A2CB },
	{ 0xF0A1BCB6, 0x7A2CE },
	{ 0xF0A1BCBA, 0x5CCEB },
	{ 0xF0A1BCBC, 0x7A2C8 },
	{ 0xF0A1BCBD, 0x4C9D1 },
	{ 0xF0A1BCBE, 0x5D4B3 },
	{ 0xF0A1BCBF, 0x4D0A3 },
	{ 0xF0A1BD80, 0x7ADCA },
	{ 0xF0A1BD81, 0x4D0A4 },
	{ 0xF0A1BD82, 0x5D4B5 },
	{ 0xF0A1BD83, 0x7ADC2 },
	{ 0xF0A1BD84, 0x5D4B8 },
	{ 0xF0A1BD85, 0x5D4B4 },
	{ 0xF0A1BD86, 0x5D4B1 },
	{ 0xF0A1BD87, 0x7ADC7 },
	{ 0xF0A1BD88, 0x7ADC3 },
	{ 0xF0A1BD89, 0x5DBB9 },
	{ 0xF0A1BD8A, 0x5D4B2 },
	{ 0xF0A1BD8C, 0xFD4BA },
	{ 0xF0A1BD8D, 0xFD4BB },
	{ 0xF0A1BD8E, 0xFD4BC },
	{ 0xF0A1BD90, 0x7ADC5 },
	{ 0xF0A1BD93, 0x7ADC9 },
	{ 0xF0A1BD94, 0x7ADC8 },
	{ 0xF0A1BD95, 0x7ADCB },
	{ 0xF0A1BD98, 0x7ADC6 },
	{ 0xF0A1BD9A, 0x7ADCD },
	{ 0xF0A1BD9B, 0x5D4B7 },
	{ 0xF0A1BD9C, 0x4D6A9 },
	{ 0xF0A1BD9D, 0x5DBBB },
	{ 0xF0A1BD9E, 0x5E1D5 },
	{ 0xF0A1BD9F, 0x7B7E0 },
	{ 0xF0A1BDA0, 0x5DBBF },
	{ 0xF0A1BDA1, 0x7B7E6 },
	{ 0xF0A1BDA3, 0x5DBBA },
	{ 0xF0A1BDA4, 0x7B7E2 },
	{ 0xF0A1BDA5, 0x7B7E4 },
	{ 0xF0A1BDA6, 0x7B7E1 },
	{ 0xF0A1BDA7, 0x5DBBD },
	{ 0xF0A1BDAC, 0x7B7DF },
	{ 0xF0A1BDAD, 0x7B7E5 },
	{ 0xF0A1BDAE, 0xFD9F9 },
	{ 0xF0A1BDAF, 0xFD9FA },
	{ 0xF0A1BDB0, 0xFD9FB },
	{ 0xF0A1BDB5, 0x4D6AA },
	{ 0xF0A1BDB8, 0x7B7E3 },
	{ 0xF0A1BDBA, 0x7B7E7 },
	{ 0xF0A1BDBD, 0x7B9A7 },
	{ 0xF0A1BE80, 0x5DBC0 },
	{ 0xF0A1BE82, 0x7C6DA },
	{ 0xF0A1BE85, 0x5E1D4 },
	{ 0xF0A1BE86, 0x7BFC7 },
	{ 0xF0A1BE87, 0x4DAFE },
	{ 0xF0A1BE88, 0x5E1D1 },
	{ 0xF0A1BE89, 0x5E1D2 },
	{ 0xF0A1BE8A, 0x7BFC9 },
	{ 0xF0A1BE8B, 0xFDED9 },
	{ 0xF0A1BE8C, 0x5E1D3 },
	{ 0xF0A1BE8D, 0x7BFC6 },
	{ 0xF0A1BE8E, 0xFDED8 },
	{ 0xF0A1BE90, 0x7BFC5 },
	{ 0xF0A1BE91, 0x7BFC8 },
	{ 0xF0A1BE94, 0x5E1D6 },
	{ 0xF0A1BE95, 0x5E1D7 },
	{ 0xF0A1BE98, 0x7C6DC },
	{ 0xF0A1BE99, 0x4DFDB },
	{ 0xF0A1BE9A, 0x7C6DE },
	{ 0xF0A1BE9B, 0x5E7E5 },
	{ 0xF0A1BE9C, 0x4DFD9 },
	{ 0xF0A1BE9D, 0x7C6DD },
	{ 0xF0A1BE9E, 0x7C6DF },
	{ 0xF0A1BE9F, 0x7C6E0 },
	{ 0xF0A1BEA2, 0xFE2B0 },
	{ 0xF0A1BEA3, 0xFE2B1 },
	{ 0xF0A1BEA4, 0xFE2B2 },
	{ 0xF0A1BEA6, 0x7C6E1 },
	{ 0xF0A1BEA7, 0x7C6E2 },
	{ 0xF0A1BEA9, 0x7C6DB },
	{ 0xF0A1BEAE, 0x4E3B8 },
	{ 0xF0A1BEAF, 0x7CDD5 },
	{ 0xF0A1BEB0, 0x4E3B7 },
	{ 0xF0A1BEB1, 0x5EBFE },
	{ 0xF0A1BEB2, 0x7CDD7 },
	{ 0xF0A1BEB6, 0xFE5A9 },
	{ 0xF0A1BEB7, 0x7CDD6 },
	{ 0xF0A1BEBB, 0x5DBBE },
	{ 0xF0A1BEBC, 0x5EFF8 },
	{ 0xF0A1BEBD, 0x5EFFA },
	{ 0xF0A1BEBE, 0x5EFF9 },
	{ 0xF0A1BF81, 0x7D3B2 },
	{ 0xF0A1BF86, 0x7D3B1 },
	{ 0xF0A1BF87, 0x5F3BB },
	{ 0xF0A1BF88, 0x4E8E9 },
	{ 0xF0A1BF89, 0x4E8EA },
	{ 0xF0A1BF8A, 0x7D7E7 },
	{ 0xF0A1BF8B, 0x7D7E9 },
	{ 0xF0A1BF8C, 0x7D7E8 },
	{ 0xF0A1BF8F, 0x7D7EA },
	{ 0xF0A1BF91, 0x5F3BC },
	{ 0xF0A1BF94, 0x7DEDE },
	{ 0xF0A1BF95, 0x4EBEA },
	{ 0xF0A1BF96, 0x4EBE9 },
	{ 0xF0A1BF98, 0x7DEE0 },
	{ 0xF0A1BF9B, 0x5F7D8 },
	{ 0xF0A1BF9C, 0x7DEDF },
	{ 0xF0A1BF9D, 0x5F9A7 },
	{ 0xF0A1BF9F, 0xFECA6 },
	{ 0xF0A1BFA0, 0x5FAA8 },
	{ 0xF0A1BFA1, 0x5FAE6 },
	{ 0xF0A1BFA2, 0x5FBBC },
	{ 0xF0A1BFA3, 0x7E3CF },
	{ 0xF0A1BFA5, 0x5FCB4 },
	{ 0xF0A1BFA7, 0x6A1ED },
	{ 0xF0A1BFA8, 0x4A1A5 },
	{ 0xF0A1BFA9, 0x4A2E2 },
	{ 0xF0A1BFAA, 0x5A2D4 },
	{ 0xF0A1BFAB, 0x6A4DB },
	{ 0xF0A1BFAC, 0x6A4DC },
	{ 0xF0A1BFAD, 0x5A2D5 },
	{ 0xF0A1BFAE, 0x6A3FE },
	{ 0xF0A1BFAF, 0x4A3FE },
	{ 0xF0A1BFB0, 0x5A3FB },
	{ 0xF0A1BFB1, 0x6AAFD },
	{ 0xF0A1BFB2, 0xFA6EA },
	{ 0xF0A1BFB3, 0xFA6E9 },
	{ 0xF0A1BFB7, 0x6B0D5 },
	{ 0xF0A1BFB8, 0x6B0D4 },
	{ 0xF0A1BFB9, 0x6B0D6 },
	{ 0xF0A1BFBB, 0x6B0D3 },
	{ 0xF0A1BFBD, 0x6B7A6 },
	{ 0xF0A1BFBE, 0x5B2AB },
	{ 0xF0A1BFBF, 0x4B1C1 },
	{ 0xF0A28080, 0x6BFAD },
	{ 0xF0A28081, 0x5B7F6 },
	{ 0xF0A28082, 0x6DCC8 },
	{ 0xF0A28083, 0x7A2D2 },
	{ 0xF0A28084, 0x5D4B9 },
	{ 0xF0A28085, 0xFCEDD },
	{ 0xF0A28086, 0xFD4BD },
	{ 0xF0A28087, 0x7B7E8 },
	{ 0xF0A28088, 0x7BFCA },
	{ 0xF0A28089, 0x7C6E3 },
	{ 0xF0A2808A, 0x5E7E6 },
	{ 0xF0A2808E, 0x7DEE1 },
	{ 0xF0A28090, 0x7E5B5 },
	{ 0xF0A28091, 0x6A1EF },
	{ 0xF0A28092, 0x6A1F1 },
	{ 0xF0A28093, 0x6A1F0 },
	{ 0xF0A28094, 0xFA1BB },
	{ 0xF0A28098, 0x5A1E8 },
	{ 0xF0A28099, 0x5A1E7 },
	{ 0xF0A2809C, 0x5A3FC },
	{ 0xF0A2809D, 0x6A7B7 },
	{ 0xF0A2809F, 0xFA6EB },
	{ 0xF0A280A0, 0x6B0D7 },
	{ 0xF0A280A1, 0x6B7A8 },
	{ 0xF0A280A2, 0xFAFB4 },
	{ 0xF0A280A3, 0x6BFAE },
	{ 0xF0A280A4, 0xFBADE },
	{ 0xF0A280A9, 0x7A2D3 },
	{ 0xF0A280AF, 0x7C6E4 },
	{ 0xF0A280B4, 0x6A2F4 },
	{ 0xF0A280B6, 0x5A2D6 },
	{ 0xF0A280B7, 0x6AAFE },
	{ 0xF0A280B9, 0x6B0D9 },
	{ 0xF0A280BB, 0x6B0D8 },
	{ 0xF0A280BF, 0x4ACE5 },
	{ 0xF0A28180, 0x6BFAF },
	{ 0xF0A28181, 0x5B5DF },
	{ 0xF0A28182, 0x5B2AD },
	{ 0xF0A28183, 0x6BFB0 },
	{ 0xF0A28184, 0x5B2AC },
	{ 0xF0A28185, 0x6C8B6 },
	{ 0xF0A28186, 0xFBADF },
	{ 0xF0A28187, 0xFBAE0 },
	{ 0xF0A28188, 0xFBAE1 },
	{ 0xF0A2818C, 0x7A2D4 },
	{ 0xF0A28190, 0x7BFCB },
	{ 0xF0A28192, 0x4A1F7 },
	{ 0xF0A28193, 0x6A2F5 },
	{ 0xF0A28194, 0x6A2F6 },
	{ 0xF0A28195, 0x5A2D9 },
	{ 0xF0A28196, 0x5A2D8 },
	{ 0xF0A28197, 0x4A2E4 },
	{ 0xF0A28198, 0x5A2DB },
	{ 0xF0A28199, 0x6A4E1 },
	{ 0xF0A2819A, 0x6A4E0 },
	{ 0xF0A2819B, 0x6A4DE },
	{ 0xF0A2819C, 0xFA2C8 },
	{ 0xF0A2819F, 0xFA2CA },
	{ 0xF0A281A2, 0x5A2D7 },
	{ 0xF0A281A3, 0x6A4DF },
	{ 0xF0A281A4, 0x5A2DA },
	{ 0xF0A281A5, 0x6A7C1 },
	{ 0xF0A281A6, 0x6A7BB },
	{ 0xF0A281A7, 0x5A4A2 },
	{ 0xF0A281A8, 0x6A7B8 },
	{ 0xF0A281A9, 0x5A3FE },
	{ 0xF0A281AA, 0x5A3FD },
	{ 0xF0A281AC, 0x5A4A3 },
	{ 0xF0A281AD, 0x6A7C0 },
	{ 0xF0A281AE, 0x5A4A4 },
	{ 0xF0A281AF, 0x6A7BC },
	{ 0xF0A281B0, 0x6A7BF },
	{ 0xF0A281B1, 0x5A4A1 },
	{ 0xF0A281B2, 0xFA4A4 },
	{ 0xF0A281B3, 0x6A7B9 },
	{ 0xF0A281B4, 0x6A7BA },
	{ 0xF0A281B5, 0x6A7BD },
	{ 0xF0A281B9, 0x5A4A5 },
	{ 0xF0A281BA, 0x6A7BE },
	{ 0xF0A281BB, 0x5A5FB },
	{ 0xF0A281BC, 0x4A6B5 },
	{ 0xF0A281BD, 0x5A5F9 },
	{ 0xF0A281BE, 0x5A5FD },
	{ 0xF0A281BF, 0x5A5FA },
	{ 0xF0A28280, 0x5A5FC },
	{ 0xF0A28281, 0x5A6A1 },
	{ 0xF0A28282, 0x6ABA3 },
	{ 0xF0A28283, 0x5A5FE },
	{ 0xF0A28286, 0x5A6A2 },
	{ 0xF0A28287, 0x6ABA2 },
	{ 0xF0A28288, 0xFA6EC },
	{ 0xF0A2828A, 0x5A6A3 },
	{ 0xF0A2828B, 0x6ABA1 },
	{ 0xF0A2828D, 0x5A5F7 },
	{ 0xF0A2828F, 0x5A5F8 },
	{ 0xF0A28290, 0x5A8FE },
	{ 0xF0A28291, 0x6B0E2 },
	{ 0xF0A28292, 0x5A8FD },
	{ 0xF0A28293, 0x5A9A2 },
	{ 0xF0A28294, 0x5A8FC },
	{ 0xF0A28295, 0x5A9A3 },
	{ 0xF0A28296, 0x6B0DF },
	{ 0xF0A28297, 0x5A9A5 },
	{ 0xF0A28298, 0x5A9A4 },
	{ 0xF0A2829A, 0x6B0DB },
	{ 0xF0A2829D, 0x5A9A1 },
	{ 0xF0A2829E, 0x6B0DA },
	{ 0xF0A2829F, 0x6B0E5 },
	{ 0xF0A282A0, 0x6B0E7 },
	{ 0xF0A282A1, 0xFAAD3 },
	{ 0xF0A282A2, 0xFAAD4 },
	{ 0xF0A282A3, 0xFAAD5 },
	{ 0xF0A282A5, 0x4A9A6 },
	{ 0xF0A282A6, 0x6B0E1 },
	{ 0xF0A282A9, 0x6B0E0 },
	{ 0xF0A282AA, 0x6B0DC },
	{ 0xF0A282AB, 0x6B0DD },
	{ 0xF0A282AC, 0x6B0E6 },
	{ 0xF0A282AE, 0x6B0E4 },
	{ 0xF0A282AF, 0x6B0DE },
	{ 0xF0A282B1, 0x5ADB8 },
	{ 0xF0A282B2, 0x6B7B2 },
	{ 0xF0A282B4, 0x5ADB7 },
	{ 0xF0A282B5, 0x6B7AE },
	{ 0xF0A282B6, 0x5ADB9 },
	{ 0xF0A282B7, 0x5B2AE },
	{ 0xF0A282B8, 0x6B7AA },
	{ 0xF0A282B9, 0x4ACE9 },
	{ 0xF0A282BA, 0x4ACEA },
	{ 0xF0A282BB, 0x6B7AF },
	{ 0xF0A282BC, 0x5ADBA },
	{ 0xF0A282BD, 0x6B7AD },
	{ 0xF0A282BE, 0x6B7B1 },
	{ 0xF0A282BF, 0x6B7B0 },
	{ 0xF0A28380, 0x4ACE7 },
	{ 0xF0A28381, 0x6B7B3 },
	{ 0xF0A28382, 0x6B7B4 },
	{ 0xF0A28383, 0xFAFB6 },
	{ 0xF0A28384, 0xFAFB5 },
	{ 0xF0A28386, 0x6B7A9 },
	{ 0xF0A2838B, 0x6B7AB },
	{ 0xF0A2838C, 0x6BFB5 },
	{ 0xF0A2838D, 0x5B2B5 },
	{ 0xF0A2838E, 0x4B1C6 },
	{ 0xF0A2838F, 0x4B1C3 },
	{ 0xF0A28390, 0x4B1C4 },
	{ 0xF0A28391, 0x5B2B3 },
	{ 0xF0A28392, 0x5B2AF },
	{ 0xF0A28393, 0x6BFBA },
	{ 0xF0A28394, 0x5B2B0 },
	{ 0xF0A28395, 0x5B2B4 },
	{ 0xF0A28396, 0x6BFBC },
	{ 0xF0A28397, 0x5B2B1 },
	{ 0xF0A28398, 0x5B2B6 },
	{ 0xF0A28399, 0x6BFB6 },
	{ 0xF0A2839A, 0x6BFBB },
	{ 0xF0A2839B, 0x6BFB2 },
	{ 0xF0A2839C, 0x5B2B2 },
	{ 0xF0A2839D, 0x6BFB4 },
	{ 0xF0A2839E, 0xFB4C9 },
	{ 0xF0A2839F, 0xFB4CA },
	{ 0xF0A283A0, 0xFB4CB },
	{ 0xF0A283A1, 0xFB4CC },
	{ 0xF0A283A3, 0x6BFB9 },
	{ 0xF0A283A4, 0x6BFB1 },
	{ 0xF0A283A7, 0x6BFBD },
	{ 0xF0A283A8, 0x6BFB7 },
	{ 0xF0A283AA, 0x6BFB3 },
	{ 0xF0A283AB, 0x6C8B9 },
	{ 0xF0A283AC, 0x4B7BE },
	{ 0xF0A283AD, 0x6C8BE },
	{ 0xF0A283AE, 0x5B7F9 },
	{ 0xF0A283AF, 0x5B7FA },
	{ 0xF0A283B0, 0x4B7B8 },
	{ 0xF0A283B1, 0x5B7F8 },
	{ 0xF0A283B2, 0x6C8BA },
	{ 0xF0A283B3, 0x4B7B7 },
	{ 0xF0A283B4, 0x5B8A1 },
	{ 0xF0A283B5, 0x5B8A2 },
	{ 0xF0A283B6, 0x6BFB8 },
	{ 0xF0A283B7, 0x6C8C0 },
	{ 0xF0A283B8, 0x6C8BD },
	{ 0xF0A283B9, 0x6C8BB },
	{ 0xF0A283BA, 0x5B7FD },
	{ 0xF0A283BB, 0x6C8B8 },
	{ 0xF0A283BD, 0xFBAE2 },
	{ 0xF0A283BE, 0xFBAE3 },
	{ 0xF0A28481, 0x6C8BF },
	{ 0xF0A28484, 0x5B7FB },
	{ 0xF0A28485, 0x5B7F7 },
	{ 0xF0A28486, 0x6C8C1 },
	{ 0xF0A28487, 0x5B7FE },
	{ 0xF0A28488, 0xFC0AB },
	{ 0xF0A2848A, 0x5BEF8 },
	{ 0xF0A2848B, 0x4BDA2 },
	{ 0xF0A2848C, 0x5C5D2 },
	{ 0xF0A2848D, 0x4BDA5 },
	{ 0xF0A2848E, 0x5BEF5 },
	{ 0xF0A2848F, 0x5BEF4 },
	{ 0xF0A28490, 0x4BDA4 },
	{ 0xF0A28493, 0x5BEF7 },
	{ 0xF0A28494, 0x5BEFA },
	{ 0xF0A28495, 0x6D2BE },
	{ 0xF0A28496, 0x6D2BB },
	{ 0xF0A28497, 0x6D2BD },
	{ 0xF0A28498, 0x6DCCB },
	{ 0xF0A2849A, 0x5BEFB },
	{ 0xF0A2849B, 0x6D2BC },
	{ 0xF0A2849C, 0x5BEF6 },
	{ 0xF0A2849E, 0x5BEF9 },
	{ 0xF0A2849F, 0x6DCCC },
	{ 0xF0A284A0, 0x6DCCD },
	{ 0xF0A284A1, 0x5C5D8 },
	{ 0xF0A284A2, 0x4C3B4 },
	{ 0xF0A284A3, 0x5C5CF },
	{ 0xF0A284A4, 0x5C5D5 },
	{ 0xF0A284A5, 0x6DCCA },
	{ 0xF0A284A6, 0x5C5D4 },
	{ 0xF0A284A7, 0x5C5D7 },
	{ 0xF0A284AB, 0xFC7E2 },
	{ 0xF0A284B0, 0x5C5D9 },
	{ 0xF0A284B1, 0x5C5D0 },
	{ 0xF0A284B2, 0x5C5D6 },
	{ 0xF0A284B3, 0x5C5D1 },
	{ 0xF0A284B4, 0x7A2D7 },
	{ 0xF0A284B5, 0x7A2D9 },
	{ 0xF0A284B6, 0x5CCF4 },
	{ 0xF0A284B7, 0x5CCF3 },
	{ 0xF0A284B8, 0x5CCF5 },
	{ 0xF0A284B9, 0x4C9D7 },
	{ 0xF0A284BA, 0x5CCF6 },
	{ 0xF0A284BC, 0x5CCF8 },
	{ 0xF0A284BD, 0x4C9D6 },
	{ 0xF0A284BE, 0x7A2D6 },
	{ 0xF0A284BF, 0x7A2D5 },
	{ 0xF0A28582, 0x7A2D8 },
	{ 0xF0A28589, 0x5CCF7 },
	{ 0xF0A2858A, 0x5CCF9 },
	{ 0xF0A2858B, 0x5CCF2 },
	{ 0xF0A2858D, 0x7ADD0 },
	{ 0xF0A2858E, 0x5D4BE },
	{ 0xF0A2858F, 0x7ADD2 },
	{ 0xF0A28590, 0x7ADD8 },
	{ 0xF0A28591, 0x5D4BD },
	{ 0xF0A28592, 0x4D0A8 },
	{ 0xF0A28593, 0x7ADD7 },
	{ 0xF0A28594, 0x7ADD6 },
	{ 0xF0A28595, 0x5D4BB },
	{ 0xF0A28596, 0x7ADD1 },
	{ 0xF0A28597, 0x5D4BC },
	{ 0xF0A28599, 0x7ADD4 },
	{ 0xF0A2859A, 0x5D4BF },
	{ 0xF0A2859B, 0x7ADCF },
	{ 0xF0A2859E, 0x4D0AA },
	{ 0xF0A2859F, 0x5DBC1 },
	{ 0xF0A285A0, 0x5DBC2 },
	{ 0xF0A285A1, 0x4D6AC },
	{ 0xF0A285A2, 0x7B7EB },
	{ 0xF0A285A3, 0xFD9FC },
	{ 0xF0A285A6, 0x7B7E9 },
	{ 0xF0A285A8, 0x7B7EA },
	{ 0xF0A285A9, 0x5E1DA },
	{ 0xF0A285AA, 0x5E1D9 },
	{ 0xF0A285AB, 0x5E1D8 },
	{ 0xF0A285AD, 0x7C6E6 },
	{ 0xF0A285AE, 0x4DFDD },
	{ 0xF0A285AF, 0x5E7E7 },
	{ 0xF0A285B0, 0x4DFDC },
	{ 0xF0A285B1, 0x7C6E5 },
	{ 0xF0A285B2, 0x7C6E7 },
	{ 0xF0A285B5, 0x5E7E8 },
	{ 0xF0A285B6, 0xFE2B3 },
	{ 0xF0A285B8, 0x7CDD8 },
	{ 0xF0A285B9, 0x5ECA1 },
	{ 0xF0A285BB, 0x7D3B3 },
	{ 0xF0A285BC, 0x7D7EC },
	{ 0xF0A285BD, 0x5EFFB },
	{ 0xF0A285BE, 0x5F3BD },
	{ 0xF0A285BF, 0x7D7EB },
	{ 0xF0A28683, 0x7DEE2 },
	{ 0xF0A28684, 0x7DEE3 },
	{ 0xF0A28685, 0x5F7D9 },
	{ 0xF0A28687, 0x7E3D0 },
	{ 0xF0A28688, 0x7E3F5 },
	{ 0xF0A28689, 0x4A1F8 },
	{ 0xF0A2868A, 0x6A7C2 },
	{ 0xF0A2868B, 0x5A4A6 },
	{ 0xF0A2868D, 0x4A4A6 },
	{ 0xF0A2868E, 0x6ABA4 },
	{ 0xF0A2868F, 0xFA6ED },
	{ 0xF0A28690, 0xFA6EE },
	{ 0xF0A28691, 0x6B0E9 },
	{ 0xF0A28692, 0x6B0E8 },
	{ 0xF0A28693, 0xFAAD6 },
	{ 0xF0A28699, 0x6B7B5 },
	{ 0xF0A2869A, 0x5B2B7 },
	{ 0xF0A2869B, 0x6C8C2 },
	{ 0xF0A2869C, 0x5B8A3 },
	{ 0xF0A2869F, 0x6D2BF },
	{ 0xF0A286A2, 0x5C5DA },
	{ 0xF0A286A4, 0xFC7E4 },
	{ 0xF0A286AC, 0x7CDD9 },
	{ 0xF0A286AE, 0xFEACE },
	{ 0xF0A286AF, 0x6A1F2 },
	{ 0xF0A286B1, 0x6A1F3 },
	{ 0xF0A286B2, 0x6A2F8 },
	{ 0xF0A286B3, 0x5A1E9 },
	{ 0xF0A286B4, 0x6A2F7 },
	{ 0xF0A286B5, 0xFA1E2 },
	{ 0xF0A286B6, 0x4A2E7 },
	{ 0xF0A286B7, 0x4A4A7 },
	{ 0xF0A286B8, 0x5A4A7 },
	{ 0xF0A286B9, 0xFA4A6 },
	{ 0xF0A286BB, 0x6A9DE },
	{ 0xF0A286BC, 0x6ABA5 },
	{ 0xF0A286BD, 0x5A6A4 },
	{ 0xF0A286BE, 0x5A6A5 },
	{ 0xF0A286BF, 0x6B0EA },
	{ 0xF0A28780, 0x6B0C1 },
	{ 0xF0A28781, 0x4AFA7 },
	{ 0xF0A28786, 0x6B7B6 },
	{ 0xF0A28787, 0x4B1CA },
	{ 0xF0A2878A, 0x6C8C3 },
	{ 0xF0A2878B, 0x5BEFC },
	{ 0xF0A2878C, 0x5C5DB },
	{ 0xF0A2878D, 0x7A2DB },
	{ 0xF0A2878E, 0xFC7E5 },
	{ 0xF0A2878F, 0x6DCCE },
	{ 0xF0A28790, 0xFCEDF },
	{ 0xF0A28791, 0x7A2DC },
	{ 0xF0A28792, 0x7A2DD },
	{ 0xF0A28794, 0x4D6A6 },
	{ 0xF0A28796, 0x7D7ED },
	{ 0xF0A28797, 0x4A2E8 },
	{ 0xF0A28798, 0x5A2DE },
	{ 0xF0A28799, 0x6A4E4 },
	{ 0xF0A2879A, 0x5A2DD },
	{ 0xF0A2879B, 0x6A4E3 },
	{ 0xF0A2879C, 0x6A4E2 },
	{ 0xF0A2879D, 0x6A4E6 },
	{ 0xF0A2879E, 0x4A2E9 },
	{ 0xF0A287A0, 0x6A4E5 },
	{ 0xF0A287A3, 0x6A7C5 },
	{ 0xF0A287A4, 0x5A4AA },
	{ 0xF0A287A5, 0x5A4AC },
	{ 0xF0A287A6, 0x5A4AB },
	{ 0xF0A287A7, 0x5A4A8 },
	{ 0xF0A287A8, 0x5A4A9 },
	{ 0xF0A287A9, 0x6A7C4 },
	{ 0xF0A287AA, 0x6A7C8 },
	{ 0xF0A287AB, 0x6ABA8 },
	{ 0xF0A287AD, 0x6A7C3 },
	{ 0xF0A287AF, 0x6A7C6 },
	{ 0xF0A287B0, 0x5A4AD },
	{ 0xF0A287B2, 0x5A6AC },
	{ 0xF0A287B3, 0x5A6A8 },
	{ 0xF0A287B4, 0x5A6A7 },
	{ 0xF0A287B5, 0x5A6AB },
	{ 0xF0A287B6, 0x5A6AA },
	{ 0xF0A287B7, 0x4A6B9 },
	{ 0xF0A287B8, 0x6ABA6 },
	{ 0xF0A287B9, 0x6ABA9 },
	{ 0xF0A287BA, 0x6ABA7 },
	{ 0xF0A287BB, 0x4A6BE },
	{ 0xF0A287BC, 0x6ABAA },
	{ 0xF0A287BD, 0xFA6F0 },
	{ 0xF0A287BE, 0xFA6F1 },
	{ 0xF0A287BF, 0xFA6F2 },
	{ 0xF0A28880, 0xFA6F3 },
	{ 0xF0A28881, 0xFA6F4 },
	{ 0xF0A28882, 0x5A6A9 },
	{ 0xF0A28884, 0x5A6AD },
	{ 0xF0A28885, 0x6ABAB },
	{ 0xF0A28887, 0x5A9A8 },
	{ 0xF0A28888, 0x5A9AA },
	{ 0xF0A28889, 0x4A9A7 },
	{ 0xF0A2888A, 0x6B0EC },
	{ 0xF0A2888B, 0x5A9A9 },
	{ 0xF0A2888C, 0x6B0ED },
	{ 0xF0A2888D, 0xFAAD7 },
	{ 0xF0A2888E, 0xFAAD9 },
	{ 0xF0A2888F, 0xFAAD8 },
	{ 0xF0A28890, 0xFAADA },
	{ 0xF0A28891, 0xFAADB },
	{ 0xF0A28892, 0xFAADC },
	{ 0xF0A28897, 0x6B0EB },
	{ 0xF0A28899, 0x5ADBD },
	{ 0xF0A2889A, 0x5ADC0 },
	{ 0xF0A2889B, 0x5ADBE },
	{ 0xF0A2889C, 0x5ADC1 },
	{ 0xF0A2889D, 0x5ADBB },
	{ 0xF0A2889E, 0x6B7BA },
	{ 0xF0A2889F, 0x6B7BB },
	{ 0xF0A288A0, 0x4ACEE },
	{ 0xF0A288A1, 0x5ADC2 },
	{ 0xF0A288A2, 0x5ADBF },
	{ 0xF0A288A3, 0x6B7BC },
	{ 0xF0A288A4, 0x5ADBC },
	{ 0xF0A288A5, 0x6B7B9 },
	{ 0xF0A288A8, 0xFAFB7 },
	{ 0xF0A288AC, 0x6B7B7 },
	{ 0xF0A288AD, 0x6B7B8 },
	{ 0xF0A288B2, 0x5ACFB },
	{ 0xF0A288B3, 0x5B2C4 },
	{ 0xF0A288B4, 0x5B2BB },
	{ 0xF0A288B5, 0x5B2B9 },
	{ 0xF0A288B6, 0x4B1CD },
	{ 0xF0A288B7, 0x6BFC3 },
	{ 0xF0A288B8, 0x5B2C2 },
	{ 0xF0A288B9, 0x6BFC8 },
	{ 0xF0A288BA, 0x6BFBE },
	{ 0xF0A288BB, 0x5B2BD },
	{ 0xF0A288BC, 0x5B2BC },
	{ 0xF0A288BD, 0x5B2BF },
	{ 0xF0A288BE, 0x5B2BE },
	{ 0xF0A288BF, 0x6BFBF },
	{ 0xF0A28980, 0x6BFC0 },
	{ 0xF0A28981, 0x5B2C1 },
	{ 0xF0A28982, 0x5B2B8 },
	{ 0xF0A28983, 0x4B1D0 },
	{ 0xF0A28984, 0x6BFC4 },
	{ 0xF0A28985, 0x5B2C3 },
	{ 0xF0A28986, 0x5B8A8 },
	{ 0xF0A28988, 0x6BFC1 },
	{ 0xF0A2898A, 0xFB4CD },
	{ 0xF0A2898B, 0xFB4CE },
	{ 0xF0A2898C, 0xFB4CF },
	{ 0xF0A2898D, 0xFB4D0 },
	{ 0xF0A2898E, 0xFB4D1 },
	{ 0xF0A2898F, 0xFB4D2 },
	{ 0xF0A28990, 0xFB4D3 },
	{ 0xF0A28995, 0x6BFC7 },
	{ 0xF0A28996, 0x6C6BD },
	{ 0xF0A28998, 0x5B2BA },
	{ 0xF0A28999, 0x6BFC2 },
	{ 0xF0A2899A, 0x5B2C0 },
	{ 0xF0A2899B, 0x6C8CA },
	{ 0xF0A2899C, 0x4B1CB },
	{ 0xF0A2899D, 0x5B8AB },
	{ 0xF0A2899E, 0x5B8AC },
	{ 0xF0A2899F, 0x5B8AD },
	{ 0xF0A289A0, 0x6C8CB },
	{ 0xF0A289A1, 0x6C8CE },
	{ 0xF0A289A2, 0x5B8A7 },
	{ 0xF0A289A3, 0x6C8CD },
	{ 0xF0A289A4, 0x4B7C2 },
	{ 0xF0A289A5, 0x5B8AA },
	{ 0xF0A289A6, 0x5B8A6 },
	{ 0xF0A289A7, 0x6C8C9 },
	{ 0xF0A289A8, 0x4B7C3 },
	{ 0xF0A289A9, 0x5B8A5 },
	{ 0xF0A289AA, 0x6D2C4 },
	{ 0xF0A289AB, 0x6C8C6 },
	{ 0xF0A289AC, 0x6C8C7 },
	{ 0xF0A289AD, 0x5B8A4 },
	{ 0xF0A289AE, 0xFBAE5 },
	{ 0xF0A289AF, 0xFBAE7 },
	{ 0xF0A289B0, 0xFBAE8 },
	{ 0xF0A289B1, 0xFBAE9 },
	{ 0xF0A289B2, 0xFBAEA },
	{ 0xF0A289B4, 0x6C8C8 },
	{ 0xF0A289B6, 0x6C8CC },
	{ 0xF0A289BC, 0xFBAE6 },
	{ 0xF0A289BF, 0x4BDAB },
	{ 0xF0A28A80, 0x5BFA5 },
	{ 0xF0A28A81, 0x4BDAC },
	{ 0xF0A28A82, 0x6D2C1 },
	{ 0xF0A28A83, 0x6D2C2 },
	{ 0xF0A28A84, 0x5BFA2 },
	{ 0xF0A28A85, 0x5BFA3 },
	{ 0xF0A28A86, 0x6D2C7 },
	{ 0xF0A28A87, 0x5BEFD },
	{ 0xF0A28A89, 0x6D2C5 },
	{ 0xF0A28A8A, 0xFC1BA },
	{ 0xF0A28A8B, 0xFC1BB },
	{ 0xF0A28A8C, 0xFC1BC },
	{ 0xF0A28A8E, 0x6D2C3 },
	{ 0xF0A28A90, 0x6D2C8 },
	{ 0xF0A28A92, 0x5BFA4 },
	{ 0xF0A28A93, 0x5BEFE },
	{ 0xF0A28A94, 0x6D2C6 },
	{ 0xF0A28A95, 0x4C3B8 },
	{ 0xF0A28A96, 0x5C5DC },
	{ 0xF0A28A97, 0x4C3B7 },
	{ 0xF0A28A98, 0x5C5DE },
	{ 0xF0A28A99, 0x6DCD0 },
	{ 0xF0A28A9B, 0x5C5E0 },
	{ 0xF0A28A9C, 0x5C5DF },
	{ 0xF0A28A9D, 0x6DCCF },
	{ 0xF0A28A9E, 0xFC7E7 },
	{ 0xF0A28A9F, 0xFC7E8 },
	{ 0xF0A28AA0, 0xFC7E9 },
	{ 0xF0A28AA1, 0xFC7EA },
	{ 0xF0A28AA2, 0xFC7EB },
	{ 0xF0A28AA3, 0xFC7EC },
	{ 0xF0A28AA4, 0xFC7ED },
	{ 0xF0A28AA5, 0xFC7EE },
	{ 0xF0A28AA6, 0xFC7EF },
	{ 0xF0A28AA8, 0x6DCD1 },
	{ 0xF0A28AAA, 0x6E0B1 },
	{ 0xF0A28AAC, 0xFCAD4 },
	{ 0xF0A28AAD, 0x7A2DE },
	{ 0xF0A28AAE, 0x4C9DA },
	{ 0xF0A28AAF, 0x4B7BF },
	{ 0xF0A28AB0, 0x4C9D8 },
	{ 0xF0A28AB1, 0x5CCFA },
	{ 0xF0A28AB2, 0x4C9D9 },
	{ 0xF0A28AB3, 0x7ADD9 },
	{ 0xF0A28AB4, 0x7A2E2 },
	{ 0xF0A28AB5, 0x5CCFC },
	{ 0xF0A28AB6, 0x5CCFE },
	{ 0xF0A28AB7, 0xFCEE0 },
	{ 0xF0A28AB8, 0xFCEE2 },
	{ 0xF0A28AB9, 0xFCEE3 },
	{ 0xF0A28ABA, 0x7A2DF },
	{ 0xF0A28ABB, 0x7A2E1 },
	{ 0xF0A28ABC, 0x7A2E3 },
	{ 0xF0A28B81, 0x7A2E0 },
	{ 0xF0A28B82, 0x5CCFB },
	{ 0xF0A28B83, 0x5D4C1 },
	{ 0xF0A28B84, 0x5CCFD },
	{ 0xF0A28B85, 0x5D4C3 },
	{ 0xF0A28B86, 0x5D4C0 },
	{ 0xF0A28B87, 0x4D0AD },
	{ 0xF0A28B8C, 0x5D4C4 },
	{ 0xF0A28B8D, 0xFD4BF },
	{ 0xF0A28B8E, 0xFD4C0 },
	{ 0xF0A28B8F, 0xFD4C1 },
	{ 0xF0A28B90, 0xFD4C2 },
	{ 0xF0A28B91, 0x7B7EE },
	{ 0xF0A28B92, 0x5DBC4 },
	{ 0xF0A28B93, 0x7B7EC },
	{ 0xF0A28B94, 0x7B7ED },
	{ 0xF0A28B95, 0xFD9FE },
	{ 0xF0A28B96, 0xFDAA1 },
	{ 0xF0A28B97, 0xFDAA2 },
	{ 0xF0A28B98, 0xFDAA3 },
	{ 0xF0A28B9A, 0x5DBC3 },
	{ 0xF0A28B9C, 0x7B7EF },
	{ 0xF0A28B9D, 0x5DBC5 },
	{ 0xF0A28BA1, 0x7BFD1 },
	{ 0xF0A28BA2, 0x7BFCE },
	{ 0xF0A28BA3, 0x5E1DB },
	{ 0xF0A28BA4, 0xFDEDA },
	{ 0xF0A28BA5, 0xFDEDC },
	{ 0xF0A28BA6, 0x7BFCD },
	{ 0xF0A28BA7, 0x7BFCF },
	{ 0xF0A28BAA, 0x7BFCC },
	{ 0xF0A28BAB, 0xFDEDB },
	{ 0xF0A28BAD, 0x7BFD0 },
	{ 0xF0A28BAF, 0x7C6E8 },
	{ 0xF0A28BB0, 0x7C6E9 },
	{ 0xF0A28BB1, 0x5E1DC },
	{ 0xF0A28BB2, 0x5E7E9 },
	{ 0xF0A28BB5, 0xFE2B4 },
	{ 0xF0A28BB6, 0xFE2B5 },
	{ 0xF0A28BB7, 0xFE2B6 },
	{ 0xF0A28BB8, 0x5E7EA },
	{ 0xF0A28BBB, 0x5ECA4 },
	{ 0xF0A28BBC, 0x5ECA3 },
	{ 0xF0A28BBD, 0x7CDDD },
	{ 0xF0A28BBE, 0x7CDDB },
	{ 0xF0A28BBF, 0x5ECA2 },
	{ 0xF0A28C80, 0x7CDDA },
	{ 0xF0A28C82, 0x7CDDC },
	{ 0xF0A28C83, 0x7CDDE },
	{ 0xF0A28C84, 0x4E6BC },
	{ 0xF0A28C86, 0x7D3B4 },
	{ 0xF0A28C87, 0x7D3E1 },
	{ 0xF0A28C88, 0x5F3BE },
	{ 0xF0A28C89, 0x7D7EE },
	{ 0xF0A28C8B, 0x7D7EF },
	{ 0xF0A28C8D, 0x5F5EA },
	{ 0xF0A28C8F, 0xFEACF },
	{ 0xF0A28C91, 0x7DBCD },
	{ 0xF0A28C92, 0x7DEE4 },
	{ 0xF0A28C93, 0x7E2B6 },
	{ 0xF0A28C94, 0x5FAE8 },
	{ 0xF0A28C95, 0x5FAE7 },
	{ 0xF0A28C96, 0xFECFB },
	{ 0xF0A28C97, 0xFA1E3 },
	{ 0xF0A28C98, 0xFA2CB },
	{ 0xF0A28C99, 0xFA2CC },
	{ 0xF0A28C9B, 0x6ABAC },
	{ 0xF0A28C9C, 0xFA4A7 },
	{ 0xF0A28C9D, 0x6ABAD },
	{ 0xF0A28C9E, 0x6ABAE },
	{ 0xF0A28CA0, 0xFAFB9 },
	{ 0xF0A28CA2, 0xFAFBB },
	{ 0xF0A28CA3, 0xFAFBC },
	{ 0xF0A28CA5, 0xFAFBA },
	{ 0xF0A28CA6, 0x5B2C5 },
	{ 0xF0A28CA7, 0xFB4D4 },
	{ 0xF0A28CA8, 0x6C8CF },
	{ 0xF0A28CA9, 0xFBAEB },
	{ 0xF0A28CAA, 0xFBAEC },
	{ 0xF0A28CAB, 0x5BFA6 },
	{ 0xF0A28CAC, 0x6A1BF },
	{ 0xF0A28CAD, 0x6A1F5 },
	{ 0xF0A28CAF, 0x6A2F9 },
	{ 0xF0A28CB1, 0x6A7C9 },
	{ 0xF0A28CB3, 0x4A4AA },
	{ 0xF0A28CB4, 0x6B0F0 },
	{ 0xF0A28CB5, 0x6A7CD },
	{ 0xF0A28CB6, 0xFA4A8 },
	{ 0xF0A28CB8, 0x6A7CB },
	{ 0xF0A28CBA, 0x6A7CE },
	{ 0xF0A28CBB, 0x4A6BF },
	{ 0xF0A28CBC, 0x6ABB0 },
	{ 0xF0A28CBD, 0x5A6AE },
	{ 0xF0A28CBE, 0x6ABB1 },
	{ 0xF0A28CBF, 0x3AAB9 },
	{ 0xF0A28D81, 0x4A7C1 },
	{ 0xF0A28D82, 0x6B5A3 },
	{ 0xF0A28D83, 0x6B0F2 },
	{ 0xF0A28D84, 0x6B0F3 },
	{ 0xF0A28D85, 0x6B0F1 },
	{ 0xF0A28D86, 0x6B0EF },
	{ 0xF0A28D8A, 0x6B0EE },
	{ 0xF0A28D8D, 0x6B7BF },
	{ 0xF0A28D8E, 0x6B7BE },
	{ 0xF0A28D8F, 0x4ACEF },
	{ 0xF0A28D90, 0x6B7BD },
	{ 0xF0A28D92, 0x6B7C0 },
	{ 0xF0A28D94, 0x6BFC9 },
	{ 0xF0A28D95, 0x6BFCA },
	{ 0xF0A28D96, 0x6BFCB },
	{ 0xF0A28D97, 0x6BFCC },
	{ 0xF0A28D98, 0x6BFCD },
	{ 0xF0A28D99, 0x6BFCE },
	{ 0xF0A28D9A, 0x4B7C4 },
	{ 0xF0A28D9B, 0x6C8D0 },
	{ 0xF0A28D9C, 0x6C8D4 },
	{ 0xF0A28D9D, 0x6C8D3 },
	{ 0xF0A28D9E, 0x6C8D1 },
	{ 0xF0A28D9F, 0xFBAED },
	{ 0xF0A28DA0, 0x6C8D2 },
	{ 0xF0A28DA2, 0x6D2C9 },
	{ 0xF0A28DA3, 0x5BFA7 },
	{ 0xF0A28DA4, 0xFC1BD },
	{ 0xF0A28DA6, 0x6DCD3 },
	{ 0xF0A28DA7, 0x6DCD4 },
	{ 0xF0A28DA8, 0x6DCD2 },
	{ 0xF0A28DAB, 0x5C5E1 },
	{ 0xF0A28DAC, 0x7A2E4 },
	{ 0xF0A28DAE, 0x7ADDA },
	{ 0xF0A28DAF, 0x7ADDC },
	{ 0xF0A28DB0, 0x4D0AF },
	{ 0xF0A28DB1, 0x5D4C5 },
	{ 0xF0A28DB2, 0x7B7F1 },
	{ 0xF0A28DB3, 0x7B7F0 },
	{ 0xF0A28DB6, 0x7D7F0 },
	{ 0xF0A28DB7, 0x7E3D1 },
	{ 0xF0A28DB8, 0x7E3D2 },
	{ 0xF0A28DB9, 0x7E5B6 },
	{ 0xF0A28DBA, 0x6A1C0 },
	{ 0xF0A28DBB, 0x6A1F6 },
	{ 0xF0A28DBE, 0xFA2CD },
	{ 0xF0A28DBF, 0x4A4AB },
	{ 0xF0A28E80, 0x6A7D0 },
	{ 0xF0A28E81, 0x6A7CF },
	{ 0xF0A28E83, 0x5A4AE },
	{ 0xF0A28E84, 0x6ABB2 },
	{ 0xF0A28E86, 0x6B0F6 },
	{ 0xF0A28E87, 0x6B0F5 },
	{ 0xF0A28E8A, 0x6B0F7 },
	{ 0xF0A28E8C, 0x5AEE8 },
	{ 0xF0A28E8D, 0x6BFCF },
	{ 0xF0A28E8E, 0x5B8AE },
	{ 0xF0A28E90, 0x6D2CA },
	{ 0xF0A28E91, 0x6DCD5 },
	{ 0xF0A28E92, 0x7A2E5 },
	{ 0xF0A28E93, 0x7ADDD },
	{ 0xF0A28E98, 0x5A1AA },
	{ 0xF0A28E99, 0x5A1C7 },
	{ 0xF0A28E9A, 0x6A1F8 },
	{ 0xF0A28E9C, 0x6A1FC },
	{ 0xF0A28E9D, 0x6A1F7 },
	{ 0xF0A28E9F, 0x6A1FA },
	{ 0xF0A28EA0, 0x6A1FB },
	{ 0xF0A28EA2, 0x6A3A1 },
	{ 0xF0A28EA3, 0x6A3A2 },
	{ 0xF0A28EA4, 0x6A2FC },
	{ 0xF0A28EA5, 0x6A2FA },
	{ 0xF0A28EA6, 0x6A3A3 },
	{ 0xF0A28EA7, 0x6A2FB },
	{ 0xF0A28EA8, 0x6A2FD },
	{ 0xF0A28EA9, 0x6A2FE },
	{ 0xF0A28EAA, 0x5A1EA },
	{ 0xF0A28EAB, 0x5A2E0 },
	{ 0xF0A28EAD, 0x5A2DF },
	{ 0xF0A28EB0, 0x6A4E8 },
	{ 0xF0A28EB1, 0x6A4E9 },
	{ 0xF0A28EB2, 0x6A4EA },
	{ 0xF0A28EB6, 0x6A4EB },
	{ 0xF0A28EB7, 0x5A4AF },
	{ 0xF0A28EB8, 0x6A7D1 },
	{ 0xF0A28EB9, 0x5A4B1 },
	{ 0xF0A28EBA, 0x6A7D3 },
	{ 0xF0A28EBB, 0x5A4B0 },
	{ 0xF0A28EBC, 0xFA4A9 },
	{ 0xF0A28EBE, 0xFA4AA },
	{ 0xF0A28EBF, 0xFA4AB },
	{ 0xF0A28F80, 0xFA4AC },
	{ 0xF0A28F81, 0x6A7D2 },
	{ 0xF0A28F85, 0x5A4B2 },
	{ 0xF0A28F86, 0x5A6AF },
	{ 0xF0A28F87, 0x6ABB6 },
	{ 0xF0A28F88, 0x6ABB3 },
	{ 0xF0A28F89, 0x6ABB4 },
	{ 0xF0A28F92, 0x6ABB7 },
	{ 0xF0A28F93, 0x6ABB5 },
	{ 0xF0A28F94, 0x6B0FE },
	{ 0xF0A28F95, 0x5A9AC },
	{ 0xF0A28F96, 0x6B0FD },
	{ 0xF0A28F97, 0x4A9B0 },
	{ 0xF0A28F98, 0x6B0F9 },
	{ 0xF0A28F99, 0x5A9AB },
	{ 0xF0A28F9A, 0x6B0F8 },
	{ 0xF0A28FA4, 0x5ADC4 },
	{ 0xF0A28FA6, 0x5ADC3 },
	{ 0xF0A28FA7, 0x5ADC5 },
	{ 0xF0A28FA8, 0x6B7C3 },
	{ 0xF0A28FA9, 0x6B7C1 },
	{ 0xF0A28FAA, 0x5ADC6 },
	{ 0xF0A28FAB, 0xFAFBD },
	{ 0xF0A28FAC, 0x6B7C2 },
	{ 0xF0A28FAE, 0x5B2CA },
	{ 0xF0A28FAF, 0x5B2C8 },
	{ 0xF0A28FB0, 0x5B2C9 },
	{ 0xF0A28FB1, 0x6BFD6 },
	{ 0xF0A28FB2, 0x6BFD0 },
	{ 0xF0A28FB3, 0x4A9AF },
	{ 0xF0A28FB4, 0x6C8D5 },
	{ 0xF0A28FB5, 0x6BFD2 },
	{ 0xF0A28FB6, 0x6BFD3 },
	{ 0xF0A28FB7, 0x5B2C7 },
	{ 0xF0A28FB8, 0x6BFD1 },
	{ 0xF0A28FB9, 0xFB4D5 },
	{ 0xF0A28FBA, 0xFB4D6 },
	{ 0xF0A28FBB, 0xFB4D7 },
	{ 0xF0A28FBC, 0x6BFD4 },
	{ 0xF0A28FBD, 0x6BFD7 },
	{ 0xF0A28FBE, 0x6BFD5 },
	{ 0xF0A29080, 0x6C8D6 },
	{ 0xF0A29081, 0x6C8D9 },
	{ 0xF0A29082, 0x5B8AF },
	{ 0xF0A29083, 0x5B8B2 },
	{ 0xF0A29084, 0x5B8B1 },
	{ 0xF0A29085, 0x6C8DA },
	{ 0xF0A29086, 0x5B8B0 },
	{ 0xF0A29087, 0x6C8D8 },
	{ 0xF0A29088, 0x6C8D7 },
	{ 0xF0A2908A, 0x5BFA8 },
	{ 0xF0A2908B, 0x4BDB1 },
	{ 0xF0A2908C, 0x6D2CB },
	{ 0xF0A2908D, 0xFC1C0 },
	{ 0xF0A2908F, 0x6D2CC },
	{ 0xF0A29092, 0x5C5E2 },
	{ 0xF0A29093, 0x6DCD6 },
	{ 0xF0A29094, 0x5C5E3 },
	{ 0xF0A29095, 0x6DCD7 },
	{ 0xF0A29096, 0x6DCD9 },
	{ 0xF0A29098, 0xFC7F0 },
	{ 0xF0A29099, 0x6DCDA },
	{ 0xF0A2909D, 0x6DCD8 },
	{ 0xF0A2909E, 0x5CDA1 },
	{ 0xF0A2909F, 0x5CDA2 },
	{ 0xF0A290A0, 0x4C9E0 },
	{ 0xF0A290A1, 0x7A2E6 },
	{ 0xF0A290A2, 0xFCEE4 },
	{ 0xF0A290A3, 0xFCEE5 },
	{ 0xF0A290A4, 0x7A2E7 },
	{ 0xF0A290A5, 0x7ADDF },
	{ 0xF0A290A6, 0x5D4C6 },
	{ 0xF0A290A7, 0x4D0B0 },
	{ 0xF0A290A8, 0x7ADE0 },
	{ 0xF0A290A9, 0x7ADDE },
	{ 0xF0A290AC, 0x7B7F3 },
	{ 0xF0A290AD, 0x7B7F2 },
	{ 0xF0A290AF, 0x7B7F4 },
	{ 0xF0A290B0, 0xFDAA4 },
	{ 0xF0A290B2, 0x4DBA2 },
	{ 0xF0A290B3, 0x5E1DE },
	{ 0xF0A290B4, 0x7BFD2 },
	{ 0xF0A290B5, 0xFDEDD },
	{ 0xF0A290B7, 0x5E1DD },
	{ 0xF0A290B8, 0x7C6ED },
	{ 0xF0A290B9, 0x7C6EB },
	{ 0xF0A290BA, 0x7C6EF },
	{ 0xF0A290BB, 0x7C6EA },
	{ 0xF0A290BC, 0x7C6EC },
	{ 0xF0A290BE, 0x5E7EB },
	{ 0xF0A290BF, 0x5ECA5 },
	{ 0xF0A29180, 0x7CDDF },
	{ 0xF0A29181, 0x4DFDF },
	{ 0xF0A29182, 0x7CDE1 },
	{ 0xF0A29183, 0x7CDE0 },
	{ 0xF0A29184, 0x5ECA6 },
	{ 0xF0A29186, 0x5EFFC },
	{ 0xF0A29187, 0x5EFFD },
	{ 0xF0A29188, 0x4E6BD },
	{ 0xF0A29189, 0x7D3B5 },
	{ 0xF0A2918A, 0x5F3BF },
	{ 0xF0A2918B, 0x7E0BC },
	{ 0xF0A2918C, 0x7E0EF },
	{ 0xF0A2918D, 0x7E4C6 },
	{ 0xF0A29190, 0x6A4EE },
	{ 0xF0A29191, 0x6A4EC },
	{ 0xF0A29192, 0x6A4ED },
	{ 0xF0A29193, 0x5A4B3 },
	{ 0xF0A29194, 0x6B1A1 },
	{ 0xF0A29195, 0x6ABB8 },
	{ 0xF0A29196, 0x6ADB2 },
	{ 0xF0A29197, 0x6B1A4 },
	{ 0xF0A29198, 0x6B7C4 },
	{ 0xF0A29199, 0x6B1A2 },
	{ 0xF0A2919A, 0x6B1A3 },
	{ 0xF0A2919B, 0x6B7C6 },
	{ 0xF0A2919C, 0x6B7C5 },
	{ 0xF0A2919E, 0x6BFD8 },
	{ 0xF0A291A1, 0x6CFA1 },
	{ 0xF0A291A2, 0x5B8B3 },
	{ 0xF0A291A3, 0x6C8DC },
	{ 0xF0A291A4, 0x6C8DB },
	{ 0xF0A291A6, 0x5BFAA },
	{ 0xF0A291A8, 0x6DCDC },
	{ 0xF0A291A9, 0x6DCDF },
	{ 0xF0A291AA, 0x6DCDD },
	{ 0xF0A291AB, 0x6DCDB },
	{ 0xF0A291AD, 0x6DCDE },
	{ 0xF0A291AF, 0x7ADE1 },
	{ 0xF0A291B0, 0x7ADCE },
	{ 0xF0A291B1, 0x4D0B2 },
	{ 0xF0A291B2, 0x7B7F5 },
	{ 0xF0A291B3, 0x7BFD5 },
	{ 0xF0A291B5, 0x7BFD4 },
	{ 0xF0A291B6, 0x7BFD3 },
	{ 0xF0A291B7, 0x7C6F2 },
	{ 0xF0A291B8, 0x7C6F0 },
	{ 0xF0A291B9, 0x7C6F1 },
	{ 0xF0A291BD, 0x7D7F1 },
	{ 0xF0A291BE, 0x7DBCE },
	{ 0xF0A291BF, 0x7E2B7 },
	{ 0xF0A29280, 0x6A3A5 },
	{ 0xF0A29281, 0x6A3A4 },
	{ 0xF0A29282, 0xFA1E4 },
	{ 0xF0A29283, 0x6A4F1 },
	{ 0xF0A29284, 0x6A4EF },
	{ 0xF0A29287, 0xFA4AD },
	{ 0xF0A29288, 0x6A7D4 },
	{ 0xF0A29289, 0x5A6B0 },
	{ 0xF0A2928A, 0x6ABBB },
	{ 0xF0A2928C, 0x6ABBA },
	{ 0xF0A2928F, 0x6B7C7 },
	{ 0xF0A29290, 0x4ACF4 },
	{ 0xF0A29291, 0x4ACF3 },
	{ 0xF0A29294, 0x5B5E0 },
	{ 0xF0A29295, 0x6BFDD },
	{ 0xF0A29296, 0x6BFD9 },
	{ 0xF0A29297, 0x6BFDA },
	{ 0xF0A29298, 0xFB4D8 },
	{ 0xF0A29299, 0xFB4D9 },
	{ 0xF0A2929A, 0xFB4DA },
	{ 0xF0A2929B, 0x6BFDC },
	{ 0xF0A2929C, 0x6BFDB },
	{ 0xF0A2929D, 0x5B2CB },
	{ 0xF0A2929E, 0x6C8DD },
	{ 0xF0A2929F, 0x6C8E0 },
	{ 0xF0A292A0, 0x6C8DE },
	{ 0xF0A292A1, 0x6C8DF },
	{ 0xF0A292A2, 0xFBAEE },
	{ 0xF0A292A4, 0x6D2D1 },
	{ 0xF0A292A5, 0x6D2CE },
	{ 0xF0A292A6, 0x6D2D0 },
	{ 0xF0A292A7, 0x6D2CF },
	{ 0xF0A292A8, 0xFC1C1 },
	{ 0xF0A292A9, 0x4C3BC },
	{ 0xF0A292AA, 0x6DCE0 },
	{ 0xF0A292AB, 0x7A2EB },
	{ 0xF0A292AC, 0x7A2EC },
	{ 0xF0A292AD, 0x7A2E9 },
	{ 0xF0A292AE, 0x7A2EA },
	{ 0xF0A292AF, 0x5CDA3 },
	{ 0xF0A292B0, 0x4D0B3 },
	{ 0xF0A292B2, 0x5D4C7 },
	{ 0xF0A292B3, 0x7ADE4 },
	{ 0xF0A292B4, 0x7B7F6 },
	{ 0xF0A292B5, 0x7BFD6 },
	{ 0xF0A292B6, 0xFE7D4 },
	{ 0xF0A292B7, 0x7CDE2 },
	{ 0xF0A292B8, 0x7D3B6 },
	{ 0xF0A292B9, 0x5F3C1 },
	{ 0xF0A292BB, 0xFECA7 },
	{ 0xF0A292BD, 0x6A1FD },
	{ 0xF0A292BE, 0x5A1EB },
	{ 0xF0A292BF, 0x4A1F9 },
	{ 0xF0A29380, 0x5A2E1 },
	{ 0xF0A29382, 0x4A2EE },
	{ 0xF0A29383, 0x5A2E2 },
	{ 0xF0A29384, 0x5A4B4 },
	{ 0xF0A29385, 0x6A7D8 },
	{ 0xF0A29386, 0x5A4B5 },
	{ 0xF0A29387, 0x6A7D7 },
	{ 0xF0A29388, 0x6A7D9 },
	{ 0xF0A29389, 0x6A7DB },
	{ 0xF0A2938A, 0x6A7D6 },
	{ 0xF0A2938B, 0x5A4B6 },
	{ 0xF0A2938F, 0x6A7D5 },
	{ 0xF0A29390, 0x6A7DA },
	{ 0xF0A29392, 0x5A6B3 },
	{ 0xF0A29393, 0x6ABBD },
	{ 0xF0A29394, 0x5A6B1 },
	{ 0xF0A29395, 0x6ABBC },
	{ 0xF0A29396, 0x5A6B2 },
	{ 0xF0A29397, 0x5A9AD },
	{ 0xF0A29398, 0x6ABBF },
	{ 0xF0A2939C, 0x4A9B3 },
	{ 0xF0A2939D, 0x6B1A6 },
	{ 0xF0A2939E, 0x5A9B0 },
	{ 0xF0A2939F, 0x5A9AE },
	{ 0xF0A293A0, 0x6B1A8 },
	{ 0xF0A293A2, 0x5A9B2 },
	{ 0xF0A293A3, 0x5A9B1 },
	{ 0xF0A293A5, 0xFAADE },
	{ 0xF0A293A9, 0x6B1A7 },
	{ 0xF0A293AA, 0x6B7CD },
	{ 0xF0A293AB, 0x4ACF9 },
	{ 0xF0A293AC, 0x4ACF7 },
	{ 0xF0A293AD, 0x4ACFC },
	{ 0xF0A293AE, 0x4ACF5 },
	{ 0xF0A293AF, 0x5ADCB },
	{ 0xF0A293B0, 0x5ADC9 },
	{ 0xF0A293B1, 0x4ACF8 },
	{ 0xF0A293B2, 0x4ACFA },
	{ 0xF0A293B3, 0x4ACF6 },
	{ 0xF0A293B4, 0x4ACFB },
	{ 0xF0A293B5, 0x5ADCA },
	{ 0xF0A293B6, 0x6B7C9 },
	{ 0xF0A293B7, 0x6B7CF },
	{ 0xF0A293B8, 0x6B7CC },
	{ 0xF0A293B9, 0xFAFBF },
	{ 0xF0A293BA, 0xFAFC0 },
	{ 0xF0A293BC, 0x6B7CB },
	{ 0xF0A293BD, 0x6B7D0 },
	{ 0xF0A293BE, 0x6B7CE },
	{ 0xF0A29480, 0x6B7CA },
	{ 0xF0A29481, 0x4B1D6 },
	{ 0xF0A29482, 0x5B2CF },
	{ 0xF0A29483, 0x6BFE8 },
	{ 0xF0A29484, 0x6BFE1 },
	{ 0xF0A29486, 0x5B2CC },
	{ 0xF0A29487, 0x5B2D1 },
	{ 0xF0A29488, 0x5B2CE },
	{ 0xF0A29489, 0x6BFE0 },
	{ 0xF0A2948A, 0x5B2D0 },
	{ 0xF0A2948B, 0x4B1D8 },
	{ 0xF0A2948C, 0x6BFE7 },
	{ 0xF0A2948D, 0x6BFE5 },
	{ 0xF0A2948E, 0x6BFE2 },
	{ 0xF0A2948F, 0x4B1D9 },
	{ 0xF0A29490, 0x6BFE6 },
	{ 0xF0A29491, 0x5B2CD },
	{ 0xF0A29498, 0x6BFE4 },
	{ 0xF0A2949A, 0x6BFDF },
	{ 0xF0A2949C, 0x6BFE3 },
	{ 0xF0A2949D, 0x6C8E4 },
	{ 0xF0A2949E, 0xFB4DC },
	{ 0xF0A2949F, 0x4B7C6 },
	{ 0xF0A294A0, 0x5B8B6 },
	{ 0xF0A294A1, 0x5B8B5 },
	{ 0xF0A294A2, 0x5B8BB },
	{ 0xF0A294A3, 0x5B8BA },
	{ 0xF0A294A4, 0x5B8B7 },
	{ 0xF0A294A5, 0x4B7C7 },
	{ 0xF0A294A6, 0x6C8E1 },
	{ 0xF0A294A7, 0x5B8B4 },
	{ 0xF0A294A8, 0x6C8E3 },
	{ 0xF0A294A9, 0x5B8B8 },
	{ 0xF0A294AA, 0x4B1D5 },
	{ 0xF0A294AB, 0xFBAF0 },
	{ 0xF0A294AD, 0x6C8E2 },
	{ 0xF0A294B0, 0xFBAEF },
	{ 0xF0A294B1, 0x5B8B9 },
	{ 0xF0A294B3, 0x5BFAC },
	{ 0xF0A294B4, 0x5BFAB },
	{ 0xF0A294B5, 0x6D2D2 },
	{ 0xF0A294B6, 0x6D2D4 },
	{ 0xF0A294B7, 0x6D2D7 },
	{ 0xF0A294B8, 0x6D2D3 },
	{ 0xF0A294BB, 0xFC1C2 },
	{ 0xF0A294BC, 0xFC1C3 },
	{ 0xF0A294BD, 0xFC1C4 },
	{ 0xF0A294BE, 0xFC1C5 },
	{ 0xF0A294BF, 0xFC1C6 },
	{ 0xF0A29580, 0xFC1C7 },
	{ 0xF0A29583, 0x6D2D5 },
	{ 0xF0A29587, 0x6D2D6 },
	{ 0xF0A29588, 0x6D6EC },
	{ 0xF0A2958D, 0x5BFAD },
	{ 0xF0A2958E, 0x4BDB2 },
	{ 0xF0A2958F, 0x6DCE6 },
	{ 0xF0A29590, 0x6DCE3 },
	{ 0xF0A29591, 0x5C5E6 },
	{ 0xF0A29592, 0x6DCE2 },
	{ 0xF0A29593, 0x4C3BE },
	{ 0xF0A29594, 0x5C5E5 },
	{ 0xF0A29595, 0x4C3C1 },
	{ 0xF0A29596, 0x4C3C0 },
	{ 0xF0A29597, 0x6DCE1 },
	{ 0xF0A29598, 0x5C5E8 },
	{ 0xF0A29599, 0x5C5EA },
	{ 0xF0A2959A, 0x5C5E4 },
	{ 0xF0A2959B, 0x6DCE8 },
	{ 0xF0A2959C, 0x6DCE9 },
	{ 0xF0A2959D, 0x6DCEA },
	{ 0xF0A2959E, 0x5C5E7 },
	{ 0xF0A2959F, 0x6DCE4 },
	{ 0xF0A295A0, 0xFC7F1 },
	{ 0xF0A295A1, 0xFC7F2 },
	{ 0xF0A295A2, 0xFC7F3 },
	{ 0xF0A295A3, 0xFC7F4 },
	{ 0xF0A295A4, 0xFC7F5 },
	{ 0xF0A295A7, 0x6DCE5 },
	{ 0xF0A295AA, 0x4C9E4 },
	{ 0xF0A295AB, 0x5CDA4 },
	{ 0xF0A295AC, 0x5DBC8 },
	{ 0xF0A295AD, 0x4C9E3 },
	{ 0xF0A295AE, 0x4C9E2 },
	{ 0xF0A295AF, 0x5CDA5 },
	{ 0xF0A295B0, 0x7A2ED },
	{ 0xF0A295B1, 0x7A2EF },
	{ 0xF0A295B3, 0xFCEE6 },
	{ 0xF0A295B4, 0xFCEE7 },
	{ 0xF0A295B6, 0x7A2EE },
	{ 0xF0A295B7, 0x7A2F0 },
	{ 0xF0A295B9, 0x7ADE5 },
	{ 0xF0A295BA, 0x5D4C8 },
	{ 0xF0A295BB, 0x5D4CA },
	{ 0xF0A295BC, 0x7ADE7 },
	{ 0xF0A295BE, 0x7ADE6 },
	{ 0xF0A29681, 0xFD4C4 },
	{ 0xF0A29682, 0xFD4C5 },
	{ 0xF0A29683, 0x7ADE8 },
	{ 0xF0A29684, 0x5D4C9 },
	{ 0xF0A29688, 0x5DBC7 },
	{ 0xF0A29689, 0x7B7F7 },
	{ 0xF0A2968A, 0x4D6B0 },
	{ 0xF0A2968D, 0xFDCDF },
	{ 0xF0A2968E, 0x5DBC6 },
	{ 0xF0A2968F, 0x5E1E0 },
	{ 0xF0A29690, 0x7BFD7 },
	{ 0xF0A29691, 0x5E1DF },
	{ 0xF0A29692, 0x7BFD8 },
	{ 0xF0A29693, 0xFDEDE },
	{ 0xF0A29697, 0x5E1E1 },
	{ 0xF0A29698, 0x7C6F3 },
	{ 0xF0A29699, 0x7C6F5 },
	{ 0xF0A2969A, 0x7C6F6 },
	{ 0xF0A2969B, 0x7CDA2 },
	{ 0xF0A2969C, 0x7C6F4 },
	{ 0xF0A2969D, 0x5ECA7 },
	{ 0xF0A2969E, 0x4E3BE },
	{ 0xF0A2969F, 0x4E3BD },
	{ 0xF0A296A0, 0xFE5AA },
	{ 0xF0A296A2, 0x7CDE3 },
	{ 0xF0A296A3, 0x7D3B7 },
	{ 0xF0A296A4, 0x5EFFE },
	{ 0xF0A296A5, 0x7D7F2 },
	{ 0xF0A296A6, 0x4EAC7 },
	{ 0xF0A296A7, 0x5F9A8 },
	{ 0xF0A296A9, 0x5A1B1 },
	{ 0xF0A296AA, 0x6A2A1 },
	{ 0xF0A296AB, 0x4A2EF },
	{ 0xF0A296AC, 0x5A1EC },
	{ 0xF0A296AD, 0x6A3A6 },
	{ 0xF0A296B0, 0xFA2CF },
	{ 0xF0A296B2, 0x6A4F5 },
	{ 0xF0A296B3, 0x5A2E3 },
	{ 0xF0A296B4, 0x6A7E0 },
	{ 0xF0A296B5, 0x5A2E9 },
	{ 0xF0A296B6, 0x6A7DD },
	{ 0xF0A296B7, 0x5A2E4 },
	{ 0xF0A296B8, 0x6A4F3 },
	{ 0xF0A296B9, 0x6A4F4 },
	{ 0xF0A296BA, 0x5A2E5 },
	{ 0xF0A296BB, 0x6A7DC },
	{ 0xF0A296BD, 0x6A7DE },
	{ 0xF0A29781, 0x6A7E1 },
	{ 0xF0A29783, 0x6A4F2 },
	{ 0xF0A29787, 0x5A2E8 },
	{ 0xF0A29788, 0x5A4B7 },
	{ 0xF0A29789, 0x5A4B9 },
	{ 0xF0A2978A, 0x4A6C5 },
	{ 0xF0A2978B, 0x6A7E6 },
	{ 0xF0A2978C, 0x6A7E4 },
	{ 0xF0A2978D, 0x6ABC6 },
	{ 0xF0A2978E, 0x6A7E7 },
	{ 0xF0A29790, 0x6ABC0 },
	{ 0xF0A29791, 0x6A7E2 },
	{ 0xF0A29792, 0x6A7E3 },
	{ 0xF0A29793, 0x6ABC4 },
	{ 0xF0A29794, 0x6A7E5 },
	{ 0xF0A29795, 0x6A7E8 },
	{ 0xF0A29797, 0x3A5FE },
	{ 0xF0A29798, 0x6A7E9 },
	{ 0xF0A2979B, 0x5A4BA },
	{ 0xF0A2979C, 0xFA4AE },
	{ 0xF0A2979D, 0xFA4AF },
	{ 0xF0A2979E, 0xFA4B1 },
	{ 0xF0A2979F, 0xFA4B2 },
	{ 0xF0A297A0, 0xFA4B4 },
	{ 0xF0A297A1, 0xFA4B5 },
	{ 0xF0A297A2, 0xFA4B6 },
	{ 0xF0A297A3, 0xFA6F7 },
	{ 0xF0A297A4, 0xFA6F8 },
	{ 0xF0A297A5, 0xFA6F9 },
	{ 0xF0A297A6, 0xFA6FA },
	{ 0xF0A297A7, 0xFA6FB },
	{ 0xF0A297A8, 0xFA6FD },
	{ 0xF0A297A9, 0xFA6FE },
	{ 0xF0A297AA, 0xFA7A1 },
	{ 0xF0A297AB, 0xFA6FC },
	{ 0xF0A297AC, 0x6ABC5 },
	{ 0xF0A297AE, 0x6ABC1 },
	{ 0xF0A297B1, 0x6ABC2 },
	{ 0xF0A297B2, 0x4A4AD },
	{ 0xF0A297B5, 0xFA4B0 },
	{ 0xF0A297B9, 0x4A6C4 },
	{ 0xF0A297BA, 0x5A6B4 },
	{ 0xF0A297BB, 0x6ABC3 },
	{ 0xF0A297BF, 0x4A6C7 },
	{ 0xF0A29880, 0x6ABCC },
	{ 0xF0A29881, 0x4A9C7 },
	{ 0xF0A29882, 0x6B1AF },
	{ 0xF0A29883, 0x4A6CB },
	{ 0xF0A29884, 0x6ABCD },
	{ 0xF0A29885, 0x6B1A9 },
	{ 0xF0A29886, 0x5A6B5 },
	{ 0xF0A29887, 0x6B1AC },
	{ 0xF0A29888, 0x6ABCF },
	{ 0xF0A29889, 0x4A6CA },
	{ 0xF0A2988A, 0x5A6B7 },
	{ 0xF0A2988B, 0x4A9B8 },
	{ 0xF0A2988C, 0x5A6B6 },
	{ 0xF0A2988D, 0x4A9C3 },
	{ 0xF0A2988E, 0x6ABC9 },
	{ 0xF0A2988F, 0x5A6B8 },
	{ 0xF0A29890, 0x4A6D1 },
	{ 0xF0A29891, 0x4A9C4 },
	{ 0xF0A29892, 0x6B1AA },
	{ 0xF0A29893, 0x6B1AB },
	{ 0xF0A29894, 0x6ABD0 },
	{ 0xF0A29895, 0x6ABC7 },
	{ 0xF0A29896, 0x6B1AD },
	{ 0xF0A2989A, 0xFA6F5 },
	{ 0xF0A2989D, 0xFA7A2 },
	{ 0xF0A2989E, 0xFAAF0 },
	{ 0xF0A298A0, 0x4A9C6 },
	{ 0xF0A298A3, 0x6B1AE },
	{ 0xF0A298A6, 0x6ABC8 },
	{ 0xF0A298A7, 0x6ABCA },
	{ 0xF0A298A8, 0x6ABCE },
	{ 0xF0A298AA, 0x6ABCB },
	{ 0xF0A298AB, 0xFAAE4 },
	{ 0xF0A298AF, 0xFAADF },
	{ 0xF0A298B0, 0xFAAE2 },
	{ 0xF0A298B1, 0xFAAE5 },
	{ 0xF0A298B2, 0xFAAE8 },
	{ 0xF0A298B3, 0xFAAEC },
	{ 0xF0A298B4, 0x6B7DB },
	{ 0xF0A298B5, 0x6B7D9 },
	{ 0xF0A298B6, 0x6B1B2 },
	{ 0xF0A298B7, 0x4A9C9 },
	{ 0xF0A298B8, 0x5A9B7 },
	{ 0xF0A298BA, 0x4A9C2 },
	{ 0xF0A298BB, 0x4ADA9 },
	{ 0xF0A298BC, 0x5ADCE },
	{ 0xF0A298BD, 0x5A9B6 },
	{ 0xF0A298BE, 0x6B1B9 },
	{ 0xF0A298BF, 0x6B7D7 },
	{ 0xF0A29980, 0x6B1B3 },
	{ 0xF0A29981, 0x4ACFD },
	{ 0xF0A29982, 0x5ADCC },
	{ 0xF0A29983, 0x6B1B5 },
	{ 0xF0A29984, 0x6B7D3 },
	{ 0xF0A29985, 0x4ADA1 },
	{ 0xF0A29986, 0x6B1B8 },
	{ 0xF0A29987, 0x5A9B4 },
	{ 0xF0A29988, 0x4ACFE },
	{ 0xF0A29989, 0x6B1BA },
	{ 0xF0A2998A, 0x6B1B1 },
	{ 0xF0A2998B, 0x6B1B7 },
	{ 0xF0A2998C, 0x6B7D6 },
	{ 0xF0A2998D, 0x6B7D5 },
	{ 0xF0A2998E, 0x4ADAA },
	{ 0xF0A29996, 0x6B1B4 },
	{ 0xF0A29997, 0xFAAE1 },
	{ 0xF0A29998, 0xFAAE6 },
	{ 0xF0A29999, 0xFAAE9 },
	{ 0xF0A2999A, 0xFAAEB },
	{ 0xF0A2999B, 0xFAAED },
	{ 0xF0A2999C, 0xFAAEE },
	{ 0xF0A2999D, 0xFAAEF },
	{ 0xF0A2999E, 0xFAFC6 },
	{ 0xF0A2999F, 0xFAFC7 },
	{ 0xF0A299A0, 0xFAFC8 },
	{ 0xF0A299A1, 0xFAFCA },
	{ 0xF0A299A2, 0x6B7D2 },
	{ 0xF0A299A3, 0xFAFC4 },
	{ 0xF0A299A6, 0x6B7D8 },
	{ 0xF0A299A8, 0xFAAE3 },
	{ 0xF0A299AE, 0x5ADCD },
	{ 0xF0A299B0, 0x6B7D1 },
	{ 0xF0A299B1, 0x5ADD2 },
	{ 0xF0A299B2, 0x5ADD8 },
	{ 0xF0A299B3, 0x5ADDB },
	{ 0xF0A299B4, 0x6BFED },
	{ 0xF0A299B5, 0x6B7E3 },
	{ 0xF0A299B6, 0x6BFEF },
	{ 0xF0A299B7, 0x6BFEB },
	{ 0xF0A299B8, 0x6BFF0 },
	{ 0xF0A299B9, 0x6B7E4 },
	{ 0xF0A299BA, 0x5ADD5 },
	{ 0xF0A299BB, 0x6BFE9 },
	{ 0xF0A299BC, 0x4ADAE },
	{ 0xF0A299BD, 0x6BFF3 },
	{ 0xF0A299BE, 0x5ADD6 },
	{ 0xF0A299BF, 0x4ADA6 },
	{ 0xF0A29A80, 0x5B2DD },
	{ 0xF0A29A81, 0x5ADD1 },
	{ 0xF0A29A82, 0x5ADDC },
	{ 0xF0A29A83, 0x6B7E2 },
	{ 0xF0A29A84, 0x6B7DD },
	{ 0xF0A29A85, 0x5B2D4 },
	{ 0xF0A29A86, 0x6B7DF },
	{ 0xF0A29A87, 0x6B7E1 },
	{ 0xF0A29A88, 0x6BFEC },
	{ 0xF0A29A89, 0x6B7E0 },
	{ 0xF0A29A8A, 0x6BFF1 },
	{ 0xF0A29A8B, 0x4ADA7 },
	{ 0xF0A29A8C, 0x5ADD0 },
	{ 0xF0A29A8D, 0x6B7DC },
	{ 0xF0A29A8E, 0x5B2D3 },
	{ 0xF0A29A8F, 0x6BFF2 },
	{ 0xF0A29A90, 0x6BFF4 },
	{ 0xF0A29A91, 0x5B2D2 },
	{ 0xF0A29A97, 0x5ADCF },
	{ 0xF0A29A99, 0xFAFC1 },
	{ 0xF0A29A9A, 0xFAFC2 },
	{ 0xF0A29A9B, 0xFAFC3 },
	{ 0xF0A29A9C, 0xFAFC9 },
	{ 0xF0A29A9D, 0xFAFCB },
	{ 0xF0A29A9E, 0xFB4DD },
	{ 0xF0A29A9F, 0xFB4DF },
	{ 0xF0A29AA0, 0xFB4E0 },
	{ 0xF0A29AA1, 0xFB4E4 },
	{ 0xF0A29AA2, 0xFB4E5 },
	{ 0xF0A29AA3, 0xFB4E6 },
	{ 0xF0A29AA4, 0xFB4E7 },
	{ 0xF0A29AA5, 0xFB4E8 },
	{ 0xF0A29AA6, 0x6BFEA },
	{ 0xF0A29AAF, 0x6B7E5 },
	{ 0xF0A29AB0, 0x6B7E6 },
	{ 0xF0A29ABA, 0x5ADD4 },
	{ 0xF0A29ABB, 0x5ADD9 },
	{ 0xF0A29B81, 0x4B7DA },
	{ 0xF0A29B82, 0x6C8F1 },
	{ 0xF0A29B83, 0x4B7CD },
	{ 0xF0A29B84, 0x5B2D9 },
	{ 0xF0A29B85, 0x6BFFC },
	{ 0xF0A29B86, 0x4B7CB },
	{ 0xF0A29B87, 0x6C8F3 },
	{ 0xF0A29B88, 0x6C8E9 },
	{ 0xF0A29B89, 0x5B8D5 },
	{ 0xF0A29B8A, 0x6BFFE },
	{ 0xF0A29B8B, 0x6C8F2 },
	{ 0xF0A29B8C, 0x6C0A2 },
	{ 0xF0A29B8D, 0x4B1E5 },
	{ 0xF0A29B8E, 0x5ADD3 },
	{ 0xF0A29B8F, 0x4B1ED },
	{ 0xF0A29B90, 0x6BFF7 },
	{ 0xF0A29B91, 0x6C8EE },
	{ 0xF0A29B92, 0x4B1E1 },
	{ 0xF0A29B93, 0x5B8BF },
	{ 0xF0A29B94, 0x5B2D7 },
	{ 0xF0A29B95, 0x5B2DA },
	{ 0xF0A29B96, 0x4B7CC },
	{ 0xF0A29B97, 0x6BFF9 },
	{ 0xF0A29B98, 0x5B2DC },
	{ 0xF0A29B99, 0x6BFF6 },
	{ 0xF0A29B9A, 0x6BFEE },
	{ 0xF0A29B9B, 0x4B1E9 },
	{ 0xF0A29B9C, 0x5B8BC },
	{ 0xF0A29B9D, 0x6C8F0 },
	{ 0xF0A29B9E, 0x5B2DE },
	{ 0xF0A29B9F, 0x4B1DF },
	{ 0xF0A29BA0, 0x6BFFD },
	{ 0xF0A29BA1, 0x6BFFB },
	{ 0xF0A29BA2, 0x6BFFA },
	{ 0xF0A29BA3, 0x6C8E6 },
	{ 0xF0A29BA4, 0x6C8EC },
	{ 0xF0A29BA5, 0x5B8BE },
	{ 0xF0A29BA6, 0x5B8C1 },
	{ 0xF0A29BA7, 0x6C8F4 },
	{ 0xF0A29BA8, 0x5B2D5 },
	{ 0xF0A29BA9, 0x6C8EB },
	{ 0xF0A29BAA, 0x6C8F6 },
	{ 0xF0A29BAB, 0x6C8E7 },
	{ 0xF0A29BAC, 0x6C8E5 },
	{ 0xF0A29BAD, 0x6BFF5 },
	{ 0xF0A29BAE, 0x5B8C0 },
	{ 0xF0A29BB0, 0xFB4E1 },
	{ 0xF0A29BB7, 0xFB4DE },
	{ 0xF0A29BB8, 0xFB4E2 },
	{ 0xF0A29BB9, 0xFB4E3 },
	{ 0xF0A29BBA, 0xFB4E9 },
	{ 0xF0A29BBB, 0xFB4EA },
	{ 0xF0A29BBC, 0xFB4EB },
	{ 0xF0A29BBD, 0xFB4EC },
	{ 0xF0A29BBE, 0xFB4ED },
	{ 0xF0A29BBF, 0xFB4EF },
	{ 0xF0A29C80, 0xFB4F0 },
	{ 0xF0A29C81, 0xFB4F2 },
	{ 0xF0A29C82, 0xFBAF2 },
	{ 0xF0A29C83, 0xFBAF3 },
	{ 0xF0A29C84, 0xFBAF4 },
	{ 0xF0A29C85, 0xFBAF5 },
	{ 0xF0A29C86, 0xFBAF6 },
	{ 0xF0A29C87, 0xFBAF7 },
	{ 0xF0A29C88, 0xFBAF9 },
	{ 0xF0A29C89, 0xFBAFA },
	{ 0xF0A29C8A, 0xFBAFC },
	{ 0xF0A29C8B, 0xFBAFD },
	{ 0xF0A29C8C, 0xFBAFE },
	{ 0xF0A29C8D, 0xFBBA1 },
	{ 0xF0A29C8E, 0xFBBA2 },
	{ 0xF0A29C8F, 0xFBBA5 },
	{ 0xF0A29C90, 0xFBBA9 },
	{ 0xF0A29C91, 0xFBBAA },
	{ 0xF0A29C92, 0xFBBAC },
	{ 0xF0A29C93, 0xFBBAE },
	{ 0xF0A29C96, 0x6C8E8 },
	{ 0xF0A29C97, 0x5B2D6 },
	{ 0xF0A29C9A, 0x6BFF8 },
	{ 0xF0A29C9B, 0xFBBA7 },
	{ 0xF0A29C9F, 0xFB4EE },
	{ 0xF0A29CA3, 0x6C9A4 },
	{ 0xF0A29CA4, 0x6C8ED },
	{ 0xF0A29CA5, 0x6C0A1 },
	{ 0xF0A29CA7, 0xFBBA4 },
	{ 0xF0A29CA8, 0x4BDBF },
	{ 0xF0A29CA9, 0x5B8CA },
	{ 0xF0A29CAA, 0x5B8CD },
	{ 0xF0A29CAB, 0x5B8D2 },
	{ 0xF0A29CAC, 0x4B7CF },
	{ 0xF0A29CAD, 0x4B7D7 },
	{ 0xF0A29CAE, 0x4B7D1 },
	{ 0xF0A29CAF, 0x6D2DD },
	{ 0xF0A29CB0, 0x6C9A3 },
	{ 0xF0A29CB1, 0x5B8D0 },
	{ 0xF0A29CB2, 0x6C9A2 },
	{ 0xF0A29CB3, 0x4B7D3 },
	{ 0xF0A29CB4, 0x5B8D6 },
	{ 0xF0A29CB5, 0x5B8D8 },
	{ 0xF0A29CB6, 0x5B8C3 },
	{ 0xF0A29CB7, 0x6D2E1 },
	{ 0xF0A29CB8, 0x5B8DA },
	{ 0xF0A29CB9, 0x5BFB3 },
	{ 0xF0A29CBA, 0x4B7DB },
	{ 0xF0A29CBB, 0x5B8D3 },
	{ 0xF0A29CBC, 0x6C9A1 },
	{ 0xF0A29CBD, 0x5B8C6 },
	{ 0xF0A29CBE, 0x6C8FB },
	{ 0xF0A29CBF, 0x5BFB4 },
	{ 0xF0A29D80, 0x5B8C4 },
	{ 0xF0A29D81, 0x5B8D4 },
	{ 0xF0A29D82, 0x5B2DF },
	{ 0xF0A29D83, 0x6D2D8 },
	{ 0xF0A29D84, 0x5B8C7 },
	{ 0xF0A29D85, 0x4BDB6 },
	{ 0xF0A29D86, 0x4B7D8 },
	{ 0xF0A29D87, 0x5B8D9 },
	{ 0xF0A29D88, 0x5B8D1 },
	{ 0xF0A29D89, 0x5B8CB },
	{ 0xF0A29D8A, 0x5BFB1 },
	{ 0xF0A29D8B, 0x6C8F7 },
	{ 0xF0A29D8C, 0x5B8CF },
	{ 0xF0A29D8D, 0x5B8BD },
	{ 0xF0A29D8E, 0x6C8FE },
	{ 0xF0A29D8F, 0x6D2E2 },
	{ 0xF0A29D90, 0x6D2E3 },
	{ 0xF0A29D91, 0x6D2DA },
	{ 0xF0A29D92, 0x6C8FD },
	{ 0xF0A29D93, 0x5B8D7 },
	{ 0xF0A29D94, 0x6D2DE },
	{ 0xF0A29D95, 0x6D2E0 },
	{ 0xF0A29D97, 0x5BFAF },
	{ 0xF0A29D9D, 0x4BDC0 },
	{ 0xF0A29D9E, 0x4B7D2 },
	{ 0xF0A29D9F, 0x5B8C9 },
	{ 0xF0A29DA0, 0x6C8F9 },
	{ 0xF0A29DA1, 0xFBAF1 },
	{ 0xF0A29DA2, 0xFBAFB },
	{ 0xF0A29DA3, 0xFBBA3 },
	{ 0xF0A29DA4, 0xFBBA8 },
	{ 0xF0A29DA5, 0xFBBAD },
	{ 0xF0A29DA6, 0xFC1C8 },
	{ 0xF0A29DA7, 0xFC1CE },
	{ 0xF0A29DA8, 0xFC1D0 },
	{ 0xF0A29DA9, 0xFC1D1 },
	{ 0xF0A29DAA, 0xFC1D2 },
	{ 0xF0A29DAD, 0x6D2DC },
	{ 0xF0A29DAE, 0x6D2DF },
	{ 0xF0A29DB2, 0x6D2DB },
	{ 0xF0A29DBD, 0x6C8FA },
	{ 0xF0A29E81, 0xFBBAB },
	{ 0xF0A29E87, 0x5B8CE },
	{ 0xF0A29E89, 0x5BFAE },
	{ 0xF0A29E8A, 0x5B8CC },
	{ 0xF0A29E8C, 0xFB4F1 },
	{ 0xF0A29E8D, 0xFC7FD },
	{ 0xF0A29E8E, 0x5BFBC },
	{ 0xF0A29E8F, 0x5BFB6 },
	{ 0xF0A29E90, 0x5BFB5 },
	{ 0xF0A29E91, 0x6D2EB },
	{ 0xF0A29E92, 0x5CDA6 },
	{ 0xF0A29E93, 0x5BFC5 },
	{ 0xF0A29E94, 0x6DCEF },
	{ 0xF0A29E95, 0x5BFB9 },
	{ 0xF0A29E96, 0x5BFBF },
	{ 0xF0A29E97, 0x5BFC4 },
	{ 0xF0A29E98, 0x6DCF4 },
	{ 0xF0A29E99, 0x6D2EF },
	{ 0xF0A29E9A, 0x5C5EB },
	{ 0xF0A29E9C, 0x5BFBB },
	{ 0xF0A29E9D, 0x6DCEC },
	{ 0xF0A29E9E, 0x6D2E5 },
	{ 0xF0A29E9F, 0x5BFB8 },
	{ 0xF0A29EA0, 0x5BFBD },
	{ 0xF0A29EA1, 0x5BFBA },
	{ 0xF0A29EA2, 0x6D2D9 },
	{ 0xF0A29EA3, 0x4C9EE },
	{ 0xF0A29EA4, 0x6DCF6 },
	{ 0xF0A29EA5, 0x6DCF9 },
	{ 0xF0A29EA6, 0x5BFC3 },
	{ 0xF0A29EA7, 0x6D2E8 },
	{ 0xF0A29EA8, 0x6DCF2 },
	{ 0xF0A29EA9, 0x4C3CF },
	{ 0xF0A29EAA, 0x6DCF8 },
	{ 0xF0A29EAB, 0x6DCF7 },
	{ 0xF0A29EAC, 0x5BFC1 },
	{ 0xF0A29EAD, 0x5C5ED },
	{ 0xF0A29EAE, 0x5BFBE },
	{ 0xF0A29EAF, 0x6DCF1 },
	{ 0xF0A29EB0, 0x6DCEE },
	{ 0xF0A29EB1, 0x6DCED },
	{ 0xF0A29EB2, 0x5BFB7 },
	{ 0xF0A29EB3, 0x6D2E7 },
	{ 0xF0A29EB6, 0x6D2ED },
	{ 0xF0A29EB7, 0xFC1CA },
	{ 0xF0A29EB8, 0xFC1CB },
	{ 0xF0A29EB9, 0xFC1CC },
	{ 0xF0A29EBA, 0xFC1CD },
	{ 0xF0A29EBB, 0xFC1CF },
	{ 0xF0A29EBC, 0xFC1D3 },
	{ 0xF0A29EBD, 0xFC7F6 },
	{ 0xF0A29EBE, 0xFC7F7 },
	{ 0xF0A29EBF, 0xFC7F9 },
	{ 0xF0A29F80, 0xFC7FA },
	{ 0xF0A29F81, 0xFC8A5 },
	{ 0xF0A29F82, 0xFC8A8 },
	{ 0xF0A29F83, 0x6DCF0 },
	{ 0xF0A29F84, 0x6DCF5 },
	{ 0xF0A29F8A, 0x5BFC0 },
	{ 0xF0A29F8B, 0xFC1C9 },
	{ 0xF0A29F9C, 0x6DCF3 },
	{ 0xF0A29F9D, 0x6D2EE },
	{ 0xF0A29FA0, 0x6DDA3 },
	{ 0xF0A29FA1, 0x6DDA7 },
	{ 0xF0A29FA2, 0x4C3C5 },
	{ 0xF0A29FA3, 0x4C3C4 },
	{ 0xF0A29FA4, 0x5CDA7 },
	{ 0xF0A29FA6, 0x6DCFC },
	{ 0xF0A29FA7, 0x5C5F7 },
	{ 0xF0A29FA8, 0x5C5F6 },
	{ 0xF0A29FA9, 0x5C5F3 },
	{ 0xF0A29FAA, 0x4BDB5 },
	{ 0xF0A29FAB, 0x6DCFB },
	{ 0xF0A29FAC, 0x7A2F2 },
	{ 0xF0A29FAE, 0x7A2F5 },
	{ 0xF0A29FAF, 0x5CDA9 },
	{ 0xF0A29FB0, 0x5C5F0 },
	{ 0xF0A29FB1, 0x5C5EF },
	{ 0xF0A29FB2, 0x5C5EC },
	{ 0xF0A29FB3, 0x5C5F1 },
	{ 0xF0A29FB4, 0x5C5F2 },
	{ 0xF0A29FB5, 0x5C5F9 },
	{ 0xF0A29FB6, 0x6DDA5 },
	{ 0xF0A29FB7, 0x6DCFD },
	{ 0xF0A29FB8, 0x6DCFE },
	{ 0xF0A29FB9, 0x6D2EA },
	{ 0xF0A29FBA, 0x6DDA2 },
	{ 0xF0A29FBB, 0x7A2F4 },
	{ 0xF0A29FBC, 0x6DDA1 },
	{ 0xF0A29FBD, 0x7A2F7 },
	{ 0xF0A29FBE, 0x5C5F4 },
	{ 0xF0A29FBF, 0x5C5F8 },
	{ 0xF0A2A080, 0x7ADEA },
	{ 0xF0A2A08A, 0x4C3D3 },
	{ 0xF0A2A08B, 0xFC7F8 },
	{ 0xF0A2A08C, 0xFC7FC },
	{ 0xF0A2A08D, 0xFC7FE },
	{ 0xF0A2A08E, 0xFC8A1 },
	{ 0xF0A2A08F, 0xFC8A3 },
	{ 0xF0A2A090, 0xFC8A4 },
	{ 0xF0A2A091, 0xFC8A6 },
	{ 0xF0A2A092, 0xFCEE9 },
	{ 0xF0A2A093, 0xFCEEA },
	{ 0xF0A2A094, 0xFCEEB },
	{ 0xF0A2A095, 0xFCEEC },
	{ 0xF0A2A096, 0xFCEED },
	{ 0xF0A2A097, 0xFCEEE },
	{ 0xF0A2A098, 0xFCEEF },
	{ 0xF0A2A099, 0xFCEF3 },
	{ 0xF0A2A09A, 0xFCEF5 },
	{ 0xF0A2A09C, 0x7A2F3 },
	{ 0xF0A2A09E, 0x7A2F8 },
	{ 0xF0A2A09F, 0x6DCEB },
	{ 0xF0A2A0A0, 0x5C5EE },
	{ 0xF0A2A0A1, 0x6DCFA },
	{ 0xF0A2A0AC, 0x5CDA8 },
	{ 0xF0A2A0AE, 0x5C5F5 },
	{ 0xF0A2A0B1, 0x7ADF1 },
	{ 0xF0A2A0B2, 0x4C9E6 },
	{ 0xF0A2A0B3, 0x4C3D2 },
	{ 0xF0A2A0B4, 0x7ADEB },
	{ 0xF0A2A0B5, 0x4C9F1 },
	{ 0xF0A2A0B6, 0x7ADED },
	{ 0xF0A2A0B7, 0x5CDAF },
	{ 0xF0A2A0B8, 0x7ADF3 },
	{ 0xF0A2A0B9, 0x4C9EA },
	{ 0xF0A2A0BA, 0x5CDAE },
	{ 0xF0A2A0BB, 0x7A2F9 },
	{ 0xF0A2A0BC, 0x5CDB3 },
	{ 0xF0A2A0BD, 0x4C9F2 },
	{ 0xF0A2A0BE, 0x7ADF5 },
	{ 0xF0A2A0BF, 0x5B8C5 },
	{ 0xF0A2A180, 0x5CDB2 },
	{ 0xF0A2A181, 0x5CDB5 },
	{ 0xF0A2A182, 0x4D0B5 },
	{ 0xF0A2A183, 0x4D0B6 },
	{ 0xF0A2A184, 0x7A3A1 },
	{ 0xF0A2A185, 0x5CDB4 },
	{ 0xF0A2A186, 0x7B7FC },
	{ 0xF0A2A187, 0x5CDB0 },
	{ 0xF0A2A188, 0x5D4CE },
	{ 0xF0A2A189, 0x4D6B4 },
	{ 0xF0A2A18A, 0x7A2FA },
	{ 0xF0A2A18B, 0x7A3A2 },
	{ 0xF0A2A18E, 0x5D4D4 },
	{ 0xF0A2A18F, 0x5CDAB },
	{ 0xF0A2A190, 0x5CDAD },
	{ 0xF0A2A191, 0x5D4CD },
	{ 0xF0A2A192, 0x5CDAC },
	{ 0xF0A2A193, 0x7AEA2 },
	{ 0xF0A2A194, 0x7ADF7 },
	{ 0xF0A2A195, 0x7ADF6 },
	{ 0xF0A2A196, 0x7A2FE },
	{ 0xF0A2A197, 0x4D0BC },
	{ 0xF0A2A198, 0x7ADF0 },
	{ 0xF0A2A199, 0x7ADEF },
	{ 0xF0A2A19E, 0xFC8A2 },
	{ 0xF0A2A1A1, 0xFCEF0 },
	{ 0xF0A2A1A2, 0x7ADF2 },
	{ 0xF0A2A1A4, 0x5CDB1 },
	{ 0xF0A2A1A5, 0x7ADEC },
	{ 0xF0A2A1A6, 0xFCEF1 },
	{ 0xF0A2A1A7, 0xFCEF2 },
	{ 0xF0A2A1A8, 0xFCEF4 },
	{ 0xF0A2A1A9, 0xFCEF6 },
	{ 0xF0A2A1AA, 0xFD4C7 },
	{ 0xF0A2A1AB, 0xFD4C8 },
	{ 0xF0A2A1AC, 0xFD4CA },
	{ 0xF0A2A1AD, 0xFD4CB },
	{ 0xF0A2A1AE, 0xFD4D1 },
	{ 0xF0A2A1AF, 0xFD4D3 },
	{ 0xF0A2A1B3, 0x7ADF4 },
	{ 0xF0A2A1B4, 0x5D4CB },
	{ 0xF0A2A1B8, 0x7B0D0 },
	{ 0xF0A2A1BD, 0x7A2FD },
	{ 0xF0A2A1BE, 0x7A5F1 },
	{ 0xF0A2A1BF, 0x4C9F0 },
	{ 0xF0A2A28C, 0x5D4CC },
	{ 0xF0A2A28D, 0x5D4CF },
	{ 0xF0A2A28F, 0xFCEE8 },
	{ 0xF0A2A291, 0xFD4CF },
	{ 0xF0A2A292, 0x5D4D0 },
	{ 0xF0A2A293, 0x5D4D2 },
	{ 0xF0A2A294, 0x7ADFB },
	{ 0xF0A2A295, 0x7ADF8 },
	{ 0xF0A2A296, 0x5D4D5 },
	{ 0xF0A2A297, 0x5D4D6 },
	{ 0xF0A2A298, 0x5D4D1 },
	{ 0xF0A2A299, 0x7ADFE },
	{ 0xF0A2A29A, 0x7ADFC },
	{ 0xF0A2A29B, 0x7ADFD },
	{ 0xF0A2A29C, 0x5D4D7 },
	{ 0xF0A2A29D, 0x4D0BD },
	{ 0xF0A2A29E, 0x5DBC9 },
	{ 0xF0A2A29F, 0x7AEA1 },
	{ 0xF0A2A2A0, 0x7B7FB },
	{ 0xF0A2A2A1, 0x7B7FD },
	{ 0xF0A2A2A2, 0x7B7FA },
	{ 0xF0A2A2A3, 0x7B8A1 },
	{ 0xF0A2A2A4, 0x5DBCB },
	{ 0xF0A2A2A5, 0x7ADFA },
	{ 0xF0A2A2A6, 0x7B7F9 },
	{ 0xF0A2A2A7, 0x7ADEE },
	{ 0xF0A2A2AE, 0xFD4CD },
	{ 0xF0A2A2B0, 0x5D4D3 },
	{ 0xF0A2A2B1, 0x7B8A2 },
	{ 0xF0A2A2B2, 0xFD4C9 },
	{ 0xF0A2A2B3, 0xFD4CE },
	{ 0xF0A2A2B4, 0xFD4D2 },
	{ 0xF0A2A2B5, 0xFDAA5 },
	{ 0xF0A2A2B6, 0xFDAA6 },
	{ 0xF0A2A2B7, 0xFDAAE },
	{ 0xF0A2A381, 0xFDAA7 },
	{ 0xF0A2A389, 0x5DBCA },
	{ 0xF0A2A38A, 0x5D4D8 },
	{ 0xF0A2A38B, 0xFDAAA },
	{ 0xF0A2A38C, 0xFD4CC },
	{ 0xF0A2A38D, 0x7B7F8 },
	{ 0xF0A2A38E, 0x5DBD1 },
	{ 0xF0A2A38F, 0x4D6B5 },
	{ 0xF0A2A390, 0x4D6B1 },
	{ 0xF0A2A391, 0x4DBAA },
	{ 0xF0A2A392, 0x5DBCE },
	{ 0xF0A2A393, 0x5E1E4 },
	{ 0xF0A2A394, 0x5E1E2 },
	{ 0xF0A2A395, 0x7BFDB },
	{ 0xF0A2A396, 0x7B8A6 },
	{ 0xF0A2A398, 0x4DBA6 },
	{ 0xF0A2A399, 0x5DBCD },
	{ 0xF0A2A39A, 0x5DBCF },
	{ 0xF0A2A39B, 0x7B8A3 },
	{ 0xF0A2A39C, 0x7B8A5 },
	{ 0xF0A2A39D, 0x5DBD0 },
	{ 0xF0A2A39E, 0x5E1E3 },
	{ 0xF0A2A39F, 0x7BFDA },
	{ 0xF0A2A3A0, 0x5E1E5 },
	{ 0xF0A2A3A1, 0x7BFD9 },
	{ 0xF0A2A3A2, 0x7A2F6 },
	{ 0xF0A2A3A8, 0xFDAAB },
	{ 0xF0A2A3A9, 0xFDAAD },
	{ 0xF0A2A3AA, 0xFDEDF },
	{ 0xF0A2A3AB, 0xFDEE0 },
	{ 0xF0A2A3AC, 0xFDEE2 },
	{ 0xF0A2A3AD, 0xFDEE3 },
	{ 0xF0A2A3AE, 0xFDEE5 },
	{ 0xF0A2A3AF, 0xFDEE6 },
	{ 0xF0A2A3B0, 0xFDEE7 },
	{ 0xF0A2A3B2, 0x7BFDC },
	{ 0xF0A2A3B6, 0x7B8A4 },
	{ 0xF0A2A3B7, 0xFDAA8 },
	{ 0xF0A2A3BB, 0x4DBA7 },
	{ 0xF0A2A3BC, 0x5DBD2 },
	{ 0xF0A2A3BD, 0x7C6F9 },
	{ 0xF0A2A3BE, 0x7BFDD },
	{ 0xF0A2A3BF, 0x5E1E8 },
	{ 0xF0A2A480, 0x7CDE4 },
	{ 0xF0A2A481, 0x4DFE3 },
	{ 0xF0A2A482, 0x4DFE2 },
	{ 0xF0A2A483, 0x7C6FC },
	{ 0xF0A2A484, 0x5E1E9 },
	{ 0xF0A2A485, 0x7CDE7 },
	{ 0xF0A2A486, 0x4DBA8 },
	{ 0xF0A2A487, 0x5E1EA },
	{ 0xF0A2A488, 0x7C7A5 },
	{ 0xF0A2A489, 0x7C7A1 },
	{ 0xF0A2A48A, 0x7C6F8 },
	{ 0xF0A2A48B, 0x5E1E7 },
	{ 0xF0A2A48C, 0x7C6FE },
	{ 0xF0A2A48E, 0x5E7ED },
	{ 0xF0A2A48F, 0x7C6FA },
	{ 0xF0A2A490, 0x5E7F0 },
	{ 0xF0A2A491, 0x7C6F7 },
	{ 0xF0A2A492, 0x7C7A2 },
	{ 0xF0A2A493, 0x7BFDE },
	{ 0xF0A2A495, 0x7C6FD },
	{ 0xF0A2A496, 0x5E7EE },
	{ 0xF0A2A497, 0xFDEE4 },
	{ 0xF0A2A498, 0x5E7EF },
	{ 0xF0A2A499, 0x7C6FB },
	{ 0xF0A2A4A4, 0x5E7EC },
	{ 0xF0A2A4A5, 0xFE2B9 },
	{ 0xF0A2A4A6, 0x7C7AA },
	{ 0xF0A2A4A7, 0x4E3C4 },
	{ 0xF0A2A4A8, 0x7C7A7 },
	{ 0xF0A2A4A9, 0x5E7F4 },
	{ 0xF0A2A4AA, 0x7C7A4 },
	{ 0xF0A2A4AB, 0x5ECAA },
	{ 0xF0A2A4AC, 0x7C7A9 },
	{ 0xF0A2A4AD, 0x7C7A6 },
	{ 0xF0A2A4AE, 0x7BFDF },
	{ 0xF0A2A4AF, 0x5E7F5 },
	{ 0xF0A2A4B0, 0x4E3BF },
	{ 0xF0A2A4B1, 0x5E7F1 },
	{ 0xF0A2A4B2, 0x5ECA8 },
	{ 0xF0A2A4B3, 0x7C7AB },
	{ 0xF0A2A4B4, 0x7C7A3 },
	{ 0xF0A2A4B5, 0x7CDE5 },
	{ 0xF0A2A4B6, 0x5E7F7 },
	{ 0xF0A2A4BA, 0xFE2BA },
	{ 0xF0A2A4BB, 0xFE2B8 },
	{ 0xF0A2A4BC, 0xFE2BB },
	{ 0xF0A2A4BD, 0xFE2BC },
	{ 0xF0A2A4BE, 0xFE2BD },
	{ 0xF0A2A581, 0x7CDE6 },
	{ 0xF0A2A583, 0x5E1E6 },
	{ 0xF0A2A584, 0x5E7F2 },
	{ 0xF0A2A58A, 0xFE5AB },
	{ 0xF0A2A58B, 0x5E7F6 },
	{ 0xF0A2A58C, 0x5ECA9 },
	{ 0xF0A2A58D, 0x7D3B9 },
	{ 0xF0A2A58E, 0x7CDEA },
	{ 0xF0A2A58F, 0x4E3C1 },
	{ 0xF0A2A590, 0x7CDE9 },
	{ 0xF0A2A591, 0x4E3C5 },
	{ 0xF0A2A592, 0x7D3B8 },
	{ 0xF0A2A593, 0x7CDEB },
	{ 0xF0A2A594, 0xFE7D5 },
	{ 0xF0A2A597, 0x7DBCF },
	{ 0xF0A2A598, 0x4E6BE },
	{ 0xF0A2A59A, 0x5ECAB },
	{ 0xF0A2A59B, 0x7D7F3 },
	{ 0xF0A2A59C, 0x7D7F4 },
	{ 0xF0A2A59D, 0x7D7F5 },
	{ 0xF0A2A59E, 0x7D3BB },
	{ 0xF0A2A59F, 0x7D3BA },
	{ 0xF0A2A5A1, 0x7D3BC },
	{ 0xF0A2A5A4, 0xFE9C2 },
	{ 0xF0A2A5A5, 0x7D7F6 },
	{ 0xF0A2A5A6, 0x7DBD0 },
	{ 0xF0A2A5A7, 0x7DBD2 },
	{ 0xF0A2A5A8, 0x7DBD3 },
	{ 0xF0A2A5A9, 0x7DBD1 },
	{ 0xF0A2A5AB, 0xFEAD0 },
	{ 0xF0A2A5AC, 0xFE9C1 },
	{ 0xF0A2A5AD, 0xFEAD1 },
	{ 0xF0A2A5AE, 0xFEAD2 },
	{ 0xF0A2A5AF, 0x7DBD5 },
	{ 0xF0A2A5B0, 0x5F7DA },
	{ 0xF0A2A5B1, 0x7DBD4 },
	{ 0xF0A2A5B2, 0x7DEE5 },
	{ 0xF0A2A5B8, 0xFEAD3 },
	{ 0xF0A2A5B9, 0xFEBC7 },
	{ 0xF0A2A5BA, 0xFEBC8 },
	{ 0xF0A2A5BB, 0x5F7DB },
	{ 0xF0A2A5BC, 0x7DEE6 },
	{ 0xF0A2A5BD, 0x5F9A9 },
	{ 0xF0A2A5BE, 0x7DEE7 },
	{ 0xF0A2A5BF, 0xFECA8 },
	{ 0xF0A2A681, 0xFECA9 },
	{ 0xF0A2A685, 0x4EDF2 },
	{ 0xF0A2A686, 0xFECFC },
	{ 0xF0A2A687, 0xFECFD },
	{ 0xF0A2A688, 0x5FBBE },
	{ 0xF0A2A689, 0x5FBE0 },
	{ 0xF0A2A68B, 0xFEDB4 },
	{ 0xF0A2A68E, 0x5A2EA },
	{ 0xF0A2A68F, 0x4A2F2 },
	{ 0xF0A2A690, 0x6A4F6 },
	{ 0xF0A2A693, 0x6A7EB },
	{ 0xF0A2A694, 0x5A4BB },
	{ 0xF0A2A695, 0x6A7EA },
	{ 0xF0A2A696, 0x6A7ED },
	{ 0xF0A2A699, 0x6A7EC },
	{ 0xF0A2A69A, 0x4A6D2 },
	{ 0xF0A2A69B, 0x6ABD1 },
	{ 0xF0A2A69C, 0x6ABD8 },
	{ 0xF0A2A69D, 0x6ABD4 },
	{ 0xF0A2A69E, 0x6ABD6 },
	{ 0xF0A2A69F, 0x4A6D3 },
	{ 0xF0A2A6A0, 0x6ABD5 },
	{ 0xF0A2A6A1, 0x6ABD3 },
	{ 0xF0A2A6A2, 0x6ABD7 },
	{ 0xF0A2A6A3, 0xFA7A4 },
	{ 0xF0A2A6A4, 0xFA7A3 },
	{ 0xF0A2A6A6, 0x6B1BD },
	{ 0xF0A2A6A7, 0x6B1BB },
	{ 0xF0A2A6A8, 0x6B1BE },
	{ 0xF0A2A6A9, 0x6B1C0 },
	{ 0xF0A2A6AA, 0x4A9CC },
	{ 0xF0A2A6AB, 0x6B1C1 },
	{ 0xF0A2A6AC, 0x6B1BF },
	{ 0xF0A2A6AE, 0xFAAF1 },
	{ 0xF0A2A6AF, 0xFAAF2 },
	{ 0xF0A2A6B6, 0x6B1BC },
	{ 0xF0A2A6B7, 0x6B7E7 },
	{ 0xF0A2A6B8, 0x5ADDF },
	{ 0xF0A2A6B9, 0x6B7E9 },
	{ 0xF0A2A6BA, 0x5ADDE },
	{ 0xF0A2A6BB, 0x6B7E8 },
	{ 0xF0A2A6BF, 0x5B2E1 },
	{ 0xF0A2A780, 0x4B1EF },
	{ 0xF0A2A781, 0x6C0A5 },
	{ 0xF0A2A782, 0xFB4F3 },
	{ 0xF0A2A783, 0xFB4F4 },
	{ 0xF0A2A786, 0x6C0A4 },
	{ 0xF0A2A787, 0x5B2E0 },
	{ 0xF0A2A788, 0x6C9A8 },
	{ 0xF0A2A789, 0x6C9A7 },
	{ 0xF0A2A78A, 0x6C9A5 },
	{ 0xF0A2A78B, 0x6C9A6 },
	{ 0xF0A2A78C, 0x4B7DC },
	{ 0xF0A2A78D, 0x6C9A9 },
	{ 0xF0A2A78E, 0xFBBAF },
	{ 0xF0A2A791, 0x5B8DB },
	{ 0xF0A2A792, 0x5B8DC },
	{ 0xF0A2A793, 0xFB4F6 },
	{ 0xF0A2A794, 0x4BDC4 },
	{ 0xF0A2A795, 0x6D2F1 },
	{ 0xF0A2A796, 0x5BFC7 },
	{ 0xF0A2A798, 0x5BFC9 },
	{ 0xF0A2A79B, 0xFC1D5 },
	{ 0xF0A2A79C, 0x4BDC1 },
	{ 0xF0A2A79F, 0x6D2F0 },
	{ 0xF0A2A7A0, 0x5BFC8 },
	{ 0xF0A2A7A2, 0x6DDA9 },
	{ 0xF0A2A7A4, 0x6DDAA },
	{ 0xF0A2A7A5, 0x5C5FA },
	{ 0xF0A2A7A6, 0x5C5FC },
	{ 0xF0A2A7A7, 0x5C5FB },
	{ 0xF0A2A7A8, 0x7A3A4 },
	{ 0xF0A2A7A9, 0x5C5FD },
	{ 0xF0A2A7AA, 0xFC8A9 },
	{ 0xF0A2A7AB, 0xFC8AA },
	{ 0xF0A2A7AC, 0x6DDA8 },
	{ 0xF0A2A7B3, 0x5CDB6 },
	{ 0xF0A2A7B4, 0x4C9F3 },
	{ 0xF0A2A7B5, 0x4C9F4 },
	{ 0xF0A2A7B6, 0x7A3A8 },
	{ 0xF0A2A7B7, 0x7A3A7 },
	{ 0xF0A2A7B8, 0x7A3A5 },
	{ 0xF0A2A7B9, 0x6DDAB },
	{ 0xF0A2A7BA, 0x7A3A3 },
	{ 0xF0A2A7BD, 0xFCEFB },
	{ 0xF0A2A7BE, 0x7A3A9 },
	{ 0xF0A2A7BF, 0x7A3A6 },
	{ 0xF0A2A884, 0xFCEF7 },
	{ 0xF0A2A885, 0xFCEF8 },
	{ 0xF0A2A886, 0xFCEFA },
	{ 0xF0A2A887, 0x7A3AA },
	{ 0xF0A2A888, 0x7AEAA },
	{ 0xF0A2A889, 0x7AEA5 },
	{ 0xF0A2A88A, 0x7AEA4 },
	{ 0xF0A2A88B, 0x7AEA7 },
	{ 0xF0A2A88C, 0x7AEA6 },
	{ 0xF0A2A88D, 0x7AEA9 },
	{ 0xF0A2A88E, 0x7AEA8 },
	{ 0xF0A2A890, 0x7ACE3 },
	{ 0xF0A2A891, 0x7B1F0 },
	{ 0xF0A2A892, 0x7AEA3 },
	{ 0xF0A2A893, 0x7B8A7 },
	{ 0xF0A2A894, 0x5DBD3 },
	{ 0xF0A2A895, 0xFDAAF },
	{ 0xF0A2A899, 0x7BFE0 },
	{ 0xF0A2A89A, 0x7C7AD },
	{ 0xF0A2A89B, 0x4DFE5 },
	{ 0xF0A2A89E, 0x7C7AE },
	{ 0xF0A2A89F, 0x5ECAC },
	{ 0xF0A2A8A0, 0xFE5AC },
	{ 0xF0A2A8A1, 0x5F0A1 },
	{ 0xF0A2A8A3, 0x7D3BD },
	{ 0xF0A2A8A4, 0x6A3A7 },
	{ 0xF0A2A8A5, 0x5A1ED },
	{ 0xF0A2A8A6, 0x6A4F7 },
	{ 0xF0A2A8A9, 0x6A4F8 },
	{ 0xF0A2A8AA, 0x4A4B4 },
	{ 0xF0A2A8AC, 0xFA4B7 },
	{ 0xF0A2A8AD, 0xFA4B8 },
	{ 0xF0A2A8AF, 0x5A6B9 },
	{ 0xF0A2A8B2, 0x6ABD9 },
	{ 0xF0A2A8B4, 0x6ABDA },
	{ 0xF0A2A8B7, 0x6B1C3 },
	{ 0xF0A2A8B8, 0x6B1C2 },
	{ 0xF0A2A8B9, 0x6B1C4 },
	{ 0xF0A2A8BA, 0x5A9B9 },
	{ 0xF0A2A8BB, 0xFAAF3 },
	{ 0xF0A2A8BC, 0xFAAF4 },
	{ 0xF0A2A8BD, 0xFAAF5 },
	{ 0xF0A2A8BE, 0x6B1C6 },
	{ 0xF0A2A981, 0x6B1C5 },
	{ 0xF0A2A984, 0x5A9B8 },
	{ 0xF0A2A985, 0x6B7EC },
	{ 0xF0A2A986, 0x6B7EA },
	{ 0xF0A2A987, 0x6B7EB },
	{ 0xF0A2A988, 0x5ADE1 },
	{ 0xF0A2A98B, 0x5ADE0 },
	{ 0xF0A2A98D, 0x6C0A6 },
	{ 0xF0A2A98E, 0xFB4F7 },
	{ 0xF0A2A991, 0x5B8DD },
	{ 0xF0A2A992, 0x5B8DF },
	{ 0xF0A2A993, 0x5B8E0 },
	{ 0xF0A2A995, 0x5B8DE },
	{ 0xF0A2A996, 0x5BFCA },
	{ 0xF0A2A998, 0x5C5FE },
	{ 0xF0A2A999, 0x4C3D5 },
	{ 0xF0A2A99D, 0x7A3AB },
	{ 0xF0A2A9A0, 0x5DBD4 },
	{ 0xF0A2A9A2, 0x5F0A2 },
	{ 0xF0A2A9A5, 0x6A3A8 },
	{ 0xF0A2A9A6, 0x5A1EE },
	{ 0xF0A2A9A8, 0x6A3A9 },
	{ 0xF0A2A9A9, 0x6A3AA },
	{ 0xF0A2A9AB, 0x5A1EF },
	{ 0xF0A2A9AC, 0x5A2EC },
	{ 0xF0A2A9AD, 0x4A2F6 },
	{ 0xF0A2A9AE, 0x6A4F9 },
	{ 0xF0A2A9B0, 0x5A2F2 },
	{ 0xF0A2A9B1, 0x5A2F0 },
	{ 0xF0A2A9B2, 0x5A2EF },
	{ 0xF0A2A9B3, 0x5A2EB },
	{ 0xF0A2A9B4, 0x5A2ED },
	{ 0xF0A2A9B5, 0xFA2D0 },
	{ 0xF0A2A9B6, 0xFA2D2 },
	{ 0xF0A2AA82, 0x5A2F1 },
	{ 0xF0A2AA83, 0x4A4B7 },
	{ 0xF0A2AA84, 0x6A7F3 },
	{ 0xF0A2AA85, 0x6A7F6 },
	{ 0xF0A2AA86, 0x6A7F5 },
	{ 0xF0A2AA87, 0x4A6D7 },
	{ 0xF0A2AA88, 0x5A4BD },
	{ 0xF0A2AA89, 0x6A7EF },
	{ 0xF0A2AA8A, 0x4A4B8 },
	{ 0xF0A2AA8B, 0x4A4B5 },
	{ 0xF0A2AA8C, 0x6A7F7 },
	{ 0xF0A2AA8D, 0x5A4BE },
	{ 0xF0A2AA8E, 0x4A4BB },
	{ 0xF0A2AA8F, 0x6A7F2 },
	{ 0xF0A2AA90, 0x6ABDD },
	{ 0xF0A2AA91, 0x6A7F1 },
	{ 0xF0A2AA92, 0x6ABE5 },
	{ 0xF0A2AA93, 0x6ABDB },
	{ 0xF0A2AA94, 0x6A7F0 },
	{ 0xF0A2AA95, 0x5A4BC },
	{ 0xF0A2AA96, 0x6ABDC },
	{ 0xF0A2AA97, 0x6A7F4 },
	{ 0xF0A2AA9C, 0xFA4BB },
	{ 0xF0A2AA9D, 0xFA4BC },
	{ 0xF0A2AA9E, 0xFA4BD },
	{ 0xF0A2AA9F, 0xFA4BE },
	{ 0xF0A2AAA0, 0xFA4BF },
	{ 0xF0A2AAA1, 0xFA4C0 },
	{ 0xF0A2AAA2, 0xFA4C1 },
	{ 0xF0A2AAA3, 0xFA4C3 },
	{ 0xF0A2AAA4, 0xFA4C4 },
	{ 0xF0A2AAA7, 0xFA4C5 },
	{ 0xF0A2AAA9, 0xFA4BA },
	{ 0xF0A2AAB4, 0x6ABDE },
	{ 0xF0A2AAB5, 0x6ABDF },
	{ 0xF0A2AAB6, 0x6ABE1 },
	{ 0xF0A2AAB7, 0x5A6BB },
	{ 0xF0A2AAB8, 0x5A9BA },
	{ 0xF0A2AABA, 0x6ABE4 },
	{ 0xF0A2AABB, 0x6B1C8 },
	{ 0xF0A2AABC, 0x5A6BD },
	{ 0xF0A2AABD, 0x6B1CA },
	{ 0xF0A2AABE, 0x5A6BC },
	{ 0xF0A2AABF, 0x6B1C9 },
	{ 0xF0A2AB80, 0x6B1C7 },
	{ 0xF0A2AB82, 0x6ABE2 },
	{ 0xF0A2AB86, 0xFA7A6 },
	{ 0xF0A2AB87, 0xFA7A7 },
	{ 0xF0A2AB88, 0xFA7A8 },
	{ 0xF0A2AB89, 0xFA7A9 },
	{ 0xF0A2AB8A, 0xFA7AA },
	{ 0xF0A2AB8B, 0xFA7AB },
	{ 0xF0A2AB8C, 0xFA7AC },
	{ 0xF0A2AB8D, 0xFA7AD },
	{ 0xF0A2AB8E, 0xFA7AF },
	{ 0xF0A2AB94, 0xFA7A5 },
	{ 0xF0A2ABA2, 0x5A6BE },
	{ 0xF0A2ABA4, 0x6B1D2 },
	{ 0xF0A2ABA5, 0x6B1D4 },
	{ 0xF0A2ABA6, 0x4A9D8 },
	{ 0xF0A2ABA7, 0x4A9CF },
	{ 0xF0A2ABA8, 0x4A9D0 },
	{ 0xF0A2ABA9, 0x6B1D3 },
	{ 0xF0A2ABAA, 0x6B7ED },
	{ 0xF0A2ABAB, 0x5A9BF },
	{ 0xF0A2ABAC, 0x5A9C2 },
	{ 0xF0A2ABAD, 0x5A9C1 },
	{ 0xF0A2ABAE, 0x6B1CD },
	{ 0xF0A2ABAF, 0x5A9C7 },
	{ 0xF0A2ABB0, 0x4ADB4 },
	{ 0xF0A2ABB1, 0x4A9DC },
	{ 0xF0A2ABB2, 0x5A9BE },
	{ 0xF0A2ABB3, 0x5A9BD },
	{ 0xF0A2ABB4, 0x5ADE3 },
	{ 0xF0A2ABB5, 0x4A9D3 },
	{ 0xF0A2ABB6, 0x6B7EE },
	{ 0xF0A2ABB7, 0x5A9C8 },
	{ 0xF0A2ABB8, 0x4A9DA },
	{ 0xF0A2ABB9, 0x6B1D0 },
	{ 0xF0A2ABBA, 0x5A9C0 },
	{ 0xF0A2ABBB, 0x5A9C4 },
	{ 0xF0A2ABBC, 0x6B1CE },
	{ 0xF0A2ABBD, 0x6B1D6 },
	{ 0xF0A2ABBE, 0x6B1CB },
	{ 0xF0A2ABBF, 0x5A9C3 },
	{ 0xF0A2AC80, 0x5A9BC },
	{ 0xF0A2AC83, 0x6B1D5 },
	{ 0xF0A2AC86, 0x6B1D1 },
	{ 0xF0A2AC87, 0xFAAF6 },
	{ 0xF0A2AC88, 0xFAAF7 },
	{ 0xF0A2AC89, 0xFAAF8 },
	{ 0xF0A2AC8A, 0xFAAF9 },
	{ 0xF0A2AC8B, 0xFAAFA },
	{ 0xF0A2AC8C, 0xFAAFB },
	{ 0xF0A2AC8D, 0xFAAFC },
	{ 0xF0A2AC8E, 0xFAAFD },
	{ 0xF0A2AC8F, 0xFAAFE },
	{ 0xF0A2AC90, 0xFABA1 },
	{ 0xF0A2AC91, 0xFABA3 },
	{ 0xF0A2AC92, 0xFABA4 },
	{ 0xF0A2AC93, 0xFABA5 },
	{ 0xF0A2AC94, 0xFABA6 },
	{ 0xF0A2AC95, 0xFABA7 },
	{ 0xF0A2AC96, 0xFABA8 },
	{ 0xF0A2AC97, 0xFABA9 },
	{ 0xF0A2AC98, 0xFABAA },
	{ 0xF0A2AC99, 0xFAFD3 },
	{ 0xF0A2AC9A, 0xFAFDC },
	{ 0xF0A2AC9B, 0xFAFE1 },
	{ 0xF0A2AC9E, 0x6B1CC },
	{ 0xF0A2ACA2, 0xFABA2 },
	{ 0xF0A2ACAA, 0x5A9BB },
	{ 0xF0A2ACAB, 0x5ADE2 },
	{ 0xF0A2ACAC, 0x5ADE4 },
	{ 0xF0A2ACAF, 0x4ADBD },
	{ 0xF0A2ACB0, 0x6B7F5 },
	{ 0xF0A2ACB1, 0x4ADB8 },
	{ 0xF0A2ACB2, 0x5ADED },
	{ 0xF0A2ACB3, 0x5ADEB },
	{ 0xF0A2ACB4, 0x4ADB9 },
	{ 0xF0A2ACB5, 0x4A9D7 },
	{ 0xF0A2ACB6, 0x4ADB5 },
	{ 0xF0A2ACB7, 0x5ADEA },
	{ 0xF0A2ACB8, 0x6B7FB },
	{ 0xF0A2ACB9, 0x6B7F0 },
	{ 0xF0A2ACBA, 0x6B7FD },
	{ 0xF0A2ACBB, 0x6B7F3 },
	{ 0xF0A2ACBC, 0x5ADE9 },
	{ 0xF0A2ACBD, 0x6B7F2 },
	{ 0xF0A2ACBE, 0x6B7F7 },
	{ 0xF0A2ACBF, 0x4ADB6 },
	{ 0xF0A2AD80, 0x6B7F8 },
	{ 0xF0A2AD81, 0x5ADEC },
	{ 0xF0A2AD82, 0x5ADE5 },
	{ 0xF0A2AD83, 0x4ADB7 },
	{ 0xF0A2AD84, 0x5ADE7 },
	{ 0xF0A2AD85, 0x5ADE8 },
	{ 0xF0A2AD86, 0x4ADBA },
	{ 0xF0A2AD87, 0x6B7FA },
	{ 0xF0A2AD88, 0x5ADE6 },
	{ 0xF0A2AD89, 0x6B1D7 },
	{ 0xF0A2AD8A, 0x6B7F6 },
	{ 0xF0A2AD8B, 0x6C0A7 },
	{ 0xF0A2AD8C, 0x6B7F9 },
	{ 0xF0A2AD8D, 0x6B7F4 },
	{ 0xF0A2AD8E, 0x5A9C6 },
	{ 0xF0A2AD92, 0x6B7FC },
	{ 0xF0A2AD93, 0x6B7FE },
	{ 0xF0A2AD94, 0xFAFCC },
	{ 0xF0A2AD95, 0xFAFCD },
	{ 0xF0A2AD96, 0xFAFCE },
	{ 0xF0A2AD97, 0xFAFCF },
	{ 0xF0A2AD98, 0xFAFD0 },
	{ 0xF0A2AD99, 0xFAFD1 },
	{ 0xF0A2AD9A, 0xFAFD2 },
	{ 0xF0A2AD9B, 0xFAFD5 },
	{ 0xF0A2AD9C, 0xFAFD6 },
	{ 0xF0A2AD9D, 0xFAFD7 },
	{ 0xF0A2AD9E, 0xFAFDA },
	{ 0xF0A2AD9F, 0xFAFDB },
	{ 0xF0A2ADA0, 0xFAFDD },
	{ 0xF0A2ADA1, 0xFAFDE },
	{ 0xF0A2ADA2, 0xFAFE0 },
	{ 0xF0A2ADA3, 0xFAFE2 },
	{ 0xF0A2ADA4, 0x6C0A8 },
	{ 0xF0A2ADA6, 0xFAFD8 },
	{ 0xF0A2ADA8, 0x6B7EF },
	{ 0xF0A2ADAA, 0xFAFD4 },
	{ 0xF0A2AE81, 0x4B1F2 },
	{ 0xF0A2AE82, 0x4B1F3 },
	{ 0xF0A2AE83, 0x4B7DE },
	{ 0xF0A2AE84, 0x5B2E9 },
	{ 0xF0A2AE86, 0x6C0B1 },
	{ 0xF0A2AE87, 0x5ADEE },
	{ 0xF0A2AE88, 0x6C0B7 },
	{ 0xF0A2AE89, 0x5B2E3 },
	{ 0xF0A2AE8A, 0x4B1F4 },
	{ 0xF0A2AE8B, 0x4B2A2 },
	{ 0xF0A2AE8C, 0x4B1F6 },
	{ 0xF0A2AE8D, 0x5B2E2 },
	{ 0xF0A2AE8E, 0x4B1FD },
	{ 0xF0A2AE8F, 0x5B8E1 },
	{ 0xF0A2AE90, 0x5B2E4 },
	{ 0xF0A2AE91, 0x6C0B4 },
	{ 0xF0A2AE92, 0x5B2E7 },
	{ 0xF0A2AE93, 0x6C0B5 },
	{ 0xF0A2AE94, 0x6C0AC },
	{ 0xF0A2AE95, 0x6C0A9 },
	{ 0xF0A2AE96, 0x4B2A4 },
	{ 0xF0A2AE97, 0x6C9AF },
	{ 0xF0A2AE98, 0x6C9AA },
	{ 0xF0A2AE99, 0x6C0AA },
	{ 0xF0A2AE9A, 0x5B2E5 },
	{ 0xF0A2AE9C, 0x6C9AD },
	{ 0xF0A2AE9D, 0x4B7DD },
	{ 0xF0A2AE9E, 0x6C0AF },
	{ 0xF0A2AE9F, 0x6C9AC },
	{ 0xF0A2AEA0, 0x6C9AB },
	{ 0xF0A2AEA1, 0x5B2E8 },
	{ 0xF0A2AEA2, 0x6C0AD },
	{ 0xF0A2AEA3, 0x6C9AE },
	{ 0xF0A2AEA4, 0x6C0B3 },
	{ 0xF0A2AEA7, 0x6C0B0 },
	{ 0xF0A2AEA8, 0x4B1F5 },
	{ 0xF0A2AEAE, 0x6C0AE },
	{ 0xF0A2AEAF, 0xFB4F8 },
	{ 0xF0A2AEB0, 0xFB4F9 },
	{ 0xF0A2AEB1, 0xFB4FA },
	{ 0xF0A2AEB2, 0xFB4FB },
	{ 0xF0A2AEB3, 0xFB4FC },
	{ 0xF0A2AEB4, 0xFB4FE },
	{ 0xF0A2AEB5, 0xFB5A2 },
	{ 0xF0A2AEB6, 0xFB5A3 },
	{ 0xF0A2AEB7, 0xFB5A4 },
	{ 0xF0A2AEB8, 0xFB5A5 },
	{ 0xF0A2AEB9, 0xFB5A6 },
	{ 0xF0A2AEBA, 0xFB5A7 },
	{ 0xF0A2AEBB, 0xFB5A8 },
	{ 0xF0A2AEBC, 0xFB5A9 },
	{ 0xF0A2AEBD, 0xFB5AA },
	{ 0xF0A2AEBE, 0xFB5AB },
	{ 0xF0A2AEBF, 0xFB5AC },
	{ 0xF0A2AF80, 0xFB5AE },
	{ 0xF0A2AF81, 0xFB5AD },
	{ 0xF0A2AF82, 0xFB5AF },
	{ 0xF0A2AF83, 0xFB5B0 },
	{ 0xF0A2AF84, 0xFBBB1 },
	{ 0xF0A2AF86, 0xFB4FD },
	{ 0xF0A2AF88, 0x5B2E6 },
	{ 0xF0A2AF8C, 0x4B2A6 },
	{ 0xF0A2AFA3, 0xFBBC1 },
	{ 0xF0A2AFA9, 0x5B8EB },
	{ 0xF0A2AFAA, 0x6C9B4 },
	{ 0xF0A2AFAB, 0x4B7E9 },
	{ 0xF0A2AFAC, 0x6C9BB },
	{ 0xF0A2AFAD, 0x6C9B6 },
	{ 0xF0A2AFAE, 0x5B8ED },
	{ 0xF0A2AFAF, 0x6C9C1 },
	{ 0xF0A2AFB0, 0x5B8F4 },
	{ 0xF0A2AFB1, 0x6C9B1 },
	{ 0xF0A2AFB2, 0x4BDD1 },
	{ 0xF0A2AFB3, 0x4B7E7 },
	{ 0xF0A2AFB4, 0x5B8E2 },
	{ 0xF0A2AFB5, 0x5B8EA },
	{ 0xF0A2AFB6, 0x4B7DF },
	{ 0xF0A2AFB7, 0x5B8E8 },
	{ 0xF0A2AFB8, 0x4B7E3 },
	{ 0xF0A2AFB9, 0x5B8E9 },
	{ 0xF0A2AFBA, 0x4B7EA },
	{ 0xF0A2AFBB, 0x5B8E6 },
	{ 0xF0A2AFBC, 0x4B7ED },
	{ 0xF0A2AFBD, 0x5B8EF },
	{ 0xF0A2AFBE, 0x4B7E6 },
	{ 0xF0A2AFBF, 0x6C9C2 },
	{ 0xF0A2B080, 0x6C9C3 },
	{ 0xF0A2B081, 0x6C9BA },
	{ 0xF0A2B082, 0x5B8F1 },
	{ 0xF0A2B083, 0x6C9B3 },
	{ 0xF0A2B084, 0x6C9C6 },
	{ 0xF0A2B085, 0x6C9B7 },
	{ 0xF0A2B086, 0x5B8F0 },
	{ 0xF0A2B087, 0x4B7EC },
	{ 0xF0A2B088, 0x6C9C7 },
	{ 0xF0A2B089, 0x6C9B2 },
	{ 0xF0A2B08A, 0x5B8EC },
	{ 0xF0A2B08B, 0x5B8EE },
	{ 0xF0A2B08C, 0x6C9C4 },
	{ 0xF0A2B08D, 0x5B8E4 },
	{ 0xF0A2B08E, 0x6C9BC },
	{ 0xF0A2B08F, 0x6C9C5 },
	{ 0xF0A2B090, 0x6C9C0 },
	{ 0xF0A2B091, 0x6C9CC },
	{ 0xF0A2B092, 0x6C9BF },
	{ 0xF0A2B093, 0x6C9CD },
	{ 0xF0A2B094, 0x6C9C8 },
	{ 0xF0A2B095, 0x6C9B9 },
	{ 0xF0A2B096, 0x5B8F2 },
	{ 0xF0A2B097, 0x6C9BD },
	{ 0xF0A2B098, 0x5B8F3 },
	{ 0xF0A2B099, 0x5B8E7 },
	{ 0xF0A2B09A, 0x6C9B8 },
	{ 0xF0A2B09B, 0x6C9CB },
	{ 0xF0A2B09C, 0x5B8E5 },
	{ 0xF0A2B0A8, 0x6D2F3 },
	{ 0xF0A2B0A9, 0xFBBB0 },
	{ 0xF0A2B0AA, 0xFBBB2 },
	{ 0xF0A2B0AB, 0xFBBB4 },
	{ 0xF0A2B0AC, 0xFBBB5 },
	{ 0xF0A2B0AD, 0xFBBB6 },
	{ 0xF0A2B0AE, 0xFBBB7 },
	{ 0xF0A2B0AF, 0xFBBB8 },
	{ 0xF0A2B0B0, 0xFBBB9 },
	{ 0xF0A2B0B1, 0xFBBBA },
	{ 0xF0A2B0B2, 0xFBBBB },
	{ 0xF0A2B0B3, 0xFBBBC },
	{ 0xF0A2B0B4, 0xFBBBD },
	{ 0xF0A2B0B5, 0xFBBBF },
	{ 0xF0A2B0B6, 0xFBBC0 },
	{ 0xF0A2B0B7, 0xFBBC2 },
	{ 0xF0A2B0B8, 0xFBBC3 },
	{ 0xF0A2B0B9, 0xFBBC4 },
	{ 0xF0A2B0BA, 0xFBBC5 },
	{ 0xF0A2B0BB, 0xFBBC6 },
	{ 0xF0A2B0BC, 0xFBBC8 },
	{ 0xF0A2B0BD, 0xFBBC9 },
	{ 0xF0A2B0BE, 0xFBBCA },
	{ 0xF0A2B180, 0x6D2F4 },
	{ 0xF0A2B182, 0x6C9BE },
	{ 0xF0A2B183, 0x6C9C9 },
	{ 0xF0A2B185, 0x6C9B5 },
	{ 0xF0A2B187, 0x5B8E3 },
	{ 0xF0A2B18D, 0xFBBC7 },
	{ 0xF0A2B19F, 0x5BFD2 },
	{ 0xF0A2B1A0, 0x6D2FB },
	{ 0xF0A2B1A1, 0x4BDCB },
	{ 0xF0A2B1A2, 0x4BDC9 },
	{ 0xF0A2B1A3, 0x5BFD5 },
	{ 0xF0A2B1A4, 0x4BDC6 },
	{ 0xF0A2B1A5, 0x6D2F8 },
	{ 0xF0A2B1A6, 0x4BDCD },
	{ 0xF0A2B1A7, 0x4BDD3 },
	{ 0xF0A2B1A8, 0x4BDC7 },
	{ 0xF0A2B1A9, 0x4BDD2 },
	{ 0xF0A2B1AA, 0x6D2FE },
	{ 0xF0A2B1AB, 0x5BFD1 },
	{ 0xF0A2B1AC, 0x5C6A1 },
	{ 0xF0A2B1AE, 0x5BFCB },
	{ 0xF0A2B1AF, 0x6DDAC },
	{ 0xF0A2B1B0, 0x6D3A5 },
	{ 0xF0A2B1B1, 0x6D2F5 },
	{ 0xF0A2B1B2, 0x6D3A3 },
	{ 0xF0A2B1B3, 0x6D3A2 },
	{ 0xF0A2B1B4, 0x5BFCD },
	{ 0xF0A2B1B6, 0x5BFD3 },
	{ 0xF0A2B1B7, 0x5BFCE },
	{ 0xF0A2B1B8, 0x6D2F9 },
	{ 0xF0A2B1B9, 0x6D3A1 },
	{ 0xF0A2B1BA, 0x5BFD0 },
	{ 0xF0A2B1BB, 0x6D3A4 },
	{ 0xF0A2B1BC, 0x6D2FC },
	{ 0xF0A2B1BE, 0x5BFCC },
	{ 0xF0A2B1BF, 0x6D2FA },
	{ 0xF0A2B280, 0x5BFCF },
	{ 0xF0A2B281, 0xFC1D6 },
	{ 0xF0A2B282, 0xFC1D7 },
	{ 0xF0A2B283, 0xFC1D8 },
	{ 0xF0A2B284, 0xFC1D9 },
	{ 0xF0A2B285, 0xFC1DA },
	{ 0xF0A2B286, 0xFC1DB },
	{ 0xF0A2B287, 0xFC1DC },
	{ 0xF0A2B288, 0xFC1DD },
	{ 0xF0A2B289, 0xFC1DE },
	{ 0xF0A2B28A, 0xFC1E0 },
	{ 0xF0A2B28B, 0xFC1E1 },
	{ 0xF0A2B28C, 0xFC1E3 },
	{ 0xF0A2B28D, 0xFC1E4 },
	{ 0xF0A2B28E, 0xFC1E5 },
	{ 0xF0A2B28F, 0xFC1E6 },
	{ 0xF0A2B290, 0xFC1E7 },
	{ 0xF0A2B291, 0xFC1E9 },
	{ 0xF0A2B292, 0xFC8B0 },
	{ 0xF0A2B295, 0x6D2F7 },
	{ 0xF0A2B296, 0x6D2FD },
	{ 0xF0A2B298, 0x6D2F6 },
	{ 0xF0A2B2A1, 0xFC1E8 },
	{ 0xF0A2B2B0, 0x5BFD4 },
	{ 0xF0A2B2B3, 0x6DDB6 },
	{ 0xF0A2B2B4, 0x5CDB9 },
	{ 0xF0A2B2B5, 0x5C6A7 },
	{ 0xF0A2B2B6, 0x5C6AA },
	{ 0xF0A2B2B7, 0x4C3E2 },
	{ 0xF0A2B2B8, 0x4C3DF },
	{ 0xF0A2B2B9, 0x6DDBC },
	{ 0xF0A2B2BA, 0x6DDBD },
	{ 0xF0A2B2BB, 0x6DDAE },
	{ 0xF0A2B2BC, 0x4C3D7 },
	{ 0xF0A2B2BD, 0x6DDBF },
	{ 0xF0A2B2BE, 0x5C6A6 },
	{ 0xF0A2B380, 0x4C3E3 },
	{ 0xF0A2B381, 0x5CDB8 },
	{ 0xF0A2B382, 0x5C6A9 },
	{ 0xF0A2B383, 0x6DDB5 },
	{ 0xF0A2B384, 0x4C3D9 },
	{ 0xF0A2B385, 0x7A3AF },
	{ 0xF0A2B386, 0x4C3DB },
	{ 0xF0A2B387, 0x4C3DA },
	{ 0xF0A2B388, 0x7A3AE },
	{ 0xF0A2B389, 0x7A3B1 },
	{ 0xF0A2B38B, 0x5C6A4 },
	{ 0xF0A2B38D, 0x4C3E5 },
	{ 0xF0A2B38E, 0x6DDB9 },
	{ 0xF0A2B38F, 0x6DDBE },
	{ 0xF0A2B390, 0x6DDBA },
	{ 0xF0A2B391, 0x5C6A8 },
	{ 0xF0A2B392, 0x6DDB7 },
	{ 0xF0A2B393, 0x5C6AB },
	{ 0xF0A2B394, 0x7A3AC },
	{ 0xF0A2B395, 0x6DDBB },
	{ 0xF0A2B396, 0x6DDB3 },
	{ 0xF0A2B398, 0x6DDB1 },
	{ 0xF0A2B399, 0x5C6A2 },
	{ 0xF0A2B39A, 0x4C3E0 },
	{ 0xF0A2B3A1, 0x6DDAF },
	{ 0xF0A2B3A2, 0x6DDB4 },
	{ 0xF0A2B3A3, 0xFC8AB },
	{ 0xF0A2B3A4, 0xFC8AC },
	{ 0xF0A2B3A5, 0xFC8AD },
	{ 0xF0A2B3A6, 0xFC8AE },
	{ 0xF0A2B3A7, 0xFC8AF },
	{ 0xF0A2B3A8, 0xFC8B3 },
	{ 0xF0A2B3A9, 0xFC8B4 },
	{ 0xF0A2B3AA, 0xFC8B5 },
	{ 0xF0A2B3AB, 0xFC8B7 },
	{ 0xF0A2B3AC, 0xFC8B8 },
	{ 0xF0A2B3AD, 0xFC8BA },
	{ 0xF0A2B3AE, 0xFC8BB },
	{ 0xF0A2B3AF, 0xFC8B9 },
	{ 0xF0A2B3B0, 0xFC8BC },
	{ 0xF0A2B3B1, 0xFC8BD },
	{ 0xF0A2B3B2, 0xFC8BE },
	{ 0xF0A2B3B3, 0xFC8BF },
	{ 0xF0A2B3B4, 0xFC8C0 },
	{ 0xF0A2B3B5, 0xFC8C1 },
	{ 0xF0A2B3B6, 0xFC8C2 },
	{ 0xF0A2B3B7, 0xFC8C3 },
	{ 0xF0A2B3B8, 0xFC8C4 },
	{ 0xF0A2B3B9, 0xFC8C5 },
	{ 0xF0A2B3BA, 0xFC8C7 },
	{ 0xF0A2B3BB, 0xFC8C8 },
	{ 0xF0A2B3BC, 0xFC8C9 },
	{ 0xF0A2B3BE, 0xFC8C6 },
	{ 0xF0A2B480, 0x6DDB0 },
	{ 0xF0A2B481, 0xFC8B6 },
	{ 0xF0A2B4A0, 0x7A3B3 },
	{ 0xF0A2B4A1, 0x7A3B8 },
	{ 0xF0A2B4A2, 0x5CDBC },
	{ 0xF0A2B4A3, 0x4CAA5 },
	{ 0xF0A2B4A4, 0x7A3BD },
	{ 0xF0A2B4A5, 0x7A3B7 },
	{ 0xF0A2B4A6, 0x7A3B9 },
	{ 0xF0A2B4A7, 0x4C9FB },
	{ 0xF0A2B4A8, 0x4C9F8 },
	{ 0xF0A2B4A9, 0x5CDBD },
	{ 0xF0A2B4AA, 0x5CDBB },
	{ 0xF0A2B4AB, 0x7A3C5 },
	{ 0xF0A2B4AC, 0x4C9FD },
	{ 0xF0A2B4AD, 0x7AEAF },
	{ 0xF0A2B4AE, 0x4CAA1 },
	{ 0xF0A2B4B0, 0x5CDC1 },
	{ 0xF0A2B4B1, 0x4CAA6 },
	{ 0xF0A2B4B2, 0x4C9FC },
	{ 0xF0A2B4B3, 0x5D4D9 },
	{ 0xF0A2B4B4, 0x7AEBC },
	{ 0xF0A2B4B5, 0x7A3B5 },
	{ 0xF0A2B4B6, 0x7A3B4 },
	{ 0xF0A2B4B7, 0x7AEAD },
	{ 0xF0A2B4B8, 0x7AEAB },
	{ 0xF0A2B4B9, 0x7A3C4 },
	{ 0xF0A2B4BA, 0x7AEAC },
	{ 0xF0A2B4BB, 0x7A3BC },
	{ 0xF0A2B4BC, 0x5CDC0 },
	{ 0xF0A2B4BD, 0x7AEAE },
	{ 0xF0A2B4BE, 0x5CDBF },
	{ 0xF0A2B4BF, 0x7A3BB },
	{ 0xF0A2B580, 0x7A3C2 },
	{ 0xF0A2B581, 0x7A3C3 },
	{ 0xF0A2B583, 0x7A3BE },
	{ 0xF0A2B584, 0x7A3C1 },
	{ 0xF0A2B588, 0x4C9F7 },
	{ 0xF0A2B58A, 0xFC8B1 },
	{ 0xF0A2B58D, 0x7A3B2 },
	{ 0xF0A2B58E, 0x7A3BF },
	{ 0xF0A2B58F, 0x7A3C0 },
	{ 0xF0A2B590, 0xFCEFC },
	{ 0xF0A2B591, 0xFCEFD },
	{ 0xF0A2B592, 0xFCEFE },
	{ 0xF0A2B593, 0xFCFA1 },
	{ 0xF0A2B594, 0xFCFA2 },
	{ 0xF0A2B595, 0xFCFA3 },
	{ 0xF0A2B596, 0xFCFA6 },
	{ 0xF0A2B597, 0xFCFA7 },
	{ 0xF0A2B598, 0xFCFA8 },
	{ 0xF0A2B599, 0xFCFA9 },
	{ 0xF0A2B59A, 0xFCFAA },
	{ 0xF0A2B59B, 0xFCFAB },
	{ 0xF0A2B59C, 0xFCFAD },
	{ 0xF0A2B59D, 0xFCFAE },
	{ 0xF0A2B59E, 0xFCFAF },
	{ 0xF0A2B59F, 0xFCFB0 },
	{ 0xF0A2B5A0, 0xFD4DF },
	{ 0xF0A2B5A3, 0xFCFA4 },
	{ 0xF0A2B5BF, 0x4D6B8 },
	{ 0xF0A2B680, 0x4D0C1 },
	{ 0xF0A2B681, 0x7AEB5 },
	{ 0xF0A2B682, 0x7AEB0 },
	{ 0xF0A2B683, 0x5D4DA },
	{ 0xF0A2B684, 0x5D4DB },
	{ 0xF0A2B685, 0x7AEBE },
	{ 0xF0A2B686, 0x7AEBA },
	{ 0xF0A2B687, 0x7AEB2 },
	{ 0xF0A2B688, 0x7A3B6 },
	{ 0xF0A2B689, 0x4D0BE },
	{ 0xF0A2B68A, 0x4D0C3 },
	{ 0xF0A2B68B, 0x4D0C0 },
	{ 0xF0A2B68C, 0x5D4DD },
	{ 0xF0A2B68D, 0x4D0BF },
	{ 0xF0A2B68E, 0x7AEBD },
	{ 0xF0A2B68F, 0x4D0C6 },
	{ 0xF0A2B690, 0x7AEBB },
	{ 0xF0A2B691, 0x4D0C8 },
	{ 0xF0A2B692, 0x4D0C2 },
	{ 0xF0A2B693, 0x4D0C7 },
	{ 0xF0A2B694, 0x7AEB9 },
	{ 0xF0A2B695, 0x7AEB1 },
	{ 0xF0A2B696, 0x7AEC0 },
	{ 0xF0A2B697, 0x7B8A9 },
	{ 0xF0A2B698, 0x7AEB8 },
	{ 0xF0A2B699, 0x5D4DF },
	{ 0xF0A2B69A, 0x5D4DC },
	{ 0xF0A2B69B, 0x7AEB7 },
	{ 0xF0A2B69C, 0x7B8A8 },
	{ 0xF0A2B69D, 0x7AEB3 },
	{ 0xF0A2B6A6, 0x7AEBF },
	{ 0xF0A2B6A7, 0xFD4D5 },
	{ 0xF0A2B6A8, 0xFD4D6 },
	{ 0xF0A2B6A9, 0xFD4D7 },
	{ 0xF0A2B6AA, 0xFD4D8 },
	{ 0xF0A2B6AB, 0xFD4D9 },
	{ 0xF0A2B6AC, 0xFD4DA },
	{ 0xF0A2B6AD, 0xFD4DB },
	{ 0xF0A2B6AE, 0xFD4DC },
	{ 0xF0A2B6AF, 0xFD4DD },
	{ 0xF0A2B6B0, 0xFD4DE },
	{ 0xF0A2B6B1, 0xFD4E0 },
	{ 0xF0A2B6B5, 0x7AEB4 },
	{ 0xF0A2B787, 0x7AEB6 },
	{ 0xF0A2B788, 0x4D0C4 },
	{ 0xF0A2B789, 0xFD4D4 },
	{ 0xF0A2B78B, 0x5DBD6 },
	{ 0xF0A2B78C, 0x7B8B1 },
	{ 0xF0A2B78D, 0x5DBD7 },
	{ 0xF0A2B78E, 0x7B8B6 },
	{ 0xF0A2B78F, 0x4D6BB },
	{ 0xF0A2B790, 0x7B8AF },
	{ 0xF0A2B791, 0x7B8B5 },
	{ 0xF0A2B792, 0x4D6BA },
	{ 0xF0A2B793, 0x7B8B4 },
	{ 0xF0A2B794, 0x7B8AC },
	{ 0xF0A2B795, 0x5DBD8 },
	{ 0xF0A2B796, 0x4D6B7 },
	{ 0xF0A2B797, 0x5DBD5 },
	{ 0xF0A2B798, 0x7B8AA },
	{ 0xF0A2B799, 0x7B8B7 },
	{ 0xF0A2B79A, 0x7B8B0 },
	{ 0xF0A2B79B, 0x7B8AE },
	{ 0xF0A2B79C, 0x7B8B2 },
	{ 0xF0A2B79D, 0x7B8B8 },
	{ 0xF0A2B7A4, 0x7B8AB },
	{ 0xF0A2B7A5, 0x7B8AD },
	{ 0xF0A2B7A6, 0xFDAB0 },
	{ 0xF0A2B7A7, 0xFDAB1 },
	{ 0xF0A2B7A8, 0xFDAB2 },
	{ 0xF0A2B7A9, 0xFDAB3 },
	{ 0xF0A2B7AA, 0xFDAB4 },
	{ 0xF0A2B7AB, 0xFDAB5 },
	{ 0xF0A2B7AD, 0x7B8B3 },
	{ 0xF0A2B7B6, 0x4DBB3 },
	{ 0xF0A2B7B7, 0x4DBB8 },
	{ 0xF0A2B7B8, 0x5E1EE },
	{ 0xF0A2B7B9, 0x5E1EB },
	{ 0xF0A2B7BA, 0x5E1EC },
	{ 0xF0A2B7BB, 0x5E1ED },
	{ 0xF0A2B7BC, 0x7BFE8 },
	{ 0xF0A2B7BD, 0x7BFE7 },
	{ 0xF0A2B7BE, 0x4DBB5 },
	{ 0xF0A2B7BF, 0x4DBB7 },
	{ 0xF0A2B880, 0x5E7FA },
	{ 0xF0A2B881, 0x5ECAD },
	{ 0xF0A2B882, 0x7BFE9 },
	{ 0xF0A2B883, 0x7BFE6 },
	{ 0xF0A2B884, 0x4DBB4 },
	{ 0xF0A2B885, 0x7BFE3 },
	{ 0xF0A2B886, 0x7BFE5 },
	{ 0xF0A2B887, 0x7C7AF },
	{ 0xF0A2B888, 0x7BFE1 },
	{ 0xF0A2B889, 0x7BFE4 },
	{ 0xF0A2B88E, 0xFDEE8 },
	{ 0xF0A2B88F, 0xFDEE9 },
	{ 0xF0A2B890, 0xFDEEA },
	{ 0xF0A2B891, 0xFDEED },
	{ 0xF0A2B892, 0xFDEEE },
	{ 0xF0A2B893, 0xFDEEF },
	{ 0xF0A2B894, 0xFDEF1 },
	{ 0xF0A2B895, 0xFDEF2 },
	{ 0xF0A2B896, 0xFDEF4 },
	{ 0xF0A2B898, 0xFDEEC },
	{ 0xF0A2B899, 0xFDEEB },
	{ 0xF0A2B8A3, 0x4DFE6 },
	{ 0xF0A2B8A4, 0x4DFE8 },
	{ 0xF0A2B8A5, 0x4DFE7 },
	{ 0xF0A2B8A6, 0x4DFE9 },
	{ 0xF0A2B8A7, 0x5ECAF },
	{ 0xF0A2B8A8, 0x7C7B2 },
	{ 0xF0A2B8A9, 0x7C7B4 },
	{ 0xF0A2B8AA, 0x7C7B6 },
	{ 0xF0A2B8AB, 0x5E7FB },
	{ 0xF0A2B8AC, 0x7C7B0 },
	{ 0xF0A2B8AD, 0x5ECAE },
	{ 0xF0A2B8AE, 0x7C7B8 },
	{ 0xF0A2B8AF, 0x4DFEB },
	{ 0xF0A2B8B0, 0x7C7B5 },
	{ 0xF0A2B8B1, 0x7C7B3 },
	{ 0xF0A2B8B2, 0x7C7B1 },
	{ 0xF0A2B8B3, 0x4DFEA },
	{ 0xF0A2B8B4, 0x5E7F9 },
	{ 0xF0A2B8B7, 0xFE2BE },
	{ 0xF0A2B8B8, 0xFE2BF },
	{ 0xF0A2B8B9, 0xFE2C0 },
	{ 0xF0A2B8BA, 0xFE2C1 },
	{ 0xF0A2B8BB, 0xFE2C2 },
	{ 0xF0A2B8BC, 0xFE2C3 },
	{ 0xF0A2B8BD, 0xFE2C4 },
	{ 0xF0A2B8BE, 0xFE2C5 },
	{ 0xF0A2B8BF, 0xFE2C6 },
	{ 0xF0A2B980, 0xFE2C9 },
	{ 0xF0A2B981, 0xFE5AF },
	{ 0xF0A2B982, 0x7BFEA },
	{ 0xF0A2B984, 0x7C7B7 },
	{ 0xF0A2B98B, 0xFE2C7 },
	{ 0xF0A2B98D, 0x5ECB2 },
	{ 0xF0A2B98F, 0x4E6BF },
	{ 0xF0A2B990, 0x7CDED },
	{ 0xF0A2B991, 0x4E3C8 },
	{ 0xF0A2B993, 0x7CDEC },
	{ 0xF0A2B994, 0x4E3C9 },
	{ 0xF0A2B995, 0x7CDF0 },
	{ 0xF0A2B996, 0x4E3CA },
	{ 0xF0A2B997, 0x7CDEE },
	{ 0xF0A2B998, 0x5ECB3 },
	{ 0xF0A2B999, 0x5ECB0 },
	{ 0xF0A2B99A, 0x5ECB1 },
	{ 0xF0A2B99F, 0x7CDEF },
	{ 0xF0A2B9A0, 0xFE5AD },
	{ 0xF0A2B9A1, 0xFE5AE },
	{ 0xF0A2B9A2, 0xFE5B0 },
	{ 0xF0A2B9AC, 0x7D3C4 },
	{ 0xF0A2B9AD, 0x7D7F7 },
	{ 0xF0A2B9AE, 0x4E6C1 },
	{ 0xF0A2B9AF, 0x7D3BF },
	{ 0xF0A2B9B0, 0x7D3C3 },
	{ 0xF0A2B9B1, 0x7D3C2 },
	{ 0xF0A2B9B2, 0x4E6C2 },
	{ 0xF0A2B9B3, 0x5F3C5 },
	{ 0xF0A2B9B4, 0x7D3C1 },
	{ 0xF0A2B9B5, 0x7D3C0 },
	{ 0xF0A2B9B7, 0xFE7D6 },
	{ 0xF0A2B9B9, 0xFE7D7 },
	{ 0xF0A2B9BA, 0xFE7D8 },
	{ 0xF0A2B9BB, 0xFE7D9 },
	{ 0xF0A2BA82, 0x7D7F8 },
	{ 0xF0A2BA83, 0x7D7F9 },
	{ 0xF0A2BA84, 0x5F3C4 },
	{ 0xF0A2BA85, 0x5F3C7 },
	{ 0xF0A2BA86, 0x5F0A3 },
	{ 0xF0A2BA87, 0x7D7FA },
	{ 0xF0A2BA88, 0x5F3C2 },
	{ 0xF0A2BA89, 0x5F3C6 },
	{ 0xF0A2BA8A, 0x7D7FC },
	{ 0xF0A2BA8B, 0x7DBD7 },
	{ 0xF0A2BA8C, 0x7D3BE },
	{ 0xF0A2BA8F, 0xFE9C3 },
	{ 0xF0A2BA90, 0xFE9C4 },
	{ 0xF0A2BA91, 0x5F3C3 },
	{ 0xF0A2BA95, 0x7D7FB },
	{ 0xF0A2BA96, 0x7DBD8 },
	{ 0xF0A2BA98, 0xFEAD4 },
	{ 0xF0A2BA99, 0xFEAD5 },
	{ 0xF0A2BA9A, 0xFEAD6 },
	{ 0xF0A2BA9E, 0x7DEEA },
	{ 0xF0A2BA9F, 0x5F7DD },
	{ 0xF0A2BAA0, 0x7DEE9 },
	{ 0xF0A2BAA1, 0x4EBEB },
	{ 0xF0A2BAA2, 0x7DEEB },
	{ 0xF0A2BAA5, 0x5F7DC },
	{ 0xF0A2BAA6, 0x7DEE8 },
	{ 0xF0A2BAA7, 0xFEBC9 },
	{ 0xF0A2BAA8, 0xFEBCA },
	{ 0xF0A2BAA9, 0xFEBCB },
	{ 0xF0A2BAAA, 0xFEBCC },
	{ 0xF0A2BAAC, 0x7E2B8 },
	{ 0xF0A2BAAD, 0xFECAA },
	{ 0xF0A2BAAE, 0xFECAB },
	{ 0xF0A2BAB0, 0x4EDF3 },
	{ 0xF0A2BAB1, 0x7E3D3 },
	{ 0xF0A2BAB2, 0xFECE1 },
	{ 0xF0A2BAB4, 0x7E6A6 },
	{ 0xF0A2BAB5, 0x4A2F7 },
	{ 0xF0A2BAB6, 0x4A4BD },
	{ 0xF0A2BAB7, 0x4A6DA },
	{ 0xF0A2BAB8, 0xFA7B1 },
	{ 0xF0A2BAB9, 0xFA7B2 },
	{ 0xF0A2BABA, 0xFA7B3 },
	{ 0xF0A2BABE, 0x6B1D8 },
	{ 0xF0A2BB81, 0x6B8A2 },
	{ 0xF0A2BB82, 0x5AFDC },
	{ 0xF0A2BB83, 0x4ADBE },
	{ 0xF0A2BB84, 0x6B8A1 },
	{ 0xF0A2BB88, 0x6B6C4 },
	{ 0xF0A2BB8A, 0x6C0B9 },
	{ 0xF0A2BB8D, 0x6C0B8 },
	{ 0xF0A2BB8E, 0x6C9CF },
	{ 0xF0A2BB8F, 0x6C9CE },
	{ 0xF0A2BB90, 0xFBBCC },
	{ 0xF0A2BB91, 0xFBBCD },
	{ 0xF0A2BB94, 0x5B8F5 },
	{ 0xF0A2BB95, 0x6D3A6 },
	{ 0xF0A2BB96, 0xFC1EA },
	{ 0xF0A2BB97, 0x6D3A7 },
	{ 0xF0A2BB9A, 0x5C6AD },
	{ 0xF0A2BB9B, 0x6DDC0 },
	{ 0xF0A2BB9D, 0x7A3C6 },
	{ 0xF0A2BB9E, 0x7A3C7 },
	{ 0xF0A2BBA0, 0x5D4E0 },
	{ 0xF0A2BBA1, 0xFD4E1 },
	{ 0xF0A2BBA5, 0x7B8BB },
	{ 0xF0A2BBA6, 0x7B8BA },
	{ 0xF0A2BBA7, 0x5DBD9 },
	{ 0xF0A2BBA9, 0x7B8BC },
	{ 0xF0A2BBAA, 0x7CDF1 },
	{ 0xF0A2BBAC, 0x5A4BF },
	{ 0xF0A2BBAD, 0x6A7F9 },
	{ 0xF0A2BBAE, 0x5A4C0 },
	{ 0xF0A2BBAF, 0x6A7FA },
	{ 0xF0A2BBB1, 0x5A4C1 },
	{ 0xF0A2BBB2, 0x6A7F8 },
	{ 0xF0A2BBB3, 0x6ABE8 },
	{ 0xF0A2BBB4, 0x4A6E0 },
	{ 0xF0A2BBB6, 0x5A6C2 },
	{ 0xF0A2BBB7, 0x5A6C0 },
	{ 0xF0A2BBB9, 0x4A6DD },
	{ 0xF0A2BBBA, 0x6ABEC },
	{ 0xF0A2BBBB, 0x6ABE6 },
	{ 0xF0A2BBBD, 0x6ABEA },
	{ 0xF0A2BBBE, 0x6ABE9 },
	{ 0xF0A2BC85, 0x6ABE7 },
	{ 0xF0A2BC86, 0x5A6BF },
	{ 0xF0A2BC87, 0x5A6C1 },
	{ 0xF0A2BC88, 0x4A6DC },
	{ 0xF0A2BC89, 0x4A9E0 },
	{ 0xF0A2BC8A, 0x6B1D9 },
	{ 0xF0A2BC8B, 0x5A9CC },
	{ 0xF0A2BC8C, 0x5A9CB },
	{ 0xF0A2BC8D, 0x6B1DC },
	{ 0xF0A2BC8E, 0x6B1DE },
	{ 0xF0A2BC8F, 0x6B1DD },
	{ 0xF0A2BC90, 0x5A9C9 },
	{ 0xF0A2BC91, 0x5A9CA },
	{ 0xF0A2BC94, 0x4A9DE },
	{ 0xF0A2BC95, 0x4A9DF },
	{ 0xF0A2BC98, 0x6B1DB },
	{ 0xF0A2BC9C, 0x6B8A3 },
	{ 0xF0A2BC9D, 0x6B8A4 },
	{ 0xF0A2BC9E, 0x6B8A6 },
	{ 0xF0A2BC9F, 0x5ADF2 },
	{ 0xF0A2BCA0, 0x6B1DF },
	{ 0xF0A2BCA1, 0x4ADC5 },
	{ 0xF0A2BCA2, 0x6B8A8 },
	{ 0xF0A2BCA3, 0x5ADF0 },
	{ 0xF0A2BCA5, 0x6B8AA },
	{ 0xF0A2BCA7, 0x5ADEF },
	{ 0xF0A2BCA8, 0x5ADF4 },
	{ 0xF0A2BCAA, 0x6B8A5 },
	{ 0xF0A2BCAC, 0x5ADF3 },
	{ 0xF0A2BCAD, 0x5ADF1 },
	{ 0xF0A2BCAE, 0x6B8A9 },
	{ 0xF0A2BCAF, 0x6B8A7 },
	{ 0xF0A2BCB6, 0x4ADC1 },
	{ 0xF0A2BCBA, 0x5B2ED },
	{ 0xF0A2BCBB, 0x6C0C0 },
	{ 0xF0A2BCBD, 0x4B2AE },
	{ 0xF0A2BCBF, 0x6C0BA },
	{ 0xF0A2BD80, 0x6C0BB },
	{ 0xF0A2BD81, 0x6C0BD },
	{ 0xF0A2BD82, 0x5B2EF },
	{ 0xF0A2BD83, 0x5B2F0 },
	{ 0xF0A2BD84, 0x4B2B0 },
	{ 0xF0A2BD85, 0x6C0BE },
	{ 0xF0A2BD86, 0x6C0BC },
	{ 0xF0A2BD87, 0x5B2EB },
	{ 0xF0A2BD88, 0x6C0C1 },
	{ 0xF0A2BD89, 0x4B2B1 },
	{ 0xF0A2BD8A, 0x4B2AA },
	{ 0xF0A2BD8B, 0x4B2AD },
	{ 0xF0A2BD8F, 0x4B2A9 },
	{ 0xF0A2BD90, 0x5B2EE },
	{ 0xF0A2BD91, 0xFB5B1 },
	{ 0xF0A2BD92, 0xFB5B2 },
	{ 0xF0A2BD93, 0xFB5B3 },
	{ 0xF0A2BD94, 0xFB5B4 },
	{ 0xF0A2BD95, 0xFB5B5 },
	{ 0xF0A2BD97, 0x5B2EA },
	{ 0xF0A2BD98, 0x6C0BF },
	{ 0xF0A2BD9B, 0x6C9D8 },
	{ 0xF0A2BD9D, 0x5B9A2 },
	{ 0xF0A2BD9E, 0x6C9D5 },
	{ 0xF0A2BD9F, 0x4B7FA },
	{ 0xF0A2BDA0, 0x4B7FB },
	{ 0xF0A2BDA1, 0x6C9D9 },
	{ 0xF0A2BDA4, 0x6C9D4 },
	{ 0xF0A2BDA5, 0x6C9DA },
	{ 0xF0A2BDA6, 0x5B8F6 },
	{ 0xF0A2BDA7, 0x5B8FE },
	{ 0xF0A2BDA8, 0x5B9A1 },
	{ 0xF0A2BDA9, 0x5B8FD },
	{ 0xF0A2BDAA, 0x5B8F7 },
	{ 0xF0A2BDAC, 0x6C9D6 },
	{ 0xF0A2BDAD, 0x5B8FB },
	{ 0xF0A2BDAE, 0x6C9D1 },
	{ 0xF0A2BDAF, 0x6C9D0 },
	{ 0xF0A2BDB0, 0x6C9D3 },
	{ 0xF0A2BDB2, 0x4B7F2 },
	{ 0xF0A2BDB3, 0x4B7F3 },
	{ 0xF0A2BDB4, 0x4B7F4 },
	{ 0xF0A2BDB5, 0x5B8F8 },
	{ 0xF0A2BDB6, 0x5B8F9 },
	{ 0xF0A2BDB7, 0x5B2EC },
	{ 0xF0A2BDBA, 0x6C9D2 },
	{ 0xF0A2BDBF, 0x6D3AF },
	{ 0xF0A2BE80, 0x5B8FA },
	{ 0xF0A2BE82, 0x5BFD7 },
	{ 0xF0A2BE83, 0x5BFDA },
	{ 0xF0A2BE84, 0x5BFDC },
	{ 0xF0A2BE85, 0x4BDD7 },
	{ 0xF0A2BE86, 0x4BDDF },
	{ 0xF0A2BE87, 0x6D3AB },
	{ 0xF0A2BE88, 0x6D3AE },
	{ 0xF0A2BE89, 0x6D3A9 },
	{ 0xF0A2BE8B, 0x5BFDB },
	{ 0xF0A2BE8C, 0x6D3B0 },
	{ 0xF0A2BE8D, 0x6D3AD },
	{ 0xF0A2BE8F, 0x6D3A8 },
	{ 0xF0A2BE90, 0x4BDE0 },
	{ 0xF0A2BE92, 0x5BFD6 },
	{ 0xF0A2BE93, 0x6D3B1 },
	{ 0xF0A2BE94, 0x5BFD9 },
	{ 0xF0A2BE99, 0x4BDDE },
	{ 0xF0A2BE9A, 0x4BDD5 },
	{ 0xF0A2BE9B, 0x4BDD6 },
	{ 0xF0A2BE9C, 0x4BDD8 },
	{ 0xF0A2BE9D, 0x5BFD8 },
	{ 0xF0A2BE9E, 0x6D3AA },
	{ 0xF0A2BE9F, 0xFC1EB },
	{ 0xF0A2BEA0, 0x6D3AC },
	{ 0xF0A2BEA3, 0x5B2F1 },
	{ 0xF0A2BEA4, 0x4BDDA },
	{ 0xF0A2BEA5, 0x6D5E0 },
	{ 0xF0A2BEA7, 0x5C6B4 },
	{ 0xF0A2BEA8, 0x6DDC9 },
	{ 0xF0A2BEA9, 0x5C6B2 },
	{ 0xF0A2BEAA, 0x6DDC1 },
	{ 0xF0A2BEAB, 0x4C3E8 },
	{ 0xF0A2BEAC, 0x5C6B1 },
	{ 0xF0A2BEAD, 0x6DDC2 },
	{ 0xF0A2BEAE, 0x5C6AF },
	{ 0xF0A2BEAF, 0x6DDC6 },
	{ 0xF0A2BEB1, 0x5C6B7 },
	{ 0xF0A2BEB3, 0x5C6B5 },
	{ 0xF0A2BEB4, 0x6DDC7 },
	{ 0xF0A2BEB5, 0x6DDC5 },
	{ 0xF0A2BEB6, 0x6DDC4 },
	{ 0xF0A2BEB7, 0x6DDC8 },
	{ 0xF0A2BEB8, 0x6DDC3 },
	{ 0xF0A2BEB9, 0x6DDCA },
	{ 0xF0A2BEBA, 0x5C6B3 },
	{ 0xF0A2BEBC, 0x4C3E7 },
	{ 0xF0A2BEBD, 0x5C6B6 },
	{ 0xF0A2BEBE, 0x6DDCB },
	{ 0xF0A2BF86, 0x5C8A5 },
	{ 0xF0A2BF87, 0x5CDC2 },
	{ 0xF0A2BF88, 0x5CDC7 },
	{ 0xF0A2BF89, 0x4CAAC },
	{ 0xF0A2BF8A, 0x7A3CE },
	{ 0xF0A2BF8B, 0x7A3C9 },
	{ 0xF0A2BF8D, 0x7A3C8 },
	{ 0xF0A2BF8E, 0x5CDC6 },
	{ 0xF0A2BF90, 0x7A3D2 },
	{ 0xF0A2BF91, 0x7A3CF },
	{ 0xF0A2BF92, 0x7A3CD },
	{ 0xF0A2BF93, 0x5CDC5 },
	{ 0xF0A2BF94, 0x7A3D0 },
	{ 0xF0A2BF95, 0x5CDC3 },
	{ 0xF0A2BF96, 0x5CDC4 },
	{ 0xF0A2BF97, 0xFCFB1 },
	{ 0xF0A2BF98, 0x7A3CB },
	{ 0xF0A2BF99, 0x7A3CC },
	{ 0xF0A2BF9B, 0x7A3CA },
	{ 0xF0A2BF9E, 0x4D0CB },
	{ 0xF0A2BF9F, 0x7AEC2 },
	{ 0xF0A2BFA0, 0x7AEC6 },
	{ 0xF0A2BFA1, 0x7AEC8 },
	{ 0xF0A2BFA3, 0xFD4E2 },
	{ 0xF0A2BFA4, 0x5D4E1 },
	{ 0xF0A2BFA5, 0x7AECB },
	{ 0xF0A2BFA8, 0x7AEC7 },
	{ 0xF0A2BFA9, 0x7AEC9 },
	{ 0xF0A2BFAA, 0x7AEC1 },
	{ 0xF0A2BFAB, 0x7AEC5 },
	{ 0xF0A2BFAC, 0x7AECC },
	{ 0xF0A2BFAD, 0x5D4E3 },
	{ 0xF0A2BFAE, 0x7AECA },
	{ 0xF0A2BFB2, 0x4D0CA },
	{ 0xF0A2BFB3, 0x5D4E4 },
	{ 0xF0A2BFB4, 0x5D4E5 },
	{ 0xF0A2BFB5, 0x5D4E6 },
	{ 0xF0A2BFB6, 0xFD4E3 },
	{ 0xF0A2BFB7, 0x7AEC4 },
	{ 0xF0A2BFB8, 0x5D4E2 },
	{ 0xF0A2BFB9, 0x7A3D1 },
	{ 0xF0A2BFBD, 0x5D4E7 },
	{ 0xF0A2BFBE, 0x7B8BE },
	{ 0xF0A2BFBF, 0x7B8BD },
	{ 0xF0A38080, 0x5DBDA },
	{ 0xF0A38081, 0x5DBDE },
	{ 0xF0A38082, 0x5DBDD },
	{ 0xF0A38086, 0x4D6BC },
	{ 0xF0A38089, 0x4D6BD },
	{ 0xF0A3808A, 0x5DBDB },
	{ 0xF0A3808B, 0xFDAB7 },
	{ 0xF0A3808C, 0xFDAB8 },
	{ 0xF0A3808E, 0x7B8BF },
	{ 0xF0A3808F, 0x5DBDC },
	{ 0xF0A38090, 0x5E1F0 },
	{ 0xF0A38091, 0x7BFEC },
	{ 0xF0A38092, 0x5E1EF },
	{ 0xF0A38094, 0x4DBBB },
	{ 0xF0A38095, 0x7BFED },
	{ 0xF0A38096, 0x7BFEE },
	{ 0xF0A38098, 0x4DBB9 },
	{ 0xF0A3809A, 0x7BFEB },
	{ 0xF0A3809D, 0x5E8A1 },
	{ 0xF0A3809E, 0x5E7FE },
	{ 0xF0A380A0, 0x5E7FC },
	{ 0xF0A380A1, 0x5E7FD },
	{ 0xF0A380A2, 0xFE2CA },
	{ 0xF0A380A3, 0x5ECB4 },
	{ 0xF0A380A4, 0x4E3CD },
	{ 0xF0A380A5, 0x5ECB5 },
	{ 0xF0A380A6, 0x7CDF2 },
	{ 0xF0A380A7, 0x4E3CB },
	{ 0xF0A380A8, 0x7CDF5 },
	{ 0xF0A380AA, 0x7CDF4 },
	{ 0xF0A380AB, 0x5ECB6 },
	{ 0xF0A380AC, 0x7CDF6 },
	{ 0xF0A380AD, 0x7CDF7 },
	{ 0xF0A380AE, 0x4E6C4 },
	{ 0xF0A380AF, 0x5F0A5 },
	{ 0xF0A380B1, 0x5F0A6 },
	{ 0xF0A380B3, 0x5F3C8 },
	{ 0xF0A380B4, 0xFE9C5 },
	{ 0xF0A380B5, 0x7DBD9 },
	{ 0xF0A380B6, 0x5F5EB },
	{ 0xF0A380B7, 0x4EACA },
	{ 0xF0A380BA, 0x7DBDA },
	{ 0xF0A380BC, 0x4ECEF },
	{ 0xF0A380BD, 0xFECE2 },
	{ 0xF0A38181, 0xFA2D3 },
	{ 0xF0A38182, 0xFA4C6 },
	{ 0xF0A38183, 0x6ABED },
	{ 0xF0A38186, 0xFABAD },
	{ 0xF0A38187, 0xFABAE },
	{ 0xF0A38188, 0xFABAF },
	{ 0xF0A3818A, 0x6B8AD },
	{ 0xF0A3818B, 0x6B8AE },
	{ 0xF0A3818C, 0xFAFE5 },
	{ 0xF0A3818E, 0x6C0C2 },
	{ 0xF0A3818F, 0x6C0C4 },
	{ 0xF0A38190, 0xFB5B7 },
	{ 0xF0A38191, 0xFB5B8 },
	{ 0xF0A38192, 0x6C0C3 },
	{ 0xF0A38195, 0xFBBCE },
	{ 0xF0A38197, 0x5BFDD },
	{ 0xF0A38198, 0xFC1EC },
	{ 0xF0A38199, 0x6D3B2 },
	{ 0xF0A3819A, 0xFB5B6 },
	{ 0xF0A3819C, 0x5CDC8 },
	{ 0xF0A3819D, 0x7A3D4 },
	{ 0xF0A3819E, 0x7A3D3 },
	{ 0xF0A3819F, 0x5CDC9 },
	{ 0xF0A381A0, 0xFCFB3 },
	{ 0xF0A381A1, 0xFCFB4 },
	{ 0xF0A381A2, 0x5CDCA },
	{ 0xF0A381A3, 0x7AECD },
	{ 0xF0A381A4, 0xFDAB9 },
	{ 0xF0A381A5, 0xFDEF5 },
	{ 0xF0A381A7, 0xFE2CB },
	{ 0xF0A381A9, 0xFE7DA },
	{ 0xF0A381AB, 0x7DBDB },
	{ 0xF0A381AC, 0x6A2A2 },
	{ 0xF0A381AE, 0xFA7B4 },
	{ 0xF0A381B1, 0x6B1E0 },
	{ 0xF0A381B3, 0x4ADC8 },
	{ 0xF0A381B4, 0x5ADF6 },
	{ 0xF0A381B5, 0x5ADF5 },
	{ 0xF0A381B6, 0x6B8AF },
	{ 0xF0A381B7, 0x5B2F2 },
	{ 0xF0A381B8, 0xFB5B9 },
	{ 0xF0A381BA, 0x6C0C6 },
	{ 0xF0A381BB, 0x6C0C5 },
	{ 0xF0A381BC, 0x6C9DD },
	{ 0xF0A381BD, 0xFC0B2 },
	{ 0xF0A381BF, 0x6C9DB },
	{ 0xF0A38280, 0x6C9DC },
	{ 0xF0A38281, 0x4BDE1 },
	{ 0xF0A38282, 0x6DDCC },
	{ 0xF0A38284, 0x5BFDE },
	{ 0xF0A38285, 0xFC1ED },
	{ 0xF0A38286, 0x4C3EA },
	{ 0xF0A38289, 0x4CAAD },
	{ 0xF0A3828A, 0x7A3D5 },
	{ 0xF0A3828C, 0x7B8C0 },
	{ 0xF0A3828F, 0x4DFEC },
	{ 0xF0A38291, 0x6A2A3 },
	{ 0xF0A38293, 0xFA4C7 },
	{ 0xF0A38294, 0x6ABEF },
	{ 0xF0A38295, 0x6ABEE },
	{ 0xF0A38299, 0x6B1E1 },
	{ 0xF0A3829B, 0xFAFE6 },
	{ 0xF0A3829E, 0x4B2B2 },
	{ 0xF0A3829F, 0x6C0C8 },
	{ 0xF0A382A0, 0x6C0C7 },
	{ 0xF0A382A1, 0x6C9E0 },
	{ 0xF0A382A2, 0x6C9E4 },
	{ 0xF0A382A3, 0x6C9E3 },
	{ 0xF0A382A4, 0x5B9A3 },
	{ 0xF0A382A5, 0x6C9E6 },
	{ 0xF0A382A6, 0x6C9DF },
	{ 0xF0A382A7, 0x6C9DE },
	{ 0xF0A382A8, 0x6C9E2 },
	{ 0xF0A382AA, 0x4B7FC },
	{ 0xF0A382AB, 0x6CCBE },
	{ 0xF0A382AD, 0x6C9E5 },
	{ 0xF0A382AE, 0x4BDE2 },
	{ 0xF0A382AF, 0x6D3B6 },
	{ 0xF0A382B1, 0x6D3B4 },
	{ 0xF0A382B2, 0x6D3B7 },
	{ 0xF0A382B5, 0x5BFDF },
	{ 0xF0A382B6, 0x6DDCF },
	{ 0xF0A382B8, 0x6DDCE },
	{ 0xF0A382B9, 0x6DDD0 },
	{ 0xF0A382BA, 0x3C7B1 },
	{ 0xF0A382BB, 0x4CAAF },
	{ 0xF0A382BC, 0x6DDCD },
	{ 0xF0A382BD, 0x5CDCC },
	{ 0xF0A382BF, 0x5CDCD },
	{ 0xF0A38380, 0x7AED1 },
	{ 0xF0A38381, 0x7AED0 },
	{ 0xF0A38382, 0x7AECF },
	{ 0xF0A38383, 0x7AED2 },
	{ 0xF0A38386, 0x7AECE },
	{ 0xF0A38388, 0x4D0CD },
	{ 0xF0A3838A, 0x7B8C1 },
	{ 0xF0A3838B, 0x7B8C2 },
	{ 0xF0A3838C, 0x7BFEF },
	{ 0xF0A3838D, 0x4DBBC },
	{ 0xF0A3838F, 0x7BFF0 },
	{ 0xF0A38390, 0x7BFF1 },
	{ 0xF0A38391, 0x7C7B9 },
	{ 0xF0A38393, 0xFE2CC },
	{ 0xF0A38394, 0x7CDF8 },
	{ 0xF0A38396, 0x7D7FD },
	{ 0xF0A38398, 0x4A4C2 },
	{ 0xF0A38399, 0x6A7FB },
	{ 0xF0A3839B, 0xFA7B5 },
	{ 0xF0A3839C, 0xFA7B6 },
	{ 0xF0A3839D, 0x5A9CD },
	{ 0xF0A3839E, 0x6B1E4 },
	{ 0xF0A3839F, 0x6B1E3 },
	{ 0xF0A383A1, 0xFABB0 },
	{ 0xF0A383A2, 0x6B1E2 },
	{ 0xF0A383A6, 0x4ADCA },
	{ 0xF0A383A7, 0x5ADF7 },
	{ 0xF0A383A8, 0x6B8B1 },
	{ 0xF0A383A9, 0x6B8B3 },
	{ 0xF0A383AA, 0x6B8B5 },
	{ 0xF0A383AB, 0xFAFE7 },
	{ 0xF0A383AC, 0xFAFE8 },
	{ 0xF0A383AD, 0xFAFE9 },
	{ 0xF0A383AE, 0xFAFEA },
	{ 0xF0A383AF, 0x6B8B2 },
	{ 0xF0A383B3, 0x4B2B3 },
	{ 0xF0A383B5, 0x4B2B5 },
	{ 0xF0A383B7, 0x6C0CA },
	{ 0xF0A383B8, 0xFB5BA },
	{ 0xF0A383B9, 0xFB5BB },
	{ 0xF0A383BB, 0x6C0C9 },
	{ 0xF0A383BC, 0x6C9E9 },
	{ 0xF0A383BD, 0x5B9A5 },
	{ 0xF0A383BE, 0x5B9A4 },
	{ 0xF0A383BF, 0x6C9E8 },
	{ 0xF0A38480, 0x6C9EA },
	{ 0xF0A38481, 0x6C9E7 },
	{ 0xF0A38482, 0xFBBCF },
	{ 0xF0A38484, 0xFBBD0 },
	{ 0xF0A38488, 0x6D3B8 },
	{ 0xF0A38489, 0x5BFE0 },
	{ 0xF0A3848A, 0x6D3B9 },
	{ 0xF0A3848B, 0xFC1EE },
	{ 0xF0A3848C, 0xFC1EF },
	{ 0xF0A3848E, 0x5C6B8 },
	{ 0xF0A3848F, 0x5C6BA },
	{ 0xF0A38490, 0x6DDD2 },
	{ 0xF0A38491, 0x5C6B9 },
	{ 0xF0A38494, 0x7A3D6 },
	{ 0xF0A38497, 0xFCFB5 },
	{ 0xF0A38498, 0x7AED3 },
	{ 0xF0A38499, 0x5D4E8 },
	{ 0xF0A3849A, 0x7B8C3 },
	{ 0xF0A3849D, 0x5DBDF },
	{ 0xF0A3849E, 0x7BFF3 },
	{ 0xF0A3849F, 0x5E1F1 },
	{ 0xF0A384A0, 0x4DBBD },
	{ 0xF0A384A1, 0x7BFF4 },
	{ 0xF0A384A2, 0x7BFF2 },
	{ 0xF0A384A4, 0x7C7BA },
	{ 0xF0A384A6, 0x7D3C5 },
	{ 0xF0A384A7, 0x4E8ED },
	{ 0xF0A384A8, 0x7D7FE },
	{ 0xF0A384AA, 0x7DEEC },
	{ 0xF0A384AB, 0x7E0F0 },
	{ 0xF0A384AE, 0x5A4C2 },
	{ 0xF0A384B0, 0x5A9CE },
	{ 0xF0A384B1, 0x5ADF9 },
	{ 0xF0A384B2, 0x5ADF8 },
	{ 0xF0A384B4, 0x4B7FD },
	{ 0xF0A384B5, 0x6C9EB },
	{ 0xF0A384B6, 0x6D3BA },
	{ 0xF0A384B7, 0x6D3BB },
	{ 0xF0A384B8, 0x4BDE6 },
	{ 0xF0A384B9, 0xFCFB6 },
	{ 0xF0A384BB, 0x6A3AC },
	{ 0xF0A384BC, 0x6A3AB },
	{ 0xF0A384BE, 0x6A4FB },
	{ 0xF0A384BF, 0x5A2F3 },
	{ 0xF0A38580, 0x6A4FA },
	{ 0xF0A38581, 0x6A4FC },
	{ 0xF0A38582, 0xFA2D4 },
	{ 0xF0A38584, 0xFA4CB },
	{ 0xF0A38586, 0x6A7FC },
	{ 0xF0A38587, 0x6A7FD },
	{ 0xF0A38588, 0x6A8A5 },
	{ 0xF0A38589, 0x5A4C3 },
	{ 0xF0A3858A, 0x6A8A2 },
	{ 0xF0A3858B, 0x6A7FE },
	{ 0xF0A3858C, 0x6A8A4 },
	{ 0xF0A3858E, 0x6A8A3 },
	{ 0xF0A38590, 0x6A8A1 },
	{ 0xF0A38591, 0xFA4C8 },
	{ 0xF0A38592, 0xFA4CA },
	{ 0xF0A38593, 0xFA4CC },
	{ 0xF0A38596, 0x4A4C4 },
	{ 0xF0A3859A, 0x5A6C8 },
	{ 0xF0A3859B, 0x6ABF4 },
	{ 0xF0A3859C, 0x6ABF3 },
	{ 0xF0A3859D, 0x5A6C9 },
	{ 0xF0A3859E, 0x6ABFD },
	{ 0xF0A3859F, 0x5A6C4 },
	{ 0xF0A385A0, 0x6ABF9 },
	{ 0xF0A385A1, 0x5A6C7 },
	{ 0xF0A385A2, 0x6ABFA },
	{ 0xF0A385A3, 0x6ABF7 },
	{ 0xF0A385A4, 0x5A6C6 },
	{ 0xF0A385A5, 0x5A6C5 },
	{ 0xF0A385A6, 0x6ABF5 },
	{ 0xF0A385A7, 0x6ABF8 },
	{ 0xF0A385A8, 0xFA7B7 },
	{ 0xF0A385A9, 0xFA7B8 },
	{ 0xF0A385AA, 0xFA7B9 },
	{ 0xF0A385AB, 0xFA7BA },
	{ 0xF0A385AC, 0xFA7BB },
	{ 0xF0A385AD, 0xFA7BC },
	{ 0xF0A385AE, 0xFA7BD },
	{ 0xF0A385AF, 0x6ABF1 },
	{ 0xF0A385B1, 0x6ABFB },
	{ 0xF0A385B2, 0x6ABFC },
	{ 0xF0A385B3, 0x6ABF2 },
	{ 0xF0A385B4, 0x6ABF6 },
	{ 0xF0A385B7, 0x5A9D1 },
	{ 0xF0A385B8, 0x6B1E5 },
	{ 0xF0A385B9, 0x6B1E6 },
	{ 0xF0A385BA, 0x5A9D0 },
	{ 0xF0A385BB, 0x4A9E6 },
	{ 0xF0A385BC, 0x6B1E8 },
	{ 0xF0A385BD, 0x6B1E9 },
	{ 0xF0A385BE, 0x4A9E8 },
	{ 0xF0A38681, 0xFABB1 },
	{ 0xF0A38683, 0xFABB2 },
	{ 0xF0A38684, 0x6B1EA },
	{ 0xF0A38685, 0xFABB5 },
	{ 0xF0A38686, 0xFABB6 },
	{ 0xF0A38689, 0x6B1EE },
	{ 0xF0A3868A, 0x6B1EC },
	{ 0xF0A3868B, 0x6B1EB },
	{ 0xF0A38692, 0x5ADFE },
	{ 0xF0A38693, 0x6B8BA },
	{ 0xF0A38694, 0x5AEA1 },
	{ 0xF0A38695, 0x5AEA2 },
	{ 0xF0A38696, 0x5ADFB },
	{ 0xF0A38697, 0x5AEA3 },
	{ 0xF0A38698, 0x5ADFC },
	{ 0xF0A38699, 0x5ADFA },
	{ 0xF0A3869A, 0x6B8BE },
	{ 0xF0A3869B, 0x6B8B8 },
	{ 0xF0A3869C, 0x6B8BC },
	{ 0xF0A3869D, 0x5ADFD },
	{ 0xF0A3869E, 0x6B8B9 },
	{ 0xF0A386A0, 0x6B8BD },
	{ 0xF0A386A3, 0xFAFEB },
	{ 0xF0A386A6, 0xFAFED },
	{ 0xF0A386A7, 0x6B8BB },
	{ 0xF0A386A8, 0xFAFEC },
	{ 0xF0A386A9, 0x6B8C1 },
	{ 0xF0A386AB, 0x6B8BF },
	{ 0xF0A386B2, 0x5B2F3 },
	{ 0xF0A386B3, 0x4B2B8 },
	{ 0xF0A386B4, 0x4B8A1 },
	{ 0xF0A386B5, 0x6C0D3 },
	{ 0xF0A386B6, 0x4B2BD },
	{ 0xF0A386B7, 0x6C0CE },
	{ 0xF0A386B8, 0x6C0CB },
	{ 0xF0A386B9, 0x6C0CC },
	{ 0xF0A386BA, 0x6C0D0 },
	{ 0xF0A386BB, 0x6C0CD },
	{ 0xF0A386BC, 0x6C0D5 },
	{ 0xF0A386BD, 0x5B2F5 },
	{ 0xF0A386BE, 0x6B8C0 },
	{ 0xF0A386BF, 0x6C0D4 },
	{ 0xF0A38780, 0x6C0D6 },
	{ 0xF0A38786, 0xFB5BC },
	{ 0xF0A3878B, 0xFB5BD },
	{ 0xF0A3878C, 0xFB5BE },
	{ 0xF0A3878D, 0xFB5BF },
	{ 0xF0A3878E, 0xFB5C0 },
	{ 0xF0A3878F, 0xFB5C1 },
	{ 0xF0A38790, 0xFB5C2 },
	{ 0xF0A38791, 0xFB5C3 },
	{ 0xF0A38792, 0xFB5C4 },
	{ 0xF0A38793, 0xFB5C5 },
	{ 0xF0A38794, 0xFB5C6 },
	{ 0xF0A38795, 0xFB5C7 },
	{ 0xF0A3879A, 0x6C0D2 },
	{ 0xF0A387A2, 0x5B2F4 },
	{ 0xF0A387A3, 0x6C9F1 },
	{ 0xF0A387A4, 0x6C9F4 },
	{ 0xF0A387A5, 0x4B2BC },
	{ 0xF0A387A6, 0x5BFE1 },
	{ 0xF0A387A7, 0x5B9AA },
	{ 0xF0A387A8, 0x6C9EF },
	{ 0xF0A387A9, 0x5B9A7 },
	{ 0xF0A387AA, 0x6C9F0 },
	{ 0xF0A387AB, 0x5B9A9 },
	{ 0xF0A387AC, 0x5B9A6 },
	{ 0xF0A387AE, 0x6C9EC },
	{ 0xF0A387AF, 0x6C9ED },
	{ 0xF0A387B0, 0x4B8A3 },
	{ 0xF0A387B1, 0x6C9F6 },
	{ 0xF0A387B2, 0x5B9AB },
	{ 0xF0A387B3, 0x4B8A7 },
	{ 0xF0A387B6, 0x6C9EE },
	{ 0xF0A387BA, 0x6C9F5 },
	{ 0xF0A387BB, 0x6C9F7 },
	{ 0xF0A387BC, 0xFBBD1 },
	{ 0xF0A387BD, 0xFBBD3 },
	{ 0xF0A387BE, 0xFBBD4 },
	{ 0xF0A387BF, 0xFBBD6 },
	{ 0xF0A38880, 0xFBBD7 },
	{ 0xF0A38881, 0xFBBD9 },
	{ 0xF0A38882, 0xFBBDA },
	{ 0xF0A38883, 0xFBBDC },
	{ 0xF0A38884, 0xFBBDD },
	{ 0xF0A38887, 0xFBBD2 },
	{ 0xF0A38888, 0xFBBD8 },
	{ 0xF0A3888D, 0x4B8A6 },
	{ 0xF0A3888F, 0x4B8A8 },
	{ 0xF0A3889F, 0x6C9F2 },
	{ 0xF0A388A0, 0x5B9AC },
	{ 0xF0A388A1, 0x5B9A8 },
	{ 0xF0A388A4, 0x6D3C3 },
	{ 0xF0A388A5, 0x5BFE3 },
	{ 0xF0A388A6, 0x6D3C1 },
	{ 0xF0A388A7, 0x6DDD3 },
	{ 0xF0A388A8, 0x6D3C2 },
	{ 0xF0A388A9, 0x6D3BF },
	{ 0xF0A388AA, 0x6D3C4 },
	{ 0xF0A388AE, 0xFC6B9 },
	{ 0xF0A388B5, 0xFBBDB },
	{ 0xF0A388B6, 0x6D3BE },
	{ 0xF0A388B7, 0xFC1F0 },
	{ 0xF0A388B8, 0xFC1F1 },
	{ 0xF0A388B9, 0xFC1F3 },
	{ 0xF0A388BA, 0xFC1F4 },
	{ 0xF0A388BB, 0xFC1F5 },
	{ 0xF0A388BC, 0xFC1F6 },
	{ 0xF0A388BD, 0xFC1F7 },
	{ 0xF0A388BE, 0xFC1F8 },
	{ 0xF0A38980, 0xFC1F9 },
	{ 0xF0A38981, 0xFC1FA },
	{ 0xF0A38982, 0xFC1FB },
	{ 0xF0A38983, 0xFC1FD },
	{ 0xF0A38984, 0x5BDD5 },
	{ 0xF0A38988, 0x6D3C5 },
	{ 0xF0A3898A, 0x6D3C0 },
	{ 0xF0A38991, 0x5BFE4 },
	{ 0xF0A38992, 0x5C6BB },
	{ 0xF0A38993, 0x5C6BF },
	{ 0xF0A38994, 0x5C6BD },
	{ 0xF0A38995, 0x5C6BE },
	{ 0xF0A38996, 0x6DDD6 },
	{ 0xF0A38997, 0x5C6C0 },
	{ 0xF0A38998, 0x5C6C3 },
	{ 0xF0A38999, 0x5C6C4 },
	{ 0xF0A3899A, 0x4C3EC },
	{ 0xF0A3899B, 0x5C6C2 },
	{ 0xF0A3899C, 0x5CDCE },
	{ 0xF0A389A3, 0xFC8CA },
	{ 0xF0A389A4, 0xFC8CB },
	{ 0xF0A389A5, 0xFC8CC },
	{ 0xF0A389A6, 0xFC8CD },
	{ 0xF0A389A7, 0xFC8CE },
	{ 0xF0A389A8, 0xFC8CF },
	{ 0xF0A389A9, 0x6DDD4 },
	{ 0xF0A389AA, 0x5C6BC },
	{ 0xF0A389AB, 0x6DDD7 },
	{ 0xF0A389AC, 0x6DDD9 },
	{ 0xF0A389AD, 0x6DDDA },
	{ 0xF0A389B0, 0x6DDD5 },
	{ 0xF0A389BA, 0x6DDD8 },
	{ 0xF0A389BB, 0x7A3E1 },
	{ 0xF0A389BC, 0x7A3DC },
	{ 0xF0A389BD, 0x7A3DB },
	{ 0xF0A389BE, 0x7A3DE },
	{ 0xF0A389BF, 0x5CDD2 },
	{ 0xF0A38A81, 0x5CDD5 },
	{ 0xF0A38A82, 0x7A3DA },
	{ 0xF0A38A83, 0x7A3D7 },
	{ 0xF0A38A84, 0x7A3D8 },
	{ 0xF0A38A86, 0x7A3E2 },
	{ 0xF0A38A8F, 0xFCFB7 },
	{ 0xF0A38A90, 0xFCFB9 },
	{ 0xF0A38A91, 0xFCFBA },
	{ 0xF0A38A94, 0x5CDD4 },
	{ 0xF0A38A95, 0x7A3E0 },
	{ 0xF0A38A96, 0xFCEB0 },
	{ 0xF0A38A99, 0x7A3DD },
	{ 0xF0A38A9A, 0x7A3DF },
	{ 0xF0A38A9B, 0x7A3D9 },
	{ 0xF0A38A9D, 0x5CDD1 },
	{ 0xF0A38A9E, 0x5D4E9 },
	{ 0xF0A38A9F, 0x5D4EB },
	{ 0xF0A38AA0, 0x7AED7 },
	{ 0xF0A38AA1, 0x4D0D5 },
	{ 0xF0A38AA3, 0x7AED5 },
	{ 0xF0A38AA4, 0x7AEDB },
	{ 0xF0A38AA5, 0x7AED9 },
	{ 0xF0A38AA6, 0x7AEDD },
	{ 0xF0A38AA7, 0x4D0D4 },
	{ 0xF0A38AA8, 0x7AEDC },
	{ 0xF0A38AAE, 0x7AED4 },
	{ 0xF0A38AAF, 0xFD4E5 },
	{ 0xF0A38AB0, 0xFD4E6 },
	{ 0xF0A38AB1, 0xFD4E7 },
	{ 0xF0A38AB2, 0xFD4E9 },
	{ 0xF0A38AB3, 0xFD4EA },
	{ 0xF0A38AB4, 0x7AED8 },
	{ 0xF0A38AB6, 0x5CDCF },
	{ 0xF0A38AB8, 0x7ADE2 },
	{ 0xF0A38ABA, 0xFD4E8 },
	{ 0xF0A38ABD, 0x7AEC3 },
	{ 0xF0A38B84, 0x5D4EA },
	{ 0xF0A38B85, 0x7AED6 },
	{ 0xF0A38B88, 0xFCFB8 },
	{ 0xF0A38B89, 0x7B8C7 },
	{ 0xF0A38B8A, 0x5DBE0 },
	{ 0xF0A38B8B, 0x5DBE1 },
	{ 0xF0A38B8C, 0x7B8C8 },
	{ 0xF0A38B8D, 0x5DBE2 },
	{ 0xF0A38B8F, 0x7B8C5 },
	{ 0xF0A38B90, 0x7B8C6 },
	{ 0xF0A38B93, 0x7B8C9 },
	{ 0xF0A38B94, 0xFDABA },
	{ 0xF0A38B95, 0xFDABB },
	{ 0xF0A38B96, 0xFDABC },
	{ 0xF0A38B97, 0x7B8C4 },
	{ 0xF0A38B98, 0xFDABD },
	{ 0xF0A38B9E, 0x4DBBE },
	{ 0xF0A38B9F, 0x5E1F2 },
	{ 0xF0A38BA3, 0x5E1F3 },
	{ 0xF0A38BA5, 0x7BFF5 },
	{ 0xF0A38BAA, 0xFDEF6 },
	{ 0xF0A38BAB, 0xFDEF7 },
	{ 0xF0A38BAC, 0xFDEF8 },
	{ 0xF0A38BAD, 0xFDEF9 },
	{ 0xF0A38BAE, 0xFDEFB },
	{ 0xF0A38BAF, 0x7BFF8 },
	{ 0xF0A38BB2, 0x5E8A3 },
	{ 0xF0A38BB3, 0x7C7BD },
	{ 0xF0A38BB4, 0x7C7BC },
	{ 0xF0A38BB5, 0x5E8A2 },
	{ 0xF0A38BB6, 0x5E8A4 },
	{ 0xF0A38BB7, 0x7C7BB },
	{ 0xF0A38BB8, 0x7C7BE },
	{ 0xF0A38BBA, 0xFE2CD },
	{ 0xF0A38BBF, 0x5ECB7 },
	{ 0xF0A38C83, 0xFE5B1 },
	{ 0xF0A38C84, 0xFE5B2 },
	{ 0xF0A38C85, 0x5EBEE },
	{ 0xF0A38C87, 0x7CDF9 },
	{ 0xF0A38C88, 0x7D3C6 },
	{ 0xF0A38C8D, 0x7D8A1 },
	{ 0xF0A38C8E, 0xFE9C6 },
	{ 0xF0A38C8F, 0x5F3B9 },
	{ 0xF0A38C93, 0x5F3C9 },
	{ 0xF0A38C96, 0x7DBDC },
	{ 0xF0A38C97, 0x5F7DE },
	{ 0xF0A38C98, 0x7DEED },
	{ 0xF0A38C99, 0xFEBCD },
	{ 0xF0A38C9C, 0x5F9AB },
	{ 0xF0A38C9F, 0x7E4C7 },
	{ 0xF0A38CA2, 0xFA4CD },
	{ 0xF0A38CA3, 0x6ABFE },
	{ 0xF0A38CA4, 0xFA7BF },
	{ 0xF0A38CA5, 0xFA7C0 },
	{ 0xF0A38CA6, 0x6ACA1 },
	{ 0xF0A38CA7, 0x5A9D3 },
	{ 0xF0A38CA8, 0x5A9D2 },
	{ 0xF0A38CA9, 0x6B1F0 },
	{ 0xF0A38CAA, 0xFABB7 },
	{ 0xF0A38CAB, 0xFABB9 },
	{ 0xF0A38CAC, 0x6B1EF },
	{ 0xF0A38CAD, 0x6B8C2 },
	{ 0xF0A38CAF, 0xFAFEF },
	{ 0xF0A38CB0, 0xFAFF0 },
	{ 0xF0A38CB1, 0xFAFF1 },
	{ 0xF0A38CB2, 0xFAFF2 },
	{ 0xF0A38CB3, 0xFAFF3 },
	{ 0xF0A38CB7, 0xFB5C9 },
	{ 0xF0A38CB8, 0xFB5CA },
	{ 0xF0A38CBB, 0xFBBDF },
	{ 0xF0A38CBC, 0x6C9FA },
	{ 0xF0A38CBD, 0x6C9F9 },
	{ 0xF0A38CBE, 0x5BFE5 },
	{ 0xF0A38D83, 0x4C3F0 },
	{ 0xF0A38D84, 0x6D3C6 },
	{ 0xF0A38D86, 0x5CDD7 },
	{ 0xF0A38D87, 0x5CDD6 },
	{ 0xF0A38D88, 0x7A3E3 },
	{ 0xF0A38D8C, 0xFD4EB },
	{ 0xF0A38D8F, 0x5DBE3 },
	{ 0xF0A38D91, 0x7BFFA },
	{ 0xF0A38D92, 0x5E1F4 },
	{ 0xF0A38D93, 0x7BFF9 },
	{ 0xF0A38D94, 0x7BFF7 },
	{ 0xF0A38D96, 0x4DFED },
	{ 0xF0A38D98, 0x7CDFA },
	{ 0xF0A38D99, 0x7CDFB },
	{ 0xF0A38D9B, 0x5FBBF },
	{ 0xF0A38D9C, 0x7E6BE },
	{ 0xF0A38D9D, 0x6A3AD },
	{ 0xF0A38D9E, 0x6A4FD },
	{ 0xF0A38D9F, 0x5A4C4 },
	{ 0xF0A38DA0, 0x6A8A9 },
	{ 0xF0A38DA1, 0x6A8A7 },
	{ 0xF0A38DA2, 0x6A8A8 },
	{ 0xF0A38DA3, 0x6A8A6 },
	{ 0xF0A38DA4, 0x6ACA2 },
	{ 0xF0A38DA5, 0x5A9D4 },
	{ 0xF0A38DA6, 0x4A9E9 },
	{ 0xF0A38DA7, 0x4A9EA },
	{ 0xF0A38DAB, 0xFABBA },
	{ 0xF0A38DAC, 0x6B1F1 },
	{ 0xF0A38DAE, 0x6B8C3 },
	{ 0xF0A38DB3, 0xFB5CB },
	{ 0xF0A38DB4, 0x5B2F6 },
	{ 0xF0A38DB5, 0x6C0D9 },
	{ 0xF0A38DB6, 0x6C0DB },
	{ 0xF0A38DB7, 0x6C9FD },
	{ 0xF0A38DB8, 0x6C9FC },
	{ 0xF0A38DB9, 0x6C0DA },
	{ 0xF0A38DBA, 0x5B9AD },
	{ 0xF0A38DBC, 0xFB9C6 },
	{ 0xF0A38E81, 0xFBBE1 },
	{ 0xF0A38E82, 0xFBBE2 },
	{ 0xF0A38E84, 0x6D3C7 },
	{ 0xF0A38E85, 0x5BFE7 },
	{ 0xF0A38E89, 0xFBBE0 },
	{ 0xF0A38E8A, 0xFC1FE },
	{ 0xF0A38E8B, 0xFC2A1 },
	{ 0xF0A38E8C, 0x6D3C8 },
	{ 0xF0A38E8D, 0x6DDDD },
	{ 0xF0A38E90, 0x6DDDE },
	{ 0xF0A38E92, 0x7A3E4 },
	{ 0xF0A38E93, 0x4CAB4 },
	{ 0xF0A38E94, 0x5CDD9 },
	{ 0xF0A38E97, 0x4CAB3 },
	{ 0xF0A38E98, 0xFCFBB },
	{ 0xF0A38E99, 0xFCFBC },
	{ 0xF0A38E9A, 0x5D4EE },
	{ 0xF0A38E9B, 0x5D4EC },
	{ 0xF0A38E9C, 0x5DBE4 },
	{ 0xF0A38E9F, 0x5D4ED },
	{ 0xF0A38EA0, 0xFD4ED },
	{ 0xF0A38EA1, 0xFD4EE },
	{ 0xF0A38EA3, 0x7B8CB },
	{ 0xF0A38EA4, 0x7B8CA },
	{ 0xF0A38EA5, 0xFDABE },
	{ 0xF0A38EA9, 0x5E1F5 },
	{ 0xF0A38EAC, 0xFDEFC },
	{ 0xF0A38EAD, 0x7BFFB },
	{ 0xF0A38EAE, 0x5ECB8 },
	{ 0xF0A38EB1, 0x5F5EF },
	{ 0xF0A38EB2, 0x5F7DF },
	{ 0xF0A38EB3, 0x5A1C8 },
	{ 0xF0A38EB4, 0x4A1CE },
	{ 0xF0A38EB5, 0x4A1FD },
	{ 0xF0A38EB6, 0xFA1E5 },
	{ 0xF0A38EB8, 0x5A2F5 },
	{ 0xF0A38EB9, 0x6A5A2 },
	{ 0xF0A38EBA, 0x5A2F4 },
	{ 0xF0A38EBB, 0x6A4FE },
	{ 0xF0A38EBC, 0x6A5A1 },
	{ 0xF0A38EBD, 0xFA2D6 },
	{ 0xF0A38EBF, 0x4A2FB },
	{ 0xF0A38F80, 0x4A2FA },
	{ 0xF0A38F81, 0x6A8AC },
	{ 0xF0A38F82, 0x4A4C9 },
	{ 0xF0A38F83, 0x6A8AA },
	{ 0xF0A38F85, 0x6A8AB },
	{ 0xF0A38F86, 0xFA4CE },
	{ 0xF0A38F87, 0xFA4CF },
	{ 0xF0A38F88, 0xFA4D4 },
	{ 0xF0A38F89, 0xFA4D0 },
	{ 0xF0A38F8A, 0xFA4D2 },
	{ 0xF0A38F8B, 0x5A4C6 },
	{ 0xF0A38F90, 0x6A8AD },
	{ 0xF0A38F91, 0x5A4C5 },
	{ 0xF0A38F92, 0x4A4C5 },
	{ 0xF0A38F94, 0x4A6EB },
	{ 0xF0A38F95, 0x5A6CC },
	{ 0xF0A38F96, 0x4A6E6 },
	{ 0xF0A38F97, 0x5A6CB },
	{ 0xF0A38F98, 0x6ACAB },
	{ 0xF0A38F99, 0x5A6D0 },
	{ 0xF0A38F9A, 0x5A6D2 },
	{ 0xF0A38F9B, 0x6ACA8 },
	{ 0xF0A38F9C, 0x6ACA7 },
	{ 0xF0A38F9D, 0x6ACA6 },
	{ 0xF0A38F9E, 0x5A6CD },
	{ 0xF0A38F9F, 0x5A6D3 },
	{ 0xF0A38FA0, 0x5A6CF },
	{ 0xF0A38FA1, 0x5A6CE },
	{ 0xF0A38FA5, 0xFA7C3 },
	{ 0xF0A38FA7, 0xFA7C5 },
	{ 0xF0A38FA8, 0xFA7C6 },
	{ 0xF0A38FA9, 0xFA7C7 },
	{ 0xF0A38FAA, 0xFA7C9 },
	{ 0xF0A38FAB, 0xFA7CA },
	{ 0xF0A38FAC, 0xFA7CB },
	{ 0xF0A38FAD, 0xFA7CD },
	{ 0xF0A38FAE, 0xFA7CF },
	{ 0xF0A38FAF, 0xFA7D1 },
	{ 0xF0A38FB0, 0xFA7D4 },
	{ 0xF0A38FB1, 0xFA7D5 },
	{ 0xF0A38FB2, 0x6ACA4 },
	{ 0xF0A38FB3, 0x6ACA9 },
	{ 0xF0A38FB6, 0x5A6D4 },
	{ 0xF0A38FB8, 0x6ACAC },
	{ 0xF0A38FB9, 0xFA7C4 },
	{ 0xF0A38FBB, 0x6ACAD },
	{ 0xF0A38FBD, 0x6ACAA },
	{ 0xF0A38FBE, 0xFA7C8 },
	{ 0xF0A39080, 0xFA7C2 },
	{ 0xF0A39081, 0x6ACA5 },
	{ 0xF0A39083, 0x5A6D5 },
	{ 0xF0A39087, 0x6ADDC },
	{ 0xF0A39088, 0x6B1F4 },
	{ 0xF0A39089, 0x6B1F3 },
	{ 0xF0A3908A, 0x4A9EB },
	{ 0xF0A3908B, 0x5A9D6 },
	{ 0xF0A3908C, 0x6B1F5 },
	{ 0xF0A3908D, 0x6B1F6 },
	{ 0xF0A3908E, 0x5A9D5 },
	{ 0xF0A3908F, 0x5A9D9 },
	{ 0xF0A39090, 0x6B1F7 },
	{ 0xF0A39091, 0x5AEA6 },
	{ 0xF0A39092, 0x5A9DA },
	{ 0xF0A39093, 0x5A9D8 },
	{ 0xF0A39097, 0xFA7D3 },
	{ 0xF0A39098, 0xFABBB },
	{ 0xF0A39099, 0xFABBC },
	{ 0xF0A3909A, 0xFABBD },
	{ 0xF0A3909B, 0xFABBF },
	{ 0xF0A3909C, 0xFABC0 },
	{ 0xF0A3909D, 0xFABC1 },
	{ 0xF0A3909E, 0xFABC2 },
	{ 0xF0A3909F, 0xFABC3 },
	{ 0xF0A390A0, 0xFABC4 },
	{ 0xF0A390A1, 0xFABC5 },
	{ 0xF0A390A2, 0xFABC6 },
	{ 0xF0A390A3, 0xFABC7 },
	{ 0xF0A390A4, 0xFABC9 },
	{ 0xF0A390A5, 0xFABCA },
	{ 0xF0A390A6, 0xFABCB },
	{ 0xF0A390A7, 0xFABCC },
	{ 0xF0A390A8, 0xFABCD },
	{ 0xF0A390A9, 0xFABCE },
	{ 0xF0A390AA, 0xFABCF },
	{ 0xF0A390B0, 0x5A9DB },
	{ 0xF0A390B5, 0x6C0DC },
	{ 0xF0A390B6, 0x6B8CF },
	{ 0xF0A390B7, 0x6B8D3 },
	{ 0xF0A390B8, 0x6B8CB },
	{ 0xF0A390B9, 0x6B8CD },
	{ 0xF0A390BA, 0x6B8C6 },
	{ 0xF0A390BB, 0x5AEA7 },
	{ 0xF0A390BC, 0x6B8C8 },
	{ 0xF0A390BD, 0x6B8C5 },
	{ 0xF0A390BE, 0x6B8D1 },
	{ 0xF0A390BF, 0x4ADD0 },
	{ 0xF0A39180, 0x6C0DD },
	{ 0xF0A39181, 0x5A9D7 },
	{ 0xF0A39182, 0x5AEA9 },
	{ 0xF0A39183, 0x5AEAA },
	{ 0xF0A39184, 0x6B8C4 },
	{ 0xF0A3918F, 0xFAFF4 },
	{ 0xF0A39191, 0xFAFF5 },
	{ 0xF0A39192, 0xFAFF6 },
	{ 0xF0A39193, 0xFAFF8 },
	{ 0xF0A39194, 0xFAFF9 },
	{ 0xF0A39195, 0xFAFFA },
	{ 0xF0A39196, 0xFAFFB },
	{ 0xF0A39197, 0xFAFFC },
	{ 0xF0A39198, 0xFAFFD },
	{ 0xF0A39199, 0xFAFFE },
	{ 0xF0A3919A, 0xFB0A1 },
	{ 0xF0A3919B, 0xFB0A2 },
	{ 0xF0A3919C, 0xFB0A3 },
	{ 0xF0A3919D, 0xFB0A5 },
	{ 0xF0A3919E, 0xFB0A6 },
	{ 0xF0A3919F, 0xFB0A7 },
	{ 0xF0A391A0, 0xFB0A9 },
	{ 0xF0A391A1, 0xFB0AA },
	{ 0xF0A391A2, 0xFB0AB },
	{ 0xF0A391A3, 0xFB0AC },
	{ 0xF0A391A4, 0xFB0AE },
	{ 0xF0A391A5, 0x6B8CC },
	{ 0xF0A391A8, 0x6B8C7 },
	{ 0xF0A391AA, 0x6B8C9 },
	{ 0xF0A391AB, 0x4ADD3 },
	{ 0xF0A391AD, 0x6B8CE },
	{ 0xF0A391AE, 0xFB0B0 },
	{ 0xF0A391AF, 0xFB0A8 },
	{ 0xF0A391B1, 0x4ADDA },
	{ 0xF0A391B2, 0xFB0AD },
	{ 0xF0A391B8, 0x5AEAC },
	{ 0xF0A391B9, 0x5AEA8 },
	{ 0xF0A391BD, 0xFAFF7 },
	{ 0xF0A391BE, 0x6B8D2 },
	{ 0xF0A391BF, 0x6C0E8 },
	{ 0xF0A39280, 0x6C0E9 },
	{ 0xF0A39281, 0x6C0DF },
	{ 0xF0A39282, 0x5B2F7 },
	{ 0xF0A39283, 0x5B3A1 },
	{ 0xF0A39284, 0x5B9B6 },
	{ 0xF0A39285, 0x4B2C5 },
	{ 0xF0A39286, 0x4B2C0 },
	{ 0xF0A39287, 0x5B2FD },
	{ 0xF0A39288, 0x6C0E7 },
	{ 0xF0A39289, 0x6CAAE },
	{ 0xF0A3928F, 0x6C0E3 },
	{ 0xF0A39290, 0xFB5CC },
	{ 0xF0A39291, 0xFB5CD },
	{ 0xF0A39292, 0xFB5CF },
	{ 0xF0A39293, 0xFB5D0 },
	{ 0xF0A39294, 0xFB5D1 },
	{ 0xF0A39295, 0xFB5D2 },
	{ 0xF0A39296, 0xFB5D3 },
	{ 0xF0A39297, 0xFB5D4 },
	{ 0xF0A39298, 0xFB5D5 },
	{ 0xF0A39299, 0xFB5D6 },
	{ 0xF0A3929A, 0xFB5D8 },
	{ 0xF0A3929B, 0xFB5D9 },
	{ 0xF0A3929C, 0xFB5DA },
	{ 0xF0A3929D, 0xFB5DB },
	{ 0xF0A3929E, 0xFB5DC },
	{ 0xF0A3929F, 0xFB5DD },
	{ 0xF0A392A0, 0xFB5DE },
	{ 0xF0A392A1, 0xFB5DF },
	{ 0xF0A392A2, 0xFB5E0 },
	{ 0xF0A392A3, 0xFB5E1 },
	{ 0xF0A392A4, 0xFB5E2 },
	{ 0xF0A392A5, 0xFB5E3 },
	{ 0xF0A392A6, 0xFB5E5 },
	{ 0xF0A392A7, 0xFB5E6 },
	{ 0xF0A392A8, 0x6C0E4 },
	{ 0xF0A392A9, 0x6C0E6 },
	{ 0xF0A392AA, 0x6C0E5 },
	{ 0xF0A392AB, 0x4B2C7 },
	{ 0xF0A392AC, 0x6C0E2 },
	{ 0xF0A392AD, 0x6C0E0 },
	{ 0xF0A392AF, 0x6C0E1 },
	{ 0xF0A392B6, 0x4B2C4 },
	{ 0xF0A392B7, 0x5B3A2 },
	{ 0xF0A392B8, 0x5B2F8 },
	{ 0xF0A392B9, 0x5B2FB },
	{ 0xF0A392BA, 0x5B2FA },
	{ 0xF0A392BB, 0x5B2FC },
	{ 0xF0A392BC, 0x6C0EA },
	{ 0xF0A392BF, 0xFB5CE },
	{ 0xF0A39380, 0x6C0DE },
	{ 0xF0A39381, 0x4B8B6 },
	{ 0xF0A39382, 0x6CAB4 },
	{ 0xF0A39383, 0x5B9B5 },
	{ 0xF0A39384, 0x6D3C9 },
	{ 0xF0A39385, 0x4B8AE },
	{ 0xF0A39386, 0x5B9B8 },
	{ 0xF0A39387, 0x6CAA2 },
	{ 0xF0A39388, 0x5B9B2 },
	{ 0xF0A39389, 0x4B8AB },
	{ 0xF0A3938A, 0x5B9B0 },
	{ 0xF0A3938B, 0x5B9B4 },
	{ 0xF0A3938C, 0x4B8B1 },
	{ 0xF0A3938D, 0x6CAAD },
	{ 0xF0A3938E, 0x6CAAF },
	{ 0xF0A3938F, 0x5B9BA },
	{ 0xF0A39390, 0x6CAA4 },
	{ 0xF0A39391, 0x6CAA1 },
	{ 0xF0A39392, 0x5B9B7 },
	{ 0xF0A39393, 0x6CAB3 },
	{ 0xF0A39394, 0x5B9BC },
	{ 0xF0A39395, 0x5B9BB },
	{ 0xF0A39396, 0x6CAA6 },
	{ 0xF0A39397, 0x4B8B0 },
	{ 0xF0A39398, 0x6CAA7 },
	{ 0xF0A39399, 0x6CAAA },
	{ 0xF0A3939A, 0x6CAB1 },
	{ 0xF0A3939B, 0x5B9C0 },
	{ 0xF0A3939C, 0x6D3CA },
	{ 0xF0A3939D, 0x5B9BD },
	{ 0xF0A3939E, 0x6CAB8 },
	{ 0xF0A3939F, 0x6CAA3 },
	{ 0xF0A393A0, 0x6CAA5 },
	{ 0xF0A393A1, 0x6CAB5 },
	{ 0xF0A393A7, 0x4B8B3 },
	{ 0xF0A393A8, 0x4B8B8 },
	{ 0xF0A393A9, 0x6CAB6 },
	{ 0xF0A393AA, 0x6CAB7 },
	{ 0xF0A393AB, 0xFBBE4 },
	{ 0xF0A393AC, 0xFBBE5 },
	{ 0xF0A393AD, 0xFBBE7 },
	{ 0xF0A393AE, 0xFBBE8 },
	{ 0xF0A393AF, 0xFBBE9 },
	{ 0xF0A393B0, 0xFBBEB },
	{ 0xF0A393B1, 0xFBBEC },
	{ 0xF0A393B2, 0xFBBED },
	{ 0xF0A393B3, 0xFBBEF },
	{ 0xF0A393B4, 0xFBBF1 },
	{ 0xF0A393B5, 0xFBBF2 },
	{ 0xF0A393B6, 0xFBBF4 },
	{ 0xF0A393B7, 0xFBBF5 },
	{ 0xF0A393B8, 0xFBBF6 },
	{ 0xF0A393B9, 0xFBBF7 },
	{ 0xF0A393BA, 0xFBBF8 },
	{ 0xF0A393BB, 0xFBBF9 },
	{ 0xF0A393BC, 0xFBBFA },
	{ 0xF0A393BD, 0xFBBFB },
	{ 0xF0A393BE, 0xFBBFC },
	{ 0xF0A393BF, 0xFBBFD },
	{ 0xF0A39480, 0xFBBFE },
	{ 0xF0A39481, 0xFBCA2 },
	{ 0xF0A39482, 0xFBCA3 },
	{ 0xF0A39483, 0xFBCA4 },
	{ 0xF0A39484, 0xFBCA5 },
	{ 0xF0A39485, 0xFBCA6 },
	{ 0xF0A39486, 0xFBCA7 },
	{ 0xF0A39487, 0xFBCA8 },
	{ 0xF0A39488, 0xFBCAA },
	{ 0xF0A39489, 0xFBCAB },
	{ 0xF0A3948A, 0xFBCAC },
	{ 0xF0A3948B, 0xFBCAD },
	{ 0xF0A3948C, 0xFBCAE },
	{ 0xF0A3948D, 0xFBCAF },
	{ 0xF0A3948E, 0x6CAA9 },
	{ 0xF0A3948F, 0x6CAAB },
	{ 0xF0A39491, 0x6CAAC },
	{ 0xF0A39492, 0x6CAB2 },
	{ 0xF0A39493, 0x5B9C2 },
	{ 0xF0A39494, 0x6CAB0 },
	{ 0xF0A39495, 0x6CAB9 },
	{ 0xF0A39496, 0x6CAA8 },
	{ 0xF0A394AB, 0x5B9BE },
	{ 0xF0A394AC, 0x5B9C1 },
	{ 0xF0A394AD, 0x5B9AE },
	{ 0xF0A394AE, 0x5B9AF },
	{ 0xF0A394AF, 0x5B9B1 },
	{ 0xF0A394B1, 0x6D3CE },
	{ 0xF0A394B2, 0x6D3D8 },
	{ 0xF0A394B3, 0x4BDF7 },
	{ 0xF0A394B4, 0x6D3D6 },
	{ 0xF0A394B5, 0x4BDF4 },
	{ 0xF0A394B6, 0x6D3D7 },
	{ 0xF0A394B7, 0x5BFEF },
	{ 0xF0A394B8, 0x5BFEA },
	{ 0xF0A394B9, 0x5BFEE },
	{ 0xF0A394BA, 0x5BFEB },
	{ 0xF0A394BB, 0x4BDEA },
	{ 0xF0A394BC, 0x6D3DB },
	{ 0xF0A394BD, 0x5BFF3 },
	{ 0xF0A394BE, 0x6D3E1 },
	{ 0xF0A394BF, 0x5BFE8 },
	{ 0xF0A39580, 0x4BDFA },
	{ 0xF0A39581, 0x5BFF4 },
	{ 0xF0A39582, 0x5BFE9 },
	{ 0xF0A39583, 0x6D3D5 },
	{ 0xF0A39584, 0x5BFF0 },
	{ 0xF0A39585, 0x5BFED },
	{ 0xF0A39586, 0x6D3E0 },
	{ 0xF0A39587, 0x4BDF3 },
	{ 0xF0A39588, 0x6D3D9 },
	{ 0xF0A39589, 0x6D3DA },
	{ 0xF0A3958A, 0x6D3DD },
	{ 0xF0A3958B, 0x6D3D0 },
	{ 0xF0A3958C, 0x4BDF0 },
	{ 0xF0A3958D, 0x6D3DC },
	{ 0xF0A3958E, 0x5BFEC },
	{ 0xF0A39590, 0x6D3E3 },
	{ 0xF0A39591, 0x6D3CF },
	{ 0xF0A39592, 0x6D3D1 },
	{ 0xF0A39593, 0x6D3CC },
	{ 0xF0A39599, 0xFC2A3 },
	{ 0xF0A3959B, 0xFC2A4 },
	{ 0xF0A3959C, 0xFC2A5 },
	{ 0xF0A3959D, 0xFC2A6 },
	{ 0xF0A3959E, 0xFC2A7 },
	{ 0xF0A3959F, 0xFC2A9 },
	{ 0xF0A395A0, 0xFC2AA },
	{ 0xF0A395A1, 0xFC2AB },
	{ 0xF0A395A2, 0xFC2AC },
	{ 0xF0A395A3, 0xFC2AD },
	{ 0xF0A395A4, 0xFC2AE },
	{ 0xF0A395A5, 0xFC2B0 },
	{ 0xF0A395A6, 0xFC2B1 },
	{ 0xF0A395A7, 0xFC2B2 },
	{ 0xF0A395A8, 0xFC2B3 },
	{ 0xF0A395A9, 0xFC2B4 },
	{ 0xF0A395AA, 0xFC2B5 },
	{ 0xF0A395AB, 0xFC2B6 },
	{ 0xF0A395AC, 0xFC2B8 },
	{ 0xF0A395AD, 0xFC2B9 },
	{ 0xF0A395AE, 0xFC2BA },
	{ 0xF0A395AF, 0xFC2BB },
	{ 0xF0A395B0, 0xFC2BD },
	{ 0xF0A395B1, 0xFC2BE },
	{ 0xF0A395B2, 0xFC2BF },
	{ 0xF0A395B3, 0xFC2C0 },
	{ 0xF0A395B4, 0xFC2C1 },
	{ 0xF0A395B5, 0xFC2C2 },
	{ 0xF0A395B6, 0xFC2C3 },
	{ 0xF0A395B7, 0xFC2C4 },
	{ 0xF0A395B8, 0xFC2C5 },
	{ 0xF0A395B9, 0xFC2C6 },
	{ 0xF0A395BA, 0xFC2C8 },
	{ 0xF0A395BB, 0xFC2CA },
	{ 0xF0A395BC, 0xFC2CC },
	{ 0xF0A395BF, 0x6D3CD },
	{ 0xF0A39680, 0x6D3D2 },
	{ 0xF0A39681, 0x6D3D4 },
	{ 0xF0A39682, 0x4BDF9 },
	{ 0xF0A39683, 0x6D3E2 },
	{ 0xF0A39687, 0x6D3CB },
	{ 0xF0A3968A, 0x6D3DF },
	{ 0xF0A39690, 0xFC2A2 },
	{ 0xF0A39693, 0xFC2AF },
	{ 0xF0A39695, 0xFC2B7 },
	{ 0xF0A396A3, 0x5B9BF },
	{ 0xF0A396A4, 0x5BFF2 },
	{ 0xF0A396A5, 0x6D3D3 },
	{ 0xF0A396A6, 0xFC3F4 },
	{ 0xF0A396A8, 0x5C6CE },
	{ 0xF0A396A9, 0xFC2CB },
	{ 0xF0A396AA, 0x5C6D0 },
	{ 0xF0A396AB, 0x4C3FB },
	{ 0xF0A396AC, 0x4C3F2 },
	{ 0xF0A396AD, 0x5C6CD },
	{ 0xF0A396AE, 0x5C6CF },
	{ 0xF0A396AF, 0x6DDE9 },
	{ 0xF0A396B0, 0x5C6D5 },
	{ 0xF0A396B1, 0x5C6D2 },
	{ 0xF0A396B2, 0x7A3E5 },
	{ 0xF0A396B4, 0x6D3E4 },
	{ 0xF0A396B5, 0x5C6C7 },
	{ 0xF0A396B6, 0x6DDDF },
	{ 0xF0A396B7, 0x5C6D4 },
	{ 0xF0A396B8, 0x5C6C6 },
	{ 0xF0A396B9, 0x5C6D8 },
	{ 0xF0A396BA, 0x6DDE2 },
	{ 0xF0A396BB, 0x5C6CA },
	{ 0xF0A396BC, 0x5C6D3 },
	{ 0xF0A396BD, 0x6DDE3 },
	{ 0xF0A396BE, 0x4C3F6 },
	{ 0xF0A396BF, 0x5C6C8 },
	{ 0xF0A39781, 0x5C6C9 },
	{ 0xF0A39782, 0x6DDE5 },
	{ 0xF0A39783, 0x5C6CC },
	{ 0xF0A39790, 0x5C6D1 },
	{ 0xF0A39794, 0xFC8D7 },
	{ 0xF0A39795, 0xFC8D8 },
	{ 0xF0A39796, 0xFC8D9 },
	{ 0xF0A39797, 0xFC8DA },
	{ 0xF0A39798, 0xFC8DB },
	{ 0xF0A39799, 0xFC8DC },
	{ 0xF0A3979A, 0xFC8DD },
	{ 0xF0A3979B, 0xFC8DE },
	{ 0xF0A3979C, 0xFC8DF },
	{ 0xF0A3979D, 0xFC8E0 },
	{ 0xF0A3979E, 0xFC8E1 },
	{ 0xF0A3979F, 0xFC8E2 },
	{ 0xF0A397A0, 0xFC8E3 },
	{ 0xF0A397A1, 0xFC8E4 },
	{ 0xF0A397A2, 0xFC8E5 },
	{ 0xF0A397A3, 0xFC8E6 },
	{ 0xF0A397A4, 0xFC8E7 },
	{ 0xF0A397A5, 0xFC8E8 },
	{ 0xF0A397A6, 0xFC8E9 },
	{ 0xF0A397A7, 0xFC8EA },
	{ 0xF0A397A8, 0xFC8EB },
	{ 0xF0A397A9, 0xFC8EC },
	{ 0xF0A397AA, 0xFC8ED },
	{ 0xF0A397AB, 0xFC8EE },
	{ 0xF0A397AC, 0xFC8EF },
	{ 0xF0A397AD, 0xFC8F1 },
	{ 0xF0A397AE, 0xFC8F2 },
	{ 0xF0A397AF, 0xFC8F3 },
	{ 0xF0A397B0, 0xFC8F5 },
	{ 0xF0A397B3, 0x3C7CB },
	{ 0xF0A397B4, 0x6DDEA },
	{ 0xF0A397B5, 0x6DDE7 },
	{ 0xF0A397B7, 0x6DDEB },
	{ 0xF0A397B8, 0x6DDEC },
	{ 0xF0A397BA, 0x5C6D6 },
	{ 0xF0A397BB, 0x5C6D7 },
	{ 0xF0A39880, 0xFC8F4 },
	{ 0xF0A39885, 0x6DDE4 },
	{ 0xF0A39887, 0x6DDE6 },
	{ 0xF0A3988B, 0xFC8D0 },
	{ 0xF0A3988D, 0xFC8D1 },
	{ 0xF0A3988E, 0xFC8D3 },
	{ 0xF0A3988F, 0xFC8D4 },
	{ 0xF0A39890, 0x6DDE0 },
	{ 0xF0A39891, 0x6DDED },
	{ 0xF0A39892, 0x6DDE1 },
	{ 0xF0A39894, 0xFC8D6 },
	{ 0xF0A39895, 0x7A3E8 },
	{ 0xF0A39896, 0x5CDE7 },
	{ 0xF0A39897, 0x5CDDE },
	{ 0xF0A39898, 0x4CABB },
	{ 0xF0A39899, 0x4CAC7 },
	{ 0xF0A3989A, 0x5CDDB },
	{ 0xF0A3989B, 0x4CAC0 },
	{ 0xF0A3989C, 0x7A3F1 },
	{ 0xF0A3989D, 0x7A3EC },
	{ 0xF0A3989E, 0x7A3F4 },
	{ 0xF0A3989F, 0x5CDEB },
	{ 0xF0A398A0, 0x5CDE5 },
	{ 0xF0A398A1, 0x7A3F0 },
	{ 0xF0A398A2, 0x4CAC6 },
	{ 0xF0A398A3, 0x5CDDF },
	{ 0xF0A398A4, 0x4CABF },
	{ 0xF0A398A5, 0x5CDE4 },
	{ 0xF0A398A6, 0x4CAC3 },
	{ 0xF0A398A7, 0x4CABE },
	{ 0xF0A398A8, 0x4CAB5 },
	{ 0xF0A398A9, 0x7A3F3 },
	{ 0xF0A398AA, 0x5CDDC },
	{ 0xF0A398AB, 0x4CACA },
	{ 0xF0A398AC, 0x5CDE9 },
	{ 0xF0A398AD, 0x7A3EE },
	{ 0xF0A398AE, 0x5CDE3 },
	{ 0xF0A398AF, 0x5CDEA },
	{ 0xF0A398B0, 0x7A3E9 },
	{ 0xF0A398B1, 0x4CAC1 },
	{ 0xF0A398B2, 0x5CDDD },
	{ 0xF0A398B3, 0x7A3F5 },
	{ 0xF0A398BB, 0x4CABC },
	{ 0xF0A398BF, 0x4CAC5 },
	{ 0xF0A39981, 0x4CAC9 },
	{ 0xF0A39982, 0x7A3E6 },
	{ 0xF0A39983, 0x7A3EA },
	{ 0xF0A39984, 0xFCFBD },
	{ 0xF0A39985, 0xFCFBE },
	{ 0xF0A39986, 0xFCFBF },
	{ 0xF0A39987, 0xFCFC3 },
	{ 0xF0A39988, 0xFCFC4 },
	{ 0xF0A39989, 0xFCFC6 },
	{ 0xF0A3998A, 0xFCFC7 },
	{ 0xF0A3998B, 0xFCFC8 },
	{ 0xF0A3998C, 0xFCFC9 },
	{ 0xF0A3998D, 0xFCFCA },
	{ 0xF0A3998E, 0xFCFCB },
	{ 0xF0A3998F, 0xFCFCC },
	{ 0xF0A39990, 0xFCFCD },
	{ 0xF0A39991, 0xFCFCE },
	{ 0xF0A39992, 0xFCFCF },
	{ 0xF0A39993, 0xFCFD0 },
	{ 0xF0A39994, 0xFCFD1 },
	{ 0xF0A39995, 0xFCFD2 },
	{ 0xF0A39996, 0xFCFD3 },
	{ 0xF0A39999, 0xFCFC0 },
	{ 0xF0A3999B, 0x7A3EB },
	{ 0xF0A399A4, 0x5CDEC },
	{ 0xF0A399B0, 0x5CDE8 },
	{ 0xF0A399B1, 0x5CDE6 },
	{ 0xF0A399B2, 0x7A3E7 },
	{ 0xF0A399B3, 0x7A3ED },
	{ 0xF0A399B4, 0x5CDE0 },
	{ 0xF0A399B5, 0x5CDDA },
	{ 0xF0A399B6, 0x5CDE2 },
	{ 0xF0A399BB, 0x4D0DB },
	{ 0xF0A399BC, 0x5D4FD },
	{ 0xF0A399BD, 0x7AEE9 },
	{ 0xF0A399BE, 0x4D0E5 },
	{ 0xF0A399BF, 0x4D0D8 },
	{ 0xF0A39A80, 0x5DBE5 },
	{ 0xF0A39A81, 0x7B8CC },
	{ 0xF0A39A82, 0x7AEE0 },
	{ 0xF0A39A83, 0x7AEE3 },
	{ 0xF0A39A84, 0x5D4FB },
	{ 0xF0A39A85, 0x7AEE8 },
	{ 0xF0A39A86, 0x7AEF2 },
	{ 0xF0A39A87, 0x5D4FA },
	{ 0xF0A39A88, 0x7AEEF },
	{ 0xF0A39A89, 0x7AEE2 },
	{ 0xF0A39A8A, 0x4D0E2 },
	{ 0xF0A39A8B, 0x4D6CC },
	{ 0xF0A39A8C, 0x4D0D7 },
	{ 0xF0A39A8D, 0x7AEDF },
	{ 0xF0A39A8E, 0x4D0DF },
	{ 0xF0A39A8F, 0x5D4F9 },
	{ 0xF0A39A90, 0x7AEE7 },
	{ 0xF0A39A91, 0x7AEE4 },
	{ 0xF0A39A92, 0x5D4F1 },
	{ 0xF0A39A94, 0x5D4F7 },
	{ 0xF0A39A95, 0x4D0DC },
	{ 0xF0A39A96, 0x7AEEE },
	{ 0xF0A39A97, 0x7AEF4 },
	{ 0xF0A39A98, 0x5D4F8 },
	{ 0xF0A39A99, 0x4D0DD },
	{ 0xF0A39A9A, 0x7AEE6 },
	{ 0xF0A39A9B, 0x7AEEB },
	{ 0xF0A39A9C, 0x4D0E3 },
	{ 0xF0A39A9D, 0x5D4F0 },
	{ 0xF0A39A9E, 0x7AEE1 },
	{ 0xF0A39A9F, 0x5E1FB },
	{ 0xF0A39AA0, 0x5D4F5 },
	{ 0xF0A39AA1, 0x5D4F6 },
	{ 0xF0A39AA2, 0x5D4F2 },
	{ 0xF0A39AA3, 0x4CAC4 },
	{ 0xF0A39AA4, 0x7AEF3 },
	{ 0xF0A39AA5, 0x7AEEC },
	{ 0xF0A39AA6, 0x7AEE5 },
	{ 0xF0A39AA8, 0x7AEDE },
	{ 0xF0A39AA9, 0x5D4FC },
	{ 0xF0A39AAA, 0x5D4EF },
	{ 0xF0A39AAF, 0x5D4F3 },
	{ 0xF0A39AB0, 0xFD4EF },
	{ 0xF0A39AB1, 0xFD4F0 },
	{ 0xF0A39AB2, 0xFD4F1 },
	{ 0xF0A39AB3, 0xFD4F2 },
	{ 0xF0A39AB4, 0xFD4F3 },
	{ 0xF0A39AB5, 0xFD4F5 },
	{ 0xF0A39AB6, 0xFD4F6 },
	{ 0xF0A39AB7, 0xFD4F7 },
	{ 0xF0A39AB8, 0xFD4F8 },
	{ 0xF0A39AB9, 0xFD4F9 },
	{ 0xF0A39ABA, 0xFD4FA },
	{ 0xF0A39ABB, 0xFD4FC },
	{ 0xF0A39ABC, 0xFD4FD },
	{ 0xF0A39ABD, 0xFD4FE },
	{ 0xF0A39ABE, 0xFD5A1 },
	{ 0xF0A39ABF, 0xFD5A2 },
	{ 0xF0A39B80, 0xFD5A4 },
	{ 0xF0A39B81, 0xFD5A5 },
	{ 0xF0A39B82, 0xFD5A6 },
	{ 0xF0A39B83, 0xFD5A7 },
	{ 0xF0A39B84, 0xFD5A8 },
	{ 0xF0A39B85, 0xFD5AB },
	{ 0xF0A39B86, 0xFD5AC },
	{ 0xF0A39B87, 0xFD5AD },
	{ 0xF0A39B88, 0xFD5AE },
	{ 0xF0A39B89, 0xFD5AF },
	{ 0xF0A39B8A, 0xFD5B0 },
	{ 0xF0A39B8B, 0xFD5B2 },
	{ 0xF0A39B8C, 0xFD5B3 },
	{ 0xF0A39B8D, 0xFD5B4 },
	{ 0xF0A39B8E, 0xFD5B5 },
	{ 0xF0A39B8F, 0xFD5B6 },
	{ 0xF0A39B90, 0xFD5B7 },
	{ 0xF0A39B91, 0xFD5B8 },
	{ 0xF0A39B96, 0x7AEF0 },
	{ 0xF0A39B98, 0x7AEF1 },
	{ 0xF0A39B9A, 0x4D0E1 },
	{ 0xF0A39B9F, 0xFD5A3 },
	{ 0xF0A39BAB, 0x5D4F4 },
	{ 0xF0A39BAC, 0xFC8F0 },
	{ 0xF0A39BAE, 0xFCFC1 },
	{ 0xF0A39BB0, 0x7AEED },
	{ 0xF0A39BB1, 0x4D6C3 },
	{ 0xF0A39BB2, 0x7B8D0 },
	{ 0xF0A39BB3, 0x7B8CE },
	{ 0xF0A39BB4, 0x4D6C7 },
	{ 0xF0A39BB5, 0x7B8D2 },
	{ 0xF0A39BB6, 0x7B8D6 },
	{ 0xF0A39BB7, 0x5DBEA },
	{ 0xF0A39BB8, 0x5DBEB },
	{ 0xF0A39BB9, 0x4D6CA },
	{ 0xF0A39BBA, 0x4D6C6 },
	{ 0xF0A39BBB, 0x5DBEE },
	{ 0xF0A39BBC, 0x7B8D3 },
	{ 0xF0A39BBD, 0x5DBEC },
	{ 0xF0A39BBF, 0x7B8D1 },
	{ 0xF0A39C80, 0x7B8D7 },
	{ 0xF0A39C81, 0x5E1FC },
	{ 0xF0A39C82, 0x5DBE7 },
	{ 0xF0A39C83, 0x4D6CD },
	{ 0xF0A39C84, 0x4D6C4 },
	{ 0xF0A39C85, 0x7B8D9 },
	{ 0xF0A39C86, 0x4D6C2 },
	{ 0xF0A39C87, 0x5DBE9 },
	{ 0xF0A39C88, 0x7B8DB },
	{ 0xF0A39C8D, 0x5DBE6 },
	{ 0xF0A39C8E, 0x7B8D4 },
	{ 0xF0A39C8F, 0xFDAC0 },
	{ 0xF0A39C90, 0xFDAC1 },
	{ 0xF0A39C91, 0xFDAC3 },
	{ 0xF0A39C92, 0xFDAC4 },
	{ 0xF0A39C93, 0xFDAC5 },
	{ 0xF0A39C94, 0xFDAC6 },
	{ 0xF0A39C95, 0xFDAC7 },
	{ 0xF0A39C96, 0xFDAC8 },
	{ 0xF0A39C97, 0xFDAC9 },
	{ 0xF0A39C98, 0xFDACA },
	{ 0xF0A39C99, 0xFDACB },
	{ 0xF0A39C9A, 0xFDACC },
	{ 0xF0A39C9B, 0xFDACE },
	{ 0xF0A39C9C, 0xFDACF },
	{ 0xF0A39C9D, 0xFDAD1 },
	{ 0xF0A39C9E, 0xFDAD2 },
	{ 0xF0A39C9F, 0xFDAD4 },
	{ 0xF0A39CA3, 0x7B8D8 },
	{ 0xF0A39CA4, 0x5DBED },
	{ 0xF0A39CA5, 0x7B8DA },
	{ 0xF0A39CA6, 0x7B8CD },
	{ 0xF0A39CA7, 0x7B8CF },
	{ 0xF0A39CA8, 0x7B7A7 },
	{ 0xF0A39CAC, 0xFDAD3 },
	{ 0xF0A39CAF, 0xFDACD },
	{ 0xF0A39CB9, 0x5DBEF },
	{ 0xF0A39CBA, 0x5DBF0 },
	{ 0xF0A39CBC, 0xFD5B1 },
	{ 0xF0A39CBF, 0xFDAD0 },
	{ 0xF0A39D81, 0x4DBC7 },
	{ 0xF0A39D82, 0x5E1F8 },
	{ 0xF0A39D83, 0x7C0A7 },
	{ 0xF0A39D84, 0x7C0A3 },
	{ 0xF0A39D85, 0x4DBC2 },
	{ 0xF0A39D86, 0x7C0AB },
	{ 0xF0A39D87, 0x5E2A4 },
	{ 0xF0A39D88, 0x5E1FD },
	{ 0xF0A39D89, 0x5E2A6 },
	{ 0xF0A39D8A, 0x7C0A9 },
	{ 0xF0A39D8B, 0x4DBC5 },
	{ 0xF0A39D8C, 0x5E1FA },
	{ 0xF0A39D8D, 0x5E2A2 },
	{ 0xF0A39D8E, 0x5E2A7 },
	{ 0xF0A39D8F, 0x5E1FE },
	{ 0xF0A39D90, 0x7B8DC },
	{ 0xF0A39D91, 0x5E2AB },
	{ 0xF0A39D92, 0x5E1F9 },
	{ 0xF0A39D93, 0x4DBC3 },
	{ 0xF0A39D94, 0x4DBCC },
	{ 0xF0A39D95, 0x4DBC6 },
	{ 0xF0A39D96, 0x7C0AD },
	{ 0xF0A39D97, 0x7C0A8 },
	{ 0xF0A39D98, 0x5E2A3 },
	{ 0xF0A39D99, 0x7C7C6 },
	{ 0xF0A39D9A, 0x5E2A9 },
	{ 0xF0A39D9B, 0x7C0A6 },
	{ 0xF0A39D9C, 0x4DBCB },
	{ 0xF0A39D9D, 0x5E2A8 },
	{ 0xF0A39D9E, 0x5E2A5 },
	{ 0xF0A39DA5, 0x5E1F6 },
	{ 0xF0A39DA7, 0x7BFFC },
	{ 0xF0A39DA8, 0x7BFFD },
	{ 0xF0A39DA9, 0xFDEFE },
	{ 0xF0A39DAA, 0xFDFA2 },
	{ 0xF0A39DAB, 0xFDFA3 },
	{ 0xF0A39DAC, 0xFDFA4 },
	{ 0xF0A39DAD, 0xFDFA5 },
	{ 0xF0A39DAE, 0xFDFA6 },
	{ 0xF0A39DAF, 0xFDFA7 },
	{ 0xF0A39DB0, 0xFDFA8 },
	{ 0xF0A39DB1, 0xFDFAA },
	{ 0xF0A39DB2, 0xFDFAB },
	{ 0xF0A39DB3, 0xFDFAC },
	{ 0xF0A39DB4, 0xFDFAE },
	{ 0xF0A39DB5, 0xFDFAF },
	{ 0xF0A39DB6, 0xFDFB0 },
	{ 0xF0A39DB7, 0x7C0A1 },
	{ 0xF0A39DB9, 0x7C0A5 },
	{ 0xF0A39DBB, 0x7C0AC },
	{ 0xF0A39DBC, 0x7C0AA },
	{ 0xF0A39DBE, 0x5E2A1 },
	{ 0xF0A39E81, 0xFDFA1 },
	{ 0xF0A39E86, 0x5E2AA },
	{ 0xF0A39E87, 0x5E1F7 },
	{ 0xF0A39E89, 0x7C0A2 },
	{ 0xF0A39E8B, 0x7C0A4 },
	{ 0xF0A39E8C, 0xFDFAD },
	{ 0xF0A39E90, 0x5E8A5 },
	{ 0xF0A39E91, 0x7C7C3 },
	{ 0xF0A39E92, 0x5E8A8 },
	{ 0xF0A39E93, 0x5E8AB },
	{ 0xF0A39E94, 0x5E8A9 },
	{ 0xF0A39E95, 0x7C7C2 },
	{ 0xF0A39E96, 0x7C7C0 },
	{ 0xF0A39E97, 0x5E8AD },
	{ 0xF0A39E98, 0x7C7C1 },
	{ 0xF0A39E99, 0x4DFF4 },
	{ 0xF0A39E9A, 0x7C7C8 },
	{ 0xF0A39E9B, 0x7C7C9 },
	{ 0xF0A39E9C, 0x5E8A7 },
	{ 0xF0A39E9D, 0x5E8A6 },
	{ 0xF0A39E9E, 0x7C7C5 },
	{ 0xF0A39E9F, 0x5E8AF },
	{ 0xF0A39EA3, 0x7C7C7 },
	{ 0xF0A39EA4, 0x7BFFE },
	{ 0xF0A39EA5, 0xFE2D2 },
	{ 0xF0A39EA6, 0xFE2D6 },
	{ 0xF0A39EA7, 0xFE2D8 },
	{ 0xF0A39EA8, 0xFE2D9 },
	{ 0xF0A39EA9, 0xFE2DA },
	{ 0xF0A39EAA, 0xFE2DB },
	{ 0xF0A39EAB, 0xFE2DC },
	{ 0xF0A39EAC, 0xFE2DD },
	{ 0xF0A39EAD, 0xFE2DF },
	{ 0xF0A39EAE, 0xFE2E0 },
	{ 0xF0A39EAF, 0xFE2E1 },
	{ 0xF0A39EB0, 0x5E8AE },
	{ 0xF0A39EB2, 0x7C7C4 },
	{ 0xF0A39EB5, 0x7C7BF },
	{ 0xF0A39EB6, 0xFE2D4 },
	{ 0xF0A39EB7, 0x5E8AC },
	{ 0xF0A39EBB, 0xFE2D7 },
	{ 0xF0A39EBC, 0xFE2CF },
	{ 0xF0A39EBF, 0xFE2DE },
	{ 0xF0A39F82, 0xFDEFD },
	{ 0xF0A39F84, 0x4E3D3 },
	{ 0xF0A39F85, 0x7CDFC },
	{ 0xF0A39F86, 0x5ECBF },
	{ 0xF0A39F87, 0x7CDFE },
	{ 0xF0A39F88, 0x5ECC2 },
	{ 0xF0A39F89, 0x5E8B0 },
	{ 0xF0A39F8A, 0x5ECBA },
	{ 0xF0A39F8B, 0x5ECB9 },
	{ 0xF0A39F8C, 0x5ECBD },
	{ 0xF0A39F8D, 0x7CDFD },
	{ 0xF0A39F8E, 0x5ECBC },
	{ 0xF0A39F8F, 0x5ECC1 },
	{ 0xF0A39F90, 0x5ECBB },
	{ 0xF0A39F91, 0x5E8AA },
	{ 0xF0A39F92, 0x5ECC0 },
	{ 0xF0A39F98, 0x5ECBE },
	{ 0xF0A39F99, 0xFE5B3 },
	{ 0xF0A39F9A, 0xFE5B4 },
	{ 0xF0A39F9B, 0xFE5B5 },
	{ 0xF0A39F9C, 0xFE5B6 },
	{ 0xF0A39F9D, 0xFE5B7 },
	{ 0xF0A39F9E, 0xFE5B9 },
	{ 0xF0A39F9F, 0xFE5BA },
	{ 0xF0A39FA0, 0xFE5BB },
	{ 0xF0A39FA1, 0xFE5BC },
	{ 0xF0A39FA2, 0xFE5BD },
	{ 0xF0A39FA3, 0xFE5BF },
	{ 0xF0A39FA8, 0x7CEA1 },
	{ 0xF0A39FAC, 0x4E3D2 },
	{ 0xF0A39FAF, 0x7D3C9 },
	{ 0xF0A39FB0, 0x7D3C8 },
	{ 0xF0A39FB2, 0x5F0AB },
	{ 0xF0A39FB3, 0x5F0AD },
	{ 0xF0A39FB4, 0x4E6C6 },
	{ 0xF0A39FB5, 0x5F0A9 },
	{ 0xF0A39FB6, 0x7D3CD },
	{ 0xF0A39FB8, 0x5F0A8 },
	{ 0xF0A39FB9, 0x5F0AA },
	{ 0xF0A39FBA, 0x5F0AC },
	{ 0xF0A39FBB, 0x7D3CA },
	{ 0xF0A39FBC, 0x4E6C5 },
	{ 0xF0A39FBD, 0x5F0AF },
	{ 0xF0A39FBE, 0x7D3CE },
	{ 0xF0A3A081, 0x5F0B2 },
	{ 0xF0A3A082, 0xFE7DB },
	{ 0xF0A3A083, 0xFE7DC },
	{ 0xF0A3A084, 0xFE7DD },
	{ 0xF0A3A085, 0xFE7DE },
	{ 0xF0A3A086, 0xFE7DF },
	{ 0xF0A3A087, 0xFE7E0 },
	{ 0xF0A3A088, 0xFE7E1 },
	{ 0xF0A3A089, 0xFE7E2 },
	{ 0xF0A3A08A, 0xFE7E3 },
	{ 0xF0A3A08B, 0xFE7E4 },
	{ 0xF0A3A08C, 0x7D3CC },
	{ 0xF0A3A08E, 0x5F0B1 },
	{ 0xF0A3A08F, 0x5F0B0 },
	{ 0xF0A3A090, 0x7D3CB },
	{ 0xF0A3A094, 0x5F0AE },
	{ 0xF0A3A099, 0x7D8A6 },
	{ 0xF0A3A09A, 0x5F3CE },
	{ 0xF0A3A09B, 0x5F3CF },
	{ 0xF0A3A09C, 0x5F3CC },
	{ 0xF0A3A09D, 0x5F3CA },
	{ 0xF0A3A09E, 0x4E8EF },
	{ 0xF0A3A09F, 0x5F3CB },
	{ 0xF0A3A0A0, 0x5F3CD },
	{ 0xF0A3A0A1, 0x7D8A5 },
	{ 0xF0A3A0A5, 0xFE9C7 },
	{ 0xF0A3A0A6, 0xFE9C8 },
	{ 0xF0A3A0A7, 0xFE9C9 },
	{ 0xF0A3A0A8, 0xFE9CB },
	{ 0xF0A3A0A9, 0xFE9CE },
	{ 0xF0A3A0AA, 0xFE9CF },
	{ 0xF0A3A0AB, 0xFE9D0 },
	{ 0xF0A3A0AC, 0xFE9D1 },
	{ 0xF0A3A0AD, 0x7D8A4 },
	{ 0xF0A3A0AE, 0x7D8A2 },
	{ 0xF0A3A0B5, 0xFE7E5 },
	{ 0xF0A3A0B7, 0x5F5F1 },
	{ 0xF0A3A0B8, 0x5F5F3 },
	{ 0xF0A3A0B9, 0x5F7E0 },
	{ 0xF0A3A0BA, 0x5F5F4 },
	{ 0xF0A3A0BB, 0x7DBE0 },
	{ 0xF0A3A0BC, 0x5F5F2 },
	{ 0xF0A3A0BD, 0x7DBE1 },
	{ 0xF0A3A0BE, 0x5F5F5 },
	{ 0xF0A3A0BF, 0x7DBDF },
	{ 0xF0A3A180, 0x5F7E1 },
	{ 0xF0A3A183, 0x7DBDD },
	{ 0xF0A3A184, 0xFEAD7 },
	{ 0xF0A3A185, 0xFEAD9 },
	{ 0xF0A3A186, 0x7DBDE },
	{ 0xF0A3A189, 0x5F5F6 },
	{ 0xF0A3A18A, 0x5F5F0 },
	{ 0xF0A3A18C, 0x4EBEC },
	{ 0xF0A3A18D, 0x7DEEE },
	{ 0xF0A3A18E, 0x5F7E2 },
	{ 0xF0A3A18F, 0x7E0F1 },
	{ 0xF0A3A190, 0xFEBCE },
	{ 0xF0A3A191, 0xFEBCF },
	{ 0xF0A3A192, 0xFEBD0 },
	{ 0xF0A3A193, 0xFEBD3 },
	{ 0xF0A3A194, 0xFEBD4 },
	{ 0xF0A3A198, 0x7DEEF },
	{ 0xF0A3A19B, 0x7DEF0 },
	{ 0xF0A3A19C, 0xFEAD8 },
	{ 0xF0A3A19E, 0x7E0F2 },
	{ 0xF0A3A1A0, 0x5F9AD },
	{ 0xF0A3A1A2, 0xFECAC },
	{ 0xF0A3A1A3, 0x7E0F3 },
	{ 0xF0A3A1A5, 0x5F9AC },
	{ 0xF0A3A1A7, 0x5F9AE },
	{ 0xF0A3A1A8, 0xFEBD2 },
	{ 0xF0A3A1A9, 0x5FAA9 },
	{ 0xF0A3A1AA, 0x7E3D4 },
	{ 0xF0A3A1AB, 0x7E0F4 },
	{ 0xF0A3A1AD, 0x4EDD5 },
	{ 0xF0A3A1AE, 0xFECAD },
	{ 0xF0A3A1B1, 0xFECCC },
	{ 0xF0A3A1B2, 0xFECE3 },
	{ 0xF0A3A1B3, 0x7E3CC },
	{ 0xF0A3A1B4, 0x7E3D5 },
	{ 0xF0A3A1B6, 0x5FBC0 },
	{ 0xF0A3A1B7, 0x7E4C8 },
	{ 0xF0A3A1B8, 0x7E4C9 },
	{ 0xF0A3A1BA, 0x7E5DB },
	{ 0xF0A3A1BB, 0xFEDAF },
	{ 0xF0A3A1BC, 0x7E5F4 },
	{ 0xF0A3A280, 0x6A5A4 },
	{ 0xF0A3A281, 0x4A4CB },
	{ 0xF0A3A282, 0x6A8AF },
	{ 0xF0A3A283, 0x6ACAE },
	{ 0xF0A3A284, 0x6A8B2 },
	{ 0xF0A3A285, 0x5A4C7 },
	{ 0xF0A3A286, 0x6A8B1 },
	{ 0xF0A3A287, 0x4A4CA },
	{ 0xF0A3A289, 0x5A6DC },
	{ 0xF0A3A28A, 0x5A6DB },
	{ 0xF0A3A28B, 0x5A6D8 },
	{ 0xF0A3A28C, 0x6ACAF },
	{ 0xF0A3A28D, 0x4A6EF },
	{ 0xF0A3A28E, 0x6ACB0 },
	{ 0xF0A3A28F, 0x5A6DD },
	{ 0xF0A3A290, 0x4A6EE },
	{ 0xF0A3A291, 0x5A6D9 },
	{ 0xF0A3A292, 0x5A6DA },
	{ 0xF0A3A293, 0x5A6D7 },
	{ 0xF0A3A294, 0xFA7D6 },
	{ 0xF0A3A297, 0x5A9DF },
	{ 0xF0A3A298, 0x6B1FA },
	{ 0xF0A3A299, 0x6B8D4 },
	{ 0xF0A3A29A, 0x6B1FC },
	{ 0xF0A3A29B, 0x5A9E2 },
	{ 0xF0A3A29C, 0x4A9F5 },
	{ 0xF0A3A29D, 0x5A9E1 },
	{ 0xF0A3A29E, 0x5A9DE },
	{ 0xF0A3A29F, 0x6B1F9 },
	{ 0xF0A3A2A0, 0x5A9DC },
	{ 0xF0A3A2A1, 0x5A9E0 },
	{ 0xF0A3A2A2, 0x6B1FB },
	{ 0xF0A3A2A3, 0x5A9DD },
	{ 0xF0A3A2A6, 0xFACF7 },
	{ 0xF0A3A2A7, 0x6B8D7 },
	{ 0xF0A3A2A8, 0x6B8D8 },
	{ 0xF0A3A2A9, 0x6B8D5 },
	{ 0xF0A3A2AA, 0x5AEB3 },
	{ 0xF0A3A2AC, 0x5AEAD },
	{ 0xF0A3A2AD, 0x6B8D6 },
	{ 0xF0A3A2AE, 0x6C0EB },
	{ 0xF0A3A2AF, 0x5AEB2 },
	{ 0xF0A3A2B0, 0x4ADDF },
	{ 0xF0A3A2B1, 0x5AEAF },
	{ 0xF0A3A2B2, 0x5AEB4 },
	{ 0xF0A3A2B3, 0x5AEB1 },
	{ 0xF0A3A2B4, 0x5AEB0 },
	{ 0xF0A3A2B5, 0xFB0B1 },
	{ 0xF0A3A2BA, 0x5B3A5 },
	{ 0xF0A3A2BB, 0x6C0EC },
	{ 0xF0A3A2BD, 0x6C0ED },
	{ 0xF0A3A2BF, 0xFB5E7 },
	{ 0xF0A3A380, 0xFB5E8 },
	{ 0xF0A3A381, 0xFB5E9 },
	{ 0xF0A3A382, 0xFB5EA },
	{ 0xF0A3A383, 0xFB5EB },
	{ 0xF0A3A384, 0xFB5EC },
	{ 0xF0A3A385, 0xFB5ED },
	{ 0xF0A3A386, 0xFB5EE },
	{ 0xF0A3A388, 0x4B8BD },
	{ 0xF0A3A389, 0x5B9C7 },
	{ 0xF0A3A38A, 0x5BFF7 },
	{ 0xF0A3A38B, 0x4B8BA },
	{ 0xF0A3A38C, 0x5B9C5 },
	{ 0xF0A3A38D, 0x6CABC },
	{ 0xF0A3A38E, 0x5B3A4 },
	{ 0xF0A3A38F, 0x5B9C8 },
	{ 0xF0A3A390, 0x6CABD },
	{ 0xF0A3A391, 0x5B9C4 },
	{ 0xF0A3A392, 0x5B9C9 },
	{ 0xF0A3A393, 0x6CABE },
	{ 0xF0A3A395, 0x5B9C6 },
	{ 0xF0A3A396, 0x6CABB },
	{ 0xF0A3A397, 0xFBCB0 },
	{ 0xF0A3A398, 0xFBCB1 },
	{ 0xF0A3A399, 0x6CABA },
	{ 0xF0A3A39D, 0x6D3EE },
	{ 0xF0A3A39E, 0x5BFF6 },
	{ 0xF0A3A39F, 0x5BFF5 },
	{ 0xF0A3A3A0, 0x5BFFA },
	{ 0xF0A3A3A1, 0x6D3EB },
	{ 0xF0A3A3A2, 0x5BFF9 },
	{ 0xF0A3A3A3, 0x6D3E7 },
	{ 0xF0A3A3A4, 0x6D3E6 },
	{ 0xF0A3A3A5, 0x6D3E8 },
	{ 0xF0A3A3A6, 0x6D3E9 },
	{ 0xF0A3A3A7, 0x6D3EA },
	{ 0xF0A3A3A8, 0x6D3ED },
	{ 0xF0A3A3A9, 0x5BFF8 },
	{ 0xF0A3A3AB, 0xFC2CE },
	{ 0xF0A3A3AC, 0x6D8DA },
	{ 0xF0A3A3AF, 0x6D3EC },
	{ 0xF0A3A3B0, 0x6D3E5 },
	{ 0xF0A3A3B1, 0xFC2CD },
	{ 0xF0A3A3B2, 0x5C6DC },
	{ 0xF0A3A3B3, 0x4C4AB },
	{ 0xF0A3A3B4, 0x5C6DE },
	{ 0xF0A3A3B5, 0x6DDEF },
	{ 0xF0A3A3B6, 0x6DDEE },
	{ 0xF0A3A3B7, 0x4C4AC },
	{ 0xF0A3A3B8, 0x5C6DD },
	{ 0xF0A3A3B9, 0x4C4A9 },
	{ 0xF0A3A3BA, 0x6DDF5 },
	{ 0xF0A3A3BB, 0x6DDF0 },
	{ 0xF0A3A3BC, 0x5C6DA },
	{ 0xF0A3A3BD, 0x6DDF6 },
	{ 0xF0A3A3BE, 0x6DDF4 },
	{ 0xF0A3A3BF, 0x5C6DB },
	{ 0xF0A3A480, 0x6DDF2 },
	{ 0xF0A3A481, 0x6DDF1 },
	{ 0xF0A3A482, 0x6DDF3 },
	{ 0xF0A3A483, 0x6D3EF },
	{ 0xF0A3A484, 0xFC8F6 },
	{ 0xF0A3A485, 0xFC8F8 },
	{ 0xF0A3A487, 0x5C6D9 },
	{ 0xF0A3A488, 0x5CDEE },
	{ 0xF0A3A489, 0x7A3FD },
	{ 0xF0A3A48A, 0x5CDF0 },
	{ 0xF0A3A48B, 0x5CDF1 },
	{ 0xF0A3A48C, 0x4CACD },
	{ 0xF0A3A48D, 0x7A3F9 },
	{ 0xF0A3A48E, 0x7A3F7 },
	{ 0xF0A3A48F, 0x7A3FE },
	{ 0xF0A3A490, 0x7A3F6 },
	{ 0xF0A3A491, 0x7A3FA },
	{ 0xF0A3A492, 0x7A3FB },
	{ 0xF0A3A494, 0x5CDEF },
	{ 0xF0A3A495, 0xFCFD4 },
	{ 0xF0A3A497, 0x7A3FC },
	{ 0xF0A3A498, 0x5D4FE },
	{ 0xF0A3A499, 0x7AEF6 },
	{ 0xF0A3A49A, 0x4D0E8 },
	{ 0xF0A3A49C, 0x7AEF5 },
	{ 0xF0A3A49D, 0xFD5BA },
	{ 0xF0A3A49E, 0xFD5BB },
	{ 0xF0A3A4A0, 0x7B8DE },
	{ 0xF0A3A4A1, 0x7B8E0 },
	{ 0xF0A3A4A2, 0x5DBF1 },
	{ 0xF0A3A4A3, 0x7B8DF },
	{ 0xF0A3A4A4, 0xFDAD5 },
	{ 0xF0A3A4A5, 0x7B8DD },
	{ 0xF0A3A4A9, 0x5E2AC },
	{ 0xF0A3A4AC, 0x5E8B2 },
	{ 0xF0A3A4AD, 0x5E8B1 },
	{ 0xF0A3A4AE, 0xFE2E2 },
	{ 0xF0A3A4B1, 0x5F0B6 },
	{ 0xF0A3A4B2, 0x7CEA3 },
	{ 0xF0A3A4B4, 0x5F0B5 },
	{ 0xF0A3A4B5, 0x5F0B4 },
	{ 0xF0A3A4B6, 0x4E8F0 },
	{ 0xF0A3A4B7, 0x5F0B3 },
	{ 0xF0A3A4B9, 0x5F3D0 },
	{ 0xF0A3A4BA, 0x7D8A9 },
	{ 0xF0A3A4BB, 0x7D8A7 },
	{ 0xF0A3A4BC, 0x7D8A8 },
	{ 0xF0A3A4BE, 0x5F7E3 },
	{ 0xF0A3A4BF, 0x7E0F5 },
	{ 0xF0A3A580, 0x4ECF0 },
	{ 0xF0A3A581, 0x4EDD6 },
	{ 0xF0A3A582, 0x5A1B2 },
	{ 0xF0A3A583, 0x5A1F0 },
	{ 0xF0A3A584, 0x6A3AE },
	{ 0xF0A3A585, 0x6A5A6 },
	{ 0xF0A3A587, 0x5A4CA },
	{ 0xF0A3A588, 0x6A8B4 },
	{ 0xF0A3A589, 0x6ACB1 },
	{ 0xF0A3A58A, 0x5A4C9 },
	{ 0xF0A3A58B, 0x5A4CB },
	{ 0xF0A3A58C, 0x6A8B3 },
	{ 0xF0A3A58D, 0x6ACBC },
	{ 0xF0A3A58E, 0x6ACB4 },
	{ 0xF0A3A58F, 0x6ACBB },
	{ 0xF0A3A590, 0x6ACBA },
	{ 0xF0A3A591, 0x6ACB6 },
	{ 0xF0A3A592, 0x6ACB3 },
	{ 0xF0A3A593, 0x6ACB8 },
	{ 0xF0A3A594, 0x6ACB2 },
	{ 0xF0A3A595, 0x6ACB7 },
	{ 0xF0A3A596, 0x5A6DE },
	{ 0xF0A3A597, 0x6ACB9 },
	{ 0xF0A3A598, 0x6ACB5 },
	{ 0xF0A3A599, 0x5A6DF },
	{ 0xF0A3A59B, 0xFA7D7 },
	{ 0xF0A3A59C, 0xFA7D8 },
	{ 0xF0A3A59D, 0xFA7D9 },
	{ 0xF0A3A5A0, 0x4A6F2 },
	{ 0xF0A3A5A2, 0x4A9F6 },
	{ 0xF0A3A5A3, 0x5A9E3 },
	{ 0xF0A3A5A5, 0x5A8B5 },
	{ 0xF0A3A5A6, 0x6B8D9 },
	{ 0xF0A3A5A7, 0x6B8DC },
	{ 0xF0A3A5A8, 0x5AEB5 },
	{ 0xF0A3A5A9, 0x6B8DA },
	{ 0xF0A3A5AA, 0x6B8DE },
	{ 0xF0A3A5AB, 0x6B8DD },
	{ 0xF0A3A5AD, 0x6B8DB },
	{ 0xF0A3A5B2, 0x6B7C8 },
	{ 0xF0A3A5B3, 0x5B3A6 },
	{ 0xF0A3A5B4, 0x6C0F0 },
	{ 0xF0A3A5B5, 0xFB5EF },
	{ 0xF0A3A5B8, 0x6C0EF },
	{ 0xF0A3A5B9, 0x4B8C0 },
	{ 0xF0A3A5BA, 0x4B8BE },
	{ 0xF0A3A5BB, 0x5B9CA },
	{ 0xF0A3A5BC, 0x5B9CB },
	{ 0xF0A3A5BD, 0x6CAC3 },
	{ 0xF0A3A5BE, 0x4B8C1 },
	{ 0xF0A3A5BF, 0x6CAC2 },
	{ 0xF0A3A681, 0x6CAC4 },
	{ 0xF0A3A682, 0x6CAC0 },
	{ 0xF0A3A683, 0x6CAC5 },
	{ 0xF0A3A684, 0x6CAC6 },
	{ 0xF0A3A685, 0x6CAC1 },
	{ 0xF0A3A687, 0x5BFFC },
	{ 0xF0A3A688, 0x6D3F0 },
	{ 0xF0A3A689, 0x5BFFB },
	{ 0xF0A3A68A, 0xFC2CF },
	{ 0xF0A3A68B, 0x6DAE1 },
	{ 0xF0A3A694, 0x7A4A2 },
	{ 0xF0A3A695, 0x7A4A5 },
	{ 0xF0A3A696, 0x7A4A3 },
	{ 0xF0A3A697, 0x7A4A6 },
	{ 0xF0A3A698, 0x7A4A1 },
	{ 0xF0A3A699, 0x7A4A4 },
	{ 0xF0A3A69A, 0xFCFD5 },
	{ 0xF0A3A69C, 0x7AEFA },
	{ 0xF0A3A69D, 0x7AEF9 },
	{ 0xF0A3A69E, 0x7AEF7 },
	{ 0xF0A3A69F, 0x7AEF8 },
	{ 0xF0A3A6A1, 0x7B8E1 },
	{ 0xF0A3A6A2, 0x4D6D0 },
	{ 0xF0A3A6A4, 0xFDAD6 },
	{ 0xF0A3A6A5, 0xFDAD7 },
	{ 0xF0A3A6A6, 0x5E2AD },
	{ 0xF0A3A6A7, 0x5E2AE },
	{ 0xF0A3A6A8, 0x7C0AE },
	{ 0xF0A3A6AF, 0x5F3D1 },
	{ 0xF0A3A6B1, 0x7DBE2 },
	{ 0xF0A3A6B2, 0x7DBE3 },
	{ 0xF0A3A6B5, 0x5A1F1 },
	{ 0xF0A3A6B6, 0x5A1C9 },
	{ 0xF0A3A6B7, 0x5A2F6 },
	{ 0xF0A3A6B8, 0x6A8B5 },
	{ 0xF0A3A6B9, 0x4A2FD },
	{ 0xF0A3A6BA, 0x6A5A7 },
	{ 0xF0A3A6BB, 0x5A4CC },
	{ 0xF0A3A6BC, 0x4A4CD },
	{ 0xF0A3A6BD, 0x6A5A8 },
	{ 0xF0A3A6BF, 0x6A8B6 },
	{ 0xF0A3A780, 0x6A8BB },
	{ 0xF0A3A781, 0x6A8B7 },
	{ 0xF0A3A782, 0x4A4CC },
	{ 0xF0A3A783, 0x6A8BC },
	{ 0xF0A3A784, 0x5A4CD },
	{ 0xF0A3A785, 0x6A8B9 },
	{ 0xF0A3A786, 0x6A8B8 },
	{ 0xF0A3A787, 0x6A8BA },
	{ 0xF0A3A789, 0x6ACBF },
	{ 0xF0A3A78A, 0x5A6E0 },
	{ 0xF0A3A78B, 0x5A6E6 },
	{ 0xF0A3A78C, 0x5A6E1 },
	{ 0xF0A3A78D, 0x5A6E4 },
	{ 0xF0A3A78E, 0x4A6F3 },
	{ 0xF0A3A78F, 0x4A6F4 },
	{ 0xF0A3A790, 0x5A6E3 },
	{ 0xF0A3A791, 0x4A6F7 },
	{ 0xF0A3A792, 0x6ACBD },
	{ 0xF0A3A793, 0x6ACBE },
	{ 0xF0A3A794, 0x6ACC0 },
	{ 0xF0A3A795, 0x6B1FD },
	{ 0xF0A3A796, 0x5A6E5 },
	{ 0xF0A3A79D, 0x5A9E8 },
	{ 0xF0A3A79E, 0x4A9F8 },
	{ 0xF0A3A79F, 0x4A9F9 },
	{ 0xF0A3A7A0, 0x6B2A6 },
	{ 0xF0A3A7A1, 0x4A9F7 },
	{ 0xF0A3A7A2, 0x6B1FE },
	{ 0xF0A3A7A3, 0x5A9E4 },
	{ 0xF0A3A7A4, 0x5A9E5 },
	{ 0xF0A3A7A5, 0x5A9EB },
	{ 0xF0A3A7A6, 0x5A9E6 },
	{ 0xF0A3A7A7, 0x5A9E7 },
	{ 0xF0A3A7A8, 0x6B2A5 },
	{ 0xF0A3A7A9, 0x4A9FA },
	{ 0xF0A3A7AA, 0x6B2A2 },
	{ 0xF0A3A7AB, 0x6B2A3 },
	{ 0xF0A3A7AC, 0x5A9EA },
	{ 0xF0A3A7AD, 0x6B2A4 },
	{ 0xF0A3A7AE, 0x6B8DF },
	{ 0xF0A3A7AF, 0xFABD0 },
	{ 0xF0A3A7B0, 0x6B2A1 },
	{ 0xF0A3A7B1, 0x5A9EC },
	{ 0xF0A3A7B2, 0x5AEB6 },
	{ 0xF0A3A7B3, 0x4ADE3 },
	{ 0xF0A3A7B4, 0x6B8E2 },
	{ 0xF0A3A7B5, 0x5AEBB },
	{ 0xF0A3A7B6, 0x6B8E5 },
	{ 0xF0A3A7B7, 0x5AEBC },
	{ 0xF0A3A7B8, 0x5AEB8 },
	{ 0xF0A3A7B9, 0x5AEB9 },
	{ 0xF0A3A7BB, 0x6B8E3 },
	{ 0xF0A3A7BC, 0x6B8E6 },
	{ 0xF0A3A7BD, 0x5AEBD },
	{ 0xF0A3A7BE, 0x5AEB7 },
	{ 0xF0A3A7BF, 0x5AEBA },
	{ 0xF0A3A880, 0x5AEBE },
	{ 0xF0A3A881, 0x6B8E0 },
	{ 0xF0A3A883, 0x6B8E1 },
	{ 0xF0A3A885, 0x5B3AB },
	{ 0xF0A3A886, 0x6C0F4 },
	{ 0xF0A3A887, 0x5B3AA },
	{ 0xF0A3A888, 0x6C0F3 },
	{ 0xF0A3A889, 0x5B3A7 },
	{ 0xF0A3A88A, 0x5B3A8 },
	{ 0xF0A3A88B, 0x5B3A9 },
	{ 0xF0A3A88C, 0x6C0F1 },
	{ 0xF0A3A88D, 0x4B2CB },
	{ 0xF0A3A88E, 0x5B3AC },
	{ 0xF0A3A88F, 0x6CAC9 },
	{ 0xF0A3A890, 0x6C0F5 },
	{ 0xF0A3A891, 0x6C0F2 },
	{ 0xF0A3A892, 0xFB5F1 },
	{ 0xF0A3A896, 0x6D3F2 },
	{ 0xF0A3A897, 0x6CACA },
	{ 0xF0A3A898, 0x5B9D3 },
	{ 0xF0A3A899, 0x4B8C8 },
	{ 0xF0A3A89A, 0x6CACB },
	{ 0xF0A3A89B, 0x4B8C3 },
	{ 0xF0A3A89C, 0x5B9CE },
	{ 0xF0A3A89D, 0x5B9CD },
	{ 0xF0A3A89E, 0x5B9CF },
	{ 0xF0A3A89F, 0x4B8C7 },
	{ 0xF0A3A8A0, 0x5B9D2 },
	{ 0xF0A3A8A1, 0x5B9D4 },
	{ 0xF0A3A8A2, 0x5B9D0 },
	{ 0xF0A3A8A3, 0x5B9CC },
	{ 0xF0A3A8A4, 0x5B9D1 },
	{ 0xF0A3A8A5, 0x6CACC },
	{ 0xF0A3A8A6, 0x6D3F1 },
	{ 0xF0A3A8A8, 0x6CAC8 },
	{ 0xF0A3A8A9, 0xFBCB2 },
	{ 0xF0A3A8AF, 0x6D3F4 },
	{ 0xF0A3A8B1, 0x6D3F9 },
	{ 0xF0A3A8B2, 0x5BFFD },
	{ 0xF0A3A8B3, 0x5BFFE },
	{ 0xF0A3A8B4, 0x6D3F6 },
	{ 0xF0A3A8B5, 0x6D3F8 },
	{ 0xF0A3A8B6, 0x4BEA5 },
	{ 0xF0A3A8B7, 0x6DDF8 },
	{ 0xF0A3A8B8, 0x6D3FA },
	{ 0xF0A3A8B9, 0x6D3F5 },
	{ 0xF0A3A8BB, 0x6D3F3 },
	{ 0xF0A3A8BD, 0xFC2D0 },
	{ 0xF0A3A983, 0xFB5F0 },
	{ 0xF0A3A984, 0x4C4B4 },
	{ 0xF0A3A985, 0x4C4AE },
	{ 0xF0A3A986, 0x6DDFB },
	{ 0xF0A3A987, 0x6DDFC },
	{ 0xF0A3A988, 0x4C4AF },
	{ 0xF0A3A989, 0x6DDF9 },
	{ 0xF0A3A98B, 0x6DDFA },
	{ 0xF0A3A98C, 0x6DDAD },
	{ 0xF0A3A98D, 0x7A4A9 },
	{ 0xF0A3A98E, 0x4CAD1 },
	{ 0xF0A3A98F, 0x5CDF2 },
	{ 0xF0A3A990, 0x7A4A7 },
	{ 0xF0A3A991, 0x5CDF5 },
	{ 0xF0A3A992, 0x7A4A8 },
	{ 0xF0A3A993, 0x7A4AB },
	{ 0xF0A3A994, 0x5CDF4 },
	{ 0xF0A3A995, 0x4D0E9 },
	{ 0xF0A3A996, 0x7A4AC },
	{ 0xF0A3A997, 0x7A4AA },
	{ 0xF0A3A998, 0xFCFD6 },
	{ 0xF0A3A999, 0x5CDF3 },
	{ 0xF0A3A99D, 0x7AEFB },
	{ 0xF0A3A99E, 0x7AEFC },
	{ 0xF0A3A99F, 0x5D5A1 },
	{ 0xF0A3A9A0, 0x4D0EC },
	{ 0xF0A3A9A1, 0x5D5A3 },
	{ 0xF0A3A9A2, 0x5D5A2 },
	{ 0xF0A3A9A3, 0x7AEFE },
	{ 0xF0A3A9A4, 0xFD5BC },
	{ 0xF0A3A9A5, 0xFD5BD },
	{ 0xF0A3A9A8, 0x7B8E4 },
	{ 0xF0A3A9A9, 0x7B8E2 },
	{ 0xF0A3A9AA, 0x5DBF3 },
	{ 0xF0A3A9AB, 0x7B8E5 },
	{ 0xF0A3A9AC, 0x7B8E3 },
	{ 0xF0A3A9AD, 0x5DBF4 },
	{ 0xF0A3A9AF, 0x5E2B0 },
	{ 0xF0A3A9B0, 0x5E2AF },
	{ 0xF0A3A9B1, 0x4DBCD },
	{ 0xF0A3A9B2, 0x7C0B0 },
	{ 0xF0A3A9B3, 0x7AEFD },
	{ 0xF0A3A9B4, 0x5DBF5 },
	{ 0xF0A3A9B6, 0x7C0AF },
	{ 0xF0A3A9B7, 0x5E8B3 },
	{ 0xF0A3A9BA, 0x5F0B7 },
	{ 0xF0A3A9BB, 0x5F0B8 },
	{ 0xF0A3A9BC, 0x7D3CF },
	{ 0xF0A3A9BE, 0x7D8AA },
	{ 0xF0A3A9BF, 0x5F5FA },
	{ 0xF0A3AA80, 0x5F5F9 },
	{ 0xF0A3AA82, 0x5A6E8 },
	{ 0xF0A3AA83, 0x5A6E7 },
	{ 0xF0A3AA85, 0x6B2A7 },
	{ 0xF0A3AA86, 0x6B2A8 },
	{ 0xF0A3AA88, 0x5AEBF },
	{ 0xF0A3AA8B, 0x4B2CC },
	{ 0xF0A3AA8C, 0x4B2CD },
	{ 0xF0A3AA8D, 0x6C0F8 },
	{ 0xF0A3AA8E, 0x6C0F9 },
	{ 0xF0A3AA8F, 0x6C0F6 },
	{ 0xF0A3AA90, 0x6C0F7 },
	{ 0xF0A3AA91, 0xFB5F3 },
	{ 0xF0A3AA92, 0xFB5F5 },
	{ 0xF0A3AA93, 0xFB5F6 },
	{ 0xF0A3AA94, 0xFB5F7 },
	{ 0xF0A3AA95, 0x6C0FB },
	{ 0xF0A3AA96, 0x6C0FA },
	{ 0xF0A3AA97, 0x5B3AD },
	{ 0xF0A3AA99, 0x6CACF },
	{ 0xF0A3AA9B, 0x6CACE },
	{ 0xF0A3AA9C, 0xFBCB3 },
	{ 0xF0A3AA9F, 0xFB5F2 },
	{ 0xF0A3AAA0, 0x6D4A1 },
	{ 0xF0A3AAA1, 0x6D4A2 },
	{ 0xF0A3AAA3, 0x6D3FD },
	{ 0xF0A3AAA4, 0x6D3FE },
	{ 0xF0A3AAA5, 0x6D4A4 },
	{ 0xF0A3AAA6, 0xFC2D1 },
	{ 0xF0A3AAA7, 0xFC2D2 },
	{ 0xF0A3AAA9, 0x6D4A3 },
	{ 0xF0A3AAAA, 0x6D3FC },
	{ 0xF0A3AAAC, 0x5C0A1 },
	{ 0xF0A3AAAD, 0x5C0FB },
	{ 0xF0A3AAAE, 0x5C6E1 },
	{ 0xF0A3AAAF, 0x4C4B6 },
	{ 0xF0A3AAB0, 0x6DEA1 },
	{ 0xF0A3AAB1, 0x4C4B7 },
	{ 0xF0A3AAB2, 0x6DDFE },
	{ 0xF0A3AAB3, 0x6DDFD },
	{ 0xF0A3AAB5, 0xFC8FA },
	{ 0xF0A3AAB6, 0x5CDF6 },
	{ 0xF0A3AAB7, 0x6DEA2 },
	{ 0xF0A3AAB8, 0x7A4AD },
	{ 0xF0A3AAB9, 0x4CAD2 },
	{ 0xF0A3AABB, 0x7AFA5 },
	{ 0xF0A3AABC, 0x7AFA3 },
	{ 0xF0A3AABD, 0x7AFA6 },
	{ 0xF0A3AABE, 0x7AFA1 },
	{ 0xF0A3AABF, 0x7AFA4 },
	{ 0xF0A3AB80, 0x5D5A4 },
	{ 0xF0A3AB81, 0x7AFA2 },
	{ 0xF0A3AB85, 0xFD5BE },
	{ 0xF0A3AB86, 0xFD5BF },
	{ 0xF0A3AB87, 0xFD5C0 },
	{ 0xF0A3AB8C, 0x7B8E6 },
	{ 0xF0A3AB8D, 0x7B8E7 },
	{ 0xF0A3AB90, 0x4DBCE },
	{ 0xF0A3AB91, 0x7C0B3 },
	{ 0xF0A3AB92, 0x5E2B2 },
	{ 0xF0A3AB93, 0x5E2B1 },
	{ 0xF0A3AB96, 0x7C0B1 },
	{ 0xF0A3AB98, 0x7C0B2 },
	{ 0xF0A3AB99, 0x4DFF8 },
	{ 0xF0A3AB9A, 0x7C7CC },
	{ 0xF0A3AB9E, 0x7CEA5 },
	{ 0xF0A3AB9F, 0x7C7CD },
	{ 0xF0A3ABA1, 0x7D3D0 },
	{ 0xF0A3ABA2, 0x4EACD },
	{ 0xF0A3ABA3, 0x5F5FB },
	{ 0xF0A3ABA4, 0x7DBE4 },
	{ 0xF0A3ABA5, 0x5F3D2 },
	{ 0xF0A3ABA6, 0x7DEF3 },
	{ 0xF0A3ABA7, 0x5F7E5 },
	{ 0xF0A3ABA8, 0x5F7E4 },
	{ 0xF0A3ABA9, 0x7E0F6 },
	{ 0xF0A3ABAB, 0x7E3D6 },
	{ 0xF0A3ABAC, 0x5A1F2 },
	{ 0xF0A3ABAD, 0x6A8BD },
	{ 0xF0A3ABAF, 0x6ACC1 },
	{ 0xF0A3ABB0, 0x6B2A9 },
	{ 0xF0A3ABB4, 0x6B8E7 },
	{ 0xF0A3ABB8, 0xFBCB4 },
	{ 0xF0A3ABB9, 0x5C0A2 },
	{ 0xF0A3ABBA, 0x4CAD3 },
	{ 0xF0A3ABBC, 0xFCFD7 },
	{ 0xF0A3ABBD, 0xFCFD8 },
	{ 0xF0A3ABBE, 0xFDAD9 },
	{ 0xF0A3ABBF, 0xFD5C1 },
	{ 0xF0A3AC80, 0xFE2E3 },
	{ 0xF0A3AC81, 0xFEADA },
	{ 0xF0A3AC82, 0x5A4CF },
	{ 0xF0A3AC83, 0x6A8BE },
	{ 0xF0A3AC84, 0x6ACC5 },
	{ 0xF0A3AC85, 0x6ACC4 },
	{ 0xF0A3AC86, 0x5A6E9 },
	{ 0xF0A3AC88, 0x6B8E8 },
	{ 0xF0A3AC89, 0x6B8EA },
	{ 0xF0A3AC8A, 0x6B8E9 },
	{ 0xF0A3AC8B, 0x6C0FC },
	{ 0xF0A3AC8C, 0x6C0FD },
	{ 0xF0A3AC8D, 0x5C0A3 },
	{ 0xF0A3AC8E, 0x4BEA6 },
	{ 0xF0A3AC8F, 0x5C6E2 },
	{ 0xF0A3AC90, 0x5C6E3 },
	{ 0xF0A3AC91, 0x6DEA3 },
	{ 0xF0A3AC92, 0x7A4AE },
	{ 0xF0A3AC93, 0x7AFA7 },
	{ 0xF0A3AC94, 0x7AFA8 },
	{ 0xF0A3AC95, 0x5D5A5 },
	{ 0xF0A3AC96, 0x7C7CE },
	{ 0xF0A3AC97, 0x5ECC3 },
	{ 0xF0A3AC9A, 0x5F9B0 },
	{ 0xF0A3AC9B, 0x5A1CA },
	{ 0xF0A3AC9C, 0x4A2FE },
	{ 0xF0A3AC9E, 0xFA2DA },
	{ 0xF0A3AC9F, 0xFA2DB },
	{ 0xF0A3ACA1, 0x6A8C0 },
	{ 0xF0A3ACA2, 0x6A8BF },
	{ 0xF0A3ACA3, 0x4A4CE },
	{ 0xF0A3ACA4, 0xFA4D5 },
	{ 0xF0A3ACA5, 0xFA4D6 },
	{ 0xF0A3ACA6, 0xFA4D7 },
	{ 0xF0A3ACA7, 0xFA4D9 },
	{ 0xF0A3ACA8, 0xFA4DA },
	{ 0xF0A3ACA9, 0x5A6ED },
	{ 0xF0A3ACAA, 0x5A6EA },
	{ 0xF0A3ACAB, 0x5A6EC },
	{ 0xF0A3ACAC, 0x5A6EB },
	{ 0xF0A3ACAD, 0x6ACC7 },
	{ 0xF0A3ACAE, 0x6ACC6 },
	{ 0xF0A3ACAF, 0xFA7DA },
	{ 0xF0A3ACB0, 0xFA7DC },
	{ 0xF0A3ACB1, 0xFA7DD },
	{ 0xF0A3ACB2, 0xFA7DE },
	{ 0xF0A3ACB3, 0xFA7DF },
	{ 0xF0A3ACB5, 0x5A6C3 },
	{ 0xF0A3ACB8, 0x6B2AC },
	{ 0xF0A3ACB9, 0x5A9EE },
	{ 0xF0A3ACBA, 0x5A9EF },
	{ 0xF0A3ACBB, 0x5A9ED },
	{ 0xF0A3ACBC, 0x5A9F0 },
	{ 0xF0A3ACBD, 0x5A9F1 },
	{ 0xF0A3ACBE, 0x6B2AD },
	{ 0xF0A3ACBF, 0x5A9F3 },
	{ 0xF0A3AD80, 0x6B2AF },
	{ 0xF0A3AD81, 0x6B8ED },
	{ 0xF0A3AD82, 0x6B2AE },
	{ 0xF0A3AD84, 0x5A9F4 },
	{ 0xF0A3AD85, 0x6B2AB },
	{ 0xF0A3AD87, 0x5A9F2 },
	{ 0xF0A3AD89, 0xFABD1 },
	{ 0xF0A3AD8A, 0xFABD2 },
	{ 0xF0A3AD8B, 0xFABD3 },
	{ 0xF0A3AD8C, 0xFABD4 },
	{ 0xF0A3AD8D, 0xFABD5 },
	{ 0xF0A3AD8E, 0xFABD6 },
	{ 0xF0A3AD8F, 0xFABD7 },
	{ 0xF0A3AD90, 0xFABD8 },
	{ 0xF0A3AD91, 0xFABD9 },
	{ 0xF0A3AD92, 0xFABDA },
	{ 0xF0A3AD93, 0xFABDB },
	{ 0xF0A3AD94, 0xFABDC },
	{ 0xF0A3AD95, 0xFABDE },
	{ 0xF0A3AD9A, 0xFABDD },
	{ 0xF0A3AD9C, 0x6B8EF },
	{ 0xF0A3AD9D, 0x5AEC1 },
	{ 0xF0A3AD9E, 0x6B8EE },
	{ 0xF0A3AD9F, 0x4ADE9 },
	{ 0xF0A3ADA0, 0x5AEC3 },
	{ 0xF0A3ADA1, 0x4ADE8 },
	{ 0xF0A3ADA2, 0x6B8EC },
	{ 0xF0A3ADA3, 0x5AEC2 },
	{ 0xF0A3ADA5, 0xFB0B2 },
	{ 0xF0A3ADA6, 0xFB0B3 },
	{ 0xF0A3ADA7, 0xFB0B4 },
	{ 0xF0A3ADA8, 0xFB0B5 },
	{ 0xF0A3ADA9, 0xFB0B6 },
	{ 0xF0A3ADAA, 0xFB0B7 },
	{ 0xF0A3ADAB, 0xFB0B8 },
	{ 0xF0A3ADAC, 0xFB0B9 },
	{ 0xF0A3ADAD, 0x6B8EB },
	{ 0xF0A3ADAE, 0x5AEC0 },
	{ 0xF0A3ADB1, 0x6C1A6 },
	{ 0xF0A3ADB2, 0x4B2D6 },
	{ 0xF0A3ADB3, 0x6C1A1 },
	{ 0xF0A3ADB4, 0x5B3B1 },
	{ 0xF0A3ADB5, 0x6C1A2 },
	{ 0xF0A3ADB6, 0x6C1A3 },
	{ 0xF0A3ADB7, 0x5B3AE },
	{ 0xF0A3ADB8, 0x6C1A5 },
	{ 0xF0A3ADB9, 0x5B3B2 },
	{ 0xF0A3ADBA, 0x5B3B0 },
	{ 0xF0A3ADBB, 0x5B3AF },
	{ 0xF0A3ADBC, 0x6C0FE },
	{ 0xF0A3ADBD, 0x6C1A4 },
	{ 0xF0A3ADBE, 0xFB5F8 },
	{ 0xF0A3ADBF, 0xFB5F9 },
	{ 0xF0A3AE80, 0xFB5FA },
	{ 0xF0A3AE81, 0xFB5FB },
	{ 0xF0A3AE82, 0xFB5FC },
	{ 0xF0A3AE88, 0x5B9D5 },
	{ 0xF0A3AE89, 0x4B8CD },
	{ 0xF0A3AE8A, 0x5B9D6 },
	{ 0xF0A3AE8B, 0x4B8D0 },
	{ 0xF0A3AE8C, 0x6CAD1 },
	{ 0xF0A3AE8D, 0x6CAD3 },
	{ 0xF0A3AE8E, 0x5B9D9 },
	{ 0xF0A3AE8F, 0x5B9D8 },
	{ 0xF0A3AE90, 0x5B9DA },
	{ 0xF0A3AE91, 0x6CAD6 },
	{ 0xF0A3AE92, 0x6CAD0 },
	{ 0xF0A3AE93, 0x6CAD5 },
	{ 0xF0A3AE94, 0x5B9D7 },
	{ 0xF0A3AE95, 0x6CAD2 },
	{ 0xF0A3AE97, 0xFBCBA },
	{ 0xF0A3AE98, 0xFBCB5 },
	{ 0xF0A3AE99, 0xFBCB7 },
	{ 0xF0A3AE9A, 0xFBCB8 },
	{ 0xF0A3AE9B, 0xFBCB9 },
	{ 0xF0A3AE9C, 0xFBCBB },
	{ 0xF0A3AE9D, 0xFBCBD },
	{ 0xF0A3AE9E, 0xFBCBF },
	{ 0xF0A3AE9F, 0xFBCC0 },
	{ 0xF0A3AEA3, 0x6CAD4 },
	{ 0xF0A3AEA4, 0xFBCB6 },
	{ 0xF0A3AEA7, 0x5B9DC },
	{ 0xF0A3AEA8, 0x6D4AE },
	{ 0xF0A3AEA9, 0x6D4AC },
	{ 0xF0A3AEAA, 0x4BEAB },
	{ 0xF0A3AEAB, 0x6D4A7 },
	{ 0xF0A3AEAC, 0x6D4AB },
	{ 0xF0A3AEAD, 0x4BEAA },
	{ 0xF0A3AEAE, 0x6D4A8 },
	{ 0xF0A3AEAF, 0x6D4A5 },
	{ 0xF0A3AEB0, 0x6D4A9 },
	{ 0xF0A3AEB1, 0x6D4A6 },
	{ 0xF0A3AEB2, 0x6D4AD },
	{ 0xF0A3AEB3, 0x6D4AA },
	{ 0xF0A3AEB4, 0x6D4AF },
	{ 0xF0A3AEB9, 0x5C0A4 },
	{ 0xF0A3AEBA, 0xFC2D3 },
	{ 0xF0A3AEBB, 0xFC2D5 },
	{ 0xF0A3AEBC, 0xFC2D6 },
	{ 0xF0A3AEBD, 0xFC2D7 },
	{ 0xF0A3AF82, 0x6D4B0 },
	{ 0xF0A3AF85, 0x6DEA9 },
	{ 0xF0A3AF86, 0x5C6E6 },
	{ 0xF0A3AF87, 0x5C6E5 },
	{ 0xF0A3AF88, 0x6DEAA },
	{ 0xF0A3AF89, 0x6DEAB },
	{ 0xF0A3AF8A, 0x6DEAD },
	{ 0xF0A3AF8B, 0x4C4BD },
	{ 0xF0A3AF8C, 0x6DEA4 },
	{ 0xF0A3AF8D, 0x4C4BE },
	{ 0xF0A3AF8E, 0x5C6E7 },
	{ 0xF0A3AF8F, 0x4C4BB },
	{ 0xF0A3AF91, 0x6DEAE },
	{ 0xF0A3AF92, 0x6DEAF },
	{ 0xF0A3AF93, 0x6DEA6 },
	{ 0xF0A3AF95, 0x6DEA7 },
	{ 0xF0A3AF96, 0xFC8FC },
	{ 0xF0A3AF97, 0xFC8FD },
	{ 0xF0A3AF98, 0xFC8FE },
	{ 0xF0A3AF99, 0xFC9A1 },
	{ 0xF0A3AF9B, 0x6DEA8 },
	{ 0xF0A3AF9C, 0x5C6E9 },
	{ 0xF0A3AF9D, 0x6DEB0 },
	{ 0xF0A3AF9F, 0x6DEA5 },
	{ 0xF0A3AFA2, 0x6DEAC },
	{ 0xF0A3AFA4, 0x4CAD6 },
	{ 0xF0A3AFA5, 0x7A4B3 },
	{ 0xF0A3AFA6, 0x7A4B7 },
	{ 0xF0A3AFA7, 0x7A4B5 },
	{ 0xF0A3AFA8, 0x4CAD5 },
	{ 0xF0A3AFA9, 0x4CAD4 },
	{ 0xF0A3AFAA, 0x5CDF9 },
	{ 0xF0A3AFAB, 0x7A4B4 },
	{ 0xF0A3AFAC, 0x5CDF7 },
	{ 0xF0A3AFAD, 0x5CDF8 },
	{ 0xF0A3AFAE, 0x7A4B1 },
	{ 0xF0A3AFAF, 0x7A4B2 },
	{ 0xF0A3AFB0, 0x7A4B0 },
	{ 0xF0A3AFB1, 0x7A4AF },
	{ 0xF0A3AFB2, 0x7A4B6 },
	{ 0xF0A3AFB7, 0x7A4B8 },
	{ 0xF0A3AFB8, 0x7AFA9 },
	{ 0xF0A3AFB9, 0x5D5A7 },
	{ 0xF0A3AFBA, 0x7AFAA },
	{ 0xF0A3AFBB, 0x4D0F0 },
	{ 0xF0A3AFBC, 0x5D5A6 },
	{ 0xF0A3AFBD, 0x4D0F3 },
	{ 0xF0A3AFBE, 0x7AFAC },
	{ 0xF0A3AFBF, 0xFD5C2 },
	{ 0xF0A3B080, 0xFD5C3 },
	{ 0xF0A3B081, 0xFD5C4 },
	{ 0xF0A3B082, 0xFD5C5 },
	{ 0xF0A3B086, 0x7AFAB },
	{ 0xF0A3B089, 0x7A4B9 },
	{ 0xF0A3B08A, 0x7B8EA },
	{ 0xF0A3B08B, 0x4D6D5 },
	{ 0xF0A3B08C, 0x4D6D4 },
	{ 0xF0A3B08D, 0x7B8E9 },
	{ 0xF0A3B08E, 0x5DBF6 },
	{ 0xF0A3B090, 0x7B8E8 },
	{ 0xF0A3B091, 0xFDADA },
	{ 0xF0A3B092, 0xFDADB },
	{ 0xF0A3B093, 0xFDADC },
	{ 0xF0A3B094, 0x7B8EC },
	{ 0xF0A3B096, 0x7B8EB },
	{ 0xF0A3B09A, 0x5E2B5 },
	{ 0xF0A3B09B, 0x5E2B4 },
	{ 0xF0A3B09C, 0x5E2B6 },
	{ 0xF0A3B09E, 0x7C0B7 },
	{ 0xF0A3B09F, 0x7C7CF },
	{ 0xF0A3B0A0, 0x7C0B5 },
	{ 0xF0A3B0A1, 0x5E2B7 },
	{ 0xF0A3B0A2, 0x7C0B4 },
	{ 0xF0A3B0A3, 0x7C0B6 },
	{ 0xF0A3B0A4, 0xFDFB1 },
	{ 0xF0A3B0A8, 0x5E2B3 },
	{ 0xF0A3B0AA, 0xFDFB2 },
	{ 0xF0A3B0AB, 0x7C7D2 },
	{ 0xF0A3B0AC, 0x5E8B4 },
	{ 0xF0A3B0AD, 0x7C7D0 },
	{ 0xF0A3B0AE, 0x7C7D1 },
	{ 0xF0A3B0B1, 0xFE5C1 },
	{ 0xF0A3B0B2, 0x7CEA6 },
	{ 0xF0A3B0B6, 0x4E6C7 },
	{ 0xF0A3B0B7, 0x5F0B9 },
	{ 0xF0A3B0B8, 0x7D3D1 },
	{ 0xF0A3B0B9, 0xFE7E7 },
	{ 0xF0A3B0BB, 0x7D8AB },
	{ 0xF0A3B0BC, 0x5F3D3 },
	{ 0xF0A3B0BE, 0xFE9D2 },
	{ 0xF0A3B0BF, 0x5F5FC },
	{ 0xF0A3B180, 0x7DBE5 },
	{ 0xF0A3B184, 0x7E4CA },
	{ 0xF0A3B185, 0x6ACC8 },
	{ 0xF0A3B187, 0x6B2B0 },
	{ 0xF0A3B188, 0x5A9F5 },
	{ 0xF0A3B189, 0x5A9F6 },
	{ 0xF0A3B18A, 0x6B3CC },
	{ 0xF0A3B18B, 0x6C1A7 },
	{ 0xF0A3B18C, 0xFB5FD },
	{ 0xF0A3B18E, 0x6C1A8 },
	{ 0xF0A3B18F, 0x6D4B1 },
	{ 0xF0A3B190, 0x4C4C0 },
	{ 0xF0A3B191, 0x7AFAD },
	{ 0xF0A3B192, 0x7B8ED },
	{ 0xF0A3B193, 0x4DBD1 },
	{ 0xF0A3B194, 0xFDADD },
	{ 0xF0A3B195, 0x6A5AA },
	{ 0xF0A3B196, 0x6A5A9 },
	{ 0xF0A3B198, 0xFA4DC },
	{ 0xF0A3B199, 0x6ACCB },
	{ 0xF0A3B19A, 0x6ACCA },
	{ 0xF0A3B19B, 0x6ACC9 },
	{ 0xF0A3B19C, 0x6B2B1 },
	{ 0xF0A3B19E, 0x6B2B2 },
	{ 0xF0A3B19F, 0xFABDF },
	{ 0xF0A3B1A0, 0x5A9F7 },
	{ 0xF0A3B1A1, 0x5AEC4 },
	{ 0xF0A3B1A3, 0xFB5FE },
	{ 0xF0A3B1A4, 0x5B9DD },
	{ 0xF0A3B1A5, 0xFBCC1 },
	{ 0xF0A3B1A6, 0x6D4B2 },
	{ 0xF0A3B1AA, 0x7A4BB },
	{ 0xF0A3B1AB, 0x7A4BA },
	{ 0xF0A3B1AE, 0x7C0B8 },
	{ 0xF0A3B1AF, 0x7D3D2 },
	{ 0xF0A3B1B2, 0xFA1E7 },
	{ 0xF0A3B1B4, 0x6A2A4 },
	{ 0xF0A3B1B5, 0x6A5AB },
	{ 0xF0A3B1B6, 0x5A1F3 },
	{ 0xF0A3B1B7, 0x6A5AC },
	{ 0xF0A3B1B8, 0xFA2DE },
	{ 0xF0A3B1B9, 0xFA4E9 },
	{ 0xF0A3B280, 0x4A3A3 },
	{ 0xF0A3B281, 0x6A5AD },
	{ 0xF0A3B282, 0x5A4D0 },
	{ 0xF0A3B283, 0x6A5AF },
	{ 0xF0A3B284, 0x6A5B1 },
	{ 0xF0A3B286, 0x3A4A4 },
	{ 0xF0A3B287, 0xFA2DC },
	{ 0xF0A3B288, 0xFA4DF },
	{ 0xF0A3B289, 0xFA4E0 },
	{ 0xF0A3B28B, 0x6A5B0 },
	{ 0xF0A3B28E, 0x6ACCD },
	{ 0xF0A3B28F, 0x5A4D2 },
	{ 0xF0A3B290, 0x6A8C2 },
	{ 0xF0A3B291, 0x5A4D1 },
	{ 0xF0A3B292, 0x5A4D3 },
	{ 0xF0A3B293, 0x4A4D0 },
	{ 0xF0A3B294, 0x6A8C6 },
	{ 0xF0A3B295, 0x6A8C7 },
	{ 0xF0A3B29D, 0x6ACCC },
	{ 0xF0A3B29E, 0x6A8C3 },
	{ 0xF0A3B29F, 0x6A8C1 },
	{ 0xF0A3B2A0, 0x6A8C5 },
	{ 0xF0A3B2A1, 0x6A8C8 },
	{ 0xF0A3B2A5, 0xFA4E1 },
	{ 0xF0A3B2A7, 0xFA4DE },
	{ 0xF0A3B2A8, 0xFA4E2 },
	{ 0xF0A3B2A9, 0xFA4E3 },
	{ 0xF0A3B2AA, 0xFA4E4 },
	{ 0xF0A3B2AB, 0xFA4E5 },
	{ 0xF0A3B2AC, 0xFA4E6 },
	{ 0xF0A3B2AD, 0xFA4E7 },
	{ 0xF0A3B2AE, 0xFA7E3 },
	{ 0xF0A3B2AF, 0xFA7E4 },
	{ 0xF0A3B2B0, 0xFA7E5 },
	{ 0xF0A3B2B2, 0x4A7A3 },
	{ 0xF0A3B2B3, 0x5A6EF },
	{ 0xF0A3B2B4, 0x6B2B3 },
	{ 0xF0A3B2B5, 0x5A6F2 },
	{ 0xF0A3B2B6, 0x5A6F3 },
	{ 0xF0A3B2B7, 0x4A7A1 },
	{ 0xF0A3B2B8, 0x6ACD7 },
	{ 0xF0A3B2B9, 0x4A7A5 },
	{ 0xF0A3B2BA, 0x6ACD0 },
	{ 0xF0A3B2BB, 0x4A7A4 },
	{ 0xF0A3B2BC, 0x6ACCE },
	{ 0xF0A3B2BD, 0x5A6EE },
	{ 0xF0A3B2BE, 0x5A6F0 },
	{ 0xF0A3B2BF, 0x6ACD8 },
	{ 0xF0A3B380, 0x5A6F1 },
	{ 0xF0A3B381, 0x6ACDA },
	{ 0xF0A3B382, 0x6B2B4 },
	{ 0xF0A3B384, 0x6ACD6 },
	{ 0xF0A3B385, 0x6ACDC },
	{ 0xF0A3B38A, 0x4A6FC },
	{ 0xF0A3B38B, 0x6ACD3 },
	{ 0xF0A3B38C, 0xFA7E0 },
	{ 0xF0A3B38D, 0xFA7E1 },
	{ 0xF0A3B38E, 0xFA7E2 },
	{ 0xF0A3B38F, 0xFA7E7 },
	{ 0xF0A3B390, 0xFA7E8 },
	{ 0xF0A3B391, 0xFA7E9 },
	{ 0xF0A3B392, 0xFA7EA },
	{ 0xF0A3B393, 0xFA7EB },
	{ 0xF0A3B394, 0xFA7ED },
	{ 0xF0A3B395, 0xFABE4 },
	{ 0xF0A3B396, 0xFABE7 },
	{ 0xF0A3B397, 0xFABEC },
	{ 0xF0A3B398, 0x6ACD2 },
	{ 0xF0A3B399, 0x6ACD4 },
	{ 0xF0A3B39A, 0x6ACD5 },
	{ 0xF0A3B39B, 0x6ACD9 },
	{ 0xF0A3B39D, 0x6ACCF },
	{ 0xF0A3B3A3, 0x5A9F8 },
	{ 0xF0A3B3A4, 0x4A9FC },
	{ 0xF0A3B3A5, 0x6B2B6 },
	{ 0xF0A3B3A6, 0x5AAA2 },
	{ 0xF0A3B3A7, 0x6B2BB },
	{ 0xF0A3B3A8, 0x6B2BE },
	{ 0xF0A3B3A9, 0x5A9F9 },
	{ 0xF0A3B3AA, 0x4AAA2 },
	{ 0xF0A3B3AB, 0x4ADF1 },
	{ 0xF0A3B3AC, 0x5AAA1 },
	{ 0xF0A3B3AD, 0x5A9FE },
	{ 0xF0A3B3AE, 0x6B2BA },
	{ 0xF0A3B3AF, 0x6B2C0 },
	{ 0xF0A3B3B0, 0x5A9FA },
	{ 0xF0A3B3B1, 0x6B2C1 },
	{ 0xF0A3B3B2, 0x5A9FD },
	{ 0xF0A3B3B3, 0x6B8F0 },
	{ 0xF0A3B3B4, 0x6B2BD },
	{ 0xF0A3B3B5, 0x6B2BC },
	{ 0xF0A3B3B6, 0x4AAA3 },
	{ 0xF0A3B3B7, 0x4A9FD },
	{ 0xF0A3B481, 0x6B2BF },
	{ 0xF0A3B482, 0xFABE0 },
	{ 0xF0A3B483, 0xFABE1 },
	{ 0xF0A3B484, 0xFABE2 },
	{ 0xF0A3B485, 0xFABE3 },
	{ 0xF0A3B486, 0xFABE5 },
	{ 0xF0A3B487, 0xFABE6 },
	{ 0xF0A3B488, 0xFABE8 },
	{ 0xF0A3B489, 0xFABE9 },
	{ 0xF0A3B48A, 0xFABEA },
	{ 0xF0A3B48B, 0xFABEB },
	{ 0xF0A3B48C, 0xFABED },
	{ 0xF0A3B48D, 0xFABEE },
	{ 0xF0A3B48E, 0xFB0BA },
	{ 0xF0A3B48F, 0xFB0BD },
	{ 0xF0A3B490, 0xFB0C4 },
	{ 0xF0A3B491, 0x6B2B8 },
	{ 0xF0A3B492, 0x4AAA4 },
	{ 0xF0A3B494, 0x6B2B5 },
	{ 0xF0A3B495, 0x6B2B7 },
	{ 0xF0A3B496, 0x5AAA3 },
	{ 0xF0A3B49D, 0xFB0D7 },
	{ 0xF0A3B49E, 0x4ADEE },
	{ 0xF0A3B49F, 0x5AEC9 },
	{ 0xF0A3B4A0, 0x6B9B0 },
	{ 0xF0A3B4A1, 0x6B9AE },
	{ 0xF0A3B4A2, 0x5AEC8 },
	{ 0xF0A3B4A3, 0x5AEC7 },
	{ 0xF0A3B4A4, 0x6B8FC },
	{ 0xF0A3B4A5, 0x5AECA },
	{ 0xF0A3B4A6, 0x6B8F1 },
	{ 0xF0A3B4A7, 0x6B8FB },
	{ 0xF0A3B4A8, 0x4ADED },
	{ 0xF0A3B4A9, 0x4ADEF },
	{ 0xF0A3B4AA, 0x6B9A5 },
	{ 0xF0A3B4AB, 0x6B8F6 },
	{ 0xF0A3B4AC, 0x6B9A6 },
	{ 0xF0A3B4AD, 0x6B9AA },
	{ 0xF0A3B4AE, 0x6B8F7 },
	{ 0xF0A3B4AF, 0x6B9A9 },
	{ 0xF0A3B4B0, 0x6B8FE },
	{ 0xF0A3B4B1, 0x6B9A8 },
	{ 0xF0A3B4B2, 0x6C1AA },
	{ 0xF0A3B4B3, 0x6C1A9 },
	{ 0xF0A3B4B4, 0x4B2E6 },
	{ 0xF0A3B4B5, 0x6B9A4 },
	{ 0xF0A3B4B6, 0x6B9AC },
	{ 0xF0A3B4B7, 0x5AEC5 },
	{ 0xF0A3B4B8, 0x6B9A3 },
	{ 0xF0A3B4B9, 0x6B8F3 },
	{ 0xF0A3B4BA, 0x6B9AB },
	{ 0xF0A3B4BB, 0x6B8F8 },
	{ 0xF0A3B4BC, 0x6B9AF },
	{ 0xF0A3B4BE, 0x6B9B2 },
	{ 0xF0A3B582, 0x6C1C6 },
	{ 0xF0A3B583, 0xFB0BB },
	{ 0xF0A3B584, 0xFB0BE },
	{ 0xF0A3B585, 0xFB0BF },
	{ 0xF0A3B586, 0xFB0C0 },
	{ 0xF0A3B587, 0xFB0C1 },
	{ 0xF0A3B588, 0xFB0C2 },
	{ 0xF0A3B589, 0xFB0C3 },
	{ 0xF0A3B58A, 0xFB0C5 },
	{ 0xF0A3B58B, 0xFB0C6 },
	{ 0xF0A3B58C, 0xFB0C7 },
	{ 0xF0A3B58D, 0xFB0C8 },
	{ 0xF0A3B58E, 0xFB0CA },
	{ 0xF0A3B58F, 0xFB0CB },
	{ 0xF0A3B590, 0xFB0CC },
	{ 0xF0A3B591, 0xFB0CD },
	{ 0xF0A3B592, 0xFB0CE },
	{ 0xF0A3B593, 0xFB0CF },
	{ 0xF0A3B594, 0xFB0D0 },
	{ 0xF0A3B595, 0xFB0D1 },
	{ 0xF0A3B596, 0xFB0D2 },
	{ 0xF0A3B597, 0xFB0D3 },
	{ 0xF0A3B598, 0xFB0D4 },
	{ 0xF0A3B599, 0xFB0D5 },
	{ 0xF0A3B59A, 0xFB0D6 },
	{ 0xF0A3B59B, 0xFB0D8 },
	{ 0xF0A3B59C, 0xFB0D9 },
	{ 0xF0A3B59D, 0xFB0DA },
	{ 0xF0A3B59E, 0x6B8F9 },
	{ 0xF0A3B5A2, 0x6B9A2 },
	{ 0xF0A3B5A4, 0x6B9B1 },
	{ 0xF0A3B5A6, 0x4ADF2 },
	{ 0xF0A3B5A8, 0x6B9A7 },
	{ 0xF0A3B5A9, 0x6B8FD },
	{ 0xF0A3B5AC, 0x6B8F5 },
	{ 0xF0A3B5B1, 0x5AEC6 },
	{ 0xF0A3B5B3, 0xFB6AD },
	{ 0xF0A3B5B7, 0x4B2DD },
	{ 0xF0A3B5B8, 0x5B3C0 },
	{ 0xF0A3B5B9, 0x4B2DB },
	{ 0xF0A3B5BA, 0x4B2EB },
	{ 0xF0A3B5BB, 0x6C1B4 },
	{ 0xF0A3B5BC, 0x6C1B8 },
	{ 0xF0A3B5BD, 0x6C1BC },
	{ 0xF0A3B5BE, 0x4B2EA },
	{ 0xF0A3B5BF, 0x6C1C3 },
	{ 0xF0A3B680, 0x4B2E1 },
	{ 0xF0A3B681, 0x6C1B6 },
	{ 0xF0A3B682, 0x4B2E5 },
	{ 0xF0A3B683, 0x6C1B5 },
	{ 0xF0A3B684, 0x6C1C5 },
	{ 0xF0A3B685, 0x4B2E9 },
	{ 0xF0A3B686, 0x5B3B3 },
	{ 0xF0A3B687, 0x6C1B1 },
	{ 0xF0A3B688, 0x4B2E0 },
	{ 0xF0A3B689, 0x4B2E7 },
	{ 0xF0A3B68A, 0x6CAE4 },
	{ 0xF0A3B68B, 0x5B3BF },
	{ 0xF0A3B68C, 0x6C1C2 },
	{ 0xF0A3B68D, 0x5B3BE },
	{ 0xF0A3B68E, 0x6C1BF },
	{ 0xF0A3B68F, 0x4B2D9 },
	{ 0xF0A3B690, 0x4B2DF },
	{ 0xF0A3B691, 0x6C1AC },
	{ 0xF0A3B692, 0x4A5AF },
	{ 0xF0A3B693, 0x6C1BB },
	{ 0xF0A3B694, 0x6C1B0 },
	{ 0xF0A3B695, 0x6CAE6 },
	{ 0xF0A3B696, 0x5B3B8 },
	{ 0xF0A3B698, 0x5B3C1 },
	{ 0xF0A3B699, 0x6CAD8 },
	{ 0xF0A3B69A, 0x6CAD9 },
	{ 0xF0A3B69B, 0x6C1BE },
	{ 0xF0A3B69C, 0x6C1C4 },
	{ 0xF0A3B69D, 0x5B3B6 },
	{ 0xF0A3B69E, 0x4B2E2 },
	{ 0xF0A3B69F, 0x6C1C0 },
	{ 0xF0A3B6A1, 0x5B3BB },
	{ 0xF0A3B6A2, 0x6C1AF },
	{ 0xF0A3B6A3, 0x6C1B2 },
	{ 0xF0A3B6A4, 0x5B3BA },
	{ 0xF0A3B6A5, 0x5B3B5 },
	{ 0xF0A3B6A6, 0x4B2EC },
	{ 0xF0A3B6B5, 0x4B2EE },
	{ 0xF0A3B6BE, 0x5B3B7 },
	{ 0xF0A3B6BF, 0x6C1BD },
	{ 0xF0A3B780, 0xFB6A1 },
	{ 0xF0A3B781, 0xFB6A2 },
	{ 0xF0A3B782, 0xFB6A3 },
	{ 0xF0A3B783, 0xFB6A5 },
	{ 0xF0A3B784, 0xFB6A6 },
	{ 0xF0A3B785, 0xFB6A7 },
	{ 0xF0A3B786, 0xFB6A8 },
	{ 0xF0A3B787, 0xFB6AA },
	{ 0xF0A3B788, 0xFB6AC },
	{ 0xF0A3B789, 0xFB6AE },
	{ 0xF0A3B78A, 0xFB6AF },
	{ 0xF0A3B78B, 0xFB6B0 },
	{ 0xF0A3B78C, 0xFB6B1 },
	{ 0xF0A3B78D, 0xFB6B2 },
	{ 0xF0A3B78E, 0xFB6B6 },
	{ 0xF0A3B78F, 0xFB6B7 },
	{ 0xF0A3B790, 0xFB6B8 },
	{ 0xF0A3B791, 0xFB6B9 },
	{ 0xF0A3B792, 0xFB6BA },
	{ 0xF0A3B793, 0xFB6BB },
	{ 0xF0A3B794, 0xFB6BC },
	{ 0xF0A3B795, 0xFB6BD },
	{ 0xF0A3B796, 0xFBCC2 },
	{ 0xF0A3B797, 0xFBCCB },
	{ 0xF0A3B798, 0xFBCCD },
	{ 0xF0A3B799, 0xFBCD7 },
	{ 0xF0A3B79A, 0xFC2DF },
	{ 0xF0A3B79B, 0x6CAD7 },
	{ 0xF0A3B79D, 0x6C1B3 },
	{ 0xF0A3B79F, 0x6C1B7 },
	{ 0xF0A3B7A1, 0x5B3B9 },
	{ 0xF0A3B7A2, 0x6C1BA },
	{ 0xF0A3B7A4, 0x6C1B9 },
	{ 0xF0A3B7A6, 0x6C1C7 },
	{ 0xF0A3B7A7, 0x6C1AD },
	{ 0xF0A3B7A9, 0x6C1AE },
	{ 0xF0A3B7B5, 0x5B3B4 },
	{ 0xF0A3B7B6, 0x5B3BC },
	{ 0xF0A3B7BB, 0x6B8FA },
	{ 0xF0A3B7BC, 0x6CAE2 },
	{ 0xF0A3B7BD, 0x6CAF0 },
	{ 0xF0A3B7BE, 0x4B8D4 },
	{ 0xF0A3B7BF, 0x5B9E3 },
	{ 0xF0A3B880, 0x4B8D5 },
	{ 0xF0A3B881, 0x6CADD },
	{ 0xF0A3B882, 0x6CADF },
	{ 0xF0A3B883, 0x5B9E7 },
	{ 0xF0A3B884, 0x5B9EA },
	{ 0xF0A3B885, 0x5B9E2 },
	{ 0xF0A3B886, 0x6D4C8 },
	{ 0xF0A3B887, 0x5B9EC },
	{ 0xF0A3B888, 0x6CADA },
	{ 0xF0A3B889, 0x4B8D3 },
	{ 0xF0A3B88A, 0x5B3C2 },
	{ 0xF0A3B88B, 0x4B8D8 },
	{ 0xF0A3B88C, 0x6CAEC },
	{ 0xF0A3B88D, 0x6CADC },
	{ 0xF0A3B88E, 0x5B9E8 },
	{ 0xF0A3B88F, 0x6CAF1 },
	{ 0xF0A3B890, 0x6D4B5 },
	{ 0xF0A3B891, 0x6CAE7 },
	{ 0xF0A3B892, 0x6CAE8 },
	{ 0xF0A3B893, 0x6CAEE },
	{ 0xF0A3B894, 0x5B9E0 },
	{ 0xF0A3B895, 0x6D4B4 },
	{ 0xF0A3B896, 0x6CAEF },
	{ 0xF0A3B897, 0x4BEAC },
	{ 0xF0A3B898, 0x5B9DF },
	{ 0xF0A3B899, 0x5B9E6 },
	{ 0xF0A3B89A, 0x5B9E5 },
	{ 0xF0A3B89B, 0x5B9E4 },
	{ 0xF0A3B89C, 0x6CAEA },
	{ 0xF0A3B89D, 0x5B9E1 },
	{ 0xF0A3B89E, 0x6D4B3 },
	{ 0xF0A3B89F, 0x6CAF2 },
	{ 0xF0A3B8A0, 0x5B9ED },
	{ 0xF0A3B8A1, 0x6CAE1 },
	{ 0xF0A3B8B2, 0xFBCC4 },
	{ 0xF0A3B8B3, 0xFBCC5 },
	{ 0xF0A3B8B4, 0xFBCC6 },
	{ 0xF0A3B8B5, 0xFBCC8 },
	{ 0xF0A3B8B6, 0xFBCC9 },
	{ 0xF0A3B8B7, 0xFBCCA },
	{ 0xF0A3B8B8, 0xFBCCE },
	{ 0xF0A3B8B9, 0xFBCCF },
	{ 0xF0A3B8BA, 0xFBCD0 },
	{ 0xF0A3B8BB, 0xFBCD1 },
	{ 0xF0A3B8BC, 0xFBCD2 },
	{ 0xF0A3B8BD, 0xFBCD3 },
	{ 0xF0A3B8BE, 0xFBCD4 },
	{ 0xF0A3B8BF, 0xFBCD5 },
	{ 0xF0A3B980, 0xFBCD6 },
	{ 0xF0A3B981, 0xFBCD8 },
	{ 0xF0A3B982, 0xFBCD9 },
	{ 0xF0A3B983, 0xFBCDB },
	{ 0xF0A3B984, 0xFBCDC },
	{ 0xF0A3B986, 0x6CAE9 },
	{ 0xF0A3B987, 0x5B9E9 },
	{ 0xF0A3B989, 0x6CAEB },
	{ 0xF0A3B98A, 0x4B8DD },
	{ 0xF0A3B98C, 0x6CADB },
	{ 0xF0A3B98D, 0x6CAE0 },
	{ 0xF0A3B98E, 0x6CADE },
	{ 0xF0A3B99A, 0x5B9EB },
	{ 0xF0A3B99B, 0xFC2F3 },
	{ 0xF0A3B99D, 0x6D4C1 },
	{ 0xF0A3B99E, 0x5C0A5 },
	{ 0xF0A3B99F, 0x4BEC1 },
	{ 0xF0A3B9A0, 0x6D4B8 },
	{ 0xF0A3B9A1, 0x4BEB4 },
	{ 0xF0A3B9A2, 0x6D4BB },
	{ 0xF0A3B9A3, 0x6D4C3 },
	{ 0xF0A3B9A4, 0x4BEBB },
	{ 0xF0A3B9A5, 0x4BEC3 },
	{ 0xF0A3B9A6, 0x4BEBE },
	{ 0xF0A3B9A7, 0x4BEAE },
	{ 0xF0A3B9A8, 0x6D4CA },
	{ 0xF0A3B9A9, 0x5C0A9 },
	{ 0xF0A3B9AA, 0x5C0A6 },
	{ 0xF0A3B9AB, 0x4BEC0 },
	{ 0xF0A3B9AC, 0x6DEB1 },
	{ 0xF0A3B9AD, 0x6D4C2 },
	{ 0xF0A3B9AE, 0x4BEBA },
	{ 0xF0A3B9AF, 0x5C0AF },
	{ 0xF0A3B9B1, 0x5C0AD },
	{ 0xF0A3B9B2, 0x4BEB1 },
	{ 0xF0A3B9B3, 0x6DEB2 },
	{ 0xF0A3B9B4, 0x4BEC2 },
	{ 0xF0A3B9B5, 0x5C0AC },
	{ 0xF0A3B9B6, 0x5C0AE },
	{ 0xF0A3B9B7, 0x6D4BE },
	{ 0xF0A3B9B8, 0x6D4CC },
	{ 0xF0A3B9B9, 0x7A4BC },
	{ 0xF0A3B9BA, 0x6D4C7 },
	{ 0xF0A3B9BB, 0x4C4CB },
	{ 0xF0A3B9BC, 0x6D4BF },
	{ 0xF0A3B9BD, 0x6D4C6 },
	{ 0xF0A3B9BE, 0x6D4B7 },
	{ 0xF0A3B9BF, 0x6D4B6 },
	{ 0xF0A3BA80, 0x5C0AB },
	{ 0xF0A3BA81, 0x5C0A8 },
	{ 0xF0A3BA8C, 0x4BEBD },
	{ 0xF0A3BA8D, 0x6D4BC },
	{ 0xF0A3BA8E, 0x6D4BD },
	{ 0xF0A3BA8F, 0x6D4C0 },
	{ 0xF0A3BA90, 0x6D4C5 },
	{ 0xF0A3BA91, 0xFC2D8 },
	{ 0xF0A3BA92, 0xFC2D9 },
	{ 0xF0A3BA93, 0xFC2DA },
	{ 0xF0A3BA94, 0xFC2DB },
	{ 0xF0A3BA95, 0xFC2DC },
	{ 0xF0A3BA96, 0xFC2DD },
	{ 0xF0A3BA97, 0xFC2DE },
	{ 0xF0A3BA98, 0xFC2E0 },
	{ 0xF0A3BA99, 0xFC2E1 },
	{ 0xF0A3BA9A, 0xFC2E2 },
	{ 0xF0A3BA9B, 0xFC2E5 },
	{ 0xF0A3BA9C, 0xFC2E6 },
	{ 0xF0A3BA9D, 0xFC2E7 },
	{ 0xF0A3BA9E, 0xFC2E8 },
	{ 0xF0A3BA9F, 0xFC2E9 },
	{ 0xF0A3BAA0, 0xFC2EA },
	{ 0xF0A3BAA1, 0xFC2EC },
	{ 0xF0A3BAA2, 0xFC2ED },
	{ 0xF0A3BAA3, 0xFC2EE },
	{ 0xF0A3BAA4, 0xFC2EF },
	{ 0xF0A3BAA5, 0xFC2F0 },
	{ 0xF0A3BAA6, 0xFC2F1 },
	{ 0xF0A3BAA7, 0xFC2F2 },
	{ 0xF0A3BAA8, 0xFC2F5 },
	{ 0xF0A3BAA9, 0xFC9A2 },
	{ 0xF0A3BAAA, 0xFC9BE },
	{ 0xF0A3BAAC, 0x5C0AA },
	{ 0xF0A3BAAF, 0x6D4C4 },
	{ 0xF0A3BAB0, 0x4BEB5 },
	{ 0xF0A3BAB1, 0x6D4CD },
	{ 0xF0A3BAB2, 0x6D4BA },
	{ 0xF0A3BAB4, 0x6D4CB },
	{ 0xF0A3BAB6, 0xFC9AF },
	{ 0xF0A3BABF, 0xFC2EB },
	{ 0xF0A3BB8A, 0xFCFEC },
	{ 0xF0A3BB8C, 0x6D4B9 },
	{ 0xF0A3BB8D, 0x7A4BD },
	{ 0xF0A3BB8F, 0x4C4D4 },
	{ 0xF0A3BB90, 0x4C4C7 },
	{ 0xF0A3BB91, 0x4C4C8 },
	{ 0xF0A3BB92, 0x4C4CC },
	{ 0xF0A3BB93, 0x5C6EB },
	{ 0xF0A3BB94, 0x4C4CE },
	{ 0xF0A3BB95, 0x5C6EA },
	{ 0xF0A3BB96, 0x5C6F4 },
	{ 0xF0A3BB97, 0x5C6F6 },
	{ 0xF0A3BB98, 0x4C4C5 },
	{ 0xF0A3BB99, 0x4C4D3 },
	{ 0xF0A3BB9A, 0x6DEC4 },
	{ 0xF0A3BB9B, 0x5C6EF },
	{ 0xF0A3BB9C, 0x6DEC1 },
	{ 0xF0A3BB9D, 0x6DEBA },
	{ 0xF0A3BB9E, 0x4C4D1 },
	{ 0xF0A3BB9F, 0x4C4D0 },
	{ 0xF0A3BBA0, 0x5C6F5 },
	{ 0xF0A3BBA1, 0x5C6F2 },
	{ 0xF0A3BBA2, 0x5C6ED },
	{ 0xF0A3BBA3, 0x7A4C0 },
	{ 0xF0A3BBA4, 0x7A4BF },
	{ 0xF0A3BBA5, 0x5C6F7 },
	{ 0xF0A3BBA6, 0x6DEC5 },
	{ 0xF0A3BBA7, 0x4C4CF },
	{ 0xF0A3BBA8, 0x6DEB9 },
	{ 0xF0A3BBA9, 0x6DEC2 },
	{ 0xF0A3BBAA, 0x5C6F0 },
	{ 0xF0A3BBAB, 0x5C6F1 },
	{ 0xF0A3BBAC, 0x4C4C1 },
	{ 0xF0A3BBAD, 0x6DEBD },
	{ 0xF0A3BBAE, 0x5CDFA },
	{ 0xF0A3BBAF, 0x7A4BE },
	{ 0xF0A3BBB0, 0x6DEB4 },
	{ 0xF0A3BBB1, 0x5C6EE },
	{ 0xF0A3BBB2, 0x6DEBF },
	{ 0xF0A3BBBF, 0x5C6F3 },
	{ 0xF0A3BC80, 0xFC9A3 },
	{ 0xF0A3BC81, 0xFC9A4 },
	{ 0xF0A3BC82, 0xFC9A5 },
	{ 0xF0A3BC83, 0xFC9A6 },
	{ 0xF0A3BC84, 0xFC9A7 },
	{ 0xF0A3BC85, 0xFC9A8 },
	{ 0xF0A3BC86, 0xFC9A9 },
	{ 0xF0A3BC87, 0xFC9AB },
	{ 0xF0A3BC88, 0xFC9AC },
	{ 0xF0A3BC89, 0xFC9AD },
	{ 0xF0A3BC8A, 0xFC9AE },
	{ 0xF0A3BC8B, 0xFC9B0 },
	{ 0xF0A3BC8C, 0xFC9B1 },
	{ 0xF0A3BC8D, 0xFC9B4 },
	{ 0xF0A3BC8E, 0xFC9B6 },
	{ 0xF0A3BC8F, 0xFC9B7 },
	{ 0xF0A3BC90, 0xFC9B8 },
	{ 0xF0A3BC91, 0xFC9B9 },
	{ 0xF0A3BC92, 0xFC9BA },
	{ 0xF0A3BC93, 0xFC9BC },
	{ 0xF0A3BC94, 0xFC9BD },
	{ 0xF0A3BC95, 0xFC9C1 },
	{ 0xF0A3BC96, 0xFC9C2 },
	{ 0xF0A3BC97, 0xFC9C3 },
	{ 0xF0A3BC98, 0xFCFED },
	{ 0xF0A3BC99, 0x7A2E8 },
	{ 0xF0A3BC9A, 0x4C4C2 },
	{ 0xF0A3BC9B, 0x6DEBC },
	{ 0xF0A3BC9D, 0x6DEC3 },
	{ 0xF0A3BC9F, 0x6DEB5 },
	{ 0xF0A3BCA0, 0x5C6EC },
	{ 0xF0A3BCA1, 0x6DEB3 },
	{ 0xF0A3BCA2, 0x6DEB7 },
	{ 0xF0A3BCA3, 0x6DEB8 },
	{ 0xF0A3BCB5, 0xFC9BB },
	{ 0xF0A3BCBB, 0x6DEB6 },
	{ 0xF0A3BCBF, 0xFC9AA },
	{ 0xF0A3BD83, 0x7A4E2 },
	{ 0xF0A3BD84, 0x7A4D2 },
	{ 0xF0A3BD85, 0x7A4CD },
	{ 0xF0A3BD86, 0x4CAE0 },
	{ 0xF0A3BD87, 0x7A4DA },
	{ 0xF0A3BD88, 0x7A4D4 },
	{ 0xF0A3BD89, 0x7A4CC },
	{ 0xF0A3BD8A, 0x4CAE5 },
	{ 0xF0A3BD8B, 0x4CAE7 },
	{ 0xF0A3BD8C, 0x5CEA5 },
	{ 0xF0A3BD8E, 0x7A4E3 },
	{ 0xF0A3BD8F, 0x7A4CE },
	{ 0xF0A3BD90, 0x7A4D0 },
	{ 0xF0A3BD91, 0x7A4D6 },
	{ 0xF0A3BD92, 0x4CADC },
	{ 0xF0A3BD93, 0x7A4D7 },
	{ 0xF0A3BD94, 0x7A4C9 },
	{ 0xF0A3BD95, 0x5CEA1 },
	{ 0xF0A3BD96, 0x7A4E5 },
	{ 0xF0A3BD97, 0x7A4C7 },
	{ 0xF0A3BD98, 0x7A4C4 },
	{ 0xF0A3BD99, 0x4CAE6 },
	{ 0xF0A3BD9A, 0x5CDFB },
	{ 0xF0A3BD9B, 0x5CEA4 },
	{ 0xF0A3BD9C, 0x7A4E4 },
	{ 0xF0A3BD9D, 0x4CADB },
	{ 0xF0A3BD9E, 0x7A4DB },
	{ 0xF0A3BD9F, 0x4CADA },
	{ 0xF0A3BDA0, 0x7A4D9 },
	{ 0xF0A3BDA1, 0x5CDFE },
	{ 0xF0A3BDA2, 0x7A4C3 },
	{ 0xF0A3BDA3, 0x7A4E7 },
	{ 0xF0A3BDA4, 0x5CEA3 },
	{ 0xF0A3BDA5, 0x5CDFD },
	{ 0xF0A3BDA6, 0x7A4D3 },
	{ 0xF0A3BDA7, 0x7A4C2 },
	{ 0xF0A3BDA8, 0x7BAE9 },
	{ 0xF0A3BDA9, 0x7A4C5 },
	{ 0xF0A3BDAA, 0x7A4E8 },
	{ 0xF0A3BDAB, 0x5CEA2 },
	{ 0xF0A3BDAC, 0x7A4C1 },
	{ 0xF0A3BDAD, 0x7A4DE },
	{ 0xF0A3BDAE, 0x7A4E6 },
	{ 0xF0A3BDAF, 0x5CEA6 },
	{ 0xF0A3BDB0, 0x5CEA8 },
	{ 0xF0A3BDB3, 0x5CDFC },
	{ 0xF0A3BDB4, 0x4CADE },
	{ 0xF0A3BDB5, 0x7A4DF },
	{ 0xF0A3BDB6, 0x7A4CB },
	{ 0xF0A3BDBD, 0x7A4D1 },
	{ 0xF0A3BE84, 0x5CEA7 },
	{ 0xF0A3BE85, 0x7A4DC },
	{ 0xF0A3BE86, 0xFCFD9 },
	{ 0xF0A3BE87, 0xFCFDA },
	{ 0xF0A3BE88, 0xFCFDB },
	{ 0xF0A3BE89, 0xFCFDC },
	{ 0xF0A3BE8A, 0xFCFDD },
	{ 0xF0A3BE8B, 0xFCFDE },
	{ 0xF0A3BE8C, 0xFCFDF },
	{ 0xF0A3BE8D, 0xFCFE2 },
	{ 0xF0A3BE8E, 0xFCFE3 },
	{ 0xF0A3BE8F, 0xFCFE4 },
	{ 0xF0A3BE90, 0xFCFE5 },
	{ 0xF0A3BE91, 0xFCFE6 },
	{ 0xF0A3BE92, 0xFCFE7 },
	{ 0xF0A3BE93, 0xFCFE8 },
	{ 0xF0A3BE94, 0xFCFEA },
	{ 0xF0A3BE95, 0xFCFEB },
	{ 0xF0A3BE96, 0xFCFEF },
	{ 0xF0A3BE97, 0xFCFF0 },
	{ 0xF0A3BE98, 0xFCFF1 },
	{ 0xF0A3BE99, 0xFCFF2 },
	{ 0xF0A3BE9A, 0xFCFF3 },
	{ 0xF0A3BE9B, 0xFCFF4 },
	{ 0xF0A3BE9C, 0xFCFF5 },
	{ 0xF0A3BE9D, 0xFCFF6 },
	{ 0xF0A3BE9E, 0xFCFF7 },
	{ 0xF0A3BE9F, 0xFCFF8 },
	{ 0xF0A3BEA0, 0xFCFFB },
	{ 0xF0A3BEA1, 0xFCFFC },
	{ 0xF0A3BEA2, 0xFD5D1 },
	{ 0xF0A3BEA3, 0x7A4D5 },
	{ 0xF0A3BEA8, 0x7A4E0 },
	{ 0xF0A3BEA9, 0x7AFB0 },
	{ 0xF0A3BEAA, 0x4CAE3 },
	{ 0xF0A3BEAB, 0x7A4C6 },
	{ 0xF0A3BEAC, 0x7A4DD },
	{ 0xF0A3BEAD, 0x7A4C8 },
	{ 0xF0A3BEAE, 0x7A4CA },
	{ 0xF0A3BEB0, 0xFD5CA },
	{ 0xF0A3BEB7, 0xFCFFE },
	{ 0xF0A3BF81, 0xFC9C0 },
	{ 0xF0A3BF85, 0x4D0FC },
	{ 0xF0A3BF86, 0x5D5B5 },
	{ 0xF0A3BF87, 0x5D5B4 },
	{ 0xF0A3BF88, 0x5D5A8 },
	{ 0xF0A3BF89, 0x5D5A9 },
	{ 0xF0A3BF8A, 0x5D5AB },
	{ 0xF0A3BF8B, 0x7AFB3 },
	{ 0xF0A3BF8C, 0x5D5B0 },
	{ 0xF0A3BF8D, 0x7AFC7 },
	{ 0xF0A3BF8E, 0x7AFC0 },
	{ 0xF0A3BF8F, 0x7AFBA },
	{ 0xF0A3BF90, 0x4D0F9 },
	{ 0xF0A3BF91, 0x7AFB9 },
	{ 0xF0A3BF92, 0x4D0FE },
	{ 0xF0A3BF93, 0x5D5B3 },
	{ 0xF0A3BF94, 0x7AFBD },
	{ 0xF0A3BF95, 0x7AFB1 },
	{ 0xF0A3BF96, 0x7AFB7 },
	{ 0xF0A3BF97, 0x7AFC6 },
	{ 0xF0A3BF98, 0x7AFBB },
	{ 0xF0A3BF99, 0x7AFB8 },
	{ 0xF0A3BF9A, 0x7AFC3 },
	{ 0xF0A3BF9B, 0x7AFB6 },
	{ 0xF0A3BF9C, 0x7AFB2 },
	{ 0xF0A3BF9D, 0x5D5B1 },
	{ 0xF0A3BF9E, 0x5D5AA },
	{ 0xF0A3BF9F, 0x5DBF7 },
	{ 0xF0A3BFA0, 0x7AFBC },
	{ 0xF0A3BFA1, 0x7AFC9 },
	{ 0xF0A3BFA2, 0x5D5AC },
	{ 0xF0A3BFA3, 0x5DBF9 },
	{ 0xF0A3BFA4, 0x5D5B2 },
	{ 0xF0A3BFB1, 0x7AFAF },
	{ 0xF0A3BFB2, 0x7AFB4 },
	{ 0xF0A3BFB3, 0x7AFBE },
	{ 0xF0A3BFB4, 0x7AFC1 },
	{ 0xF0A3BFB5, 0xFD5C6 },
	{ 0xF0A3BFB6, 0xFD5C8 },
	{ 0xF0A3BFB7, 0xFD5C9 },
	{ 0xF0A3BFB8, 0xFD5CB },
	{ 0xF0A3BFB9, 0xFD5CC },
	{ 0xF0A3BFBA, 0xFD5CF },
	{ 0xF0A3BFBB, 0xFD5D0 },
	{ 0xF0A3BFBC, 0xFD5D2 },
	{ 0xF0A3BFBD, 0xFD5D3 },
	{ 0xF0A3BFBE, 0xFD5D4 },
	{ 0xF0A3BFBF, 0xFD5D5 },
	{ 0xF0A48080, 0xFD5D7 },
	{ 0xF0A48081, 0xFDAED },
	{ 0xF0A48084, 0x5D5AF },
	{ 0xF0A48085, 0x7AFBF },
	{ 0xF0A48086, 0x7AFC5 },
	{ 0xF0A48087, 0x7AFC8 },
	{ 0xF0A48088, 0x7AFCA },
	{ 0xF0A4808B, 0x7AFAE },
	{ 0xF0A4808E, 0x7AFC4 },
	{ 0xF0A48091, 0x4D1A1 },
	{ 0xF0A4809F, 0xFCFE1 },
	{ 0xF0A480A0, 0xFDAE6 },
	{ 0xF0A480A1, 0xFDADF },
	{ 0xF0A480A2, 0x5D4BA },
	{ 0xF0A480A3, 0x5DBFC },
	{ 0xF0A480A4, 0x4D6DA },
	{ 0xF0A480A5, 0x4D6DF },
	{ 0xF0A480A6, 0x5DBFA },
	{ 0xF0A480A7, 0x7B8FA },
	{ 0xF0A480A8, 0x7B8EE },
	{ 0xF0A480A9, 0x4DBD2 },
	{ 0xF0A480AA, 0x5DBFB },
	{ 0xF0A480AB, 0x5DBF8 },
	{ 0xF0A480AC, 0x7B8F0 },
	{ 0xF0A480AD, 0x7B8F6 },
	{ 0xF0A480AE, 0x7B8EF },
	{ 0xF0A480AF, 0x7B8F9 },
	{ 0xF0A480B0, 0x7B8F4 },
	{ 0xF0A480B1, 0x7B8F3 },
	{ 0xF0A480B2, 0x5E2B8 },
	{ 0xF0A480B3, 0x7B8F5 },
	{ 0xF0A480B4, 0x7B8FB },
	{ 0xF0A480B5, 0x5DBFD },
	{ 0xF0A480B6, 0x7B8F7 },
	{ 0xF0A480B7, 0x5D5B7 },
	{ 0xF0A480B9, 0x3D5BA },
	{ 0xF0A480BE, 0x7B8F8 },
	{ 0xF0A480BF, 0xFDAE0 },
	{ 0xF0A48180, 0xFDAE1 },
	{ 0xF0A48181, 0xFDAE2 },
	{ 0xF0A48182, 0xFDAE3 },
	{ 0xF0A48183, 0xFDAE4 },
	{ 0xF0A48184, 0xFDAE5 },
	{ 0xF0A48185, 0xFDAE7 },
	{ 0xF0A48186, 0xFDAE9 },
	{ 0xF0A48187, 0xFDAEB },
	{ 0xF0A48188, 0xFDAF0 },
	{ 0xF0A48189, 0x7B8F2 },
	{ 0xF0A4818A, 0x5DBFE },
	{ 0xF0A4818C, 0x7B8FC },
	{ 0xF0A4818D, 0x7B8F1 },
	{ 0xF0A48190, 0xFD5CE },
	{ 0xF0A48197, 0xFDAEC },
	{ 0xF0A4819A, 0xFDAEF },
	{ 0xF0A4819C, 0xFD5C7 },
	{ 0xF0A4819D, 0xFD5CD },
	{ 0xF0A4819E, 0xFDADE },
	{ 0xF0A4819F, 0x7AFB5 },
	{ 0xF0A481A1, 0x5E2BF },
	{ 0xF0A481A2, 0x5E2C6 },
	{ 0xF0A481A3, 0x5E2C5 },
	{ 0xF0A481A4, 0x4DBDD },
	{ 0xF0A481A5, 0x5E2BD },
	{ 0xF0A481A6, 0x5E2B9 },
	{ 0xF0A481A7, 0x5E2C2 },
	{ 0xF0A481A8, 0x7C0C0 },
	{ 0xF0A481A9, 0x7C0C6 },
	{ 0xF0A481AA, 0x4DBD9 },
	{ 0xF0A481AB, 0x5E2CB },
	{ 0xF0A481AC, 0x5E2C4 },
	{ 0xF0A481AD, 0x7C0BC },
	{ 0xF0A481AE, 0x5E2C1 },
	{ 0xF0A481AF, 0x5E2CA },
	{ 0xF0A481B0, 0x4DBD8 },
	{ 0xF0A481B1, 0x5E2C3 },
	{ 0xF0A481B2, 0x7C0C7 },
	{ 0xF0A481B3, 0x5E2BB },
	{ 0xF0A481B4, 0x7C0C1 },
	{ 0xF0A481B5, 0x5E2C0 },
	{ 0xF0A481B6, 0x7C0C8 },
	{ 0xF0A481B7, 0x7C0BA },
	{ 0xF0A481B8, 0x4DBDF },
	{ 0xF0A481B9, 0x4DBD5 },
	{ 0xF0A481BA, 0x7C0C5 },
	{ 0xF0A481BB, 0x7C0C4 },
	{ 0xF0A481BC, 0x7C0BE },
	{ 0xF0A481BD, 0x5E2BA },
	{ 0xF0A481BE, 0x4DBD3 },
	{ 0xF0A481BF, 0x5E2BC },
	{ 0xF0A48280, 0x5E2BE },
	{ 0xF0A48281, 0x5E2C9 },
	{ 0xF0A48282, 0x5E2CC },
	{ 0xF0A48283, 0x5E2C7 },
	{ 0xF0A48284, 0x7C0BF },
	{ 0xF0A48285, 0x4DBDC },
	{ 0xF0A48286, 0x7C0C2 },
	{ 0xF0A48287, 0x7C7DF },
	{ 0xF0A4828A, 0x5E2CD },
	{ 0xF0A4828E, 0xFDFB3 },
	{ 0xF0A4828F, 0xFDFB5 },
	{ 0xF0A48290, 0xFDFB6 },
	{ 0xF0A48291, 0xFDFB7 },
	{ 0xF0A48292, 0xFDFB9 },
	{ 0xF0A48293, 0xFDFBA },
	{ 0xF0A48294, 0xFDFBB },
	{ 0xF0A48295, 0xFDFBC },
	{ 0xF0A48296, 0xFDFBD },
	{ 0xF0A48297, 0xFDFBE },
	{ 0xF0A48298, 0xFDFBF },
	{ 0xF0A48299, 0xFDFC0 },
	{ 0xF0A4829A, 0xFDFC1 },
	{ 0xF0A4829B, 0xFDFC2 },
	{ 0xF0A4829C, 0xFDFC3 },
	{ 0xF0A4829D, 0xFE2E4 },
	{ 0xF0A4829E, 0xFE2E5 },
	{ 0xF0A4829F, 0xFE2EC },
	{ 0xF0A482A1, 0x7C7DE },
	{ 0xF0A482A2, 0x7C0BD },
	{ 0xF0A482A3, 0x7C0B9 },
	{ 0xF0A482A5, 0x7C0C3 },
	{ 0xF0A482A6, 0x7C0BB },
	{ 0xF0A482AF, 0xFDFB4 },
	{ 0xF0A482B0, 0xFDAEA },
	{ 0xF0A482B1, 0xFDAEE },
	{ 0xF0A482B2, 0x5E2C8 },
	{ 0xF0A482B3, 0x7C7E5 },
	{ 0xF0A482B4, 0x7C7DC },
	{ 0xF0A482B5, 0x7C7E2 },
	{ 0xF0A482B6, 0x4DFFC },
	{ 0xF0A482B7, 0x4DFFA },
	{ 0xF0A482B8, 0x7C7D3 },
	{ 0xF0A482B9, 0x5E8B6 },
	{ 0xF0A482BA, 0x7C7D6 },
	{ 0xF0A482BB, 0x7C7D4 },
	{ 0xF0A482BD, 0x7C7DB },
	{ 0xF0A482BE, 0x7C7DA },
	{ 0xF0A482BF, 0x7C7D5 },
	{ 0xF0A48380, 0x5E8B5 },
	{ 0xF0A48381, 0x7C7D9 },
	{ 0xF0A48382, 0x7C7DD },
	{ 0xF0A48384, 0x5ECC5 },
	{ 0xF0A4838A, 0x7C7E1 },
	{ 0xF0A4838B, 0xFE2E6 },
	{ 0xF0A4838C, 0xFE2E7 },
	{ 0xF0A4838D, 0xFE2E8 },
	{ 0xF0A4838E, 0xFE2E9 },
	{ 0xF0A4838F, 0xFE2EA },
	{ 0xF0A48390, 0xFE2ED },
	{ 0xF0A48391, 0xFE2EE },
	{ 0xF0A48392, 0xFE2EF },
	{ 0xF0A48393, 0xFE2F0 },
	{ 0xF0A48394, 0xFE2F1 },
	{ 0xF0A48395, 0x7C7D7 },
	{ 0xF0A48397, 0x7C7E0 },
	{ 0xF0A48398, 0x7C7E6 },
	{ 0xF0A48399, 0x7C7E4 },
	{ 0xF0A4839A, 0x7C7E3 },
	{ 0xF0A483A3, 0x7C7D8 },
	{ 0xF0A483A9, 0x5ECC7 },
	{ 0xF0A483AA, 0x5ECCA },
	{ 0xF0A483AB, 0x5ECCB },
	{ 0xF0A483AC, 0x7CEAB },
	{ 0xF0A483AD, 0x4E3D9 },
	{ 0xF0A483AF, 0x4E3DD },
	{ 0xF0A483B0, 0x7CEAA },
	{ 0xF0A483B1, 0x7CEA9 },
	{ 0xF0A483B2, 0x5ECC8 },
	{ 0xF0A483B4, 0x4E3DC },
	{ 0xF0A483B5, 0x7CEAE },
	{ 0xF0A483B6, 0x4E3D7 },
	{ 0xF0A483B7, 0x4E3D8 },
	{ 0xF0A483B8, 0x4E3D6 },
	{ 0xF0A483B9, 0x7CEAD },
	{ 0xF0A483BB, 0x5F0BB },
	{ 0xF0A483BC, 0x5ECC9 },
	{ 0xF0A483BD, 0x5ECCC },
	{ 0xF0A483BE, 0x7CEAF },
	{ 0xF0A48485, 0xFE5C2 },
	{ 0xF0A48486, 0xFE5C3 },
	{ 0xF0A48487, 0xFE5C4 },
	{ 0xF0A48489, 0x7CEAC },
	{ 0xF0A4848E, 0x4E6C8 },
	{ 0xF0A4848F, 0x5F0C0 },
	{ 0xF0A48490, 0x7D3D6 },
	{ 0xF0A48491, 0x5F0BF },
	{ 0xF0A48493, 0x5F0BD },
	{ 0xF0A48494, 0x4E6CB },
	{ 0xF0A48495, 0x7D3D4 },
	{ 0xF0A48496, 0x5F0BC },
	{ 0xF0A48497, 0x7D3D9 },
	{ 0xF0A48498, 0x7D3D3 },
	{ 0xF0A48499, 0x4E6CD },
	{ 0xF0A4849A, 0x7D3DF },
	{ 0xF0A4849B, 0x5F0C1 },
	{ 0xF0A4849C, 0x7D3D5 },
	{ 0xF0A4849D, 0x7D3DA },
	{ 0xF0A4849E, 0xFE7E8 },
	{ 0xF0A4849F, 0xFE7E9 },
	{ 0xF0A484A0, 0xFE7EA },
	{ 0xF0A484A1, 0xFE7EB },
	{ 0xF0A484A2, 0xFE7ED },
	{ 0xF0A484A3, 0xFE7EE },
	{ 0xF0A484A4, 0xFE7EF },
	{ 0xF0A484A6, 0x7D3DB },
	{ 0xF0A484A8, 0x7D3DC },
	{ 0xF0A484A9, 0x7D3DD },
	{ 0xF0A484AA, 0x7D3DE },
	{ 0xF0A484AB, 0x5F0BA },
	{ 0xF0A484AC, 0xFE7F0 },
	{ 0xF0A484B3, 0xFE9D5 },
	{ 0xF0A484B4, 0x7D8AE },
	{ 0xF0A484B5, 0x7D3D7 },
	{ 0xF0A484B6, 0x7D8AF },
	{ 0xF0A484B7, 0x5F3D4 },
	{ 0xF0A484B8, 0x5F0C2 },
	{ 0xF0A484B9, 0x7D8AD },
	{ 0xF0A484BA, 0x5F3D5 },
	{ 0xF0A484BB, 0x7D8B1 },
	{ 0xF0A484BD, 0x4E8F2 },
	{ 0xF0A48581, 0x7D8B2 },
	{ 0xF0A48582, 0xFE9D3 },
	{ 0xF0A48583, 0xFE9D4 },
	{ 0xF0A48585, 0x7D8B3 },
	{ 0xF0A48586, 0x7D8B0 },
	{ 0xF0A48587, 0x7D8AC },
	{ 0xF0A4858A, 0x5F6A1 },
	{ 0xF0A4858B, 0x5F6A2 },
	{ 0xF0A4858C, 0x7DBE9 },
	{ 0xF0A4858D, 0x7DBE8 },
	{ 0xF0A4858E, 0x5F5FE },
	{ 0xF0A48591, 0x7DBE7 },
	{ 0xF0A48592, 0x5F5FD },
	{ 0xF0A48598, 0xFEADB },
	{ 0xF0A48599, 0xFEADC },
	{ 0xF0A4859A, 0xFEADD },
	{ 0xF0A4859B, 0x7DBEA },
	{ 0xF0A4859D, 0x7DBE6 },
	{ 0xF0A485A0, 0x7DEF6 },
	{ 0xF0A485A1, 0x5F7E7 },
	{ 0xF0A485A2, 0x7DEF7 },
	{ 0xF0A485A3, 0x4ECF1 },
	{ 0xF0A485A4, 0x7DEF4 },
	{ 0xF0A485A6, 0x5F7E6 },
	{ 0xF0A485A8, 0x7DEF5 },
	{ 0xF0A485A9, 0x4ECF2 },
	{ 0xF0A485AA, 0x7E0F9 },
	{ 0xF0A485AB, 0x7E0F8 },
	{ 0xF0A485AD, 0x7E0F7 },
	{ 0xF0A485AE, 0xFECAF },
	{ 0xF0A485B0, 0x7E2B9 },
	{ 0xF0A485B1, 0x4EDD8 },
	{ 0xF0A485B2, 0x5FAAB },
	{ 0xF0A485B3, 0x5FAAA },
	{ 0xF0A485B4, 0x4EDD9 },
	{ 0xF0A485B7, 0x4EDF4 },
	{ 0xF0A485B8, 0x5FAE9 },
	{ 0xF0A485B9, 0x5FAEA },
	{ 0xF0A485BB, 0x7E3D7 },
	{ 0xF0A485BC, 0x7E4CB },
	{ 0xF0A485BD, 0x5FBC1 },
	{ 0xF0A485BE, 0xFEDA6 },
	{ 0xF0A485BF, 0x7E5DC },
	{ 0xF0A48680, 0x5FCBC },
	{ 0xF0A48682, 0x6A3AF },
	{ 0xF0A48683, 0x6A5B3 },
	{ 0xF0A48684, 0x4A3A4 },
	{ 0xF0A48685, 0x4A3A5 },
	{ 0xF0A48686, 0x6A5B2 },
	{ 0xF0A48688, 0xFA2DF },
	{ 0xF0A48689, 0xFA2E0 },
	{ 0xF0A4868A, 0xFA2E1 },
	{ 0xF0A4868B, 0x6A5B4 },
	{ 0xF0A4868D, 0x4A4D3 },
	{ 0xF0A4868E, 0x4A4D4 },
	{ 0xF0A4868F, 0x5A4D4 },
	{ 0xF0A48690, 0x6A8CC },
	{ 0xF0A48691, 0x5A4D5 },
	{ 0xF0A48692, 0x5A4D7 },
	{ 0xF0A48694, 0xFA4EB },
	{ 0xF0A48695, 0xFA4EC },
	{ 0xF0A48696, 0xFA4ED },
	{ 0xF0A48697, 0xFA4F0 },
	{ 0xF0A48698, 0xFA4F2 },
	{ 0xF0A4869A, 0x6A8CB },
	{ 0xF0A4869D, 0x5A6F4 },
	{ 0xF0A4869E, 0x4A7A8 },
	{ 0xF0A4869F, 0x5A6F5 },
	{ 0xF0A486A6, 0xFA7EF },
	{ 0xF0A486A7, 0xFA7F0 },
	{ 0xF0A486A8, 0xFA7F1 },
	{ 0xF0A486A9, 0xFA7F3 },
	{ 0xF0A486AA, 0xFA7F4 },
	{ 0xF0A486AB, 0xFA7F5 },
	{ 0xF0A486AC, 0xFA7F6 },
	{ 0xF0A486AD, 0xFA7F7 },
	{ 0xF0A486AF, 0x6ACDF },
	{ 0xF0A486B0, 0xFA7F2 },
	{ 0xF0A486B1, 0x6ACDE },
	{ 0xF0A486B2, 0x4A7AA },
	{ 0xF0A486B4, 0x5A4D6 },
	{ 0xF0A486BC, 0x5AAA5 },
	{ 0xF0A486BD, 0x6B2CC },
	{ 0xF0A486BE, 0x5AAA6 },
	{ 0xF0A486BF, 0x6B2C4 },
	{ 0xF0A48780, 0x5AAA7 },
	{ 0xF0A48781, 0x6B2CB },
	{ 0xF0A48787, 0x6B2C6 },
	{ 0xF0A48788, 0xFABEF },
	{ 0xF0A48789, 0xFABF0 },
	{ 0xF0A4878A, 0xFABF1 },
	{ 0xF0A4878B, 0xFABF2 },
	{ 0xF0A4878C, 0xFABF3 },
	{ 0xF0A4878D, 0xFABF4 },
	{ 0xF0A4878E, 0xFABF5 },
	{ 0xF0A4878F, 0xFABF6 },
	{ 0xF0A48790, 0xFABF7 },
	{ 0xF0A48791, 0xFABF8 },
	{ 0xF0A48792, 0xFABF9 },
	{ 0xF0A48793, 0xFABFB },
	{ 0xF0A48794, 0xFABFC },
	{ 0xF0A48795, 0xFABFD },
	{ 0xF0A48796, 0xFABFE },
	{ 0xF0A48797, 0xFACA1 },
	{ 0xF0A48798, 0xFACA3 },
	{ 0xF0A48799, 0x4AAA9 },
	{ 0xF0A4879A, 0x6B2C5 },
	{ 0xF0A4879B, 0x6B2C3 },
	{ 0xF0A4879D, 0x6B2C7 },
	{ 0xF0A4879F, 0x6B9BA },
	{ 0xF0A487A0, 0x5AAA8 },
	{ 0xF0A487A1, 0x6B2CA },
	{ 0xF0A487A2, 0xFACA2 },
	{ 0xF0A487AB, 0x6B2C9 },
	{ 0xF0A487AF, 0x5AECF },
	{ 0xF0A487B0, 0x5AECE },
	{ 0xF0A487B1, 0x6B9B6 },
	{ 0xF0A487B2, 0x6B9B9 },
	{ 0xF0A487B3, 0xFB0EA },
	{ 0xF0A487B4, 0x4B2EF },
	{ 0xF0A487B5, 0x6B9B7 },
	{ 0xF0A487B6, 0x4ADF4 },
	{ 0xF0A487B7, 0x6B9B4 },
	{ 0xF0A487BD, 0x5AECB },
	{ 0xF0A487BE, 0xFB0DD },
	{ 0xF0A487BF, 0xFB0DE },
	{ 0xF0A48880, 0xFB0DF },
	{ 0xF0A48881, 0xFB0E0 },
	{ 0xF0A48882, 0xFB0E1 },
	{ 0xF0A48883, 0xFB0E2 },
	{ 0xF0A48884, 0xFB0E3 },
	{ 0xF0A48885, 0xFB0E4 },
	{ 0xF0A48886, 0xFB0E5 },
	{ 0xF0A48887, 0xFB0E6 },
	{ 0xF0A48888, 0xFB0E8 },
	{ 0xF0A48889, 0xFB0E9 },
	{ 0xF0A4888A, 0xFB0EB },
	{ 0xF0A4888B, 0xFB0EC },
	{ 0xF0A4888C, 0xFB0EE },
	{ 0xF0A4888D, 0xFB0EF },
	{ 0xF0A4888E, 0xFB0F0 },
	{ 0xF0A4888F, 0xFB0F1 },
	{ 0xF0A48890, 0xFB0F2 },
	{ 0xF0A48891, 0x5AECC },
	{ 0xF0A48892, 0x6B9B5 },
	{ 0xF0A48895, 0x6B9BB },
	{ 0xF0A48896, 0x6B9BC },
	{ 0xF0A48898, 0xFB0E7 },
	{ 0xF0A4889B, 0xFB0ED },
	{ 0xF0A488A2, 0x6B9B8 },
	{ 0xF0A488A3, 0x5AECD },
	{ 0xF0A488A5, 0x6C1CB },
	{ 0xF0A488A6, 0x4B2F4 },
	{ 0xF0A488A7, 0x5B3C4 },
	{ 0xF0A488A8, 0x6C1CF },
	{ 0xF0A488A9, 0x4B2F3 },
	{ 0xF0A488AA, 0x4B2F5 },
	{ 0xF0A488AB, 0x6C1CE },
	{ 0xF0A488AC, 0x6C1D4 },
	{ 0xF0A488AD, 0x6C1D1 },
	{ 0xF0A488AE, 0x6C1CD },
	{ 0xF0A488AF, 0x6C1CC },
	{ 0xF0A488B0, 0x6CAF3 },
	{ 0xF0A488B1, 0x6C1D2 },
	{ 0xF0A488B2, 0x6C1D0 },
	{ 0xF0A488B9, 0x6C1D3 },
	{ 0xF0A488BA, 0xFB6A4 },
	{ 0xF0A488BB, 0xFB6BE },
	{ 0xF0A488BC, 0xFB6BF },
	{ 0xF0A488BD, 0xFB6C0 },
	{ 0xF0A488BE, 0xFB6C1 },
	{ 0xF0A488BF, 0xFB6C3 },
	{ 0xF0A48980, 0xFB6C4 },
	{ 0xF0A48981, 0xFB6C5 },
	{ 0xF0A48982, 0xFB6C6 },
	{ 0xF0A48983, 0xFB6C7 },
	{ 0xF0A48984, 0xFB6C9 },
	{ 0xF0A48985, 0xFB6CA },
	{ 0xF0A48986, 0xFB6CC },
	{ 0xF0A48987, 0xFB6CD },
	{ 0xF0A48988, 0xFB6CE },
	{ 0xF0A48989, 0xFB6D0 },
	{ 0xF0A4898A, 0x6C1C9 },
	{ 0xF0A48991, 0x6C1C8 },
	{ 0xF0A48999, 0xFB6CB },
	{ 0xF0A4899D, 0x5B3C3 },
	{ 0xF0A4899F, 0x5B3C5 },
	{ 0xF0A489A1, 0x6C1D5 },
	{ 0xF0A489A2, 0x4B8E9 },
	{ 0xF0A489A3, 0x6CAF8 },
	{ 0xF0A489A4, 0x6C1CA },
	{ 0xF0A489A5, 0x5B9F1 },
	{ 0xF0A489A6, 0x5B9EF },
	{ 0xF0A489A7, 0x6CAFE },
	{ 0xF0A489A9, 0x6CBA1 },
	{ 0xF0A489AA, 0x5B9EE },
	{ 0xF0A489AB, 0x6CAF5 },
	{ 0xF0A489AC, 0x4B8E6 },
	{ 0xF0A489AD, 0x6CAFA },
	{ 0xF0A489AE, 0x6CAF4 },
	{ 0xF0A489AF, 0x6CAFD },
	{ 0xF0A489B9, 0x4B8E3 },
	{ 0xF0A489BA, 0x5B9F0 },
	{ 0xF0A489BB, 0x6CAF7 },
	{ 0xF0A489BC, 0xFBCDE },
	{ 0xF0A489BD, 0xFBCDF },
	{ 0xF0A489BE, 0xFBCE0 },
	{ 0xF0A489BF, 0xFBCE1 },
	{ 0xF0A48A80, 0xFBCE2 },
	{ 0xF0A48A81, 0xFBCE3 },
	{ 0xF0A48A82, 0xFBCE4 },
	{ 0xF0A48A83, 0xFBCE6 },
	{ 0xF0A48A84, 0xFBCE7 },
	{ 0xF0A48A85, 0xFBCE8 },
	{ 0xF0A48A86, 0xFBCE9 },
	{ 0xF0A48A87, 0xFBCEB },
	{ 0xF0A48A88, 0xFBCEC },
	{ 0xF0A48A89, 0xFBCED },
	{ 0xF0A48A8A, 0xFBCEE },
	{ 0xF0A48A8B, 0xFBCEF },
	{ 0xF0A48A8C, 0xFBCF0 },
	{ 0xF0A48A8D, 0xFBCF1 },
	{ 0xF0A48A8E, 0xFBCF2 },
	{ 0xF0A48A8F, 0xFBCF5 },
	{ 0xF0A48A90, 0xFBCF7 },
	{ 0xF0A48A91, 0xFBCF8 },
	{ 0xF0A48A92, 0xFBCF9 },
	{ 0xF0A48A93, 0xFBCFA },
	{ 0xF0A48A94, 0xFBCFB },
	{ 0xF0A48A95, 0xFBCFC },
	{ 0xF0A48A96, 0xFBDA1 },
	{ 0xF0A48A97, 0x6CAF9 },
	{ 0xF0A48A98, 0x6CAFC },
	{ 0xF0A48A99, 0x4B8E7 },
	{ 0xF0A48A9B, 0x6CAF6 },
	{ 0xF0A48A9C, 0x6CAFB },
	{ 0xF0A48AA5, 0xFBCEA },
	{ 0xF0A48AAF, 0x5B9F2 },
	{ 0xF0A48AB2, 0x5C0B4 },
	{ 0xF0A48AB4, 0x6D4DA },
	{ 0xF0A48AB5, 0x6D4D8 },
	{ 0xF0A48AB6, 0x5C0B0 },
	{ 0xF0A48AB7, 0x6D4D6 },
	{ 0xF0A48AB8, 0x6D4DD },
	{ 0xF0A48AB9, 0x4BEC7 },
	{ 0xF0A48ABA, 0x6D4D7 },
	{ 0xF0A48ABB, 0x4BEC4 },
	{ 0xF0A48ABC, 0x6D4DB },
	{ 0xF0A48ABD, 0x6D4DE },
	{ 0xF0A48ABE, 0x4BEC5 },
	{ 0xF0A48ABF, 0x5C0B2 },
	{ 0xF0A48B80, 0x6D4D3 },
	{ 0xF0A48B81, 0x6D4E3 },
	{ 0xF0A48B82, 0x6D4DF },
	{ 0xF0A48B83, 0x6D4E4 },
	{ 0xF0A48B84, 0x5C0B5 },
	{ 0xF0A48B86, 0x6D4DC },
	{ 0xF0A48B87, 0x6D4E2 },
	{ 0xF0A48B8B, 0xFC2F6 },
	{ 0xF0A48B8C, 0xFC2F9 },
	{ 0xF0A48B8D, 0xFC2FB },
	{ 0xF0A48B8E, 0xFC2FC },
	{ 0xF0A48B8F, 0xFC2FD },
	{ 0xF0A48B90, 0xFC3A1 },
	{ 0xF0A48B91, 0xFC3A2 },
	{ 0xF0A48B92, 0xFC3A3 },
	{ 0xF0A48B93, 0xFC3A5 },
	{ 0xF0A48B94, 0xFC3A6 },
	{ 0xF0A48B95, 0xFC3A7 },
	{ 0xF0A48B96, 0xFC3A8 },
	{ 0xF0A48B97, 0xFC3A9 },
	{ 0xF0A48B98, 0xFC3AA },
	{ 0xF0A48B99, 0xFC3AB },
	{ 0xF0A48B9A, 0xFC3AD },
	{ 0xF0A48B9B, 0xFC3AE },
	{ 0xF0A48B9C, 0xFC3B0 },
	{ 0xF0A48B9D, 0xFC3B3 },
	{ 0xF0A48B9E, 0xFC3B4 },
	{ 0xF0A48B9F, 0xFC3B5 },
	{ 0xF0A48BA0, 0xFC3B6 },
	{ 0xF0A48BA1, 0xFC3B7 },
	{ 0xF0A48BA2, 0xFC3B8 },
	{ 0xF0A48BA3, 0xFC3B9 },
	{ 0xF0A48BA4, 0xFC3BA },
	{ 0xF0A48BA5, 0xFC3BB },
	{ 0xF0A48BA6, 0xFC3BD },
	{ 0xF0A48BA7, 0xFC3BE },
	{ 0xF0A48BA8, 0x6D4D1 },
	{ 0xF0A48BA9, 0x6D4D2 },
	{ 0xF0A48BAA, 0x6D4D5 },
	{ 0xF0A48BAC, 0x6D4E6 },
	{ 0xF0A48BAF, 0x4BECA },
	{ 0xF0A48BB0, 0x6D4E1 },
	{ 0xF0A48BB1, 0x6D4E5 },
	{ 0xF0A48BB3, 0x6DAD4 },
	{ 0xF0A48BBA, 0xFC3AC },
	{ 0xF0A48C81, 0x5C0B3 },
	{ 0xF0A48C83, 0x5C0B1 },
	{ 0xF0A48C87, 0xFC9D4 },
	{ 0xF0A48C88, 0x6DED1 },
	{ 0xF0A48C89, 0x6DED0 },
	{ 0xF0A48C8A, 0x5C6FE },
	{ 0xF0A48C8B, 0x6DECA },
	{ 0xF0A48C8C, 0x5C7A2 },
	{ 0xF0A48C8D, 0x4C4D5 },
	{ 0xF0A48C8E, 0x5C6FC },
	{ 0xF0A48C8F, 0x5C6FB },
	{ 0xF0A48C90, 0x5C6FA },
	{ 0xF0A48C91, 0x7A4F0 },
	{ 0xF0A48C92, 0x7A4EA },
	{ 0xF0A48C93, 0x6DEC6 },
	{ 0xF0A48C94, 0x5C7A1 },
	{ 0xF0A48C95, 0x6DEC7 },
	{ 0xF0A48C96, 0x6DEC8 },
	{ 0xF0A48C9B, 0x5C6F9 },
	{ 0xF0A48C9C, 0x6DECB },
	{ 0xF0A48C9D, 0x6DECF },
	{ 0xF0A48C9E, 0xFC9C4 },
	{ 0xF0A48C9F, 0xFC9C5 },
	{ 0xF0A48CA0, 0xFC9C6 },
	{ 0xF0A48CA1, 0xFC9C7 },
	{ 0xF0A48CA2, 0xFC9C9 },
	{ 0xF0A48CA3, 0xFC9CA },
	{ 0xF0A48CA4, 0xFC9CC },
	{ 0xF0A48CA5, 0xFC9CD },
	{ 0xF0A48CA6, 0xFC9CE },
	{ 0xF0A48CA7, 0xFC9CF },
	{ 0xF0A48CA8, 0xFC9D0 },
	{ 0xF0A48CA9, 0xFC9D1 },
	{ 0xF0A48CAA, 0xFC9D2 },
	{ 0xF0A48CAB, 0xFC9D3 },
	{ 0xF0A48CAC, 0xFC9D5 },
	{ 0xF0A48CAD, 0xFC9D6 },
	{ 0xF0A48CAE, 0xFC9D7 },
	{ 0xF0A48CAF, 0xFC9DA },
	{ 0xF0A48CB0, 0xFC9DB },
	{ 0xF0A48CB1, 0xFC9DD },
	{ 0xF0A48CB2, 0xFC9DE },
	{ 0xF0A48CB3, 0xFC9E0 },
	{ 0xF0A48CB4, 0xFC9E2 },
	{ 0xF0A48CB5, 0xFC9E3 },
	{ 0xF0A48CB6, 0xFC9E4 },
	{ 0xF0A48CB8, 0x4C4DD },
	{ 0xF0A48CB9, 0x5C6FD },
	{ 0xF0A48CBA, 0x6DECC },
	{ 0xF0A48CBB, 0x6DED2 },
	{ 0xF0A48CBC, 0x6DEC9 },
	{ 0xF0A48CBD, 0x6DECD },
	{ 0xF0A48D88, 0xFC9DC },
	{ 0xF0A48D8D, 0x6D4E0 },
	{ 0xF0A48D8E, 0xFC2FE },
	{ 0xF0A48D8F, 0xFC2FA },
	{ 0xF0A48D90, 0x4CAEB },
	{ 0xF0A48D93, 0x5CEAC },
	{ 0xF0A48D94, 0x7A4F4 },
	{ 0xF0A48D95, 0x7A4ED },
	{ 0xF0A48D96, 0x7A4E9 },
	{ 0xF0A48D97, 0x5CEAA },
	{ 0xF0A48D98, 0x7A4EC },
	{ 0xF0A48D99, 0x7A4F1 },
	{ 0xF0A48D9A, 0x7A4F2 },
	{ 0xF0A48D9B, 0x7A4F5 },
	{ 0xF0A48D9C, 0x7A4EB },
	{ 0xF0A48D9D, 0x5CEA9 },
	{ 0xF0A48DA2, 0xFCEA2 },
	{ 0xF0A48DA6, 0x5CEAB },
	{ 0xF0A48DA7, 0x7A4F3 },
	{ 0xF0A48DA8, 0xFD0A3 },
	{ 0xF0A48DA9, 0xFD0A4 },
	{ 0xF0A48DAA, 0xFD0A6 },
	{ 0xF0A48DAB, 0xFD0A7 },
	{ 0xF0A48DAC, 0xFD0A8 },
	{ 0xF0A48DAD, 0xFD0A9 },
	{ 0xF0A48DAE, 0xFD0AA },
	{ 0xF0A48DAF, 0xFD0AB },
	{ 0xF0A48DB0, 0xFD0AE },
	{ 0xF0A48DB1, 0xFD0AF },
	{ 0xF0A48DB2, 0xFD0B1 },
	{ 0xF0A48DB3, 0xFD0B2 },
	{ 0xF0A48DB4, 0xFD0B3 },
	{ 0xF0A48DB5, 0xFD0B4 },
	{ 0xF0A48DB6, 0xFD0B5 },
	{ 0xF0A48DB7, 0xFD0B7 },
	{ 0xF0A48DB8, 0xFD0B8 },
	{ 0xF0A48DB9, 0xFD0B9 },
	{ 0xF0A48DBA, 0xFD0BA },
	{ 0xF0A48DBB, 0xFD0BB },
	{ 0xF0A48DBC, 0xFD0BC },
	{ 0xF0A48DBE, 0x7A4EE },
	{ 0xF0A48DBF, 0xFD0AC },
	{ 0xF0A48E82, 0x7AAF1 },
	{ 0xF0A48E84, 0xFD0AD },
	{ 0xF0A48E85, 0xFD0B0 },
	{ 0xF0A48E8C, 0xFD0A5 },
	{ 0xF0A48E96, 0xFD0A2 },
	{ 0xF0A48E97, 0x5CEAE },
	{ 0xF0A48E98, 0x5CEAD },
	{ 0xF0A48E9A, 0x6DECE },
	{ 0xF0A48E9D, 0x4D1AA },
	{ 0xF0A48E9E, 0x7AFD2 },
	{ 0xF0A48E9F, 0x7AFE6 },
	{ 0xF0A48EA0, 0x7AFD0 },
	{ 0xF0A48EA1, 0x7AFE0 },
	{ 0xF0A48EA2, 0x7AFDE },
	{ 0xF0A48EA3, 0x5D5BB },
	{ 0xF0A48EA4, 0x4D1A7 },
	{ 0xF0A48EA5, 0x7AFE1 },
	{ 0xF0A48EA6, 0x7AFE3 },
	{ 0xF0A48EA7, 0x7AFD5 },
	{ 0xF0A48EA8, 0x7A4EF },
	{ 0xF0A48EA9, 0x4D1A8 },
	{ 0xF0A48EAA, 0x7AFD6 },
	{ 0xF0A48EAB, 0x7AFE4 },
	{ 0xF0A48EAC, 0x7AFE5 },
	{ 0xF0A48EAD, 0x4D1A6 },
	{ 0xF0A48EAE, 0x7AFD8 },
	{ 0xF0A48EAF, 0x7AFD4 },
	{ 0xF0A48EB0, 0x4D1A9 },
	{ 0xF0A48EB1, 0x7AFE7 },
	{ 0xF0A48EB2, 0x5D5BA },
	{ 0xF0A48EB3, 0x5D5BC },
	{ 0xF0A48EB4, 0x7AFE2 },
	{ 0xF0A48EB5, 0x7AFD9 },
	{ 0xF0A48EB7, 0x7AFDD },
	{ 0xF0A48EB8, 0x7AFDA },
	{ 0xF0A48EBE, 0x7AFCB },
	{ 0xF0A48EBF, 0x7AFD3 },
	{ 0xF0A48F80, 0x7AFDC },
	{ 0xF0A48F81, 0xFD5D9 },
	{ 0xF0A48F82, 0xFD5DA },
	{ 0xF0A48F83, 0xFD5DB },
	{ 0xF0A48F84, 0xFD5DC },
	{ 0xF0A48F85, 0xFD5DD },
	{ 0xF0A48F86, 0xFD5DE },
	{ 0xF0A48F87, 0xFD5DF },
	{ 0xF0A48F88, 0xFD5E0 },
	{ 0xF0A48F89, 0xFD5E1 },
	{ 0xF0A48F8A, 0xFD5E2 },
	{ 0xF0A48F8B, 0xFD5E3 },
	{ 0xF0A48F8C, 0xFD5E6 },
	{ 0xF0A48F8D, 0xFD5E7 },
	{ 0xF0A48F8E, 0xFD5E8 },
	{ 0xF0A48F8F, 0xFD5EA },
	{ 0xF0A48F90, 0xFD5EB },
	{ 0xF0A48F91, 0xFD5ED },
	{ 0xF0A48F92, 0xFD5EE },
	{ 0xF0A48F93, 0xFD5F0 },
	{ 0xF0A48F94, 0xFD5F1 },
	{ 0xF0A48F95, 0xFD5F2 },
	{ 0xF0A48F97, 0xFD5E5 },
	{ 0xF0A48F98, 0x5D5B8 },
	{ 0xF0A48F99, 0x7AFCD },
	{ 0xF0A48F9A, 0x7AFCE },
	{ 0xF0A48F9B, 0x7AFDB },
	{ 0xF0A48F9D, 0x7AFDF },
	{ 0xF0A48F9E, 0x7B1FA },
	{ 0xF0A48F9F, 0x7AFD1 },
	{ 0xF0A48FA0, 0x7ACFB },
	{ 0xF0A48FA9, 0xFD5EF },
	{ 0xF0A48FAD, 0x5D5BD },
	{ 0xF0A48FAE, 0x5D5B9 },
	{ 0xF0A48FAF, 0x7AFCC },
	{ 0xF0A48FB0, 0x7A4F6 },
	{ 0xF0A48FB4, 0x7AFD7 },
	{ 0xF0A48FB5, 0x7B9A3 },
	{ 0xF0A48FB6, 0x4D6E1 },
	{ 0xF0A48FB7, 0x7B9A5 },
	{ 0xF0A48FB8, 0x5D5BE },
	{ 0xF0A48FB9, 0x7B9A9 },
	{ 0xF0A48FBA, 0x7B9A8 },
	{ 0xF0A48FBB, 0x4D6E3 },
	{ 0xF0A48FBC, 0x7AFE8 },
	{ 0xF0A48FBD, 0x5DCA1 },
	{ 0xF0A48FBE, 0x7B8FD },
	{ 0xF0A48FBF, 0x5DCA4 },
	{ 0xF0A49080, 0x5DCA2 },
	{ 0xF0A49084, 0xFDAF1 },
	{ 0xF0A49085, 0xFDAF2 },
	{ 0xF0A49086, 0xFDAF6 },
	{ 0xF0A49087, 0xFDAF7 },
	{ 0xF0A49088, 0xFDAF8 },
	{ 0xF0A49089, 0xFDAF9 },
	{ 0xF0A4908A, 0xFDAFA },
	{ 0xF0A4908B, 0xFDAFB },
	{ 0xF0A4908C, 0xFDAFC },
	{ 0xF0A4908D, 0xFDAFD },
	{ 0xF0A4908E, 0xFDAFE },
	{ 0xF0A4908F, 0xFDBA1 },
	{ 0xF0A49090, 0xFDBA2 },
	{ 0xF0A49091, 0xFDBA3 },
	{ 0xF0A49092, 0x7B8FE },
	{ 0xF0A49095, 0x7B9A4 },
	{ 0xF0A49097, 0x7B9A2 },
	{ 0xF0A4909E, 0x5DCA3 },
	{ 0xF0A4909F, 0x7B9A1 },
	{ 0xF0A490A2, 0xFD5E9 },
	{ 0xF0A490A6, 0x7C0CF },
	{ 0xF0A490A7, 0x4DBE2 },
	{ 0xF0A490A8, 0x7C0CE },
	{ 0xF0A490A9, 0x5E2CE },
	{ 0xF0A490AA, 0x7C0CB },
	{ 0xF0A490AB, 0x7C0D3 },
	{ 0xF0A490AC, 0x7C0D1 },
	{ 0xF0A490AD, 0x7C0CC },
	{ 0xF0A490AF, 0x4DBE3 },
	{ 0xF0A490B0, 0x5E2CF },
	{ 0xF0A490B1, 0x5E2D0 },
	{ 0xF0A490B2, 0x4DBE1 },
	{ 0xF0A490B3, 0x7C0D4 },
	{ 0xF0A490B7, 0x7C0CA },
	{ 0xF0A490B8, 0x7C0D2 },
	{ 0xF0A490B9, 0xFDFC4 },
	{ 0xF0A490BA, 0xFDFC6 },
	{ 0xF0A490BB, 0xFDFC5 },
	{ 0xF0A490BC, 0xFDFC7 },
	{ 0xF0A490BD, 0xFDFC8 },
	{ 0xF0A490BE, 0xFDFC9 },
	{ 0xF0A490BF, 0xFDFCA },
	{ 0xF0A49180, 0xFDFCC },
	{ 0xF0A49181, 0xFDFCD },
	{ 0xF0A49182, 0x7C0D0 },
	{ 0xF0A49183, 0x7C2A2 },
	{ 0xF0A49185, 0x7C0D5 },
	{ 0xF0A49186, 0x7C0CD },
	{ 0xF0A4918A, 0x7C0C9 },
	{ 0xF0A4918B, 0x7B9AA },
	{ 0xF0A4918E, 0xFE1F6 },
	{ 0xF0A4918F, 0xFDAF4 },
	{ 0xF0A49190, 0xFDAF5 },
	{ 0xF0A49192, 0x7C7EC },
	{ 0xF0A49193, 0x5E8B7 },
	{ 0xF0A49194, 0x4E0A1 },
	{ 0xF0A49196, 0x7C7ED },
	{ 0xF0A49197, 0x4E0A2 },
	{ 0xF0A4919C, 0x7C7EA },
	{ 0xF0A4919D, 0xFE2F4 },
	{ 0xF0A4919E, 0xFE2F5 },
	{ 0xF0A4919F, 0xFE2F6 },
	{ 0xF0A491A0, 0xFE2F7 },
	{ 0xF0A491A2, 0x7C7E9 },
	{ 0xF0A491A7, 0x7C7E7 },
	{ 0xF0A491A8, 0x7C7EB },
	{ 0xF0A491B0, 0xFDFCB },
	{ 0xF0A491B1, 0x7C7E8 },
	{ 0xF0A491B2, 0xFE5C5 },
	{ 0xF0A491B3, 0x5ECCF },
	{ 0xF0A491B4, 0x7CEB0 },
	{ 0xF0A491B5, 0x7CEB3 },
	{ 0xF0A491B6, 0x7CEBB },
	{ 0xF0A491B7, 0x5ECCE },
	{ 0xF0A491B8, 0x5ECCD },
	{ 0xF0A491B9, 0x5ECD1 },
	{ 0xF0A491BA, 0x4E0A3 },
	{ 0xF0A491BC, 0x7CEB2 },
	{ 0xF0A491BD, 0x7CEB8 },
	{ 0xF0A491BE, 0x4E3E2 },
	{ 0xF0A491BF, 0x4E3E0 },
	{ 0xF0A49280, 0x7CEBC },
	{ 0xF0A49281, 0x7CEB1 },
	{ 0xF0A49282, 0x7CEB5 },
	{ 0xF0A49286, 0x7CEB7 },
	{ 0xF0A49288, 0xFE5C8 },
	{ 0xF0A49289, 0x7CEB4 },
	{ 0xF0A4928A, 0xFE5C6 },
	{ 0xF0A4928B, 0xFE5C7 },
	{ 0xF0A4928C, 0xFE5CA },
	{ 0xF0A4928D, 0xFE5CB },
	{ 0xF0A4928E, 0xFE5CC },
	{ 0xF0A4928F, 0xFE5CD },
	{ 0xF0A49290, 0xFE5CE },
	{ 0xF0A49293, 0x7CEB9 },
	{ 0xF0A49297, 0x7CEB6 },
	{ 0xF0A4929C, 0x7CEBA },
	{ 0xF0A4929E, 0x5ECD0 },
	{ 0xF0A492A1, 0x7D3E4 },
	{ 0xF0A492A2, 0x4E3E1 },
	{ 0xF0A492A3, 0x7D3E6 },
	{ 0xF0A492A4, 0x5F0C3 },
	{ 0xF0A492A6, 0x4E6CF },
	{ 0xF0A492A7, 0x7D3E7 },
	{ 0xF0A492AB, 0x7D3E2 },
	{ 0xF0A492AC, 0x7D3E3 },
	{ 0xF0A492AE, 0x7D3E5 },
	{ 0xF0A492B3, 0xFE7F1 },
	{ 0xF0A492B5, 0xFE7F2 },
	{ 0xF0A492B6, 0xFE7F3 },
	{ 0xF0A492B7, 0xFE7F4 },
	{ 0xF0A492B8, 0xFE7F5 },
	{ 0xF0A492BA, 0x7D8B6 },
	{ 0xF0A492BB, 0x5F3D6 },
	{ 0xF0A492BC, 0x4EACF },
	{ 0xF0A492BD, 0x7D8B7 },
	{ 0xF0A492BE, 0x7D8B8 },
	{ 0xF0A49380, 0x7D8B4 },
	{ 0xF0A49381, 0xFE9D6 },
	{ 0xF0A49382, 0xFE9D7 },
	{ 0xF0A49383, 0xFE9D8 },
	{ 0xF0A49384, 0x7D8B5 },
	{ 0xF0A49385, 0x7DBA4 },
	{ 0xF0A49388, 0x7DBEE },
	{ 0xF0A49389, 0x7DBF0 },
	{ 0xF0A4938A, 0x7DBED },
	{ 0xF0A4938F, 0x7DCC4 },
	{ 0xF0A49390, 0x7DBEF },
	{ 0xF0A49392, 0x7DBEC },
	{ 0xF0A49394, 0x7DBEB },
	{ 0xF0A49395, 0x5F6A3 },
	{ 0xF0A49396, 0xFEAE0 },
	{ 0xF0A49397, 0x7DEF8 },
	{ 0xF0A49399, 0xFEADF },
	{ 0xF0A4939A, 0x5F7E8 },
	{ 0xF0A4939C, 0x7E1A1 },
	{ 0xF0A4939D, 0x7E0FC },
	{ 0xF0A4939E, 0x7E0FE },
	{ 0xF0A4939F, 0x7E1B8 },
	{ 0xF0A493A0, 0x7E0FB },
	{ 0xF0A493A1, 0x7E0FD },
	{ 0xF0A493A5, 0x7E2BA },
	{ 0xF0A493A6, 0x5FAEB },
	{ 0xF0A493A7, 0xFECE4 },
	{ 0xF0A493A8, 0xFECE5 },
	{ 0xF0A493AA, 0x7E4CD },
	{ 0xF0A493AB, 0x7E4CC },
	{ 0xF0A493AC, 0x7E4CE },
	{ 0xF0A493AD, 0x7E5B7 },
	{ 0xF0A493AE, 0x7E6B4 },
	{ 0xF0A493AF, 0x5A1CB },
	{ 0xF0A493B1, 0x6A3B0 },
	{ 0xF0A493B2, 0x6A8CD },
	{ 0xF0A493B3, 0x6A8CE },
	{ 0xF0A493B4, 0x5A4D8 },
	{ 0xF0A493B6, 0x6ACE2 },
	{ 0xF0A493B7, 0x6ACE1 },
	{ 0xF0A493B8, 0x6ACE3 },
	{ 0xF0A493BB, 0xFA7F8 },
	{ 0xF0A493BC, 0xFA7F9 },
	{ 0xF0A493BD, 0x6B2CE },
	{ 0xF0A493BE, 0x5AAAB },
	{ 0xF0A49480, 0x5AAA9 },
	{ 0xF0A49481, 0x6B2CF },
	{ 0xF0A49482, 0x5AAAA },
	{ 0xF0A49483, 0x6B2D1 },
	{ 0xF0A49484, 0xFACA4 },
	{ 0xF0A49485, 0xFACA5 },
	{ 0xF0A49486, 0xFACA6 },
	{ 0xF0A49487, 0x6B2CD },
	{ 0xF0A4948A, 0x6B2D0 },
	{ 0xF0A4948C, 0x5AED1 },
	{ 0xF0A4948E, 0x5AED0 },
	{ 0xF0A4948F, 0xFB0F3 },
	{ 0xF0A49490, 0x6C1D7 },
	{ 0xF0A49491, 0x6C1D6 },
	{ 0xF0A49492, 0x6C1D8 },
	{ 0xF0A49493, 0xFB6D1 },
	{ 0xF0A49494, 0x4B8EA },
	{ 0xF0A49495, 0x6CBA2 },
	{ 0xF0A49497, 0x6C7C3 },
	{ 0xF0A49498, 0x6CDDD },
	{ 0xF0A4949C, 0x6D4E8 },
	{ 0xF0A494A0, 0x6D4E9 },
	{ 0xF0A494A2, 0x6DED3 },
	{ 0xF0A494A3, 0x5C7A3 },
	{ 0xF0A494A4, 0x6DED6 },
	{ 0xF0A494A5, 0x6DED5 },
	{ 0xF0A494A6, 0x6DED4 },
	{ 0xF0A494A7, 0x7A4FA },
	{ 0xF0A494A8, 0x5CEAF },
	{ 0xF0A494A9, 0x7A4F7 },
	{ 0xF0A494AA, 0x7A4F9 },
	{ 0xF0A494AC, 0x7A4F8 },
	{ 0xF0A494AE, 0x7AFE9 },
	{ 0xF0A494B0, 0x7AFEA },
	{ 0xF0A494B1, 0x5D5BF },
	{ 0xF0A494B2, 0x4D6E5 },
	{ 0xF0A494B3, 0xFDBA4 },
	{ 0xF0A494B4, 0xFDBA5 },
	{ 0xF0A494B5, 0xFDBA6 },
	{ 0xF0A494B8, 0xFD5F3 },
	{ 0xF0A494B9, 0x7C0D6 },
	{ 0xF0A49580, 0x5E8B8 },
	{ 0xF0A49582, 0xFE5CF },
	{ 0xF0A49583, 0xFE5D0 },
	{ 0xF0A49585, 0x7CEBD },
	{ 0xF0A49588, 0x7D3E8 },
	{ 0xF0A49589, 0x7DBF1 },
	{ 0xF0A4958B, 0x7DEF9 },
	{ 0xF0A4958D, 0x7E1A2 },
	{ 0xF0A4958E, 0xFA4F3 },
	{ 0xF0A4958F, 0xFA4F4 },
	{ 0xF0A49590, 0x6ACE4 },
	{ 0xF0A49591, 0x6ACE5 },
	{ 0xF0A49593, 0x6C1D9 },
	{ 0xF0A49595, 0x6C1DA },
	{ 0xF0A49596, 0xFBDA2 },
	{ 0xF0A49597, 0xFBDA3 },
	{ 0xF0A49598, 0x6D4EA },
	{ 0xF0A49599, 0xFC9E5 },
	{ 0xF0A4959A, 0x5C7A4 },
	{ 0xF0A4959B, 0x5D5C0 },
	{ 0xF0A4959C, 0xFA1E8 },
	{ 0xF0A4959D, 0x6ABEB },
	{ 0xF0A4959E, 0x5AAAC },
	{ 0xF0A4959F, 0x4AAAB },
	{ 0xF0A495A0, 0x4ADF7 },
	{ 0xF0A495A1, 0xFB0F4 },
	{ 0xF0A495A2, 0x5B1EC },
	{ 0xF0A495A3, 0x6CBA3 },
	{ 0xF0A495A4, 0x6D4EC },
	{ 0xF0A495A5, 0x6D4EB },
	{ 0xF0A495A6, 0x5D5C1 },
	{ 0xF0A495A7, 0x7A4FB },
	{ 0xF0A495A8, 0x7A4FC },
	{ 0xF0A495A9, 0x5D5C2 },
	{ 0xF0A495AA, 0x6A2A5 },
	{ 0xF0A495AB, 0x6A3B1 },
	{ 0xF0A495AD, 0x6A5B5 },
	{ 0xF0A495AE, 0x6A8CF },
	{ 0xF0A495AF, 0x4A7AD },
	{ 0xF0A495B0, 0x6ACE7 },
	{ 0xF0A495B1, 0x6ACE6 },
	{ 0xF0A495B2, 0x6B2D2 },
	{ 0xF0A495B3, 0x4AAAD },
	{ 0xF0A495B4, 0x6B2D3 },
	{ 0xF0A495B5, 0x6B2D4 },
	{ 0xF0A495B6, 0x6B9BE },
	{ 0xF0A495B7, 0x4ADF8 },
	{ 0xF0A495B9, 0xFB0F5 },
	{ 0xF0A495BA, 0x6B9BD },
	{ 0xF0A495BB, 0x6C1DB },
	{ 0xF0A495BC, 0x6C1DE },
	{ 0xF0A495BD, 0x6C1DD },
	{ 0xF0A495BE, 0x4B2F8 },
	{ 0xF0A49681, 0x6C1DC },
	{ 0xF0A49682, 0xFB6D2 },
	{ 0xF0A49683, 0xFB6D3 },
	{ 0xF0A49685, 0x6CBA8 },
	{ 0xF0A49686, 0x6CBA4 },
	{ 0xF0A49687, 0x6CBA6 },
	{ 0xF0A49688, 0x6CBA7 },
	{ 0xF0A49689, 0x6CBA9 },
	{ 0xF0A4968A, 0x6CBA5 },
	{ 0xF0A4968B, 0x6CDD8 },
	{ 0xF0A4968C, 0x6D4ED },
	{ 0xF0A4968D, 0x6D4EE },
	{ 0xF0A4968E, 0xFC3BF },
	{ 0xF0A4968F, 0x6DED8 },
	{ 0xF0A49690, 0x6DED9 },
	{ 0xF0A49691, 0xFC9E6 },
	{ 0xF0A49693, 0x7A4FD },
	{ 0xF0A49694, 0xFD0BE },
	{ 0xF0A49695, 0x7A4FE },
	{ 0xF0A49696, 0x5D5C3 },
	{ 0xF0A49697, 0x5E2D1 },
	{ 0xF0A49698, 0x4D1AC },
	{ 0xF0A49699, 0x7AFEB },
	{ 0xF0A4969A, 0x7A5A1 },
	{ 0xF0A4969B, 0x5D5C4 },
	{ 0xF0A4969C, 0x7B9AB },
	{ 0xF0A4969D, 0x7B9AC },
	{ 0xF0A4969E, 0x5DCA5 },
	{ 0xF0A496A0, 0x7C7F0 },
	{ 0xF0A496A2, 0x5ECD2 },
	{ 0xF0A496A3, 0x7D8B9 },
	{ 0xF0A496A4, 0x7DBF2 },
	{ 0xF0A496A5, 0x7E3D8 },
	{ 0xF0A496A6, 0x5FBC2 },
	{ 0xF0A496A7, 0x7E4CF },
	{ 0xF0A496A8, 0xFA1E9 },
	{ 0xF0A496A9, 0x6A8D1 },
	{ 0xF0A496AA, 0x5A4D9 },
	{ 0xF0A496AB, 0x6A8D0 },
	{ 0xF0A496AC, 0x4A7AE },
	{ 0xF0A496AD, 0x6ACEB },
	{ 0xF0A496AE, 0x6ACEA },
	{ 0xF0A496AF, 0x6ACE9 },
	{ 0xF0A496B0, 0x6ACE8 },
	{ 0xF0A496B1, 0x6B2D6 },
	{ 0xF0A496B2, 0x6B2D5 },
	{ 0xF0A496B3, 0x5AAAD },
	{ 0xF0A496B4, 0x6B2D7 },
	{ 0xF0A496B7, 0x5AAAE },
	{ 0xF0A496BA, 0x5AED2 },
	{ 0xF0A496BB, 0x4ADF9 },
	{ 0xF0A496BC, 0x4ADFB },
	{ 0xF0A496BD, 0x6B9C1 },
	{ 0xF0A496BE, 0x6B9BF },
	{ 0xF0A49780, 0x5B3C6 },
	{ 0xF0A49781, 0x5B3C7 },
	{ 0xF0A49782, 0x6C1DF },
	{ 0xF0A49784, 0x6C1E2 },
	{ 0xF0A49785, 0x6C1E0 },
	{ 0xF0A49787, 0x6CBAB },
	{ 0xF0A49788, 0x4B8ED },
	{ 0xF0A49789, 0x6CBAE },
	{ 0xF0A4978A, 0x6CBAA },
	{ 0xF0A4978B, 0x6CBAC },
	{ 0xF0A4978C, 0x6CBAD },
	{ 0xF0A4978D, 0x5B9F3 },
	{ 0xF0A4978E, 0x5B9F6 },
	{ 0xF0A4978F, 0x5B9F4 },
	{ 0xF0A49791, 0x5B9F5 },
	{ 0xF0A49797, 0x4B8EE },
	{ 0xF0A49798, 0x5C0B8 },
	{ 0xF0A49799, 0x6D4EF },
	{ 0xF0A4979A, 0x4BECD },
	{ 0xF0A4979B, 0x5C0B6 },
	{ 0xF0A4979C, 0x5C0B7 },
	{ 0xF0A497A0, 0x6D4F0 },
	{ 0xF0A497A1, 0xFBDA4 },
	{ 0xF0A497A2, 0x5C7A5 },
	{ 0xF0A497A3, 0x6DEDB },
	{ 0xF0A497A5, 0x6DEDC },
	{ 0xF0A497A6, 0x6DEDA },
	{ 0xF0A497A7, 0xFC9E7 },
	{ 0xF0A497A8, 0x5CEB2 },
	{ 0xF0A497A9, 0x7A5A5 },
	{ 0xF0A497AA, 0x5CEB1 },
	{ 0xF0A497AB, 0x5CEB0 },
	{ 0xF0A497AC, 0x5CEB3 },
	{ 0xF0A497AD, 0x7A5A4 },
	{ 0xF0A497AE, 0x7A5A2 },
	{ 0xF0A497AF, 0x5CEB4 },
	{ 0xF0A497B1, 0x7A5A3 },
	{ 0xF0A497B3, 0x5D5C6 },
	{ 0xF0A497B4, 0x5D5C7 },
	{ 0xF0A497B5, 0x5D5C8 },
	{ 0xF0A497B6, 0x7AFED },
	{ 0xF0A497B7, 0x5D5C5 },
	{ 0xF0A497B8, 0x7AFEC },
	{ 0xF0A497BA, 0x5DCA6 },
	{ 0xF0A497BB, 0x4D6E6 },
	{ 0xF0A497BC, 0xFDBA7 },
	{ 0xF0A497BD, 0xFDBA8 },
	{ 0xF0A497BF, 0x5E2D3 },
	{ 0xF0A49880, 0x5E2D2 },
	{ 0xF0A49883, 0x5ECD3 },
	{ 0xF0A49884, 0x7D3E9 },
	{ 0xF0A49885, 0x5A3E8 },
	{ 0xF0A49888, 0x6B9C3 },
	{ 0xF0A49889, 0x6B9C2 },
	{ 0xF0A4988C, 0x4B8EF },
	{ 0xF0A4988D, 0x6CBAF },
	{ 0xF0A4988E, 0xFBDA5 },
	{ 0xF0A4988F, 0xFBDA6 },
	{ 0xF0A49890, 0x6D4F1 },
	{ 0xF0A49891, 0x6DEDD },
	{ 0xF0A49894, 0x5A1F5 },
	{ 0xF0A49895, 0xFA2E3 },
	{ 0xF0A49896, 0x6A5B6 },
	{ 0xF0A49897, 0xFA2E2 },
	{ 0xF0A49898, 0x6A8D3 },
	{ 0xF0A49899, 0xFA4F5 },
	{ 0xF0A4989A, 0x6A8D2 },
	{ 0xF0A4989B, 0x6A8D4 },
	{ 0xF0A4989C, 0x5A6F9 },
	{ 0xF0A4989D, 0x5A7A2 },
	{ 0xF0A4989E, 0x5A6F8 },
	{ 0xF0A4989F, 0x5A6FB },
	{ 0xF0A498A0, 0x5A6F6 },
	{ 0xF0A498A1, 0x5A6FD },
	{ 0xF0A498A2, 0x6ACEE },
	{ 0xF0A498A3, 0x4A7B0 },
	{ 0xF0A498A4, 0x5A7A1 },
	{ 0xF0A498A5, 0x6ACEC },
	{ 0xF0A498A6, 0x5A6FE },
	{ 0xF0A498A7, 0x5A7A3 },
	{ 0xF0A498AB, 0x5A6FC },
	{ 0xF0A498AC, 0x6ACED },
	{ 0xF0A498AD, 0xFA7FB },
	{ 0xF0A498AE, 0xFA7FC },
	{ 0xF0A498AF, 0xFA7FE },
	{ 0xF0A498B0, 0xFA8A1 },
	{ 0xF0A498B2, 0x5A6FA },
	{ 0xF0A498B3, 0x6ACEF },
	{ 0xF0A498B4, 0x6ACF0 },
	{ 0xF0A498B8, 0x5AAB2 },
	{ 0xF0A498B9, 0x5AAB0 },
	{ 0xF0A498BA, 0x5AAAF },
	{ 0xF0A498BB, 0x6B2DF },
	{ 0xF0A498BC, 0x6B2DC },
	{ 0xF0A498BD, 0x5AAB3 },
	{ 0xF0A498BE, 0x5AAB1 },
	{ 0xF0A498BF, 0x4AAB0 },
	{ 0xF0A49980, 0x6B2DA },
	{ 0xF0A49982, 0x6B2D9 },
	{ 0xF0A49983, 0xFACA8 },
	{ 0xF0A49984, 0xFACA9 },
	{ 0xF0A49989, 0x6B2DB },
	{ 0xF0A4998A, 0x6B2DE },
	{ 0xF0A4998C, 0x6B2D8 },
	{ 0xF0A4998D, 0x6B2DD },
	{ 0xF0A4998F, 0x5AAB4 },
	{ 0xF0A49990, 0xFA7FD },
	{ 0xF0A49991, 0x5AED8 },
	{ 0xF0A49992, 0x5AED4 },
	{ 0xF0A49993, 0x5AED6 },
	{ 0xF0A49994, 0x5AED7 },
	{ 0xF0A49995, 0x5AED5 },
	{ 0xF0A49997, 0x6B9C4 },
	{ 0xF0A49998, 0x5AED9 },
	{ 0xF0A4999B, 0x4B2FB },
	{ 0xF0A4999C, 0x6C1E7 },
	{ 0xF0A4999D, 0x6C1E8 },
	{ 0xF0A4999E, 0x5B3C9 },
	{ 0xF0A4999F, 0x5B9F7 },
	{ 0xF0A499A0, 0x4B2FD },
	{ 0xF0A499A1, 0x4B2FC },
	{ 0xF0A499A2, 0x5B3CB },
	{ 0xF0A499A4, 0x5B3CC },
	{ 0xF0A499A6, 0xFB6D4 },
	{ 0xF0A499A7, 0xFB6D5 },
	{ 0xF0A499A8, 0x6C1E5 },
	{ 0xF0A499AA, 0x6C1E9 },
	{ 0xF0A499AB, 0x6C1E4 },
	{ 0xF0A499AD, 0x5B3C8 },
	{ 0xF0A499B0, 0x4B8F1 },
	{ 0xF0A499B1, 0x4B8F4 },
	{ 0xF0A499B2, 0x5B9FD },
	{ 0xF0A499B3, 0x6CBB4 },
	{ 0xF0A499B4, 0x5B9F9 },
	{ 0xF0A499B5, 0x5B9FB },
	{ 0xF0A499B7, 0x5B9F8 },
	{ 0xF0A499B8, 0x6CBB2 },
	{ 0xF0A499B9, 0x6CBB5 },
	{ 0xF0A499BA, 0xFBDA7 },
	{ 0xF0A499BB, 0xFBDA8 },
	{ 0xF0A49A82, 0x6CBB3 },
	{ 0xF0A49A83, 0x6CBB0 },
	{ 0xF0A49A84, 0x6CBB1 },
	{ 0xF0A49A88, 0x5B9FA },
	{ 0xF0A49A89, 0x5B9FC },
	{ 0xF0A49A8A, 0x5B3CA },
	{ 0xF0A49A8B, 0xFBDA9 },
	{ 0xF0A49A8C, 0x6CBB6 },
	{ 0xF0A49A8D, 0x5C7AB },
	{ 0xF0A49A8E, 0x5C0BE },
	{ 0xF0A49A8F, 0x5C0BC },
	{ 0xF0A49A90, 0x4BED0 },
	{ 0xF0A49A91, 0x6DEE4 },
	{ 0xF0A49A92, 0x6D4F3 },
	{ 0xF0A49A93, 0x5C7A6 },
	{ 0xF0A49A94, 0x6D4F2 },
	{ 0xF0A49A95, 0x6D4F5 },
	{ 0xF0A49A96, 0x6D4F4 },
	{ 0xF0A49A98, 0xFC3C0 },
	{ 0xF0A49A99, 0xFC3C1 },
	{ 0xF0A49A9E, 0x5C0BD },
	{ 0xF0A49AA0, 0x6D4F7 },
	{ 0xF0A49AA8, 0x5C0BB },
	{ 0xF0A49AA9, 0x4C4E1 },
	{ 0xF0A49AAA, 0x5C7AD },
	{ 0xF0A49AAB, 0x5C7A8 },
	{ 0xF0A49AAC, 0x5C7AE },
	{ 0xF0A49AAD, 0x5C7AC },
	{ 0xF0A49AAE, 0x6DEDF },
	{ 0xF0A49AAF, 0x6DEE3 },
	{ 0xF0A49AB0, 0x5C7A7 },
	{ 0xF0A49AB1, 0x5C7AA },
	{ 0xF0A49AB2, 0x6DEE7 },
	{ 0xF0A49AB3, 0x6DEE2 },
	{ 0xF0A49AB4, 0x6DEE1 },
	{ 0xF0A49AB5, 0x5C0BA },
	{ 0xF0A49AB6, 0x6DEE6 },
	{ 0xF0A49AB8, 0xFC9E8 },
	{ 0xF0A49AB9, 0xFC9E9 },
	{ 0xF0A49ABA, 0xFC9EA },
	{ 0xF0A49ABB, 0xFC9EB },
	{ 0xF0A49ABC, 0x5C7AF },
	{ 0xF0A49ABD, 0x5C7A9 },
	{ 0xF0A49ABE, 0x6DEE0 },
	{ 0xF0A49ABF, 0x6D4F6 },
	{ 0xF0A49B82, 0x6DEE5 },
	{ 0xF0A49B88, 0xFC9EC },
	{ 0xF0A49B89, 0x5C7B0 },
	{ 0xF0A49B8A, 0x5CEB6 },
	{ 0xF0A49B8B, 0x7A5A6 },
	{ 0xF0A49B8C, 0x4CAF4 },
	{ 0xF0A49B8D, 0x5CEB9 },
	{ 0xF0A49B8E, 0x5CEBA },
	{ 0xF0A49B8F, 0x5CEB8 },
	{ 0xF0A49B90, 0x4CAF0 },
	{ 0xF0A49B91, 0x5CEB5 },
	{ 0xF0A49B95, 0xFD0BF },
	{ 0xF0A49B9B, 0x7A5A8 },
	{ 0xF0A49B9F, 0x7A5A7 },
	{ 0xF0A49BA1, 0x7AFF0 },
	{ 0xF0A49BA2, 0x5D5C9 },
	{ 0xF0A49BA3, 0x5D5CE },
	{ 0xF0A49BA4, 0x7AFF1 },
	{ 0xF0A49BA5, 0x5D5CB },
	{ 0xF0A49BA6, 0x5D5CD },
	{ 0xF0A49BA7, 0x5D5CA },
	{ 0xF0A49BA9, 0x5D5CC },
	{ 0xF0A49BAB, 0x7AFEF },
	{ 0xF0A49BAF, 0x7B9B0 },
	{ 0xF0A49BB0, 0x7B9AE },
	{ 0xF0A49BB1, 0x5DCA7 },
	{ 0xF0A49BB2, 0x4D6E8 },
	{ 0xF0A49BB3, 0x4D6E9 },
	{ 0xF0A49BB4, 0x7AFEE },
	{ 0xF0A49BB6, 0x7B9AF },
	{ 0xF0A49BB9, 0x7C0D7 },
	{ 0xF0A49BBA, 0x7C0D8 },
	{ 0xF0A49BBB, 0x5E8BA },
	{ 0xF0A49BBD, 0x7D3EA },
	{ 0xF0A49BBE, 0x7C7F2 },
	{ 0xF0A49BBF, 0x7C7F3 },
	{ 0xF0A49C80, 0x7C7F1 },
	{ 0xF0A49C82, 0x5E8B9 },
	{ 0xF0A49C83, 0x7CEBF },
	{ 0xF0A49C84, 0x5ECD4 },
	{ 0xF0A49C85, 0x5ECD5 },
	{ 0xF0A49C87, 0x5F0C5 },
	{ 0xF0A49C88, 0x7D3EC },
	{ 0xF0A49C89, 0x5F0C4 },
	{ 0xF0A49C8B, 0x5F0C6 },
	{ 0xF0A49C8C, 0x7D8BA },
	{ 0xF0A49C8D, 0x5F3D9 },
	{ 0xF0A49C8F, 0x7DBF4 },
	{ 0xF0A49C90, 0x5F3D8 },
	{ 0xF0A49C91, 0x7DBF5 },
	{ 0xF0A49C92, 0x7DBF3 },
	{ 0xF0A49C94, 0x5F7E9 },
	{ 0xF0A49C96, 0x7E1A3 },
	{ 0xF0A49C97, 0xFECB1 },
	{ 0xF0A49C99, 0x7E4D0 },
	{ 0xF0A49C9A, 0xFA1BD },
	{ 0xF0A49C9B, 0x6A3B2 },
	{ 0xF0A49C9C, 0x5A1F7 },
	{ 0xF0A49C9D, 0x5A1F8 },
	{ 0xF0A49CA1, 0x5A2F8 },
	{ 0xF0A49CA2, 0x5A2FB },
	{ 0xF0A49CA3, 0x5A2F7 },
	{ 0xF0A49CA4, 0x4A3A8 },
	{ 0xF0A49CA6, 0x5A2FA },
	{ 0xF0A49CA8, 0x6A5B7 },
	{ 0xF0A49CAB, 0x5A2F9 },
	{ 0xF0A49CAF, 0x5A4DE },
	{ 0xF0A49CB0, 0x5A4DF },
	{ 0xF0A49CB1, 0x4A4DB },
	{ 0xF0A49CB2, 0x4A7B7 },
	{ 0xF0A49CB3, 0x6A8D8 },
	{ 0xF0A49CB4, 0x4A4DA },
	{ 0xF0A49CB5, 0x5A4DA },
	{ 0xF0A49CB6, 0x6A8DE },
	{ 0xF0A49CB7, 0x5A4DB },
	{ 0xF0A49CB8, 0x6A8DB },
	{ 0xF0A49CB9, 0x5A7AF },
	{ 0xF0A49CBA, 0x6ACF2 },
	{ 0xF0A49CBB, 0x4A4D7 },
	{ 0xF0A49CBC, 0x5A4DD },
	{ 0xF0A49CBD, 0x5A4DC },
	{ 0xF0A49CBE, 0x6A8DA },
	{ 0xF0A49CBF, 0x6A8D9 },
	{ 0xF0A49D80, 0x6ACF3 },
	{ 0xF0A49D81, 0xFA4F7 },
	{ 0xF0A49D82, 0x6A8D7 },
	{ 0xF0A49D83, 0x6A8DC },
	{ 0xF0A49D86, 0x6A8DD },
	{ 0xF0A49D8C, 0x6A8D6 },
	{ 0xF0A49D8D, 0x4A4D8 },
	{ 0xF0A49D8F, 0x6ACFA },
	{ 0xF0A49D90, 0x5A7A8 },
	{ 0xF0A49D91, 0x6ACFB },
	{ 0xF0A49D92, 0x5A7AC },
	{ 0xF0A49D93, 0x6ACF9 },
	{ 0xF0A49D94, 0x6ACFC },
	{ 0xF0A49D95, 0x5A7A7 },
	{ 0xF0A49D96, 0x5A7AA },
	{ 0xF0A49D97, 0x6ACF8 },
	{ 0xF0A49D98, 0x5A7AD },
	{ 0xF0A49D99, 0x5A7A5 },
	{ 0xF0A49D9A, 0x5A7A9 },
	{ 0xF0A49D9B, 0x5A7A4 },
	{ 0xF0A49D9C, 0x6ACF7 },
	{ 0xF0A49D9E, 0x4A7B8 },
	{ 0xF0A49D9F, 0x5AAB6 },
	{ 0xF0A49DA0, 0x6A8D5 },
	{ 0xF0A49DA1, 0x6B2E0 },
	{ 0xF0A49DA3, 0x5A7AB },
	{ 0xF0A49DA4, 0x6ACF6 },
	{ 0xF0A49DA5, 0xFA8A2 },
	{ 0xF0A49DA6, 0x6ACFD },
	{ 0xF0A49DA8, 0x6ACF4 },
	{ 0xF0A49DAC, 0x4A7B5 },
	{ 0xF0A49DAE, 0x5AAB5 },
	{ 0xF0A49DAF, 0x5AABE },
	{ 0xF0A49DB0, 0x6B2E8 },
	{ 0xF0A49DB1, 0x5AAB9 },
	{ 0xF0A49DB2, 0x6B9CB },
	{ 0xF0A49DB3, 0x5AABD },
	{ 0xF0A49DB4, 0x6B2E1 },
	{ 0xF0A49DB5, 0x6B9CC },
	{ 0xF0A49DB6, 0x6C1EC },
	{ 0xF0A49DB7, 0x5AABC },
	{ 0xF0A49DB8, 0x4AAB1 },
	{ 0xF0A49DB9, 0x5AABB },
	{ 0xF0A49DBA, 0x6B2E4 },
	{ 0xF0A49DBB, 0x5AABA },
	{ 0xF0A49DBC, 0x6B2E6 },
	{ 0xF0A49DBD, 0x4AAB3 },
	{ 0xF0A49DBE, 0x5AAC0 },
	{ 0xF0A49DBF, 0x6B2E3 },
	{ 0xF0A49E80, 0x5A7A6 },
	{ 0xF0A49E81, 0x5AAB7 },
	{ 0xF0A49E82, 0x5AAB8 },
	{ 0xF0A49E84, 0xFACAA },
	{ 0xF0A49E85, 0xFACAC },
	{ 0xF0A49E86, 0xFACAD },
	{ 0xF0A49E88, 0x6B2E5 },
	{ 0xF0A49E8F, 0xFACAB },
	{ 0xF0A49E97, 0x5AABF },
	{ 0xF0A49E99, 0x6B9CE },
	{ 0xF0A49E9A, 0x5AEDE },
	{ 0xF0A49E9B, 0x4B3A1 },
	{ 0xF0A49E9C, 0x6B9C9 },
	{ 0xF0A49E9D, 0x6B9CD },
	{ 0xF0A49E9E, 0x4AEA5 },
	{ 0xF0A49E9F, 0x5AEDB },
	{ 0xF0A49EA0, 0x5AEE0 },
	{ 0xF0A49EA1, 0x5AEDD },
	{ 0xF0A49EA2, 0x4AEA3 },
	{ 0xF0A49EA3, 0x6B9C5 },
	{ 0xF0A49EA5, 0x6B9CA },
	{ 0xF0A49EAC, 0xFB0F7 },
	{ 0xF0A49EAD, 0xFB0F8 },
	{ 0xF0A49EAF, 0x6B9C8 },
	{ 0xF0A49EB0, 0x5AEDA },
	{ 0xF0A49EB2, 0x4AEA4 },
	{ 0xF0A49EB8, 0x6B9C7 },
	{ 0xF0A49EB9, 0x6B9CF },
	{ 0xF0A49EBE, 0x5AEDF },
	{ 0xF0A49EBF, 0x6B9C6 },
	{ 0xF0A49F80, 0x5B3CE },
	{ 0xF0A49F81, 0xFB0F6 },
	{ 0xF0A49F83, 0x4B3A4 },
	{ 0xF0A49F84, 0x6C1EE },
	{ 0xF0A49F85, 0x5B3D5 },
	{ 0xF0A49F86, 0x5B9FE },
	{ 0xF0A49F87, 0x5B3D2 },
	{ 0xF0A49F88, 0x6C1F0 },
	{ 0xF0A49F89, 0x6C1F3 },
	{ 0xF0A49F8A, 0x5B3CF },
	{ 0xF0A49F8B, 0x6C1EF },
	{ 0xF0A49F8C, 0x6CBBB },
	{ 0xF0A49F8D, 0x4B3A6 },
	{ 0xF0A49F8E, 0x5B3D3 },
	{ 0xF0A49F8F, 0x6CBB8 },
	{ 0xF0A49F90, 0x6CBB7 },
	{ 0xF0A49F91, 0x5B3D0 },
	{ 0xF0A49F92, 0x6CBB9 },
	{ 0xF0A49F94, 0x6C1F1 },
	{ 0xF0A49F95, 0x6C1F2 },
	{ 0xF0A49F97, 0x6C1F4 },
	{ 0xF0A49F99, 0x6CBBA },
	{ 0xF0A49F9A, 0x5BAA8 },
	{ 0xF0A49F9C, 0x6D4FB },
	{ 0xF0A49F9D, 0x5BAA6 },
	{ 0xF0A49F9E, 0x5C0BF },
	{ 0xF0A49F9F, 0x4B8F5 },
	{ 0xF0A49FA0, 0x5BAA2 },
	{ 0xF0A49FA1, 0x6CBC4 },
	{ 0xF0A49FA2, 0x5C0C0 },
	{ 0xF0A49FA3, 0x5BAA7 },
	{ 0xF0A49FA4, 0x4B8F6 },
	{ 0xF0A49FA5, 0x5BAA5 },
	{ 0xF0A49FA6, 0x5BAA4 },
	{ 0xF0A49FA7, 0x4B8F8 },
	{ 0xF0A49FA8, 0x6CBBF },
	{ 0xF0A49FA9, 0x4BED1 },
	{ 0xF0A49FAA, 0x5BAA1 },
	{ 0xF0A49FAB, 0x6CBBC },
	{ 0xF0A49FAC, 0x6CBBE },
	{ 0xF0A49FAD, 0x4BED7 },
	{ 0xF0A49FB2, 0xFBDAA },
	{ 0xF0A49FB3, 0xFBDAB },
	{ 0xF0A49FB4, 0x6D4F9 },
	{ 0xF0A49FB5, 0x6D2F2 },
	{ 0xF0A49FB6, 0x6D4FA },
	{ 0xF0A49FB8, 0x6CBC0 },
	{ 0xF0A49FBA, 0x6CBC1 },
	{ 0xF0A49FBB, 0x6CBC5 },
	{ 0xF0A49FBD, 0x6CBBD },
	{ 0xF0A4A087, 0x5BAA3 },
	{ 0xF0A4A08A, 0xFC3C3 },
	{ 0xF0A4A08D, 0x4BED6 },
	{ 0xF0A4A08E, 0x5C0C8 },
	{ 0xF0A4A08F, 0x6D5A2 },
	{ 0xF0A4A090, 0x5C0C7 },
	{ 0xF0A4A091, 0x4BED5 },
	{ 0xF0A4A092, 0x6D5A7 },
	{ 0xF0A4A093, 0x5C0CB },
	{ 0xF0A4A094, 0x6D5A4 },
	{ 0xF0A4A095, 0x6D4FE },
	{ 0xF0A4A096, 0x6D4FD },
	{ 0xF0A4A097, 0x6D5A6 },
	{ 0xF0A4A098, 0x5C0C6 },
	{ 0xF0A4A099, 0x5C0C4 },
	{ 0xF0A4A09A, 0x5C0C3 },
	{ 0xF0A4A09C, 0x6D5A1 },
	{ 0xF0A4A09D, 0x5C0C2 },
	{ 0xF0A4A09E, 0x6D5A8 },
	{ 0xF0A4A09F, 0x5C0CA },
	{ 0xF0A4A0A0, 0x5C0C1 },
	{ 0xF0A4A0A1, 0x4BED8 },
	{ 0xF0A4A0A4, 0x5C0C9 },
	{ 0xF0A4A0A5, 0x6D5A5 },
	{ 0xF0A4A0A6, 0xFC3C5 },
	{ 0xF0A4A0A7, 0xFC3C6 },
	{ 0xF0A4A0A8, 0xFC9F0 },
	{ 0xF0A4A0A9, 0xFD0C0 },
	{ 0xF0A4A0AB, 0x5C0C5 },
	{ 0xF0A4A0AC, 0x6D5A3 },
	{ 0xF0A4A0B5, 0x5C0CC },
	{ 0xF0A4A0B9, 0x6DEED },
	{ 0xF0A4A0BA, 0x5C7BA },
	{ 0xF0A4A0BB, 0x6DEE9 },
	{ 0xF0A4A0BC, 0x7A5A9 },
	{ 0xF0A4A0BD, 0x5C7B7 },
	{ 0xF0A4A0BE, 0x4C4EB },
	{ 0xF0A4A0BF, 0x5C7B5 },
	{ 0xF0A4A180, 0x5C7B3 },
	{ 0xF0A4A181, 0x6DEEC },
	{ 0xF0A4A182, 0x5C7BB },
	{ 0xF0A4A183, 0x5C7B6 },
	{ 0xF0A4A184, 0x5C7B4 },
	{ 0xF0A4A185, 0x6DEF0 },
	{ 0xF0A4A186, 0x4C4EC },
	{ 0xF0A4A187, 0x5C7B1 },
	{ 0xF0A4A18D, 0xFC9ED },
	{ 0xF0A4A18E, 0x7A5AA },
	{ 0xF0A4A190, 0xFC9EF },
	{ 0xF0A4A191, 0x6DEEB },
	{ 0xF0A4A197, 0x6DEE8 },
	{ 0xF0A4A198, 0x6DEEA },
	{ 0xF0A4A199, 0x6DEEF },
	{ 0xF0A4A19C, 0x4CAFD },
	{ 0xF0A4A19D, 0x5C7BD },
	{ 0xF0A4A19E, 0x5C7BC },
	{ 0xF0A4A19F, 0x5C7B9 },
	{ 0xF0A4A1A0, 0x5C7B8 },
	{ 0xF0A4A1A1, 0x6DEF1 },
	{ 0xF0A4A1A2, 0x5C7B2 },
	{ 0xF0A4A1A3, 0x7A5B1 },
	{ 0xF0A4A1A4, 0x4CAF8 },
	{ 0xF0A4A1A5, 0x4CAF9 },
	{ 0xF0A4A1A6, 0x7A5B0 },
	{ 0xF0A4A1A7, 0x5CEBC },
	{ 0xF0A4A1A8, 0x7A5B4 },
	{ 0xF0A4A1A9, 0x7AFF3 },
	{ 0xF0A4A1AA, 0x5CEC1 },
	{ 0xF0A4A1AB, 0x7A5AF },
	{ 0xF0A4A1AC, 0x7A5AB },
	{ 0xF0A4A1AD, 0x5CEBE },
	{ 0xF0A4A1AE, 0x5CEC5 },
	{ 0xF0A4A1B0, 0x5CEBB },
	{ 0xF0A4A1B1, 0x5CEC4 },
	{ 0xF0A4A1B2, 0x5CEC3 },
	{ 0xF0A4A1B3, 0x5CEBD },
	{ 0xF0A4A1B4, 0x5D5CF },
	{ 0xF0A4A1B5, 0x7AFF2 },
	{ 0xF0A4A1B6, 0x5CEBF },
	{ 0xF0A4A1B9, 0x5CEC0 },
	{ 0xF0A4A1BA, 0x5CEC6 },
	{ 0xF0A4A1BB, 0x7A5AC },
	{ 0xF0A4A1BC, 0x7A5AD },
	{ 0xF0A4A1BD, 0xFD5F5 },
	{ 0xF0A4A1BF, 0x5D5D0 },
	{ 0xF0A4A283, 0x7A5AE },
	{ 0xF0A4A285, 0x7A5B3 },
	{ 0xF0A4A289, 0xFC9EE },
	{ 0xF0A4A28A, 0x4D1B3 },
	{ 0xF0A4A28B, 0x5CEC2 },
	{ 0xF0A4A28C, 0x5D5D7 },
	{ 0xF0A4A28D, 0x4D1B5 },
	{ 0xF0A4A28E, 0x5D5D5 },
	{ 0xF0A4A28F, 0x5D5D1 },
	{ 0xF0A4A290, 0x5D5D2 },
	{ 0xF0A4A291, 0x7AFF9 },
	{ 0xF0A4A292, 0x4D1B1 },
	{ 0xF0A4A293, 0x7AFF8 },
	{ 0xF0A4A294, 0x7AFF7 },
	{ 0xF0A4A295, 0x5DCA8 },
	{ 0xF0A4A296, 0x4D1B6 },
	{ 0xF0A4A297, 0x5D5D3 },
	{ 0xF0A4A298, 0x5D5D6 },
	{ 0xF0A4A299, 0x7AFF5 },
	{ 0xF0A4A29A, 0x7B9B2 },
	{ 0xF0A4A29C, 0x4D6ED },
	{ 0xF0A4A29D, 0x7B9B1 },
	{ 0xF0A4A29E, 0x7AFF6 },
	{ 0xF0A4A2A0, 0x7A5B2 },
	{ 0xF0A4A2A1, 0xFD5F7 },
	{ 0xF0A4A2A2, 0x7A5B5 },
	{ 0xF0A4A2A3, 0x5D5D4 },
	{ 0xF0A4A2A6, 0x5DCAA },
	{ 0xF0A4A2A7, 0x7B9B3 },
	{ 0xF0A4A2A8, 0x5DCA9 },
	{ 0xF0A4A2A9, 0x7C7F7 },
	{ 0xF0A4A2AA, 0x7B9B5 },
	{ 0xF0A4A2AF, 0x7B9B4 },
	{ 0xF0A4A2B0, 0xFDBA9 },
	{ 0xF0A4A2B1, 0xFDBAA },
	{ 0xF0A4A2B2, 0xFDBAB },
	{ 0xF0A4A2B3, 0xFDBAC },
	{ 0xF0A4A2B4, 0x7C0DD },
	{ 0xF0A4A2B5, 0x5E2D5 },
	{ 0xF0A4A2B6, 0x5E2D4 },
	{ 0xF0A4A2B7, 0x7C0DA },
	{ 0xF0A4A2B8, 0x7C0D9 },
	{ 0xF0A4A2B9, 0x7C0DC },
	{ 0xF0A4A2BA, 0x4DBE8 },
	{ 0xF0A4A2BB, 0x7C0DB },
	{ 0xF0A4A380, 0xFDFCE },
	{ 0xF0A4A381, 0xFDFCF },
	{ 0xF0A4A383, 0x5E2D6 },
	{ 0xF0A4A385, 0x4E3E4 },
	{ 0xF0A4A388, 0x7C7F8 },
	{ 0xF0A4A389, 0x7CEC0 },
	{ 0xF0A4A38A, 0x7C7F6 },
	{ 0xF0A4A38B, 0x7C7F4 },
	{ 0xF0A4A38D, 0x7CEC1 },
	{ 0xF0A4A38E, 0x5ECD6 },
	{ 0xF0A4A390, 0x7CEC2 },
	{ 0xF0A4A391, 0x5F0C8 },
	{ 0xF0A4A392, 0x7D3ED },
	{ 0xF0A4A393, 0x5F0C7 },
	{ 0xF0A4A397, 0x4E8F4 },
	{ 0xF0A4A398, 0x5F0C9 },
	{ 0xF0A4A399, 0x7D8BB },
	{ 0xF0A4A39B, 0x7DBF6 },
	{ 0xF0A4A39C, 0x7DBF8 },
	{ 0xF0A4A39D, 0x7DBF7 },
	{ 0xF0A4A39F, 0x5F7EA },
	{ 0xF0A4A3A0, 0x7DEFA },
	{ 0xF0A4A3A2, 0xFEBD5 },
	{ 0xF0A4A3A3, 0x7E1A4 },
	{ 0xF0A4A3A4, 0x7E3D9 },
	{ 0xF0A4A3A6, 0xFA8A3 },
	{ 0xF0A4A3A7, 0x6CBC6 },
	{ 0xF0A4A3A8, 0x6DEF2 },
	{ 0xF0A4A3A9, 0x5A1CC },
	{ 0xF0A4A3AA, 0x6A5B8 },
	{ 0xF0A4A3AB, 0x6A3B3 },
	{ 0xF0A4A3AE, 0x6A8DF },
	{ 0xF0A4A3AF, 0x5A4E1 },
	{ 0xF0A4A3B0, 0x4A4DD },
	{ 0xF0A4A3B2, 0x4A4DC },
	{ 0xF0A4A3B4, 0x6A8E1 },
	{ 0xF0A4A3B5, 0x6A8E0 },
	{ 0xF0A4A3B7, 0xFA4F9 },
	{ 0xF0A4A3B8, 0x5A4E0 },
	{ 0xF0A4A3B9, 0x5A7B0 },
	{ 0xF0A4A3BA, 0x6ADA5 },
	{ 0xF0A4A3BB, 0x4A7BC },
	{ 0xF0A4A3BC, 0x5AAC1 },
	{ 0xF0A4A482, 0xFA8A5 },
	{ 0xF0A4A483, 0xFA8A6 },
	{ 0xF0A4A484, 0xFA8A7 },
	{ 0xF0A4A485, 0xFA8A8 },
	{ 0xF0A4A486, 0xFA8A9 },
	{ 0xF0A4A488, 0x6ADA3 },
	{ 0xF0A4A48B, 0xFACC0 },
	{ 0xF0A4A48C, 0xFA8A4 },
	{ 0xF0A4A48D, 0x6ADA2 },
	{ 0xF0A4A48E, 0xFACBC },
	{ 0xF0A4A48F, 0x6B2E9 },
	{ 0xF0A4A490, 0x5AAC5 },
	{ 0xF0A4A491, 0x5AAC2 },
	{ 0xF0A4A492, 0x4AAB6 },
	{ 0xF0A4A493, 0x6B2EB },
	{ 0xF0A4A498, 0x6AFE9 },
	{ 0xF0A4A49A, 0xFACAF },
	{ 0xF0A4A49B, 0xFACB0 },
	{ 0xF0A4A49C, 0xFACB1 },
	{ 0xF0A4A49D, 0xFACB3 },
	{ 0xF0A4A49E, 0xFACB4 },
	{ 0xF0A4A49F, 0xFACB5 },
	{ 0xF0A4A4A0, 0xFACB6 },
	{ 0xF0A4A4A1, 0xFACB7 },
	{ 0xF0A4A4A2, 0xFACB8 },
	{ 0xF0A4A4A3, 0xFACBA },
	{ 0xF0A4A4A4, 0xFACBB },
	{ 0xF0A4A4A5, 0xFACBD },
	{ 0xF0A4A4A8, 0x6B2EA },
	{ 0xF0A4A4AA, 0x6B2EC },
	{ 0xF0A4A4AB, 0xFACBE },
	{ 0xF0A4A4AC, 0xFACBF },
	{ 0xF0A4A4AF, 0xFACAE },
	{ 0xF0A4A4B1, 0x5AAC4 },
	{ 0xF0A4A4B2, 0x5AAC3 },
	{ 0xF0A4A4B5, 0x6B9D3 },
	{ 0xF0A4A4B6, 0x5B3D6 },
	{ 0xF0A4A4B7, 0x5AEE1 },
	{ 0xF0A4A4B8, 0x4AEA9 },
	{ 0xF0A4A4B9, 0x6B9D1 },
	{ 0xF0A4A4BA, 0x4AEA8 },
	{ 0xF0A4A4BB, 0x6B9D2 },
	{ 0xF0A4A4BC, 0x6B9D4 },
	{ 0xF0A4A583, 0xFB0F9 },
	{ 0xF0A4A584, 0xFB0FA },
	{ 0xF0A4A585, 0xFB0FB },
	{ 0xF0A4A586, 0xFB0FC },
	{ 0xF0A4A587, 0xFB0FD },
	{ 0xF0A4A588, 0xFB0FE },
	{ 0xF0A4A589, 0xFB1A1 },
	{ 0xF0A4A58A, 0xFB1A3 },
	{ 0xF0A4A58B, 0xFB1A4 },
	{ 0xF0A4A58C, 0xFB1A5 },
	{ 0xF0A4A58D, 0xFB1A6 },
	{ 0xF0A4A58E, 0x6B9D0 },
	{ 0xF0A4A58F, 0xFB6E3 },
	{ 0xF0A4A594, 0x4B3B1 },
	{ 0xF0A4A595, 0x6B9D5 },
	{ 0xF0A4A596, 0x6C1FA },
	{ 0xF0A4A597, 0x5B3D7 },
	{ 0xF0A4A598, 0x6C1FB },
	{ 0xF0A4A599, 0x4B3B2 },
	{ 0xF0A4A59A, 0x6C1F7 },
	{ 0xF0A4A59B, 0x6C1F8 },
	{ 0xF0A4A59C, 0x6C1F9 },
	{ 0xF0A4A5A4, 0xFB1A2 },
	{ 0xF0A4A5A5, 0xFB6D6 },
	{ 0xF0A4A5A6, 0xFB6D8 },
	{ 0xF0A4A5A7, 0xFB6DC },
	{ 0xF0A4A5A8, 0xFB6DF },
	{ 0xF0A4A5A9, 0xFB6E0 },
	{ 0xF0A4A5AA, 0xFB6E1 },
	{ 0xF0A4A5AB, 0xFB6E2 },
	{ 0xF0A4A5AC, 0xFB6E4 },
	{ 0xF0A4A5AD, 0xFB6DD },
	{ 0xF0A4A5B1, 0x6C1FC },
	{ 0xF0A4A5B4, 0xFB6DB },
	{ 0xF0A4A5B5, 0xFB6DA },
	{ 0xF0A4A5B6, 0xFB6DE },
	{ 0xF0A4A5B7, 0x5B3D8 },
	{ 0xF0A4A5B8, 0x6C1F6 },
	{ 0xF0A4A5B9, 0xFBDBE },
	{ 0xF0A4A5BB, 0xFBDB4 },
	{ 0xF0A4A5BC, 0x6CBCB },
	{ 0xF0A4A5BD, 0x5BAAB },
	{ 0xF0A4A5BE, 0x5BAAA },
	{ 0xF0A4A5BF, 0x5BAAC },
	{ 0xF0A4A680, 0x6D5A9 },
	{ 0xF0A4A681, 0x4BEDA },
	{ 0xF0A4A683, 0x5C0CD },
	{ 0xF0A4A685, 0xFBDB8 },
	{ 0xF0A4A690, 0x4B8FC },
	{ 0xF0A4A691, 0x6CBC9 },
	{ 0xF0A4A692, 0x6CBCC },
	{ 0xF0A4A693, 0xFBDAC },
	{ 0xF0A4A694, 0xFBDAD },
	{ 0xF0A4A695, 0xFBDAE },
	{ 0xF0A4A696, 0xFBDAF },
	{ 0xF0A4A697, 0xFBDB0 },
	{ 0xF0A4A698, 0xFBDB2 },
	{ 0xF0A4A699, 0xFBDB5 },
	{ 0xF0A4A69A, 0xFBDB6 },
	{ 0xF0A4A69B, 0xFBDB7 },
	{ 0xF0A4A69C, 0xFBDB9 },
	{ 0xF0A4A69D, 0xFBDBA },
	{ 0xF0A4A69E, 0xFBDBF },
	{ 0xF0A4A69F, 0xFC3D0 },
	{ 0xF0A4A6A0, 0x6CBCE },
	{ 0xF0A4A6A1, 0x6D5B2 },
	{ 0xF0A4A6A2, 0x6CBCD },
	{ 0xF0A4A6A4, 0xFBDC0 },
	{ 0xF0A4A6A5, 0x6CBC8 },
	{ 0xF0A4A6A6, 0x6CBCA },
	{ 0xF0A4A6A8, 0x6D5AA },
	{ 0xF0A4A6AB, 0xFBDB3 },
	{ 0xF0A4A6AC, 0xFBDBD },
	{ 0xF0A4A6AD, 0xFBDB1 },
	{ 0xF0A4A6AE, 0x5BAA9 },
	{ 0xF0A4A6AF, 0x6D5AB },
	{ 0xF0A4A6B0, 0x6D5B0 },
	{ 0xF0A4A6B1, 0x4BEDB },
	{ 0xF0A4A6B2, 0x6D5B1 },
	{ 0xF0A4A6B3, 0x6D5AF },
	{ 0xF0A4A6B4, 0x6D5AE },
	{ 0xF0A4A6BC, 0x5C7BE },
	{ 0xF0A4A6BD, 0xFC3C7 },
	{ 0xF0A4A6BE, 0xFC3CA },
	{ 0xF0A4A6BF, 0xFC3CC },
	{ 0xF0A4A780, 0xFC3CD },
	{ 0xF0A4A781, 0xFC3CE },
	{ 0xF0A4A782, 0xFC3CF },
	{ 0xF0A4A783, 0xFC3D1 },
	{ 0xF0A4A784, 0xFC3D2 },
	{ 0xF0A4A785, 0xFC3D3 },
	{ 0xF0A4A786, 0xFC3D4 },
	{ 0xF0A4A787, 0xFC3D5 },
	{ 0xF0A4A788, 0xFC3D7 },
	{ 0xF0A4A789, 0xFC3D8 },
	{ 0xF0A4A78A, 0xFC3DA },
	{ 0xF0A4A78B, 0xFC3DB },
	{ 0xF0A4A78C, 0xFC3DC },
	{ 0xF0A4A78D, 0xFC3DD },
	{ 0xF0A4A78E, 0xFC3DE },
	{ 0xF0A4A78F, 0xFC3DF },
	{ 0xF0A4A790, 0xFC3E0 },
	{ 0xF0A4A791, 0xFC3E1 },
	{ 0xF0A4A792, 0xFC3E2 },
	{ 0xF0A4A793, 0xFC3E3 },
	{ 0xF0A4A794, 0xFC3E5 },
	{ 0xF0A4A796, 0x6D5AC },
	{ 0xF0A4A797, 0x5C0CF },
	{ 0xF0A4A799, 0x5BAAE },
	{ 0xF0A4A79E, 0xFC3CB },
	{ 0xF0A4A79F, 0xFC3C8 },
	{ 0xF0A4A7A0, 0x5C7BF },
	{ 0xF0A4A7A2, 0x6D5AD },
	{ 0xF0A4A7A3, 0xFC3D9 },
	{ 0xF0A4A7A4, 0xFC9FA },
	{ 0xF0A4A7A5, 0xFC9FB },
	{ 0xF0A4A7A6, 0xFCAA6 },
	{ 0xF0A4A7A7, 0x7A5B8 },
	{ 0xF0A4A7AA, 0x6DEF4 },
	{ 0xF0A4A7AB, 0x5C7C1 },
	{ 0xF0A4A7AC, 0x7A5B6 },
	{ 0xF0A4A7AD, 0x4C4ED },
	{ 0xF0A4A7AE, 0x5C7C0 },
	{ 0xF0A4A7AF, 0x6DEF5 },
	{ 0xF0A4A7B0, 0x6DEF7 },
	{ 0xF0A4A7B2, 0x6DEF6 },
	{ 0xF0A4A7BA, 0x6DEF3 },
	{ 0xF0A4A7BB, 0xFC9F1 },
	{ 0xF0A4A7BC, 0xFC9F2 },
	{ 0xF0A4A7BD, 0xFC9F3 },
	{ 0xF0A4A7BE, 0xFC9F4 },
	{ 0xF0A4A7BF, 0xFC9F5 },
	{ 0xF0A4A880, 0xFC9F7 },
	{ 0xF0A4A881, 0xFC9F8 },
	{ 0xF0A4A882, 0xFC9F9 },
	{ 0xF0A4A883, 0xFC9FC },
	{ 0xF0A4A884, 0xFC9FD },
	{ 0xF0A4A885, 0xFC9FE },
	{ 0xF0A4A886, 0xFCAA1 },
	{ 0xF0A4A887, 0xFCAA2 },
	{ 0xF0A4A888, 0xFCAA4 },
	{ 0xF0A4A889, 0xFCAA5 },
	{ 0xF0A4A88A, 0xFCAA7 },
	{ 0xF0A4A88B, 0xFCAA8 },
	{ 0xF0A4A88C, 0xFCAA9 },
	{ 0xF0A4A88D, 0x5C7C2 },
	{ 0xF0A4A88F, 0x3C8A6 },
	{ 0xF0A4A890, 0x7A5B9 },
	{ 0xF0A4A893, 0xFCAA3 },
	{ 0xF0A4A894, 0x7A5C0 },
	{ 0xF0A4A895, 0x4CAFE },
	{ 0xF0A4A896, 0x5CEC7 },
	{ 0xF0A4A897, 0x7AFFB },
	{ 0xF0A4A898, 0x7A5BA },
	{ 0xF0A4A899, 0x7AFFA },
	{ 0xF0A4A89A, 0x7A5BC },
	{ 0xF0A4A89B, 0x7A5BF },
	{ 0xF0A4A89C, 0x7A5C1 },
	{ 0xF0A4A89D, 0x7A5C2 },
	{ 0xF0A4A8AB, 0xFD0C1 },
	{ 0xF0A4A8AC, 0xFD0C2 },
	{ 0xF0A4A8AD, 0xFD0C3 },
	{ 0xF0A4A8AE, 0xFD0C4 },
	{ 0xF0A4A8AF, 0xFD0C5 },
	{ 0xF0A4A8B0, 0xFD0C6 },
	{ 0xF0A4A8B1, 0xFD0C8 },
	{ 0xF0A4A8B2, 0xFD0C9 },
	{ 0xF0A4A8B3, 0xFD0CA },
	{ 0xF0A4A8B4, 0xFD0CB },
	{ 0xF0A4A8B5, 0xFD0CC },
	{ 0xF0A4A8B8, 0x7A5BD },
	{ 0xF0A4A8B9, 0x5CEC8 },
	{ 0xF0A4A8BA, 0x7A5BB },
	{ 0xF0A4A8BB, 0x5CEC9 },
	{ 0xF0A4A8BC, 0xFD5FC },
	{ 0xF0A4A8BD, 0xFD6AE },
	{ 0xF0A4A8BE, 0xFD0C7 },
	{ 0xF0A4A980, 0x7B0A2 },
	{ 0xF0A4A981, 0x7A5BE },
	{ 0xF0A4A982, 0x5D5D8 },
	{ 0xF0A4A983, 0x5D5DB },
	{ 0xF0A4A984, 0x5D5D9 },
	{ 0xF0A4A985, 0x4D1BB },
	{ 0xF0A4A986, 0x7B0A4 },
	{ 0xF0A4A987, 0x7AFFD },
	{ 0xF0A4A988, 0x7AFFE },
	{ 0xF0A4A989, 0x7AFFC },
	{ 0xF0A4A98B, 0x4D1BC },
	{ 0xF0A4A992, 0x7B0A1 },
	{ 0xF0A4A993, 0xFD5F8 },
	{ 0xF0A4A994, 0xFD5F9 },
	{ 0xF0A4A995, 0xFD5FB },
	{ 0xF0A4A996, 0xFD5FD },
	{ 0xF0A4A997, 0xFD6A3 },
	{ 0xF0A4A998, 0xFD6A4 },
	{ 0xF0A4A999, 0xFD6A5 },
	{ 0xF0A4A99A, 0xFD6A6 },
	{ 0xF0A4A99B, 0xFD6A7 },
	{ 0xF0A4A99C, 0xFD6A9 },
	{ 0xF0A4A99D, 0xFD6AD },
	{ 0xF0A4A99E, 0xFD6AF },
	{ 0xF0A4A99F, 0x7B0A5 },
	{ 0xF0A4A9A3, 0x7B0A3 },
	{ 0xF0A4A9A4, 0x7B9B6 },
	{ 0xF0A4A9A5, 0xFD6B0 },
	{ 0xF0A4A9A6, 0xFD6A1 },
	{ 0xF0A4A9A7, 0xFD6A8 },
	{ 0xF0A4A9A8, 0x5D5DC },
	{ 0xF0A4A9A9, 0x5D5DA },
	{ 0xF0A4A9AA, 0xFD6AC },
	{ 0xF0A4A9AB, 0x7B9BB },
	{ 0xF0A4A9AC, 0x7B9BD },
	{ 0xF0A4A9AD, 0x5DCAD },
	{ 0xF0A4A9AE, 0x5DCAB },
	{ 0xF0A4A9AF, 0x7C0DE },
	{ 0xF0A4A9B0, 0x7B9B9 },
	{ 0xF0A4A9B1, 0x4DBEA },
	{ 0xF0A4A9B2, 0x4D6EE },
	{ 0xF0A4A9B4, 0x4D6F0 },
	{ 0xF0A4A9B5, 0x7B9B8 },
	{ 0xF0A4A9BB, 0xFDBAE },
	{ 0xF0A4A9BC, 0xFDBAF },
	{ 0xF0A4A9BD, 0xFDBB0 },
	{ 0xF0A4A9BE, 0xFDBB1 },
	{ 0xF0A4A9BF, 0xFDBB2 },
	{ 0xF0A4AA80, 0xFDBB3 },
	{ 0xF0A4AA81, 0xFDBB4 },
	{ 0xF0A4AA82, 0xFDBB5 },
	{ 0xF0A4AA83, 0x5DCAC },
	{ 0xF0A4AA84, 0x7B9BA },
	{ 0xF0A4AA85, 0x7B9BC },
	{ 0xF0A4AA86, 0x7B9B7 },
	{ 0xF0A4AA87, 0x7C0DF },
	{ 0xF0A4AA8B, 0x5E8BC },
	{ 0xF0A4AA8C, 0x4DBEB },
	{ 0xF0A4AA8D, 0x5E2D7 },
	{ 0xF0A4AA8E, 0x4E0A6 },
	{ 0xF0A4AA8F, 0x7C0E0 },
	{ 0xF0A4AA90, 0x4E0A8 },
	{ 0xF0A4AA97, 0xFDFD1 },
	{ 0xF0A4AA98, 0xFDFD3 },
	{ 0xF0A4AA99, 0xFDFD4 },
	{ 0xF0A4AA9A, 0xFDFD5 },
	{ 0xF0A4AA9B, 0xFDFD7 },
	{ 0xF0A4AA9C, 0xFDFD9 },
	{ 0xF0A4AA9D, 0xFDFDA },
	{ 0xF0A4AA9E, 0xFDFDB },
	{ 0xF0A4AA9F, 0xFDFDC },
	{ 0xF0A4AAA0, 0xFDFDF },
	{ 0xF0A4AAA2, 0x7C0E1 },
	{ 0xF0A4AAA3, 0x7C0E2 },
	{ 0xF0A4AAA4, 0xFDFD0 },
	{ 0xF0A4AAA5, 0xFDFD2 },
	{ 0xF0A4AAA6, 0xFDFD8 },
	{ 0xF0A4AAA8, 0xFE3A3 },
	{ 0xF0A4AAA9, 0x7C7FC },
	{ 0xF0A4AAAA, 0x7C7FB },
	{ 0xF0A4AAAB, 0x5E8BE },
	{ 0xF0A4AAAC, 0x7C7FA },
	{ 0xF0A4AAAD, 0x7CEC3 },
	{ 0xF0A4AAAE, 0x5E8BD },
	{ 0xF0A4AAB4, 0x7C7F9 },
	{ 0xF0A4AAB5, 0xFE2FC },
	{ 0xF0A4AAB6, 0xFE2FE },
	{ 0xF0A4AAB7, 0xFE3A1 },
	{ 0xF0A4AAB8, 0xFE3A2 },
	{ 0xF0A4AAB9, 0x4E0A9 },
	{ 0xF0A4AABA, 0xFE2F9 },
	{ 0xF0A4AABC, 0xFE2FA },
	{ 0xF0A4AABD, 0xFE2FD },
	{ 0xF0A4AABE, 0x7D3EF },
	{ 0xF0A4AABF, 0x5ECD7 },
	{ 0xF0A4AB80, 0x4E6D2 },
	{ 0xF0A4AB81, 0xFE5D2 },
	{ 0xF0A4AB82, 0xFE5D3 },
	{ 0xF0A4AB83, 0xFE5D4 },
	{ 0xF0A4AB84, 0xFE5D5 },
	{ 0xF0A4AB85, 0x7CEC4 },
	{ 0xF0A4AB86, 0x7D3EE },
	{ 0xF0A4AB88, 0xFDFDE },
	{ 0xF0A4AB89, 0x4E6D1 },
	{ 0xF0A4AB8A, 0x7D5FC },
	{ 0xF0A4AB8C, 0x4E6D3 },
	{ 0xF0A4AB8D, 0x7D8BC },
	{ 0xF0A4AB90, 0xFE7F6 },
	{ 0xF0A4AB94, 0x7DBF9 },
	{ 0xF0A4AB95, 0x4EAD2 },
	{ 0xF0A4AB96, 0xFE9D9 },
	{ 0xF0A4AB97, 0xFE9DA },
	{ 0xF0A4AB98, 0x5F6A4 },
	{ 0xF0A4AB9A, 0xFEAE1 },
	{ 0xF0A4AB9B, 0xFEAE3 },
	{ 0xF0A4AB9C, 0xFEBD6 },
	{ 0xF0A4AB9F, 0xFEAE2 },
	{ 0xF0A4ABA3, 0x5F9B1 },
	{ 0xF0A4ABA4, 0x7E1A6 },
	{ 0xF0A4ABA5, 0x7E1A5 },
	{ 0xF0A4ABA6, 0xFECB2 },
	{ 0xF0A4ABA8, 0x5FAAC },
	{ 0xF0A4ABA9, 0x4EEB4 },
	{ 0xF0A4ABAA, 0x6ADA6 },
	{ 0xF0A4ABAB, 0x5AAC7 },
	{ 0xF0A4ABAC, 0x5AAC6 },
	{ 0xF0A4ABAD, 0x6B2ED },
	{ 0xF0A4ABAE, 0xFACC1 },
	{ 0xF0A4ABAF, 0x6B2EE },
	{ 0xF0A4ABB0, 0x6B9D6 },
	{ 0xF0A4ABB1, 0x5AEE3 },
	{ 0xF0A4ABB2, 0x5AEE4 },
	{ 0xF0A4ABB3, 0x6B9D7 },
	{ 0xF0A4ABB4, 0x6B9D8 },
	{ 0xF0A4ABB5, 0x4B3B6 },
	{ 0xF0A4ABB6, 0x5B3D9 },
	{ 0xF0A4ABB7, 0x5B3DA },
	{ 0xF0A4ABB8, 0xFB6E5 },
	{ 0xF0A4ABBA, 0x5BAAF },
	{ 0xF0A4ABBB, 0x5BAB0 },
	{ 0xF0A4ABBC, 0x6CBCF },
	{ 0xF0A4ABBD, 0xFBDC1 },
	{ 0xF0A4ABBE, 0x6CBD0 },
	{ 0xF0A4AC81, 0x4BEDC },
	{ 0xF0A4AC82, 0x5C0D0 },
	{ 0xF0A4AC83, 0x5C0D1 },
	{ 0xF0A4AC84, 0xFC3E6 },
	{ 0xF0A4AC87, 0x7A5C5 },
	{ 0xF0A4AC88, 0x6DEF8 },
	{ 0xF0A4AC89, 0x5C7C3 },
	{ 0xF0A4AC8B, 0xFCAAA },
	{ 0xF0A4AC8C, 0x5C7C4 },
	{ 0xF0A4AC8D, 0x7A5C4 },
	{ 0xF0A4AC8E, 0x7B0A6 },
	{ 0xF0A4AC8F, 0x4D1BD },
	{ 0xF0A4AC90, 0x5CECA },
	{ 0xF0A4AC91, 0xFD0CD },
	{ 0xF0A4AC92, 0x7A5C3 },
	{ 0xF0A4AC96, 0x4D1BE },
	{ 0xF0A4AC97, 0x7B9BE },
	{ 0xF0A4AC98, 0x5E2D8 },
	{ 0xF0A4AC99, 0xFDFE0 },
	{ 0xF0A4AC9A, 0x4DBED },
	{ 0xF0A4AC9B, 0x4E6D4 },
	{ 0xF0A4AC9C, 0x7D3F0 },
	{ 0xF0A4AC9D, 0x5F0CA },
	{ 0xF0A4ACA0, 0x5F6A5 },
	{ 0xF0A4ACA1, 0x7DBFA },
	{ 0xF0A4ACA2, 0x7DEFB },
	{ 0xF0A4ACA3, 0x7E2BB },
	{ 0xF0A4ACA4, 0x7E2BC },
	{ 0xF0A4ACA6, 0x5A4E2 },
	{ 0xF0A4ACA8, 0x5A7B1 },
	{ 0xF0A4ACA9, 0x4A7BD },
	{ 0xF0A4ACAA, 0x6ADA7 },
	{ 0xF0A4ACAC, 0x5AAC8 },
	{ 0xF0A4ACAD, 0x5AAC9 },
	{ 0xF0A4ACAE, 0x6B2EF },
	{ 0xF0A4ACAF, 0x4AABB },
	{ 0xF0A4ACB0, 0x4AABE },
	{ 0xF0A4ACB4, 0x5AEE5 },
	{ 0xF0A4ACB5, 0x5AEE7 },
	{ 0xF0A4ACB6, 0x6B9DC },
	{ 0xF0A4ACB7, 0x5AEE6 },
	{ 0xF0A4ACB9, 0xFB1A9 },
	{ 0xF0A4ACBA, 0x6B9DB },
	{ 0xF0A4ACBB, 0x6B9D9 },
	{ 0xF0A4ACBC, 0x6B9DA },
	{ 0xF0A4ACBE, 0x5B3DD },
	{ 0xF0A4ACBF, 0x6C2A2 },
	{ 0xF0A4AD80, 0x6C1FE },
	{ 0xF0A4AD81, 0x6C2A4 },
	{ 0xF0A4AD82, 0x5B3DE },
	{ 0xF0A4AD83, 0x6C2A3 },
	{ 0xF0A4AD84, 0x5B3DC },
	{ 0xF0A4AD85, 0xFB6E6 },
	{ 0xF0A4AD86, 0xFB6E8 },
	{ 0xF0A4AD8C, 0x4B9A2 },
	{ 0xF0A4AD8D, 0x5BAB1 },
	{ 0xF0A4AD8E, 0x6D5B6 },
	{ 0xF0A4AD8F, 0x4B9A7 },
	{ 0xF0A4AD90, 0x5BAB4 },
	{ 0xF0A4AD91, 0x5BAB3 },
	{ 0xF0A4AD92, 0x5B3DF },
	{ 0xF0A4AD93, 0x6CBD2 },
	{ 0xF0A4AD94, 0x5BAB2 },
	{ 0xF0A4AD95, 0x5B3DB },
	{ 0xF0A4AD97, 0x6CBD1 },
	{ 0xF0A4AD98, 0x6CBD3 },
	{ 0xF0A4AD9B, 0x4BEE4 },
	{ 0xF0A4AD9C, 0x5C0D2 },
	{ 0xF0A4AD9D, 0x6D5B7 },
	{ 0xF0A4AD9E, 0x4BEDE },
	{ 0xF0A4AD9F, 0x5C0D3 },
	{ 0xF0A4ADA0, 0x6D5B3 },
	{ 0xF0A4ADA1, 0x6D5B5 },
	{ 0xF0A4ADA2, 0x4BEDF },
	{ 0xF0A4ADA3, 0x6D5B8 },
	{ 0xF0A4ADA5, 0xFC3E7 },
	{ 0xF0A4ADA6, 0x6D5B4 },
	{ 0xF0A4ADA7, 0x5C7C7 },
	{ 0xF0A4ADA8, 0x6DEFC },
	{ 0xF0A4ADA9, 0x5C7C5 },
	{ 0xF0A4ADAA, 0x6DEFA },
	{ 0xF0A4ADAC, 0x4C4F2 },
	{ 0xF0A4ADB0, 0x6DEF9 },
	{ 0xF0A4ADB3, 0x6DEFB },
	{ 0xF0A4ADB4, 0x5C7C6 },
	{ 0xF0A4ADB9, 0x4CBA8 },
	{ 0xF0A4ADBA, 0x7A5CA },
	{ 0xF0A4ADBB, 0x5CECC },
	{ 0xF0A4ADBC, 0x5CECD },
	{ 0xF0A4ADBD, 0x5CECE },
	{ 0xF0A4ADBE, 0x7A5C6 },
	{ 0xF0A4ADBF, 0x7A5C7 },
	{ 0xF0A4AE80, 0x7A5C9 },
	{ 0xF0A4AE85, 0x7B0A7 },
	{ 0xF0A4AE86, 0x4D6F4 },
	{ 0xF0A4AE87, 0x7B0A8 },
	{ 0xF0A4AE88, 0x5D5DF },
	{ 0xF0A4AE89, 0x5D5E1 },
	{ 0xF0A4AE8A, 0x4D1C0 },
	{ 0xF0A4AE8B, 0x5D5E0 },
	{ 0xF0A4AE8D, 0x5D5DE },
	{ 0xF0A4AE8E, 0x4D6F6 },
	{ 0xF0A4AE8F, 0x5DCAE },
	{ 0xF0A4AE90, 0x4D6F7 },
	{ 0xF0A4AE93, 0x7B9C0 },
	{ 0xF0A4AE94, 0x7B9BF },
	{ 0xF0A4AE96, 0x5CECB },
	{ 0xF0A4AE98, 0x4DBF0 },
	{ 0xF0A4AE99, 0x5E2DB },
	{ 0xF0A4AE9A, 0x5E2DA },
	{ 0xF0A4AE9B, 0x7C0E4 },
	{ 0xF0A4AE9C, 0x5E2D9 },
	{ 0xF0A4AE9D, 0x7C0E5 },
	{ 0xF0A4AEA1, 0x5E8BF },
	{ 0xF0A4AEA2, 0x7CEC5 },
	{ 0xF0A4AEA6, 0x7D3F1 },
	{ 0xF0A4AEA7, 0x7D3F2 },
	{ 0xF0A4AEA8, 0x4E6D6 },
	{ 0xF0A4AEA9, 0x5F0CB },
	{ 0xF0A4AEAA, 0x4E6D5 },
	{ 0xF0A4AEAB, 0x7D3F3 },
	{ 0xF0A4AEAD, 0x4E8F6 },
	{ 0xF0A4AEAE, 0x7D8BD },
	{ 0xF0A4AEAF, 0x5F3DA },
	{ 0xF0A4AEB0, 0x5F6A8 },
	{ 0xF0A4AEB1, 0x5F6A7 },
	{ 0xF0A4AEB2, 0x7DBFB },
	{ 0xF0A4AEB3, 0x5F6A6 },
	{ 0xF0A4AEB5, 0x7DCEB },
	{ 0xF0A4AEB8, 0x5FAEC },
	{ 0xF0A4AEB9, 0x7E5B8 },
	{ 0xF0A4AEBA, 0x6A3B4 },
	{ 0xF0A4AEBB, 0x6ADA8 },
	{ 0xF0A4AEBC, 0x5A7B3 },
	{ 0xF0A4AEBD, 0x4A7BE },
	{ 0xF0A4AF80, 0xFA8AB },
	{ 0xF0A4AF81, 0x6B2F0 },
	{ 0xF0A4AF83, 0xFACC3 },
	{ 0xF0A4AF87, 0x5C0D4 },
	{ 0xF0A4AF88, 0x6DEFD },
	{ 0xF0A4AF89, 0x7B0AB },
	{ 0xF0A4AF8B, 0x7B0A9 },
	{ 0xF0A4AF8C, 0x7B0AA },
	{ 0xF0A4AF8D, 0x4D6F9 },
	{ 0xF0A4AF8E, 0x7C0E6 },
	{ 0xF0A4AF90, 0x5F0CC },
	{ 0xF0A4AF93, 0x6A3B5 },
	{ 0xF0A4AF94, 0x6A5B9 },
	{ 0xF0A4AF95, 0x6ADA9 },
	{ 0xF0A4AF96, 0x5A7B4 },
	{ 0xF0A4AF97, 0x6ADAA },
	{ 0xF0A4AF98, 0xFACC4 },
	{ 0xF0A4AF99, 0xFACC5 },
	{ 0xF0A4AF9A, 0x5AACA },
	{ 0xF0A4AF9B, 0x4AABF },
	{ 0xF0A4AF9D, 0x6B2F1 },
	{ 0xF0A4AF9E, 0x6B4F9 },
	{ 0xF0A4AF9F, 0x5AEE9 },
	{ 0xF0A4AFA0, 0x6C2A6 },
	{ 0xF0A4AFA1, 0x5B3E0 },
	{ 0xF0A4AFA2, 0x6C2A5 },
	{ 0xF0A4AFA3, 0x6C2A7 },
	{ 0xF0A4AFA4, 0xFB6E9 },
	{ 0xF0A4AFA6, 0x6D5B9 },
	{ 0xF0A4AFA7, 0x6CBD4 },
	{ 0xF0A4AFAA, 0xFBDC3 },
	{ 0xF0A4AFAB, 0xFBDC2 },
	{ 0xF0A4AFAC, 0x6D5BB },
	{ 0xF0A4AFAE, 0xFC3E8 },
	{ 0xF0A4AFAF, 0x6D5BA },
	{ 0xF0A4AFB2, 0x6DEFE },
	{ 0xF0A4AFB3, 0x7A5CB },
	{ 0xF0A4AFB4, 0xFCAAB },
	{ 0xF0A4AFB7, 0x4D6FA },
	{ 0xF0A4AFB9, 0xFDBB6 },
	{ 0xF0A4AFBC, 0xFE3A6 },
	{ 0xF0A4AFBD, 0x7C6EE },
	{ 0xF0A4AFBE, 0xFE3A5 },
	{ 0xF0A4B080, 0x7D3F4 },
	{ 0xF0A4B083, 0x6A5BA },
	{ 0xF0A4B084, 0xFA4FA },
	{ 0xF0A4B085, 0x5A7B5 },
	{ 0xF0A4B086, 0x6ADAE },
	{ 0xF0A4B087, 0x6B9DD },
	{ 0xF0A4B088, 0x5B3E1 },
	{ 0xF0A4B08A, 0xFCAAC },
	{ 0xF0A4B08D, 0xFDFE1 },
	{ 0xF0A4B08E, 0x7C7FD },
	{ 0xF0A4B090, 0xFECB3 },
	{ 0xF0A4B091, 0x5F3DB },
	{ 0xF0A4B095, 0x4A4DF },
	{ 0xF0A4B097, 0xFA4FC },
	{ 0xF0A4B099, 0xFA4FB },
	{ 0xF0A4B09B, 0x6A8E3 },
	{ 0xF0A4B09D, 0x4A7C2 },
	{ 0xF0A4B09E, 0x4A5D3 },
	{ 0xF0A4B09F, 0x4A7BF },
	{ 0xF0A4B0A0, 0x5A7B6 },
	{ 0xF0A4B0A1, 0x6ADB1 },
	{ 0xF0A4B0A2, 0x6ADB0 },
	{ 0xF0A4B0A3, 0x6ADB3 },
	{ 0xF0A4B0A4, 0xFA8AC },
	{ 0xF0A4B0A5, 0xFA8AD },
	{ 0xF0A4B0A8, 0x6ADAF },
	{ 0xF0A4B0A9, 0x4AAC2 },
	{ 0xF0A4B0AA, 0x5AACD },
	{ 0xF0A4B0AB, 0x6B2F4 },
	{ 0xF0A4B0AC, 0x5AACC },
	{ 0xF0A4B0AD, 0x6B2F3 },
	{ 0xF0A4B0AE, 0x5AACB },
	{ 0xF0A4B0AF, 0x6B2F6 },
	{ 0xF0A4B0B0, 0x6B2FA },
	{ 0xF0A4B0B1, 0x6B2F7 },
	{ 0xF0A4B0B2, 0x6B9E5 },
	{ 0xF0A4B0B3, 0x5AACE },
	{ 0xF0A4B0B4, 0x6B2F8 },
	{ 0xF0A4B0B5, 0x6B2F5 },
	{ 0xF0A4B0B6, 0x5AEEE },
	{ 0xF0A4B0B8, 0xFACC6 },
	{ 0xF0A4B0B9, 0xFACC7 },
	{ 0xF0A4B0BA, 0xFACC8 },
	{ 0xF0A4B0BB, 0xFACC9 },
	{ 0xF0A4B0BC, 0xFACCB },
	{ 0xF0A4B0BD, 0xFACCC },
	{ 0xF0A4B0BE, 0xFACCD },
	{ 0xF0A4B0BF, 0xFACCE },
	{ 0xF0A4B180, 0xFACCF },
	{ 0xF0A4B18B, 0x5AACF },
	{ 0xF0A4B18C, 0x5AEEA },
	{ 0xF0A4B18D, 0x4AEAE },
	{ 0xF0A4B18E, 0x5AEEB },
	{ 0xF0A4B18F, 0x6B9E1 },
	{ 0xF0A4B190, 0x6B9E0 },
	{ 0xF0A4B192, 0x6B9E2 },
	{ 0xF0A4B195, 0x6B9DF },
	{ 0xF0A4B196, 0x6B9E3 },
	{ 0xF0A4B197, 0xFB1AA },
	{ 0xF0A4B198, 0xFB1AB },
	{ 0xF0A4B199, 0xFB1AC },
	{ 0xF0A4B19A, 0xFB1AE },
	{ 0xF0A4B19E, 0x4AEB0 },
	{ 0xF0A4B19F, 0xFB1AD },
	{ 0xF0A4B1A3, 0x5AEED },
	{ 0xF0A4B1A4, 0x5AEEC },
	{ 0xF0A4B1A5, 0x4B3BE },
	{ 0xF0A4B1A6, 0x6C2A8 },
	{ 0xF0A4B1A7, 0x5B3E3 },
	{ 0xF0A4B1A8, 0x5B3E2 },
	{ 0xF0A4B1A9, 0x4B3BD },
	{ 0xF0A4B1AA, 0x6C2AC },
	{ 0xF0A4B1AB, 0x6C2AF },
	{ 0xF0A4B1AC, 0x6C2AA },
	{ 0xF0A4B1AD, 0x6C2AD },
	{ 0xF0A4B1AE, 0x6C2AE },
	{ 0xF0A4B1AF, 0xFB6EB },
	{ 0xF0A4B1B0, 0xFB6EC },
	{ 0xF0A4B1B1, 0x6C2AB },
	{ 0xF0A4B1B3, 0x6C2A9 },
	{ 0xF0A4B1B6, 0x6C1EB },
	{ 0xF0A4B1BC, 0x4B9AB },
	{ 0xF0A4B1BD, 0x4B9A9 },
	{ 0xF0A4B1BE, 0x4B9AA },
	{ 0xF0A4B283, 0x6CBD7 },
	{ 0xF0A4B284, 0x6CBD9 },
	{ 0xF0A4B285, 0xFB6EA },
	{ 0xF0A4B286, 0xFBDC6 },
	{ 0xF0A4B287, 0xFBDC7 },
	{ 0xF0A4B288, 0xFBDC8 },
	{ 0xF0A4B28B, 0x6CBD8 },
	{ 0xF0A4B28D, 0x4B9AD },
	{ 0xF0A4B28E, 0x6CBD5 },
	{ 0xF0A4B28F, 0xFBDC4 },
	{ 0xF0A4B290, 0xFBDC5 },
	{ 0xF0A4B291, 0x6D5C0 },
	{ 0xF0A4B292, 0x4BEEA },
	{ 0xF0A4B293, 0x4BEE7 },
	{ 0xF0A4B294, 0x6D5BE },
	{ 0xF0A4B295, 0x6D5BF },
	{ 0xF0A4B296, 0x4BEE6 },
	{ 0xF0A4B297, 0x5C0D6 },
	{ 0xF0A4B298, 0x6D5BC },
	{ 0xF0A4B299, 0x6D5C2 },
	{ 0xF0A4B29A, 0x5C0D5 },
	{ 0xF0A4B29B, 0x6D5C3 },
	{ 0xF0A4B29C, 0x6D5C4 },
	{ 0xF0A4B29D, 0x6D5C1 },
	{ 0xF0A4B2A0, 0xFC3E9 },
	{ 0xF0A4B2A1, 0xFC3EA },
	{ 0xF0A4B2A3, 0x5C0D7 },
	{ 0xF0A4B2A7, 0x6D5BD },
	{ 0xF0A4B2AB, 0x6DFA3 },
	{ 0xF0A4B2AC, 0x4C4FA },
	{ 0xF0A4B2AD, 0x5C7CA },
	{ 0xF0A4B2AE, 0x6DFA2 },
	{ 0xF0A4B2AF, 0x6DFA5 },
	{ 0xF0A4B2B0, 0x6DFA8 },
	{ 0xF0A4B2B1, 0xFCAAD },
	{ 0xF0A4B2B2, 0x6DFA6 },
	{ 0xF0A4B2B5, 0x6DFA4 },
	{ 0xF0A4B2B6, 0x6DFA7 },
	{ 0xF0A4B2B7, 0x7A5D0 },
	{ 0xF0A4B2B8, 0x4CBAC },
	{ 0xF0A4B2B9, 0x7A5CC },
	{ 0xF0A4B2BA, 0x7A5CE },
	{ 0xF0A4B2BB, 0x7A5CD },
	{ 0xF0A4B2BD, 0x7A5CF },
	{ 0xF0A4B2BE, 0x5CECF },
	{ 0xF0A4B2BF, 0x7A5D1 },
	{ 0xF0A4B380, 0xFD0CF },
	{ 0xF0A4B385, 0x4CBAB },
	{ 0xF0A4B388, 0x4D1C5 },
	{ 0xF0A4B389, 0x4D1C3 },
	{ 0xF0A4B38A, 0x4D1C6 },
	{ 0xF0A4B38B, 0x7B0AC },
	{ 0xF0A4B38C, 0x5D5E2 },
	{ 0xF0A4B38D, 0xFD6B2 },
	{ 0xF0A4B38F, 0x7ACBB },
	{ 0xF0A4B392, 0x7B9C1 },
	{ 0xF0A4B393, 0x5DCB3 },
	{ 0xF0A4B394, 0x7B9C3 },
	{ 0xF0A4B395, 0x5DCB1 },
	{ 0xF0A4B396, 0x4D6FB },
	{ 0xF0A4B397, 0x7B9C2 },
	{ 0xF0A4B398, 0x5DCB4 },
	{ 0xF0A4B39A, 0xFDBB7 },
	{ 0xF0A4B39B, 0x7BCF6 },
	{ 0xF0A4B39F, 0x5DCB0 },
	{ 0xF0A4B3A0, 0x5DCB2 },
	{ 0xF0A4B3A1, 0xFD6B1 },
	{ 0xF0A4B3A4, 0x4DBF1 },
	{ 0xF0A4B3A9, 0x7C7FE },
	{ 0xF0A4B3AA, 0x5E8C1 },
	{ 0xF0A4B3AB, 0x7C8A3 },
	{ 0xF0A4B3AC, 0x7CEC6 },
	{ 0xF0A4B3AD, 0x7C8A1 },
	{ 0xF0A4B3AE, 0x7C8A4 },
	{ 0xF0A4B3AF, 0x4E0AD },
	{ 0xF0A4B3B2, 0x7C8A2 },
	{ 0xF0A4B3B3, 0x7CEC8 },
	{ 0xF0A4B3B6, 0x7CEC7 },
	{ 0xF0A4B3B9, 0x7D3F7 },
	{ 0xF0A4B3BA, 0xFE7F7 },
	{ 0xF0A4B3BB, 0x7D3F5 },
	{ 0xF0A4B3BC, 0x7D3F6 },
	{ 0xF0A4B3BE, 0xFE7D2 },
	{ 0xF0A4B3BF, 0x7D8BE },
	{ 0xF0A4B480, 0x4E8F7 },
	{ 0xF0A4B481, 0x7D3F8 },
	{ 0xF0A4B482, 0x7DBFD },
	{ 0xF0A4B483, 0xFEAE4 },
	{ 0xF0A4B484, 0x7DBFC },
	{ 0xF0A4B485, 0x7DEFC },
	{ 0xF0A4B487, 0x7E2BE },
	{ 0xF0A4B488, 0x7E2BD },
	{ 0xF0A4B48B, 0x7E3DA },
	{ 0xF0A4B48C, 0x7E3DC },
	{ 0xF0A4B48E, 0x7E3DB },
	{ 0xF0A4B490, 0x7E6A9 },
	{ 0xF0A4B491, 0x7E6B5 },
	{ 0xF0A4B492, 0x7E6C6 },
	{ 0xF0A4B493, 0x6A3B6 },
	{ 0xF0A4B495, 0x6A5BB },
	{ 0xF0A4B496, 0xFA8AE },
	{ 0xF0A4B497, 0x4AEB2 },
	{ 0xF0A4B498, 0x5AAD0 },
	{ 0xF0A4B499, 0x4B9AE },
	{ 0xF0A4B49C, 0x6D5C6 },
	{ 0xF0A4B49D, 0x6D5C5 },
	{ 0xF0A4B49E, 0x6DFA9 },
	{ 0xF0A4B49F, 0x5D5E3 },
	{ 0xF0A4B4A0, 0x7B0AE },
	{ 0xF0A4B4A1, 0x7A5D2 },
	{ 0xF0A4B4A4, 0x7D8BF },
	{ 0xF0A4B4A5, 0x5A2FC },
	{ 0xF0A4B4A6, 0x5A4E4 },
	{ 0xF0A4B4A7, 0x5A4E5 },
	{ 0xF0A4B4A8, 0x4A4E0 },
	{ 0xF0A4B4A9, 0x6A8E6 },
	{ 0xF0A4B4AA, 0x6A8E7 },
	{ 0xF0A4B4AB, 0x6A8E5 },
	{ 0xF0A4B4AE, 0x6A8E8 },
	{ 0xF0A4B4AF, 0x4A7C5 },
	{ 0xF0A4B4B0, 0x6ADB5 },
	{ 0xF0A4B4B1, 0x4A7C4 },
	{ 0xF0A4B4B2, 0xFA8AF },
	{ 0xF0A4B4B3, 0x5A7B8 },
	{ 0xF0A4B4B4, 0x6ADB6 },
	{ 0xF0A4B4B7, 0x6B2FD },
	{ 0xF0A4B4B8, 0x4AACB },
	{ 0xF0A4B4B9, 0x6B2FC },
	{ 0xF0A4B4BA, 0x6B2FB },
	{ 0xF0A4B4BB, 0x5AAD2 },
	{ 0xF0A4B4BC, 0x5AAD6 },
	{ 0xF0A4B4BD, 0x4AAC7 },
	{ 0xF0A4B4BE, 0x4AAC8 },
	{ 0xF0A4B4BF, 0x5AAD3 },
	{ 0xF0A4B580, 0x4AAC5 },
	{ 0xF0A4B581, 0x5AAD4 },
	{ 0xF0A4B582, 0x5AAD1 },
	{ 0xF0A4B583, 0x5AAD5 },
	{ 0xF0A4B587, 0x6B3A4 },
	{ 0xF0A4B588, 0xFACD0 },
	{ 0xF0A4B58B, 0x6B2FE },
	{ 0xF0A4B58C, 0xFACD1 },
	{ 0xF0A4B58D, 0x6B3A2 },
	{ 0xF0A4B591, 0x6B3A3 },
	{ 0xF0A4B594, 0x6B3A1 },
	{ 0xF0A4B597, 0x6B9E9 },
	{ 0xF0A4B598, 0x5AEEF },
	{ 0xF0A4B599, 0x5AEF3 },
	{ 0xF0A4B59A, 0x6B9EF },
	{ 0xF0A4B59B, 0x5AEF1 },
	{ 0xF0A4B59C, 0x6B9F0 },
	{ 0xF0A4B59D, 0x6B9EA },
	{ 0xF0A4B59E, 0x5AEF6 },
	{ 0xF0A4B59F, 0x5AEF2 },
	{ 0xF0A4B5A0, 0x5AEF5 },
	{ 0xF0A4B5A1, 0x6B9ED },
	{ 0xF0A4B5A2, 0x6B9F1 },
	{ 0xF0A4B5A3, 0x6B9E6 },
	{ 0xF0A4B5A4, 0x4AEBD },
	{ 0xF0A4B5A5, 0x5AEF4 },
	{ 0xF0A4B5A6, 0x6B9E8 },
	{ 0xF0A4B5A7, 0x4AEBE },
	{ 0xF0A4B5A8, 0x5AEF0 },
	{ 0xF0A4B5A9, 0x6B9EE },
	{ 0xF0A4B5AA, 0xFB1AF },
	{ 0xF0A4B5AB, 0x6B9E7 },
	{ 0xF0A4B5AD, 0x6B9EC },
	{ 0xF0A4B5B7, 0x6C2B1 },
	{ 0xF0A4B5B8, 0x6C2B7 },
	{ 0xF0A4B5B9, 0x5B3E8 },
	{ 0xF0A4B5BA, 0x6C2B5 },
	{ 0xF0A4B5BB, 0x5B3EB },
	{ 0xF0A4B5BC, 0x4B3C1 },
	{ 0xF0A4B5BD, 0x5B3EA },
	{ 0xF0A4B5BE, 0x5B3E6 },
	{ 0xF0A4B5BF, 0x6C2B3 },
	{ 0xF0A4B680, 0x4B3C4 },
	{ 0xF0A4B681, 0x5B3E9 },
	{ 0xF0A4B682, 0xFB6ED },
	{ 0xF0A4B683, 0xFB6EE },
	{ 0xF0A4B684, 0xFB6EF },
	{ 0xF0A4B685, 0x6C2B6 },
	{ 0xF0A4B686, 0x6C2B9 },
	{ 0xF0A4B689, 0x6C2B4 },
	{ 0xF0A4B68A, 0x6C2B8 },
	{ 0xF0A4B68B, 0xFB6F0 },
	{ 0xF0A4B68C, 0x6C2B0 },
	{ 0xF0A4B693, 0x5B3E7 },
	{ 0xF0A4B694, 0x5B3EC },
	{ 0xF0A4B695, 0x5BAB6 },
	{ 0xF0A4B696, 0x5BABF },
	{ 0xF0A4B697, 0x6CBE1 },
	{ 0xF0A4B698, 0x5BAB5 },
	{ 0xF0A4B699, 0x6CBE5 },
	{ 0xF0A4B69A, 0x5BAB9 },
	{ 0xF0A4B69B, 0x5BABA },
	{ 0xF0A4B69C, 0x5BABC },
	{ 0xF0A4B69D, 0x5BAB7 },
	{ 0xF0A4B69E, 0x6CBE3 },
	{ 0xF0A4B69F, 0x6CBDF },
	{ 0xF0A4B6A0, 0x5BAC0 },
	{ 0xF0A4B6A1, 0x6CBE2 },
	{ 0xF0A4B6A2, 0x6CBDB },
	{ 0xF0A4B6A3, 0x6CBE6 },
	{ 0xF0A4B6A4, 0x5BABE },
	{ 0xF0A4B6A5, 0x6CBDE },
	{ 0xF0A4B6A8, 0x4B9B9 },
	{ 0xF0A4B6A9, 0x6CBDD },
	{ 0xF0A4B6AA, 0x6CBE0 },
	{ 0xF0A4B6AB, 0x6CBE4 },
	{ 0xF0A4B6AC, 0xFBDC9 },
	{ 0xF0A4B6AD, 0xFBDCA },
	{ 0xF0A4B6B6, 0x4B9B7 },
	{ 0xF0A4B6B7, 0x6CBDC },
	{ 0xF0A4B780, 0x4B9B1 },
	{ 0xF0A4B781, 0x5BAB8 },
	{ 0xF0A4B782, 0x6D5CC },
	{ 0xF0A4B783, 0x4BEF2 },
	{ 0xF0A4B784, 0x4BEF0 },
	{ 0xF0A4B785, 0x4BEFB },
	{ 0xF0A4B786, 0x5C0D9 },
	{ 0xF0A4B787, 0x4BEF1 },
	{ 0xF0A4B788, 0x4BEF5 },
	{ 0xF0A4B789, 0x4C4FD },
	{ 0xF0A4B78A, 0x4BEF9 },
	{ 0xF0A4B78B, 0x6D5C9 },
	{ 0xF0A4B78C, 0x5C0DA },
	{ 0xF0A4B78D, 0x5C0DC },
	{ 0xF0A4B78E, 0x5C0E2 },
	{ 0xF0A4B78F, 0x4BEFC },
	{ 0xF0A4B790, 0x6D5C7 },
	{ 0xF0A4B791, 0x5C0E1 },
	{ 0xF0A4B793, 0x6D5CD },
	{ 0xF0A4B794, 0x5C0E5 },
	{ 0xF0A4B795, 0x5C0E3 },
	{ 0xF0A4B796, 0x5C0DB },
	{ 0xF0A4B797, 0x5BABD },
	{ 0xF0A4B798, 0x5C0DF },
	{ 0xF0A4B799, 0x5C0DE },
	{ 0xF0A4B79A, 0x6D5CB },
	{ 0xF0A4B79B, 0x6D5CA },
	{ 0xF0A4B79C, 0x4BEFD },
	{ 0xF0A4B79D, 0xFC3EB },
	{ 0xF0A4B79E, 0xFC3EC },
	{ 0xF0A4B7A0, 0x6D5C8 },
	{ 0xF0A4B7A5, 0x6D5CE },
	{ 0xF0A4B7B7, 0x5C0D8 },
	{ 0xF0A4B7B8, 0x5C0E6 },
	{ 0xF0A4B7B9, 0x5C0DD },
	{ 0xF0A4B7BB, 0x5C7D8 },
	{ 0xF0A4B7BC, 0x5C7D0 },
	{ 0xF0A4B7BD, 0x4C5A5 },
	{ 0xF0A4B7BE, 0x4C5AB },
	{ 0xF0A4B7BF, 0x5C7CB },
	{ 0xF0A4B880, 0x5C7CF },
	{ 0xF0A4B881, 0x4C5A6 },
	{ 0xF0A4B882, 0x6DFAF },
	{ 0xF0A4B883, 0x6DFAA },
	{ 0xF0A4B884, 0x4C5AE },
	{ 0xF0A4B885, 0x4C5AA },
	{ 0xF0A4B886, 0x6DFAB },
	{ 0xF0A4B887, 0x6DFB4 },
	{ 0xF0A4B888, 0x5C7CD },
	{ 0xF0A4B889, 0x5C7CE },
	{ 0xF0A4B88A, 0x5C7D3 },
	{ 0xF0A4B88B, 0x4C5AC },
	{ 0xF0A4B88C, 0x6DFB7 },
	{ 0xF0A4B88D, 0x6DFB5 },
	{ 0xF0A4B88E, 0x5C7DA },
	{ 0xF0A4B88F, 0x6DFAE },
	{ 0xF0A4B891, 0x4C5A7 },
	{ 0xF0A4B892, 0x4C5A2 },
	{ 0xF0A4B893, 0x5C7D1 },
	{ 0xF0A4B894, 0x5C7D2 },
	{ 0xF0A4B895, 0x6DFB3 },
	{ 0xF0A4B896, 0x5C7CC },
	{ 0xF0A4B897, 0x5C7D6 },
	{ 0xF0A4B898, 0x6DFB1 },
	{ 0xF0A4B899, 0x6DFB0 },
	{ 0xF0A4B89D, 0xFCAAE },
	{ 0xF0A4B89E, 0x6DFB8 },
	{ 0xF0A4B89F, 0x6DFAC },
	{ 0xF0A4B8A0, 0x4C5AD },
	{ 0xF0A4B8A2, 0x6DFB2 },
	{ 0xF0A4B8A4, 0x6DFB6 },
	{ 0xF0A4B8A9, 0x5C7D5 },
	{ 0xF0A4B8AA, 0x4CBBA },
	{ 0xF0A4B8AB, 0x4CBB6 },
	{ 0xF0A4B8AC, 0x4CBAD },
	{ 0xF0A4B8AD, 0x4CBB9 },
	{ 0xF0A4B8AE, 0x5CED3 },
	{ 0xF0A4B8AF, 0x4CBB4 },
	{ 0xF0A4B8B0, 0x7A5DD },
	{ 0xF0A4B8B1, 0x4CBB2 },
	{ 0xF0A4B8B2, 0x5CED5 },
	{ 0xF0A4B8B3, 0x5CED7 },
	{ 0xF0A4B8B4, 0x5CED4 },
	{ 0xF0A4B8B5, 0x4CBB1 },
	{ 0xF0A4B8B6, 0x7A5D5 },
	{ 0xF0A4B8B7, 0x4CBB0 },
	{ 0xF0A4B8B8, 0x5CED1 },
	{ 0xF0A4B8B9, 0x5CED2 },
	{ 0xF0A4B8BA, 0x7A5D3 },
	{ 0xF0A4B8BB, 0x5C7D7 },
	{ 0xF0A4B8BC, 0x5CED8 },
	{ 0xF0A4B8BD, 0x7A5D4 },
	{ 0xF0A4B8BE, 0x7A5DB },
	{ 0xF0A4B8BF, 0x7A5D9 },
	{ 0xF0A4B982, 0xFD0D0 },
	{ 0xF0A4B983, 0xFD0D1 },
	{ 0xF0A4B984, 0xFD0D2 },
	{ 0xF0A4B985, 0xFD0D3 },
	{ 0xF0A4B986, 0xFD0D4 },
	{ 0xF0A4B989, 0x7A5D6 },
	{ 0xF0A4B98D, 0x7A5DA },
	{ 0xF0A4B98F, 0x7A5DE },
	{ 0xF0A4B99B, 0x5CED6 },
	{ 0xF0A4B99C, 0x5CED0 },
	{ 0xF0A4B99D, 0x4D1CB },
	{ 0xF0A4B99E, 0x5D5E5 },
	{ 0xF0A4B99F, 0x7B0AF },
	{ 0xF0A4B9A0, 0x7B0B0 },
	{ 0xF0A4B9A1, 0x5D5EC },
	{ 0xF0A4B9A2, 0x5D5ED },
	{ 0xF0A4B9A3, 0x4D1CC },
	{ 0xF0A4B9A4, 0x4D1C7 },
	{ 0xF0A4B9A5, 0x5D5E8 },
	{ 0xF0A4B9A6, 0x7B0B5 },
	{ 0xF0A4B9A7, 0x5D5E6 },
	{ 0xF0A4B9A8, 0x5D5E7 },
	{ 0xF0A4B9A9, 0x5D5EB },
	{ 0xF0A4B9AA, 0x7B0B1 },
	{ 0xF0A4B9AB, 0x7B0B7 },
	{ 0xF0A4B9AC, 0x5D5EE },
	{ 0xF0A4B9AF, 0xFD6B4 },
	{ 0xF0A4B9B0, 0xFD6B5 },
	{ 0xF0A4B9B1, 0x7B0B4 },
	{ 0xF0A4B9B3, 0x7B0B3 },
	{ 0xF0A4B9B4, 0x5D5EA },
	{ 0xF0A4B9B6, 0x7B0B2 },
	{ 0xF0A4B9B9, 0x7B0B8 },
	{ 0xF0A4B9BB, 0x7B0B9 },
	{ 0xF0A4BA80, 0x5D5E4 },
	{ 0xF0A4BA81, 0x7A5D7 },
	{ 0xF0A4BA84, 0x4D6FC },
	{ 0xF0A4BA85, 0x5DCB9 },
	{ 0xF0A4BA86, 0x5D5F0 },
	{ 0xF0A4BA87, 0x7B9D0 },
	{ 0xF0A4BA88, 0x4D1D1 },
	{ 0xF0A4BA89, 0x4C5A9 },
	{ 0xF0A4BA8A, 0x4D6FE },
	{ 0xF0A4BA8B, 0x7B9C7 },
	{ 0xF0A4BA8C, 0x5DCB5 },
	{ 0xF0A4BA8D, 0x7B9C8 },
	{ 0xF0A4BA8E, 0x5DCBC },
	{ 0xF0A4BA8F, 0x5DCBA },
	{ 0xF0A4BA90, 0x5DCBD },
	{ 0xF0A4BA91, 0x7B9CF },
	{ 0xF0A4BA92, 0x7C0EA },
	{ 0xF0A4BA93, 0x5D5EF },
	{ 0xF0A4BA94, 0x5DCB7 },
	{ 0xF0A4BA95, 0x4D6FD },
	{ 0xF0A4BA96, 0x5DCB8 },
	{ 0xF0A4BA97, 0x4D7A3 },
	{ 0xF0A4BA98, 0x7B9C9 },
	{ 0xF0A4BA99, 0x7B9CD },
	{ 0xF0A4BA9A, 0x7B9D1 },
	{ 0xF0A4BA9B, 0x7B9CB },
	{ 0xF0A4BA9C, 0x7B9C6 },
	{ 0xF0A4BA9D, 0x7B9CC },
	{ 0xF0A4BAA1, 0xFDBB8 },
	{ 0xF0A4BAA6, 0x7B9C4 },
	{ 0xF0A4BAA7, 0x7B9C5 },
	{ 0xF0A4BAA8, 0x7B9CE },
	{ 0xF0A4BAA9, 0x5DCBB },
	{ 0xF0A4BAB7, 0x5E2DC },
	{ 0xF0A4BAB8, 0x5DCBE },
	{ 0xF0A4BAB9, 0x7B9CA },
	{ 0xF0A4BABA, 0x4DBF8 },
	{ 0xF0A4BABB, 0x5DCC0 },
	{ 0xF0A4BABC, 0x5E2E0 },
	{ 0xF0A4BABD, 0x7C0E8 },
	{ 0xF0A4BABE, 0x5E2E5 },
	{ 0xF0A4BABF, 0x7C0E9 },
	{ 0xF0A4BB80, 0x5E2E1 },
	{ 0xF0A4BB81, 0x5E2E4 },
	{ 0xF0A4BB82, 0x4DBF6 },
	{ 0xF0A4BB83, 0x5DCBF },
	{ 0xF0A4BB84, 0x5E2DD },
	{ 0xF0A4BB85, 0x5E2E2 },
	{ 0xF0A4BB86, 0x5E2DE },
	{ 0xF0A4BB87, 0x5E2DF },
	{ 0xF0A4BB88, 0x4DBFA },
	{ 0xF0A4BB89, 0x7C0ED },
	{ 0xF0A4BB8D, 0x5E2E3 },
	{ 0xF0A4BB95, 0x7C8AB },
	{ 0xF0A4BB96, 0x4E0B3 },
	{ 0xF0A4BB97, 0x7C8A7 },
	{ 0xF0A4BB98, 0x4E0B4 },
	{ 0xF0A4BB99, 0x5E8C4 },
	{ 0xF0A4BB9A, 0x4E0B5 },
	{ 0xF0A4BB9B, 0x7C8A6 },
	{ 0xF0A4BB9C, 0x5E8C3 },
	{ 0xF0A4BB9D, 0x5E8C2 },
	{ 0xF0A4BB9E, 0x4E0B6 },
	{ 0xF0A4BBA1, 0xFE3A7 },
	{ 0xF0A4BBA2, 0x4E0B1 },
	{ 0xF0A4BBA3, 0x7C8A8 },
	{ 0xF0A4BBA5, 0x7C8A9 },
	{ 0xF0A4BBA8, 0x7C8A5 },
	{ 0xF0A4BBAE, 0x7C8AA },
	{ 0xF0A4BBAF, 0x7C0EC },
	{ 0xF0A4BBB1, 0x4E3EA },
	{ 0xF0A4BBB2, 0x4E3EB },
	{ 0xF0A4BBB3, 0x7CEC9 },
	{ 0xF0A4BBB4, 0x7CECD },
	{ 0xF0A4BBB5, 0x7CECC },
	{ 0xF0A4BBB6, 0x5ECD8 },
	{ 0xF0A4BBB7, 0x5ECD9 },
	{ 0xF0A4BBB8, 0x7CECE },
	{ 0xF0A4BBB9, 0x7CECB },
	{ 0xF0A4BBBA, 0x7CECA },
	{ 0xF0A4BC80, 0x5F0D1 },
	{ 0xF0A4BC81, 0x5F0D0 },
	{ 0xF0A4BC82, 0x5F0CE },
	{ 0xF0A4BC83, 0x4E6D7 },
	{ 0xF0A4BC84, 0x7D3FA },
	{ 0xF0A4BC85, 0x5F0CF },
	{ 0xF0A4BC86, 0x7D3F9 },
	{ 0xF0A4BC87, 0xFE7F8 },
	{ 0xF0A4BC8B, 0x5F3DF },
	{ 0xF0A4BC8C, 0x5F3DE },
	{ 0xF0A4BC8D, 0x5F3DD },
	{ 0xF0A4BC90, 0x7DCA2 },
	{ 0xF0A4BC91, 0x7DBFE },
	{ 0xF0A4BC92, 0x4EAD6 },
	{ 0xF0A4BC96, 0x7DCA1 },
	{ 0xF0A4BC97, 0x5F6A9 },
	{ 0xF0A4BC98, 0x5F7EB },
	{ 0xF0A4BC99, 0x7DEFD },
	{ 0xF0A4BC9A, 0x7DEFE },
	{ 0xF0A4BC9C, 0x7E1C2 },
	{ 0xF0A4BC9D, 0x7E1A7 },
	{ 0xF0A4BC9F, 0x7E2BF },
	{ 0xF0A4BCA0, 0x7E2C0 },
	{ 0xF0A4BCA1, 0x7E2C1 },
	{ 0xF0A4BCA2, 0x5FAED },
	{ 0xF0A4BCA3, 0x7E4D1 },
	{ 0xF0A4BCA4, 0x7E5B9 },
	{ 0xF0A4BCA5, 0x4A4E3 },
	{ 0xF0A4BCA7, 0x6B3A5 },
	{ 0xF0A4BCA8, 0xFACD2 },
	{ 0xF0A4BCA9, 0x6B9F3 },
	{ 0xF0A4BCAA, 0x6B9F2 },
	{ 0xF0A4BCAB, 0xFB1B0 },
	{ 0xF0A4BCAC, 0x6C2BA },
	{ 0xF0A4BCAD, 0xFB6F1 },
	{ 0xF0A4BCAF, 0x6CBE9 },
	{ 0xF0A4BCB0, 0x6CBE7 },
	{ 0xF0A4BCB1, 0x5BAC1 },
	{ 0xF0A4BCB2, 0x6CBE8 },
	{ 0xF0A4BCB7, 0x7A5DF },
	{ 0xF0A4BCB9, 0x4D1D3 },
	{ 0xF0A4BCBA, 0x4D1D2 },
	{ 0xF0A4BCBC, 0x7B0BA },
	{ 0xF0A4BCBD, 0x6A5BC },
	{ 0xF0A4BCBE, 0x6A5BD },
	{ 0xF0A4BD81, 0x5A4E6 },
	{ 0xF0A4BD82, 0x5A7BA },
	{ 0xF0A4BD83, 0x5A7BB },
	{ 0xF0A4BD86, 0x5A7B9 },
	{ 0xF0A4BD87, 0x5A7BC },
	{ 0xF0A4BD88, 0x4AACD },
	{ 0xF0A4BD89, 0x5AAD9 },
	{ 0xF0A4BD8A, 0x5AAD8 },
	{ 0xF0A4BD8C, 0x5AAD7 },
	{ 0xF0A4BD8D, 0x6B3A7 },
	{ 0xF0A4BD8E, 0x6B3A8 },
	{ 0xF0A4BD90, 0x6B3A6 },
	{ 0xF0A4BD91, 0xFACD3 },
	{ 0xF0A4BD92, 0xFACD4 },
	{ 0xF0A4BD94, 0x6B3A9 },
	{ 0xF0A4BD96, 0x5AADA },
	{ 0xF0A4BD98, 0x6B9F4 },
	{ 0xF0A4BD99, 0x4AEC2 },
	{ 0xF0A4BD9A, 0x6B9F5 },
	{ 0xF0A4BD9B, 0x6C2BC },
	{ 0xF0A4BD9D, 0xFB1B1 },
	{ 0xF0A4BD9E, 0xFB1B2 },
	{ 0xF0A4BD9F, 0xFB1B3 },
	{ 0xF0A4BDA0, 0xFB1B5 },
	{ 0xF0A4BDA1, 0xFB1B6 },
	{ 0xF0A4BDA4, 0xFB6F5 },
	{ 0xF0A4BDA5, 0x4B3C6 },
	{ 0xF0A4BDA6, 0x5B3EE },
	{ 0xF0A4BDA7, 0x6C2BB },
	{ 0xF0A4BDA8, 0xFB6F2 },
	{ 0xF0A4BDA9, 0xFB6F3 },
	{ 0xF0A4BDAA, 0xFB6F6 },
	{ 0xF0A4BDAC, 0x6CBEB },
	{ 0xF0A4BDAF, 0x6CBEC },
	{ 0xF0A4BDB0, 0x6CBEA },
	{ 0xF0A4BDB7, 0xFB6F4 },
	{ 0xF0A4BDB9, 0x5C0E8 },
	{ 0xF0A4BDBA, 0x5C0E7 },
	{ 0xF0A4BDBB, 0x6D5D0 },
	{ 0xF0A4BDBC, 0x4BEFE },
	{ 0xF0A4BDBD, 0x6D5CF },
	{ 0xF0A4BDBF, 0x5C0E9 },
	{ 0xF0A4BE83, 0xFC3ED },
	{ 0xF0A4BE88, 0x4C5AF },
	{ 0xF0A4BE89, 0x6DFB9 },
	{ 0xF0A4BE8A, 0x6DFBA },
	{ 0xF0A4BE8B, 0xFCAB0 },
	{ 0xF0A4BE8C, 0xFCAB1 },
	{ 0xF0A4BE8D, 0xFCAB3 },
	{ 0xF0A4BE8E, 0xFCAB4 },
	{ 0xF0A4BE8F, 0xFCAB2 },
	{ 0xF0A4BE95, 0x4CBBC },
	{ 0xF0A4BE98, 0x7A5E0 },
	{ 0xF0A4BE99, 0x7A5E1 },
	{ 0xF0A4BE9B, 0x5D5F2 },
	{ 0xF0A4BE9C, 0x7B0BC },
	{ 0xF0A4BE9D, 0x5D5F1 },
	{ 0xF0A4BE9E, 0x7B0BB },
	{ 0xF0A4BEA0, 0x4D7A7 },
	{ 0xF0A4BEA1, 0x4D7A8 },
	{ 0xF0A4BEA2, 0x5DCC2 },
	{ 0xF0A4BEA3, 0x5DCC4 },
	{ 0xF0A4BEA4, 0x7C0EE },
	{ 0xF0A4BEA5, 0x5DCC1 },
	{ 0xF0A4BEA6, 0x7B9D2 },
	{ 0xF0A4BEA7, 0x5E2E6 },
	{ 0xF0A4BEA8, 0x7C0EF },
	{ 0xF0A4BEAA, 0x7C0F0 },
	{ 0xF0A4BEAB, 0x5E8C5 },
	{ 0xF0A4BEAC, 0x5E8C6 },
	{ 0xF0A4BEAD, 0x5E8C7 },
	{ 0xF0A4BEB2, 0x5E8C8 },
	{ 0xF0A4BEB3, 0x7C8AC },
	{ 0xF0A4BEB4, 0x7CED0 },
	{ 0xF0A4BEB6, 0x7CECF },
	{ 0xF0A4BEB8, 0x5E2E7 },
	{ 0xF0A4BEBB, 0x7D8C0 },
	{ 0xF0A4BEBC, 0x7D8C1 },
	{ 0xF0A4BEBD, 0xFE7F9 },
	{ 0xF0A4BEBE, 0x7DCA3 },
	{ 0xF0A4BF80, 0x4EBF3 },
	{ 0xF0A4BF83, 0x7DFA1 },
	{ 0xF0A4BF85, 0x7E5BA },
	{ 0xF0A4BF86, 0x5A4E7 },
	{ 0xF0A4BF87, 0x5A4E8 },
	{ 0xF0A4BF88, 0x6ADB9 },
	{ 0xF0A4BF89, 0x6ADB7 },
	{ 0xF0A4BF8A, 0x6ADB8 },
	{ 0xF0A4BF8B, 0x5A7BD },
	{ 0xF0A4BF8E, 0x6B3AB },
	{ 0xF0A4BF8F, 0x5AADB },
	{ 0xF0A4BF90, 0x4AACF },
	{ 0xF0A4BF91, 0x6B0B6 },
	{ 0xF0A4BF92, 0x6B3AA },
	{ 0xF0A4BF95, 0x5AEF7 },
	{ 0xF0A4BF96, 0x5AEF8 },
	{ 0xF0A4BF97, 0x6B9F6 },
	{ 0xF0A4BF98, 0x6B9FA },
	{ 0xF0A4BF99, 0x5B3EF },
	{ 0xF0A4BF9A, 0x4AEC4 },
	{ 0xF0A4BF9B, 0x6B9F7 },
	{ 0xF0A4BF9C, 0x6B9F8 },
	{ 0xF0A4BF9D, 0x6B9F9 },
	{ 0xF0A4BF9F, 0x4B3C9 },
	{ 0xF0A4BFA0, 0x5B3F0 },
	{ 0xF0A4BFA1, 0x6C2BE },
	{ 0xF0A4BFA2, 0xFB6F9 },
	{ 0xF0A4BFA5, 0x6C2BD },
	{ 0xF0A4BFA7, 0x4B9BC },
	{ 0xF0A4BFA8, 0x6CBED },
	{ 0xF0A4BFA9, 0x5BAC2 },
	{ 0xF0A4BFAA, 0x6CBEF },
	{ 0xF0A4BFAB, 0x4B9BB },
	{ 0xF0A4BFAC, 0xFBDCB },
	{ 0xF0A4BFAE, 0x6CBEE },
	{ 0xF0A4BFB2, 0xFB6F8 },
	{ 0xF0A4BFB3, 0x5C0EA },
	{ 0xF0A4BFB4, 0x5C0ED },
	{ 0xF0A4BFB5, 0x5C0EB },
	{ 0xF0A4BFB6, 0x5C0EC },
	{ 0xF0A4BFB7, 0x5C0EE },
	{ 0xF0A4BFB9, 0x6D5D3 },
	{ 0xF0A4BFBA, 0xFC3EE },
	{ 0xF0A4BFBF, 0x6D5D1 },
	{ 0xF0A58081, 0x4BFA1 },
	{ 0xF0A58082, 0x4C5B1 },
	{ 0xF0A58083, 0x4C5B3 },
	{ 0xF0A58084, 0x6DFBE },
	{ 0xF0A58086, 0xFCAB5 },
	{ 0xF0A58087, 0x6DFBD },
	{ 0xF0A58088, 0x5C7DC },
	{ 0xF0A58089, 0x6DFBF },
	{ 0xF0A5808A, 0x6DFBB },
	{ 0xF0A5808B, 0x6DFBC },
	{ 0xF0A5808D, 0x7A5E3 },
	{ 0xF0A5808E, 0x5CEDA },
	{ 0xF0A5808F, 0x5CEDB },
	{ 0xF0A58090, 0x5CEDC },
	{ 0xF0A58091, 0x7A5E2 },
	{ 0xF0A58094, 0x5D5F6 },
	{ 0xF0A58095, 0x5D5F8 },
	{ 0xF0A58096, 0x5D5F4 },
	{ 0xF0A58097, 0x4D1D8 },
	{ 0xF0A58098, 0x5D5F7 },
	{ 0xF0A58099, 0x5D5F5 },
	{ 0xF0A5809A, 0xFD6B6 },
	{ 0xF0A5809B, 0x5D5F3 },
	{ 0xF0A5809C, 0x7B0BD },
	{ 0xF0A5809E, 0x7B0BE },
	{ 0xF0A5809F, 0x7B9D3 },
	{ 0xF0A580A1, 0x7B0BF },
	{ 0xF0A580A2, 0x4D7A9 },
	{ 0xF0A580A3, 0x5E2E8 },
	{ 0xF0A580A4, 0x7C0F2 },
	{ 0xF0A580A5, 0x7C0F3 },
	{ 0xF0A580A6, 0x7C0F4 },
	{ 0xF0A580A8, 0x7C0F1 },
	{ 0xF0A580AB, 0x5E8CA },
	{ 0xF0A580AC, 0x5E8C9 },
	{ 0xF0A580AD, 0x7C8AD },
	{ 0xF0A580AF, 0x4E3ED },
	{ 0xF0A580B0, 0x5ECDB },
	{ 0xF0A580B1, 0x5ECDA },
	{ 0xF0A580B2, 0x7CED1 },
	{ 0xF0A580B4, 0x7D3FC },
	{ 0xF0A580B5, 0x4E6DC },
	{ 0xF0A580B6, 0x7D8C2 },
	{ 0xF0A580B9, 0x5F7EC },
	{ 0xF0A580BA, 0x5F7ED },
	{ 0xF0A580BC, 0x7E3C4 },
	{ 0xF0A580BD, 0x7E5D8 },
	{ 0xF0A580BF, 0x6A8E9 },
	{ 0xF0A58180, 0xFA4FD },
	{ 0xF0A58181, 0x4A7C9 },
	{ 0xF0A58182, 0x5A7BE },
	{ 0xF0A58183, 0x4A7C7 },
	{ 0xF0A58184, 0x6ADBB },
	{ 0xF0A58185, 0x5A7BF },
	{ 0xF0A58186, 0x5AADE },
	{ 0xF0A58187, 0x5AADC },
	{ 0xF0A58188, 0x5AADD },
	{ 0xF0A58189, 0x6B3AD },
	{ 0xF0A5818B, 0x6B3AC },
	{ 0xF0A5818C, 0xFACD5 },
	{ 0xF0A5818E, 0x5AEF9 },
	{ 0xF0A5818F, 0x6BAA1 },
	{ 0xF0A58190, 0x6BAA3 },
	{ 0xF0A58191, 0x4AEC8 },
	{ 0xF0A58192, 0x5AEFA },
	{ 0xF0A58193, 0x6B9FE },
	{ 0xF0A58194, 0x6B9FB },
	{ 0xF0A58195, 0x4AECA },
	{ 0xF0A58196, 0x6BAA2 },
	{ 0xF0A58198, 0xFB1B7 },
	{ 0xF0A58199, 0xFB1B8 },
	{ 0xF0A5819A, 0x6BAA4 },
	{ 0xF0A5819B, 0x6B9FC },
	{ 0xF0A5819C, 0x6B9FD },
	{ 0xF0A5819E, 0x4B3CC },
	{ 0xF0A5819F, 0x5B3F2 },
	{ 0xF0A581A0, 0x4B3CA },
	{ 0xF0A581A1, 0x6C2BF },
	{ 0xF0A581A3, 0xFB6FA },
	{ 0xF0A581A4, 0xFB6FB },
	{ 0xF0A581A5, 0xFB6FC },
	{ 0xF0A581A6, 0xFB6FD },
	{ 0xF0A581A7, 0xFB7A1 },
	{ 0xF0A581A8, 0xFB7A2 },
	{ 0xF0A581A9, 0x6C2C0 },
	{ 0xF0A581AA, 0x6C2C1 },
	{ 0xF0A581AB, 0x6BAA5 },
	{ 0xF0A581AC, 0x6CBF4 },
	{ 0xF0A581AD, 0x6CBF0 },
	{ 0xF0A581AE, 0x5BAC3 },
	{ 0xF0A581AF, 0x4B9BD },
	{ 0xF0A581B0, 0x6CBF2 },
	{ 0xF0A581B1, 0x6CBF3 },
	{ 0xF0A581B3, 0xFBDCC },
	{ 0xF0A581B4, 0xFBDCD },
	{ 0xF0A581B6, 0x6CBF1 },
	{ 0xF0A581B7, 0x6D5D4 },
	{ 0xF0A581B8, 0x6D5D6 },
	{ 0xF0A581B9, 0x5C0F0 },
	{ 0xF0A581BA, 0x6D5D8 },
	{ 0xF0A581BB, 0x6D5D7 },
	{ 0xF0A581BC, 0x6D5D5 },
	{ 0xF0A581BF, 0xFC3EF },
	{ 0xF0A58280, 0xFC3F0 },
	{ 0xF0A58283, 0x6DFC1 },
	{ 0xF0A58284, 0x6DFC0 },
	{ 0xF0A58285, 0x6DFCB },
	{ 0xF0A58286, 0xFCAB6 },
	{ 0xF0A58287, 0x5CEDD },
	{ 0xF0A58288, 0x7A5E4 },
	{ 0xF0A5828A, 0x7A5E5 },
	{ 0xF0A5828C, 0xFD0D5 },
	{ 0xF0A5828D, 0xFD0D6 },
	{ 0xF0A5828E, 0xFD0D7 },
	{ 0xF0A5828F, 0xFD0D8 },
	{ 0xF0A58290, 0xFD0D9 },
	{ 0xF0A58291, 0xFD0DA },
	{ 0xF0A58293, 0x4D1D9 },
	{ 0xF0A58294, 0x7B0C4 },
	{ 0xF0A58295, 0x4D1DB },
	{ 0xF0A58296, 0x7B0C0 },
	{ 0xF0A58297, 0x7B0C5 },
	{ 0xF0A58298, 0x5D5FA },
	{ 0xF0A58299, 0x5D5F9 },
	{ 0xF0A5829A, 0xFD6B7 },
	{ 0xF0A5829B, 0xFD6B8 },
	{ 0xF0A5829C, 0xFD6B9 },
	{ 0xF0A5829E, 0xFD6BA },
	{ 0xF0A5829F, 0xFD6BB },
	{ 0xF0A582A0, 0x7B0C3 },
	{ 0xF0A582A1, 0x7B0C1 },
	{ 0xF0A582A4, 0x4D7AB },
	{ 0xF0A582A5, 0x4DCA3 },
	{ 0xF0A582A6, 0x4D7AA },
	{ 0xF0A582A7, 0x7B9D4 },
	{ 0xF0A582A8, 0x5DCC7 },
	{ 0xF0A582A9, 0x7C0F5 },
	{ 0xF0A582AC, 0x5DCC6 },
	{ 0xF0A582AD, 0xFDBBB },
	{ 0xF0A582AE, 0xFDBBC },
	{ 0xF0A582B1, 0x7B9D5 },
	{ 0xF0A582B2, 0x7B9D6 },
	{ 0xF0A582B3, 0x7B6F9 },
	{ 0xF0A582B5, 0x5DCC5 },
	{ 0xF0A582B6, 0x7B0C2 },
	{ 0xF0A582B7, 0x7B9D7 },
	{ 0xF0A582B8, 0x4DCA2 },
	{ 0xF0A582B9, 0x4DCA1 },
	{ 0xF0A582BA, 0x7C0F6 },
	{ 0xF0A582BC, 0x7C0F8 },
	{ 0xF0A582BE, 0x7C0F7 },
	{ 0xF0A582BF, 0xFDFE2 },
	{ 0xF0A58380, 0x7C0F9 },
	{ 0xF0A58381, 0x7C8AE },
	{ 0xF0A58382, 0x5E8CB },
	{ 0xF0A58383, 0x7C8AF },
	{ 0xF0A58384, 0xFE3A8 },
	{ 0xF0A58385, 0xFE3A9 },
	{ 0xF0A58387, 0x5ECDD },
	{ 0xF0A58388, 0x7CED3 },
	{ 0xF0A58389, 0x5ECDC },
	{ 0xF0A5838A, 0x7CED5 },
	{ 0xF0A5838B, 0xFE5D6 },
	{ 0xF0A5838D, 0x7CED2 },
	{ 0xF0A5838E, 0x7CED4 },
	{ 0xF0A58392, 0xFE7FB },
	{ 0xF0A58393, 0x7D8C4 },
	{ 0xF0A58394, 0x5F3E0 },
	{ 0xF0A58395, 0x7D8C3 },
	{ 0xF0A58396, 0x7D8C5 },
	{ 0xF0A58397, 0xFE7FA },
	{ 0xF0A58398, 0x7DFA2 },
	{ 0xF0A58399, 0x5F6AA },
	{ 0xF0A5839C, 0x7DFA3 },
	{ 0xF0A583A1, 0x7E2C2 },
	{ 0xF0A583A4, 0x5A2FD },
	{ 0xF0A583A5, 0xFA2E7 },
	{ 0xF0A583A6, 0x6A8EA },
	{ 0xF0A583A7, 0x4A4E4 },
	{ 0xF0A583A8, 0x5A4EA },
	{ 0xF0A583A9, 0x4A4E6 },
	{ 0xF0A583AA, 0x5A4EB },
	{ 0xF0A583AB, 0x5A4E9 },
	{ 0xF0A583AC, 0xFA4FE },
	{ 0xF0A583B2, 0x4A7D0 },
	{ 0xF0A583B3, 0x6ADBC },
	{ 0xF0A583B4, 0x5A7C1 },
	{ 0xF0A583B5, 0x4A7CB },
	{ 0xF0A583B6, 0x6ADC0 },
	{ 0xF0A583B7, 0x6ADC2 },
	{ 0xF0A583B8, 0x6ADBE },
	{ 0xF0A583B9, 0x5A7C2 },
	{ 0xF0A583BA, 0x5A7C3 },
	{ 0xF0A583BB, 0x6ADC1 },
	{ 0xF0A583BC, 0x6ADBF },
	{ 0xF0A583BD, 0x5A7C0 },
	{ 0xF0A58480, 0x6ADC3 },
	{ 0xF0A58482, 0x6ADC4 },
	{ 0xF0A58483, 0x6B3B9 },
	{ 0xF0A58484, 0x6B3B5 },
	{ 0xF0A58485, 0x6B3AE },
	{ 0xF0A58486, 0x6B3B2 },
	{ 0xF0A58487, 0x4AADE },
	{ 0xF0A58488, 0x6B3B6 },
	{ 0xF0A58489, 0x4AADC },
	{ 0xF0A5848A, 0x6B3BC },
	{ 0xF0A5848B, 0x5AAE5 },
	{ 0xF0A5848C, 0x6B3B3 },
	{ 0xF0A5848D, 0x5AAE9 },
	{ 0xF0A5848E, 0x4AADB },
	{ 0xF0A5848F, 0x6B3AF },
	{ 0xF0A58490, 0x6B3BB },
	{ 0xF0A58491, 0x5AAE0 },
	{ 0xF0A58492, 0x5AAE7 },
	{ 0xF0A58493, 0x5AAEB },
	{ 0xF0A58494, 0x5AAE1 },
	{ 0xF0A58495, 0x5AAEA },
	{ 0xF0A58496, 0x5AAE8 },
	{ 0xF0A58497, 0x5AAE3 },
	{ 0xF0A58498, 0x5AAEC },
	{ 0xF0A58499, 0x6B3B0 },
	{ 0xF0A5849B, 0x5AADF },
	{ 0xF0A5849C, 0x5AAE6 },
	{ 0xF0A5849D, 0x5AAE2 },
	{ 0xF0A5849E, 0x5AAE4 },
	{ 0xF0A584A3, 0xFACD6 },
	{ 0xF0A584A4, 0xFACD8 },
	{ 0xF0A584A5, 0x6B3B7 },
	{ 0xF0A584A7, 0x6B3BA },
	{ 0xF0A584A9, 0x6B3B4 },
	{ 0xF0A584B1, 0x4AED0 },
	{ 0xF0A584B2, 0x5AFA4 },
	{ 0xF0A584B3, 0x3AEDA },
	{ 0xF0A584B4, 0x4AECC },
	{ 0xF0A584B5, 0x5AEFB },
	{ 0xF0A584B6, 0x6BAA6 },
	{ 0xF0A584B7, 0x4AECE },
	{ 0xF0A584B8, 0x5AFA2 },
	{ 0xF0A584B9, 0x5AEFC },
	{ 0xF0A584BA, 0x6BAA8 },
	{ 0xF0A584BB, 0x4AECB },
	{ 0xF0A584BC, 0x6BAA9 },
	{ 0xF0A584BD, 0x5AFA3 },
	{ 0xF0A584BE, 0x6BAAA },
	{ 0xF0A584BF, 0x4AED3 },
	{ 0xF0A58580, 0x6BAAC },
	{ 0xF0A58581, 0x5AEFE },
	{ 0xF0A58584, 0x5AFA5 },
	{ 0xF0A58589, 0x6BAAB },
	{ 0xF0A5858A, 0xFB1B9 },
	{ 0xF0A5858B, 0xFB1BA },
	{ 0xF0A5858C, 0xFB1BB },
	{ 0xF0A5858D, 0xFB1BC },
	{ 0xF0A5858E, 0xFB1BD },
	{ 0xF0A58593, 0x6BAA7 },
	{ 0xF0A58597, 0x5AFA1 },
	{ 0xF0A58598, 0x5AEFD },
	{ 0xF0A58599, 0x4AED4 },
	{ 0xF0A5859A, 0x4B3D5 },
	{ 0xF0A5859B, 0x6C2D3 },
	{ 0xF0A5859C, 0x6C2C6 },
	{ 0xF0A5859D, 0x6C2CD },
	{ 0xF0A5859E, 0x5B3F4 },
	{ 0xF0A5859F, 0x5B3F3 },
	{ 0xF0A585A0, 0x5B3FD },
	{ 0xF0A585A1, 0x4B3D4 },
	{ 0xF0A585A2, 0x6C2C7 },
	{ 0xF0A585A3, 0x6C2C4 },
	{ 0xF0A585A5, 0x6C2C2 },
	{ 0xF0A585A6, 0x5B3FA },
	{ 0xF0A585A7, 0x5B3FB },
	{ 0xF0A585A8, 0x5B3F5 },
	{ 0xF0A585A9, 0x6C2CA },
	{ 0xF0A585AA, 0x5B3F8 },
	{ 0xF0A585AB, 0x6C2D4 },
	{ 0xF0A585AC, 0x5B3F9 },
	{ 0xF0A585AD, 0x6C2C3 },
	{ 0xF0A585AE, 0x6C2CF },
	{ 0xF0A585B0, 0x6C2CB },
	{ 0xF0A585B1, 0x6C2D0 },
	{ 0xF0A585B2, 0xFB7A5 },
	{ 0xF0A585B3, 0x6C2D2 },
	{ 0xF0A585B6, 0x6C2CC },
	{ 0xF0A585B9, 0x6C2C9 },
	{ 0xF0A585BC, 0x6C2D1 },
	{ 0xF0A585BD, 0xFB7A6 },
	{ 0xF0A58685, 0x5B3FE },
	{ 0xF0A58686, 0x6C2C5 },
	{ 0xF0A58687, 0x6C2CE },
	{ 0xF0A58688, 0x5B3F7 },
	{ 0xF0A58689, 0x5B3FC },
	{ 0xF0A5868B, 0x5BAC9 },
	{ 0xF0A5868C, 0x5BACC },
	{ 0xF0A5868D, 0x6CBF9 },
	{ 0xF0A5868E, 0x6CCA3 },
	{ 0xF0A5868F, 0x4B3D3 },
	{ 0xF0A58690, 0x6CBF8 },
	{ 0xF0A58691, 0x5BACB },
	{ 0xF0A58692, 0x6CBFD },
	{ 0xF0A58693, 0x6CCA1 },
	{ 0xF0A58694, 0x5BAC6 },
	{ 0xF0A58695, 0x6CCA6 },
	{ 0xF0A58696, 0x6CBF7 },
	{ 0xF0A58697, 0x4B9CF },
	{ 0xF0A58698, 0x5BACA },
	{ 0xF0A58699, 0x5BAC8 },
	{ 0xF0A5869A, 0x5BAC4 },
	{ 0xF0A5869B, 0x4B9CE },
	{ 0xF0A5869C, 0x5C0F1 },
	{ 0xF0A5869D, 0x6CCA5 },
	{ 0xF0A5869E, 0x5C0FE },
	{ 0xF0A5869F, 0x4B9C0 },
	{ 0xF0A586A0, 0x6CBFE },
	{ 0xF0A586A1, 0x5BACD },
	{ 0xF0A586A2, 0x6CBFB },
	{ 0xF0A586A3, 0x5BACE },
	{ 0xF0A586A4, 0x6CCA8 },
	{ 0xF0A586A5, 0x5BAC5 },
	{ 0xF0A586A6, 0x5BAC7 },
	{ 0xF0A586AA, 0xFBDCF },
	{ 0xF0A586AB, 0xFBDD0 },
	{ 0xF0A586AC, 0xFBDD1 },
	{ 0xF0A586B0, 0x6CBFC },
	{ 0xF0A586B3, 0x6CCA7 },
	{ 0xF0A586B5, 0x6CBF6 },
	{ 0xF0A586B6, 0x6CCA4 },
	{ 0xF0A58783, 0x6CCA2 },
	{ 0xF0A58784, 0x4B9C4 },
	{ 0xF0A58785, 0x4B9D0 },
	{ 0xF0A58786, 0x5BACF },
	{ 0xF0A58787, 0x4B9BE },
	{ 0xF0A58789, 0x6D5DB },
	{ 0xF0A5878A, 0x6D5DE },
	{ 0xF0A5878B, 0x6D5DA },
	{ 0xF0A5878C, 0x4BFAA },
	{ 0xF0A5878D, 0x5C0F8 },
	{ 0xF0A5878E, 0x6D5DC },
	{ 0xF0A5878F, 0x5C0F7 },
	{ 0xF0A58790, 0x6D5DF },
	{ 0xF0A58791, 0x5C0F5 },
	{ 0xF0A58792, 0x6D5D9 },
	{ 0xF0A58793, 0x4BFA3 },
	{ 0xF0A58794, 0x4BFA8 },
	{ 0xF0A58795, 0x4BFB1 },
	{ 0xF0A58796, 0x4BFAE },
	{ 0xF0A58798, 0x5C0FA },
	{ 0xF0A58799, 0x6D5E2 },
	{ 0xF0A5879A, 0x5C0F6 },
	{ 0xF0A5879B, 0x4BFAF },
	{ 0xF0A5879C, 0x4BFA4 },
	{ 0xF0A5879D, 0x6D5E4 },
	{ 0xF0A5879E, 0x5C0F9 },
	{ 0xF0A5879F, 0x5C0F2 },
	{ 0xF0A587A0, 0x5C0FC },
	{ 0xF0A587A1, 0x6D5E6 },
	{ 0xF0A587A4, 0x6D5DD },
	{ 0xF0A587A8, 0xFC3F1 },
	{ 0xF0A587A9, 0xFC3F2 },
	{ 0xF0A587AA, 0xFC3F3 },
	{ 0xF0A587AB, 0x6CBF5 },
	{ 0xF0A587AE, 0x6D5E3 },
	{ 0xF0A587B4, 0x6D3B5 },
	{ 0xF0A587B5, 0x5C0F3 },
	{ 0xF0A587BE, 0x5C0FD },
	{ 0xF0A587BF, 0x5C0F4 },
	{ 0xF0A58880, 0x6D5E5 },
	{ 0xF0A58882, 0x5C7E0 },
	{ 0xF0A58883, 0x4C5C5 },
	{ 0xF0A58885, 0x6DFC4 },
	{ 0xF0A58886, 0x4C5BE },
	{ 0xF0A58887, 0x5C7E3 },
	{ 0xF0A58888, 0x6DFC8 },
	{ 0xF0A58889, 0x5C7E5 },
	{ 0xF0A5888A, 0x5C7E6 },
	{ 0xF0A5888B, 0x6DFC9 },
	{ 0xF0A5888C, 0x4CBCF },
	{ 0xF0A5888D, 0x6DFCE },
	{ 0xF0A5888E, 0x6DFC6 },
	{ 0xF0A5888F, 0x6DFCF },
	{ 0xF0A58890, 0x7A5EC },
	{ 0xF0A58891, 0x6DFC7 },
	{ 0xF0A58892, 0x5C7E7 },
	{ 0xF0A58893, 0x5C7E4 },
	{ 0xF0A58894, 0x6DFC3 },
	{ 0xF0A58895, 0x6DFCA },
	{ 0xF0A58896, 0x6DFC5 },
	{ 0xF0A58897, 0x5C7E2 },
	{ 0xF0A58898, 0x6DFC2 },
	{ 0xF0A58899, 0x5C7DF },
	{ 0xF0A5889A, 0x5C7DE },
	{ 0xF0A5889B, 0x5C7DD },
	{ 0xF0A5889C, 0x7A5E6 },
	{ 0xF0A588A2, 0xFCAB7 },
	{ 0xF0A588A3, 0xFCAB8 },
	{ 0xF0A588A4, 0xFCAB9 },
	{ 0xF0A588A5, 0xFCABA },
	{ 0xF0A588A6, 0xFCABB },
	{ 0xF0A588A7, 0xFCABC },
	{ 0xF0A588A8, 0xFCABD },
	{ 0xF0A588A9, 0x4C5BA },
	{ 0xF0A588AA, 0x6DFCD },
	{ 0xF0A588B7, 0x6DFCC },
	{ 0xF0A588B8, 0x5C7E9 },
	{ 0xF0A588BB, 0x4C5BB },
	{ 0xF0A588BC, 0x4CBD0 },
	{ 0xF0A588BD, 0x4CBCC },
	{ 0xF0A588BE, 0x4CBBE },
	{ 0xF0A588BF, 0x5CEE2 },
	{ 0xF0A58980, 0x5CEE7 },
	{ 0xF0A58981, 0x4CBCE },
	{ 0xF0A58982, 0x7A5EB },
	{ 0xF0A58983, 0x5CEEC },
	{ 0xF0A58984, 0x5CEE5 },
	{ 0xF0A58985, 0x4CBC1 },
	{ 0xF0A58986, 0x7A5F0 },
	{ 0xF0A58987, 0x4CBC0 },
	{ 0xF0A58988, 0x4D1E5 },
	{ 0xF0A58989, 0x7B0CD },
	{ 0xF0A5898A, 0x5CEE4 },
	{ 0xF0A5898B, 0x5D6A1 },
	{ 0xF0A5898C, 0x5CEE6 },
	{ 0xF0A5898D, 0x7A5ED },
	{ 0xF0A5898E, 0x5CEEA },
	{ 0xF0A5898F, 0x7A5F2 },
	{ 0xF0A58990, 0x4CBC9 },
	{ 0xF0A58991, 0x4CBCB },
	{ 0xF0A58992, 0x4CBC6 },
	{ 0xF0A58993, 0x5CEDF },
	{ 0xF0A58994, 0x5CEEB },
	{ 0xF0A58995, 0x7A5E7 },
	{ 0xF0A58996, 0x7A5E8 },
	{ 0xF0A58997, 0x7A5EA },
	{ 0xF0A58998, 0x4CBCA },
	{ 0xF0A58999, 0x5CEE3 },
	{ 0xF0A5899A, 0x7A5EE },
	{ 0xF0A5899B, 0x5CEDE },
	{ 0xF0A5899C, 0x5CEE1 },
	{ 0xF0A5899D, 0x5D5FB },
	{ 0xF0A5899E, 0x5CEE9 },
	{ 0xF0A5899F, 0x5CEE8 },
	{ 0xF0A589A2, 0x7A5E9 },
	{ 0xF0A589A3, 0xFD0DB },
	{ 0xF0A589A4, 0xFD0DC },
	{ 0xF0A589A5, 0xFD0DD },
	{ 0xF0A589A6, 0x7A5EF },
	{ 0xF0A589B0, 0x4CBC8 },
	{ 0xF0A589B4, 0x5D6AA },
	{ 0xF0A589B5, 0x5D6AB },
	{ 0xF0A589B6, 0x4D1DE },
	{ 0xF0A589B7, 0x5D6A5 },
	{ 0xF0A589B8, 0x5D6A3 },
	{ 0xF0A589B9, 0x5D6A7 },
	{ 0xF0A589BA, 0x5D5FD },
	{ 0xF0A589BB, 0x4D1E3 },
	{ 0xF0A589BC, 0x5D6A9 },
	{ 0xF0A589BD, 0x5D5FE },
	{ 0xF0A589BE, 0x5D6A6 },
	{ 0xF0A589BF, 0x5D6A4 },
	{ 0xF0A58A80, 0x4D1E2 },
	{ 0xF0A58A81, 0x7B0C6 },
	{ 0xF0A58A82, 0x7B0CE },
	{ 0xF0A58A84, 0x7B0CF },
	{ 0xF0A58A85, 0x7B0CB },
	{ 0xF0A58A86, 0x7B0C7 },
	{ 0xF0A58A87, 0x5CEED },
	{ 0xF0A58A88, 0x4D1E7 },
	{ 0xF0A58A89, 0x5D5FC },
	{ 0xF0A58A8A, 0x7B0C9 },
	{ 0xF0A58A8E, 0xFD6BD },
	{ 0xF0A58A90, 0x7B0D1 },
	{ 0xF0A58A95, 0x7B0CC },
	{ 0xF0A58AA7, 0x5D6AC },
	{ 0xF0A58AA8, 0x4D1E6 },
	{ 0xF0A58AAA, 0x5C7E8 },
	{ 0xF0A58AAB, 0x5D6A8 },
	{ 0xF0A58AAC, 0x4DCAB },
	{ 0xF0A58AAD, 0x5DCC8 },
	{ 0xF0A58AAE, 0x5DCCB },
	{ 0xF0A58AAF, 0x4D7B5 },
	{ 0xF0A58AB0, 0x4D7B6 },
	{ 0xF0A58AB1, 0x7B0D2 },
	{ 0xF0A58AB2, 0x7B9DE },
	{ 0xF0A58AB3, 0x7B9D9 },
	{ 0xF0A58AB4, 0x5DCCA },
	{ 0xF0A58AB5, 0x7B9DA },
	{ 0xF0A58AB6, 0x5DCCC },
	{ 0xF0A58AB7, 0x7B9E4 },
	{ 0xF0A58AB8, 0x5DCC9 },
	{ 0xF0A58AB9, 0x7C1A2 },
	{ 0xF0A58ABA, 0x7B9DF },
	{ 0xF0A58ABB, 0x7B9E0 },
	{ 0xF0A58ABC, 0x7B9DD },
	{ 0xF0A58ABD, 0x4D7B7 },
	{ 0xF0A58ABE, 0x7B9E3 },
	{ 0xF0A58ABF, 0x5DCCF },
	{ 0xF0A58B80, 0x7B0C8 },
	{ 0xF0A58B81, 0x5DCCE },
	{ 0xF0A58B82, 0x7B9E1 },
	{ 0xF0A58B83, 0x7B9DC },
	{ 0xF0A58B84, 0x7B9DB },
	{ 0xF0A58B88, 0xFDBBE },
	{ 0xF0A58B89, 0xFDBBF },
	{ 0xF0A58B8A, 0xFDBC0 },
	{ 0xF0A58B8D, 0x7B9E2 },
	{ 0xF0A58B90, 0x7B9D8 },
	{ 0xF0A58B99, 0x4DCA8 },
	{ 0xF0A58B9A, 0x7C1A3 },
	{ 0xF0A58B9B, 0x7C0FE },
	{ 0xF0A58B9C, 0x5E2EE },
	{ 0xF0A58B9D, 0x4DCAC },
	{ 0xF0A58B9E, 0x5E2EB },
	{ 0xF0A58B9F, 0x7C0FB },
	{ 0xF0A58BA0, 0x7C0FC },
	{ 0xF0A58BA1, 0x5E2F0 },
	{ 0xF0A58BA2, 0x4DCA4 },
	{ 0xF0A58BA3, 0x5E2EC },
	{ 0xF0A58BA4, 0x5E2EF },
	{ 0xF0A58BA5, 0x5E2F1 },
	{ 0xF0A58BA8, 0x5E2EA },
	{ 0xF0A58BA9, 0xFDFE3 },
	{ 0xF0A58BAA, 0xFDFE4 },
	{ 0xF0A58BAB, 0x7C1A4 },
	{ 0xF0A58BAC, 0x7C1A5 },
	{ 0xF0A58BAD, 0x7C0FD },
	{ 0xF0A58BAF, 0x5E2ED },
	{ 0xF0A58BB0, 0x7C0FA },
	{ 0xF0A58BBB, 0x7C1A1 },
	{ 0xF0A58BBF, 0x5E8CF },
	{ 0xF0A58C80, 0x5E8CC },
	{ 0xF0A58C81, 0x5E8D1 },
	{ 0xF0A58C82, 0x4E0BE },
	{ 0xF0A58C83, 0x5E8D0 },
	{ 0xF0A58C84, 0x4E0BB },
	{ 0xF0A58C85, 0x5E8D4 },
	{ 0xF0A58C86, 0x5E8CE },
	{ 0xF0A58C87, 0x7C8B2 },
	{ 0xF0A58C88, 0x4E0BA },
	{ 0xF0A58C89, 0x7C8B4 },
	{ 0xF0A58C8A, 0x4E0BC },
	{ 0xF0A58C8B, 0x4E0BD },
	{ 0xF0A58C8C, 0x7C8B0 },
	{ 0xF0A58C8D, 0x5E8CD },
	{ 0xF0A58C8E, 0x7C8B1 },
	{ 0xF0A58C8F, 0x5E8D3 },
	{ 0xF0A58C90, 0x5E8D2 },
	{ 0xF0A58C94, 0xFE3AA },
	{ 0xF0A58C95, 0x7CBDD },
	{ 0xF0A58C96, 0x7C8B5 },
	{ 0xF0A58C97, 0x7C8B3 },
	{ 0xF0A58C9A, 0x5ECE0 },
	{ 0xF0A58C9B, 0x5ECE2 },
	{ 0xF0A58C9C, 0x5ECDE },
	{ 0xF0A58C9D, 0x7CED8 },
	{ 0xF0A58C9E, 0x5ECE1 },
	{ 0xF0A58C9F, 0x5ECE3 },
	{ 0xF0A58CA1, 0x7CED7 },
	{ 0xF0A58CA2, 0xFE5D7 },
	{ 0xF0A58CA3, 0x4E3F2 },
	{ 0xF0A58CA8, 0x5ECDF },
	{ 0xF0A58CA9, 0x4E3F3 },
	{ 0xF0A58CAA, 0x7CED6 },
	{ 0xF0A58CAD, 0x7D4A2 },
	{ 0xF0A58CAE, 0x5F0D2 },
	{ 0xF0A58CAF, 0x5F0D4 },
	{ 0xF0A58CB0, 0x5F0D3 },
	{ 0xF0A58CB1, 0x5F0D5 },
	{ 0xF0A58CB2, 0x7D3FE },
	{ 0xF0A58CB5, 0x7D4A3 },
	{ 0xF0A58CB6, 0x7D3FD },
	{ 0xF0A58CBA, 0x4E8F9 },
	{ 0xF0A58CBB, 0x5F3E3 },
	{ 0xF0A58CBC, 0x7D8C6 },
	{ 0xF0A58CBD, 0x5F3E1 },
	{ 0xF0A58CBE, 0x5F3E2 },
	{ 0xF0A58CBF, 0x7D8C7 },
	{ 0xF0A58D80, 0x5F3E5 },
	{ 0xF0A58D81, 0x4EAD9 },
	{ 0xF0A58D82, 0x7D4A1 },
	{ 0xF0A58D83, 0x5F3E4 },
	{ 0xF0A58D84, 0x7D9B3 },
	{ 0xF0A58D86, 0x5F3E6 },
	{ 0xF0A58D89, 0x5F6AB },
	{ 0xF0A58D8A, 0x7DCA6 },
	{ 0xF0A58D8B, 0x4EAD8 },
	{ 0xF0A58D8C, 0x7DCA5 },
	{ 0xF0A58D8F, 0x7DFA4 },
	{ 0xF0A58D93, 0x4ECF4 },
	{ 0xF0A58D94, 0x7E2C3 },
	{ 0xF0A58D95, 0x7E2C5 },
	{ 0xF0A58D97, 0x7E2C4 },
	{ 0xF0A58D99, 0xFECE6 },
	{ 0xF0A58D9A, 0x5FBC3 },
	{ 0xF0A58D9E, 0x5A7C4 },
	{ 0xF0A58D9F, 0x4AAE0 },
	{ 0xF0A58DA0, 0x4AAE1 },
	{ 0xF0A58DA1, 0x4AED6 },
	{ 0xF0A58DA2, 0x5AFA8 },
	{ 0xF0A58DA3, 0x5AFA7 },
	{ 0xF0A58DA4, 0x6BAAF },
	{ 0xF0A58DA5, 0x6BAB0 },
	{ 0xF0A58DA7, 0x4B3D8 },
	{ 0xF0A58DA8, 0x5B4A2 },
	{ 0xF0A58DA9, 0xFB7A7 },
	{ 0xF0A58DAA, 0x5BAD2 },
	{ 0xF0A58DAB, 0x4B9D1 },
	{ 0xF0A58DAC, 0x5BAD3 },
	{ 0xF0A58DAD, 0x5BAD1 },
	{ 0xF0A58DAE, 0x5BAD5 },
	{ 0xF0A58DAF, 0x5BAD0 },
	{ 0xF0A58DB0, 0x6CCA9 },
	{ 0xF0A58DB1, 0x5BAD4 },
	{ 0xF0A58DB2, 0x5C1A3 },
	{ 0xF0A58DB3, 0x5C1A2 },
	{ 0xF0A58DB5, 0x5C1A1 },
	{ 0xF0A58DB6, 0x6DFD1 },
	{ 0xF0A58DB7, 0x6DFD2 },
	{ 0xF0A58DB8, 0x4C5C7 },
	{ 0xF0A58DB9, 0x4C5C8 },
	{ 0xF0A58DBA, 0x5C7EC },
	{ 0xF0A58DBB, 0x5C7EA },
	{ 0xF0A58DBC, 0x5C7EB },
	{ 0xF0A58DBD, 0x4C5C9 },
	{ 0xF0A58DBE, 0x6DFD0 },
	{ 0xF0A58DBF, 0x4C5CB },
	{ 0xF0A58E80, 0xFCDBF },
	{ 0xF0A58E82, 0x5CEEE },
	{ 0xF0A58E83, 0x4CBD2 },
	{ 0xF0A58E84, 0x7A5F5 },
	{ 0xF0A58E85, 0x5CEEF },
	{ 0xF0A58E86, 0x4CBD1 },
	{ 0xF0A58E87, 0x7A5F4 },
	{ 0xF0A58E89, 0x4CBD3 },
	{ 0xF0A58E8A, 0x4D1E9 },
	{ 0xF0A58E8B, 0x4D1E8 },
	{ 0xF0A58E8C, 0x4D1EA },
	{ 0xF0A58E8D, 0x5D6AD },
	{ 0xF0A58E8E, 0x5E2F5 },
	{ 0xF0A58E8F, 0x7B9E5 },
	{ 0xF0A58E90, 0x5DAF5 },
	{ 0xF0A58E92, 0x5DCD0 },
	{ 0xF0A58E93, 0x5E2F4 },
	{ 0xF0A58E94, 0x5E2F3 },
	{ 0xF0A58E95, 0x5E2F2 },
	{ 0xF0A58E96, 0x5E8D7 },
	{ 0xF0A58E97, 0x5E8D6 },
	{ 0xF0A58E98, 0x5E8D5 },
	{ 0xF0A58E99, 0x5E8D8 },
	{ 0xF0A58E9A, 0x7C8B6 },
	{ 0xF0A58E9C, 0x7C8B7 },
	{ 0xF0A58EA1, 0x4EADA },
	{ 0xF0A58EA4, 0x7E6BF },
	{ 0xF0A58EA5, 0x7E6C9 },
	{ 0xF0A58EA6, 0x6A6BF },
	{ 0xF0A58EA7, 0x6A8EB },
	{ 0xF0A58EA8, 0x6A8EC },
	{ 0xF0A58EA9, 0x6B3C1 },
	{ 0xF0A58EAA, 0x6B3BF },
	{ 0xF0A58EAB, 0x6B3C0 },
	{ 0xF0A58EAC, 0x5AAEE },
	{ 0xF0A58EB0, 0x5AFAA },
	{ 0xF0A58EB1, 0x5AFAB },
	{ 0xF0A58EB2, 0x6BAB3 },
	{ 0xF0A58EB3, 0xFB1BF },
	{ 0xF0A58EB4, 0xFB1C0 },
	{ 0xF0A58EB5, 0x6BAB1 },
	{ 0xF0A58EB6, 0x6BAB2 },
	{ 0xF0A58EB8, 0x5AFA9 },
	{ 0xF0A58EB9, 0x5B4A3 },
	{ 0xF0A58EBA, 0x5B4A4 },
	{ 0xF0A58EBB, 0x4B3DC },
	{ 0xF0A58EBC, 0x6C2D9 },
	{ 0xF0A58EBD, 0x6C2D7 },
	{ 0xF0A58EBE, 0x5B4A5 },
	{ 0xF0A58EBF, 0x6C2D5 },
	{ 0xF0A58F80, 0x6C2DB },
	{ 0xF0A58F81, 0x6C2D6 },
	{ 0xF0A58F82, 0x6C2DA },
	{ 0xF0A58F89, 0x6C2D8 },
	{ 0xF0A58F8E, 0x4B9D2 },
	{ 0xF0A58F8F, 0x6CCAC },
	{ 0xF0A58F91, 0xFBDD2 },
	{ 0xF0A58F94, 0x6CCAA },
	{ 0xF0A58F97, 0xFBDD3 },
	{ 0xF0A58F98, 0x5C1A4 },
	{ 0xF0A58F99, 0x4BFB2 },
	{ 0xF0A58F9A, 0x6D5E9 },
	{ 0xF0A58F9C, 0x4BFB5 },
	{ 0xF0A58F9D, 0x4BFB4 },
	{ 0xF0A58F9E, 0x6D5E7 },
	{ 0xF0A58F9F, 0x5BAD6 },
	{ 0xF0A58FA0, 0x4BFB6 },
	{ 0xF0A58FA1, 0xFC3F5 },
	{ 0xF0A58FA2, 0x6D5E8 },
	{ 0xF0A58FAA, 0x5C7ED },
	{ 0xF0A58FAB, 0x5C7EE },
	{ 0xF0A58FAC, 0x6DFD3 },
	{ 0xF0A58FAF, 0x5C7EF },
	{ 0xF0A58FB0, 0x5C7F0 },
	{ 0xF0A58FB1, 0xFCABE },
	{ 0xF0A58FB2, 0x7A5F8 },
	{ 0xF0A58FB3, 0x4CBD4 },
	{ 0xF0A58FB4, 0x7A5F6 },
	{ 0xF0A58FB5, 0x7A5F7 },
	{ 0xF0A58FB6, 0xFD0E1 },
	{ 0xF0A58FB7, 0x7A5F9 },
	{ 0xF0A58FBB, 0x7B0D4 },
	{ 0xF0A58FBC, 0x4D1EB },
	{ 0xF0A58FBD, 0xFD6BF },
	{ 0xF0A58FBE, 0x7B0D3 },
	{ 0xF0A59080, 0x5DCD1 },
	{ 0xF0A59081, 0x5DCD2 },
	{ 0xF0A59083, 0x7B9E6 },
	{ 0xF0A59084, 0x7B9E7 },
	{ 0xF0A59091, 0x5F3E7 },
	{ 0xF0A59093, 0x5F6AC },
	{ 0xF0A59095, 0x5A2FE },
	{ 0xF0A59096, 0x6A5BE },
	{ 0xF0A59097, 0x4A4E7 },
	{ 0xF0A59098, 0x6A8ED },
	{ 0xF0A59099, 0x5A4ED },
	{ 0xF0A5909A, 0x5A4EC },
	{ 0xF0A5909B, 0xFA5A1 },
	{ 0xF0A5909C, 0xFA5A2 },
	{ 0xF0A5909D, 0x5A7C5 },
	{ 0xF0A5909E, 0x4A7D4 },
	{ 0xF0A590A0, 0xFA8B0 },
	{ 0xF0A590A1, 0xFA8B1 },
	{ 0xF0A590A2, 0xFA8B2 },
	{ 0xF0A590A3, 0xFA8B3 },
	{ 0xF0A590A4, 0x6ADC7 },
	{ 0xF0A590A5, 0xFA8B5 },
	{ 0xF0A590A9, 0x4AAE5 },
	{ 0xF0A590AA, 0x4AAE3 },
	{ 0xF0A590AB, 0x6B3C5 },
	{ 0xF0A590AC, 0x5AAF0 },
	{ 0xF0A590B1, 0xFACD9 },
	{ 0xF0A590B2, 0xFACDA },
	{ 0xF0A590B3, 0xFACDB },
	{ 0xF0A590B4, 0xFACDD },
	{ 0xF0A590B5, 0xFACDE },
	{ 0xF0A590B6, 0xFACDF },
	{ 0xF0A590B7, 0xFACE1 },
	{ 0xF0A590B8, 0xFACE3 },
	{ 0xF0A590BA, 0x6B3C3 },
	{ 0xF0A590BC, 0x6B3C4 },
	{ 0xF0A590BD, 0xFACE4 },
	{ 0xF0A59180, 0xFACE0 },
	{ 0xF0A59181, 0x6B3C2 },
	{ 0xF0A59184, 0x5AAEF },
	{ 0xF0A59185, 0x5AAF1 },
	{ 0xF0A59186, 0x4AEE0 },
	{ 0xF0A59187, 0x5AFB3 },
	{ 0xF0A59188, 0x6BAB4 },
	{ 0xF0A59189, 0x6B3C6 },
	{ 0xF0A5918A, 0x6BAB5 },
	{ 0xF0A5918B, 0x5AFAF },
	{ 0xF0A5918C, 0x6BAB9 },
	{ 0xF0A5918D, 0x5AFAC },
	{ 0xF0A5918E, 0x5AFB1 },
	{ 0xF0A5918F, 0x5AFB0 },
	{ 0xF0A59190, 0x4AEDB },
	{ 0xF0A59191, 0x4AEDD },
	{ 0xF0A59192, 0x5AFB6 },
	{ 0xF0A59193, 0x5AFB2 },
	{ 0xF0A59194, 0x5AFB5 },
	{ 0xF0A59197, 0xFB1BE },
	{ 0xF0A59198, 0x4AED9 },
	{ 0xF0A59199, 0x5AFB7 },
	{ 0xF0A5919A, 0x6BAB8 },
	{ 0xF0A5919B, 0xFB1C2 },
	{ 0xF0A5919C, 0xFB1C3 },
	{ 0xF0A5919D, 0xFB1C5 },
	{ 0xF0A5919E, 0xFB1C6 },
	{ 0xF0A591A2, 0x4AEDA },
	{ 0xF0A591A3, 0x5AFAD },
	{ 0xF0A591A9, 0x6BAB7 },
	{ 0xF0A591AC, 0xFB1C8 },
	{ 0xF0A591AE, 0xFB1C1 },
	{ 0xF0A591AF, 0x5B4A6 },
	{ 0xF0A591B0, 0x5AFAE },
	{ 0xF0A591B2, 0x6BAB6 },
	{ 0xF0A591B3, 0x5B4AC },
	{ 0xF0A591B4, 0x5B4A8 },
	{ 0xF0A591B5, 0x6C2E1 },
	{ 0xF0A591B6, 0x6C2DF },
	{ 0xF0A591B8, 0x5B4B1 },
	{ 0xF0A591B9, 0x5B4B0 },
	{ 0xF0A591BA, 0x5B4AA },
	{ 0xF0A591BB, 0x6C2E0 },
	{ 0xF0A591BC, 0x5B4B4 },
	{ 0xF0A591BD, 0x5B4B2 },
	{ 0xF0A591BE, 0x5AFB8 },
	{ 0xF0A591BF, 0x5B4AE },
	{ 0xF0A59280, 0x5B4A7 },
	{ 0xF0A59281, 0x5B4A9 },
	{ 0xF0A59282, 0x5B4AD },
	{ 0xF0A59284, 0xFB7A8 },
	{ 0xF0A59286, 0xFB7A9 },
	{ 0xF0A59287, 0xFB7AA },
	{ 0xF0A59288, 0xFB7AB },
	{ 0xF0A59289, 0xFB7AE },
	{ 0xF0A5928A, 0xFB7AF },
	{ 0xF0A5928B, 0xFB7B1 },
	{ 0xF0A5928C, 0xFB7B2 },
	{ 0xF0A5928D, 0xFB7B3 },
	{ 0xF0A5928F, 0x6C2DE },
	{ 0xF0A59292, 0x6C2DC },
	{ 0xF0A59294, 0x6CCAE },
	{ 0xF0A59296, 0xFB7B0 },
	{ 0xF0A5929C, 0x5B4AB },
	{ 0xF0A5929E, 0xFB7AC },
	{ 0xF0A592A4, 0x6C2E2 },
	{ 0xF0A592A7, 0x5B4AF },
	{ 0xF0A592A8, 0x5B4B3 },
	{ 0xF0A592A9, 0x6C2DD },
	{ 0xF0A592AA, 0x5BAD8 },
	{ 0xF0A592AB, 0x5BADE },
	{ 0xF0A592AC, 0x5BAD7 },
	{ 0xF0A592AD, 0x5BADB },
	{ 0xF0A592AE, 0x4B9D6 },
	{ 0xF0A592AF, 0x6CCB5 },
	{ 0xF0A592B0, 0x4B9D7 },
	{ 0xF0A592B1, 0x4B9D5 },
	{ 0xF0A592B2, 0x5BADC },
	{ 0xF0A592B3, 0x5BADD },
	{ 0xF0A592B4, 0x6CCB1 },
	{ 0xF0A592B5, 0x5BADA },
	{ 0xF0A592B6, 0x5BADF },
	{ 0xF0A592B9, 0xFBDD4 },
	{ 0xF0A592BA, 0xFBDD5 },
	{ 0xF0A592BB, 0xFBDD6 },
	{ 0xF0A592BC, 0xFBDD7 },
	{ 0xF0A592BD, 0x6CCB4 },
	{ 0xF0A59380, 0x6CCB0 },
	{ 0xF0A59381, 0x6CCB2 },
	{ 0xF0A59386, 0x5BAE1 },
	{ 0xF0A59387, 0x5BAE0 },
	{ 0xF0A5938A, 0x5C1A8 },
	{ 0xF0A5938B, 0x6D5F1 },
	{ 0xF0A5938C, 0x4BFB7 },
	{ 0xF0A5938D, 0x5C1A9 },
	{ 0xF0A5938E, 0x6D5EA },
	{ 0xF0A5938F, 0x6D5EC },
	{ 0xF0A59390, 0x5C1A5 },
	{ 0xF0A59391, 0x6D5EE },
	{ 0xF0A59392, 0x4BFC1 },
	{ 0xF0A59393, 0x4BFC3 },
	{ 0xF0A59394, 0x6D5EF },
	{ 0xF0A59395, 0x6D5F2 },
	{ 0xF0A59396, 0x5C1A6 },
	{ 0xF0A59397, 0x5C1A7 },
	{ 0xF0A5939A, 0x6D5ED },
	{ 0xF0A5939B, 0xFC3F7 },
	{ 0xF0A5939C, 0xFC3F8 },
	{ 0xF0A5939D, 0xFC3F9 },
	{ 0xF0A5939E, 0xFC3FA },
	{ 0xF0A5939F, 0xFC3FB },
	{ 0xF0A593A0, 0xFC3FC },
	{ 0xF0A593A1, 0xFC3FD },
	{ 0xF0A593A2, 0xFC3FE },
	{ 0xF0A593A3, 0xFC4A1 },
	{ 0xF0A593A4, 0xFC4A2 },
	{ 0xF0A593A5, 0xFC4A3 },
	{ 0xF0A593A6, 0xFC4A4 },
	{ 0xF0A593A7, 0xFC4A6 },
	{ 0xF0A593AD, 0x6D5F0 },
	{ 0xF0A593B1, 0x6D5F3 },
	{ 0xF0A593BA, 0x6DFDB },
	{ 0xF0A593BB, 0x5C7F8 },
	{ 0xF0A593BC, 0x6DFD4 },
	{ 0xF0A593BD, 0x7A5FE },
	{ 0xF0A593BE, 0x5C7FA },
	{ 0xF0A593BF, 0x6DFD6 },
	{ 0xF0A59480, 0x4C5D2 },
	{ 0xF0A59481, 0x5C7F3 },
	{ 0xF0A59482, 0x5C7F2 },
	{ 0xF0A59483, 0x6DFD7 },
	{ 0xF0A59484, 0x5C7FB },
	{ 0xF0A59485, 0x6DFD9 },
	{ 0xF0A59486, 0x6DFDA },
	{ 0xF0A59487, 0x5C7F5 },
	{ 0xF0A59488, 0x6DFD5 },
	{ 0xF0A59489, 0x5C7F1 },
	{ 0xF0A5948A, 0x5C7FD },
	{ 0xF0A59490, 0x6DFD8 },
	{ 0xF0A59492, 0xFCAC1 },
	{ 0xF0A59493, 0xFCAC3 },
	{ 0xF0A59494, 0xFCAC4 },
	{ 0xF0A59495, 0xFCAC5 },
	{ 0xF0A59496, 0xFCAC6 },
	{ 0xF0A59497, 0xFCAC7 },
	{ 0xF0A59498, 0xFCAC8 },
	{ 0xF0A59499, 0xFCAC9 },
	{ 0xF0A5949A, 0xFCACB },
	{ 0xF0A5949B, 0xFCACC },
	{ 0xF0A5949C, 0xFCACD },
	{ 0xF0A5949D, 0xFCACF },
	{ 0xF0A5949E, 0xFCAD0 },
	{ 0xF0A5949F, 0xFCAD1 },
	{ 0xF0A594A0, 0xFCAD2 },
	{ 0xF0A594A2, 0x4C5D4 },
	{ 0xF0A594A3, 0xFCAC0 },
	{ 0xF0A594A8, 0x5C7F7 },
	{ 0xF0A594A9, 0x5C7FC },
	{ 0xF0A594AA, 0x5C7F9 },
	{ 0xF0A594AB, 0x5C7F4 },
	{ 0xF0A594AC, 0xFD0E4 },
	{ 0xF0A594AD, 0x4CBDA },
	{ 0xF0A594AE, 0x5CEF2 },
	{ 0xF0A594AF, 0x5CEF3 },
	{ 0xF0A594B0, 0x7A6A1 },
	{ 0xF0A594B1, 0x5CEF0 },
	{ 0xF0A594B2, 0x4C5D0 },
	{ 0xF0A594B3, 0x7A6A5 },
	{ 0xF0A594B4, 0x5CEF5 },
	{ 0xF0A594B5, 0x7A5FD },
	{ 0xF0A594B6, 0xFD0E2 },
	{ 0xF0A594B7, 0xFD0E3 },
	{ 0xF0A594B8, 0xFD0E5 },
	{ 0xF0A594B9, 0xFD0E6 },
	{ 0xF0A594BA, 0xFD0E8 },
	{ 0xF0A59583, 0x7A6A2 },
	{ 0xF0A59585, 0x7A5FA },
	{ 0xF0A59586, 0x7A6A3 },
	{ 0xF0A59587, 0x5CEF1 },
	{ 0xF0A59588, 0x5CEF4 },
	{ 0xF0A59589, 0x7A5FC },
	{ 0xF0A5958B, 0xFCACA },
	{ 0xF0A5958C, 0x7B0D8 },
	{ 0xF0A5958D, 0x5D6B1 },
	{ 0xF0A5958E, 0x5D6AE },
	{ 0xF0A5958F, 0x5D6B2 },
	{ 0xF0A59590, 0x7B0D5 },
	{ 0xF0A59591, 0x4D1F1 },
	{ 0xF0A59593, 0x4D1F3 },
	{ 0xF0A59594, 0x5D6B4 },
	{ 0xF0A59595, 0x4D1F2 },
	{ 0xF0A59596, 0x7B0D6 },
	{ 0xF0A59597, 0x7B0DA },
	{ 0xF0A59598, 0x4D1EF },
	{ 0xF0A5959A, 0x7B0D7 },
	{ 0xF0A5959E, 0xFD6C1 },
	{ 0xF0A5959F, 0xFD6C2 },
	{ 0xF0A595A0, 0xFD6C3 },
	{ 0xF0A595A1, 0x5D6B0 },
	{ 0xF0A595A5, 0xFD6C4 },
	{ 0xF0A595A6, 0x5D6AF },
	{ 0xF0A595A7, 0xFD6C5 },
	{ 0xF0A595A8, 0xFD6C6 },
	{ 0xF0A595A9, 0xFD6C7 },
	{ 0xF0A595AA, 0xFD6C9 },
	{ 0xF0A595AB, 0xFD6CB },
	{ 0xF0A595AC, 0xFD6CC },
	{ 0xF0A595AD, 0xFD6CD },
	{ 0xF0A595B0, 0x5DCD6 },
	{ 0xF0A595B1, 0x7B9E8 },
	{ 0xF0A595B2, 0x5DCD4 },
	{ 0xF0A595B3, 0x7B9EF },
	{ 0xF0A595B4, 0x7B9EA },
	{ 0xF0A595B5, 0x5DCD3 },
	{ 0xF0A595B6, 0x4D7BA },
	{ 0xF0A595B7, 0x7B9E9 },
	{ 0xF0A595B8, 0x5DCD5 },
	{ 0xF0A595B9, 0x4D7BD },
	{ 0xF0A595BA, 0x7B9EC },
	{ 0xF0A595BB, 0x4D7BC },
	{ 0xF0A595BC, 0x5D6B5 },
	{ 0xF0A595BD, 0x5DCD8 },
	{ 0xF0A595BE, 0x5DCD7 },
	{ 0xF0A595BF, 0x5DCD9 },
	{ 0xF0A59682, 0xFDBC1 },
	{ 0xF0A59683, 0xFDBC2 },
	{ 0xF0A59684, 0xFDBC3 },
	{ 0xF0A59685, 0xFDBC4 },
	{ 0xF0A59686, 0xFDBC5 },
	{ 0xF0A59687, 0xFDBC6 },
	{ 0xF0A59688, 0xFDBC7 },
	{ 0xF0A59689, 0xFDBC8 },
	{ 0xF0A5968A, 0xFDBC9 },
	{ 0xF0A5968B, 0x7B9EB },
	{ 0xF0A5968C, 0x7B9EE },
	{ 0xF0A5968F, 0xFD6CA },
	{ 0xF0A59697, 0x7C1A9 },
	{ 0xF0A59698, 0x5E2F6 },
	{ 0xF0A59699, 0x5E2F8 },
	{ 0xF0A5969A, 0x7C1A6 },
	{ 0xF0A5969B, 0x7C1A8 },
	{ 0xF0A5969C, 0x5E2F7 },
	{ 0xF0A5969D, 0x4DCB0 },
	{ 0xF0A5969E, 0x5E2FA },
	{ 0xF0A5969F, 0x7C1A7 },
	{ 0xF0A596A0, 0x5E2F9 },
	{ 0xF0A596A1, 0x7C1AA },
	{ 0xF0A596A2, 0xFDFE5 },
	{ 0xF0A596A3, 0xFDFE6 },
	{ 0xF0A596A4, 0xFDFE7 },
	{ 0xF0A596A5, 0xFDFE8 },
	{ 0xF0A596A6, 0xFDFE9 },
	{ 0xF0A596AA, 0x4E0C0 },
	{ 0xF0A596AB, 0x5E8DA },
	{ 0xF0A596AC, 0x5E8D9 },
	{ 0xF0A596AE, 0xFE3AB },
	{ 0xF0A596AF, 0xFE3AC },
	{ 0xF0A596B0, 0xFE3AD },
	{ 0xF0A596B1, 0xFE3AE },
	{ 0xF0A596B3, 0x7C8BA },
	{ 0xF0A596B4, 0x7C8B8 },
	{ 0xF0A596B7, 0x7C8B9 },
	{ 0xF0A596B9, 0xFE3AF },
	{ 0xF0A596BB, 0x5ECE5 },
	{ 0xF0A596BC, 0x5ECE6 },
	{ 0xF0A596BD, 0x7CED9 },
	{ 0xF0A596BE, 0x7CEDA },
	{ 0xF0A596BF, 0x5ECE4 },
	{ 0xF0A59780, 0x5ECE7 },
	{ 0xF0A59781, 0x4E0C1 },
	{ 0xF0A59782, 0x7CEDB },
	{ 0xF0A59783, 0xFE5DA },
	{ 0xF0A59784, 0xFE5DB },
	{ 0xF0A59785, 0xFE5DC },
	{ 0xF0A59786, 0xFE5DD },
	{ 0xF0A59789, 0x7CEDD },
	{ 0xF0A59792, 0x5F0D6 },
	{ 0xF0A59793, 0x5F0D7 },
	{ 0xF0A59796, 0xFE7FD },
	{ 0xF0A59798, 0x7D4A4 },
	{ 0xF0A59799, 0x4E6E2 },
	{ 0xF0A5979B, 0xFE7FC },
	{ 0xF0A5979D, 0x5F3E8 },
	{ 0xF0A5979E, 0x7D8C8 },
	{ 0xF0A5979F, 0x5F3E9 },
	{ 0xF0A597A1, 0xFE9DB },
	{ 0xF0A597A2, 0xFE9DC },
	{ 0xF0A597A3, 0x7D8C9 },
	{ 0xF0A597AA, 0x5F3EA },
	{ 0xF0A597AB, 0x5F6AE },
	{ 0xF0A597AC, 0x4EADB },
	{ 0xF0A597AD, 0x5F6AD },
	{ 0xF0A597AE, 0x5F6AF },
	{ 0xF0A597AF, 0xFEAE5 },
	{ 0xF0A597B1, 0x7DCA8 },
	{ 0xF0A597B2, 0x7DCA7 },
	{ 0xF0A597B4, 0x7DFA6 },
	{ 0xF0A597B7, 0x7DFA5 },
	{ 0xF0A597B8, 0x7DFA7 },
	{ 0xF0A597BA, 0x7E2C6 },
	{ 0xF0A597BB, 0x5FAAD },
	{ 0xF0A597BE, 0x5FAEE },
	{ 0xF0A597BF, 0x4EDF5 },
	{ 0xF0A59881, 0x7E4D3 },
	{ 0xF0A59883, 0x7E5BB },
	{ 0xF0A59884, 0x5FCC3 },
	{ 0xF0A59885, 0x6A2A7 },
	{ 0xF0A59886, 0x6A5C0 },
	{ 0xF0A59888, 0x6A8EE },
	{ 0xF0A59889, 0xFA2E8 },
	{ 0xF0A5988D, 0x6ADC8 },
	{ 0xF0A5988E, 0xFA5A4 },
	{ 0xF0A59895, 0x6B3C7 },
	{ 0xF0A59896, 0x6B3C9 },
	{ 0xF0A59899, 0xFA8B6 },
	{ 0xF0A5989A, 0xFA8B8 },
	{ 0xF0A5989B, 0xFA8B9 },
	{ 0xF0A5989C, 0xFA8BA },
	{ 0xF0A5989D, 0xFA8BB },
	{ 0xF0A5989E, 0xFA8BD },
	{ 0xF0A598A4, 0xFA8B7 },
	{ 0xF0A598A6, 0x6B1DA },
	{ 0xF0A598AB, 0x5AFB9 },
	{ 0xF0A598AC, 0x6BABA },
	{ 0xF0A598AD, 0x4AEE3 },
	{ 0xF0A598AE, 0x5AFBA },
	{ 0xF0A598B0, 0x6BABB },
	{ 0xF0A598B1, 0x6B3CB },
	{ 0xF0A598B8, 0xFACE5 },
	{ 0xF0A598B9, 0xFACE6 },
	{ 0xF0A598BA, 0xFACE7 },
	{ 0xF0A598BB, 0xFACE8 },
	{ 0xF0A598BC, 0xFACE9 },
	{ 0xF0A598BD, 0xFB1C9 },
	{ 0xF0A598BE, 0xFB1CB },
	{ 0xF0A598BF, 0xFB1CE },
	{ 0xF0A59982, 0x6BABE },
	{ 0xF0A59984, 0x6BABF },
	{ 0xF0A59989, 0x6BABD },
	{ 0xF0A5998A, 0x6BAC0 },
	{ 0xF0A5998B, 0x6BABC },
	{ 0xF0A5998C, 0xFACEA },
	{ 0xF0A5998D, 0x4AAE8 },
	{ 0xF0A5998E, 0x5B4B6 },
	{ 0xF0A5998F, 0x6BAC1 },
	{ 0xF0A59994, 0xFB1CA },
	{ 0xF0A59995, 0xFB1CC },
	{ 0xF0A59996, 0xFB1CD },
	{ 0xF0A59997, 0xFB1CF },
	{ 0xF0A59998, 0xFB1D0 },
	{ 0xF0A59999, 0xFB1D1 },
	{ 0xF0A5999A, 0xFB1D2 },
	{ 0xF0A5999B, 0xFB1D3 },
	{ 0xF0A5999C, 0xFB1D4 },
	{ 0xF0A5999D, 0xFB7B7 },
	{ 0xF0A599A4, 0x6C2E3 },
	{ 0xF0A599A8, 0x5B4B5 },
	{ 0xF0A599AB, 0x6CCB8 },
	{ 0xF0A599AC, 0x5BAE2 },
	{ 0xF0A599AD, 0x6CCB9 },
	{ 0xF0A599AE, 0x6CCBA },
	{ 0xF0A599AF, 0x6CCBC },
	{ 0xF0A599B0, 0x5BAE3 },
	{ 0xF0A599B1, 0x6CCBD },
	{ 0xF0A599B2, 0x6CCBB },
	{ 0xF0A599B7, 0x6CCB6 },
	{ 0xF0A599B8, 0x6CCB7 },
	{ 0xF0A599B9, 0xFB7B4 },
	{ 0xF0A599BA, 0xFB7B6 },
	{ 0xF0A599BB, 0xFB7B8 },
	{ 0xF0A599BC, 0xFBDDB },
	{ 0xF0A59A83, 0xFB7B5 },
	{ 0xF0A59A88, 0x6D5F5 },
	{ 0xF0A59A89, 0x5C1AB },
	{ 0xF0A59A8A, 0x5C1AA },
	{ 0xF0A59A8B, 0x5C1AC },
	{ 0xF0A59A8C, 0x6CCBF },
	{ 0xF0A59A8D, 0x4BFC8 },
	{ 0xF0A59A8E, 0xFBDD8 },
	{ 0xF0A59A8F, 0xFBDD9 },
	{ 0xF0A59A90, 0xFBDDA },
	{ 0xF0A59A91, 0xFBDDC },
	{ 0xF0A59A92, 0xFBDDD },
	{ 0xF0A59A93, 0xFBDDE },
	{ 0xF0A59A94, 0xFBDDF },
	{ 0xF0A59A95, 0xFBDE2 },
	{ 0xF0A59A96, 0xFBDE3 },
	{ 0xF0A59A97, 0xFBDE4 },
	{ 0xF0A59A98, 0xFC4A8 },
	{ 0xF0A59A99, 0xFC4AA },
	{ 0xF0A59A9A, 0xFBDE1 },
	{ 0xF0A59A9C, 0x6D5F4 },
	{ 0xF0A59AA6, 0x5C8A3 },
	{ 0xF0A59AA7, 0x6DFDF },
	{ 0xF0A59AA8, 0x6DFE0 },
	{ 0xF0A59AA9, 0x4C5D6 },
	{ 0xF0A59AAA, 0x6DFE3 },
	{ 0xF0A59AAB, 0x6DFE1 },
	{ 0xF0A59AB0, 0xFC4A7 },
	{ 0xF0A59AB1, 0xFC4A9 },
	{ 0xF0A59AB2, 0xFC4AB },
	{ 0xF0A59AB3, 0xFC4AC },
	{ 0xF0A59AB4, 0xFC4AD },
	{ 0xF0A59AB5, 0xFC4AE },
	{ 0xF0A59AB6, 0xFC4AF },
	{ 0xF0A59AB7, 0xFC4B0 },
	{ 0xF0A59AB8, 0xFC4B1 },
	{ 0xF0A59AB9, 0xFC4B2 },
	{ 0xF0A59B80, 0x6DFDD },
	{ 0xF0A59B81, 0x6DFE2 },
	{ 0xF0A59B82, 0x5C8A1 },
	{ 0xF0A59B83, 0x6DFDE },
	{ 0xF0A59B85, 0x4CBDF },
	{ 0xF0A59B86, 0x7A6A6 },
	{ 0xF0A59B87, 0x6DFDC },
	{ 0xF0A59B88, 0x6DFE4 },
	{ 0xF0A59B8A, 0xFCAD3 },
	{ 0xF0A59B8B, 0xFCAD5 },
	{ 0xF0A59B8C, 0xFCAD6 },
	{ 0xF0A59B8D, 0xFCAD7 },
	{ 0xF0A59B8E, 0xFCAD8 },
	{ 0xF0A59B8F, 0xFCADA },
	{ 0xF0A59B94, 0x7A6A8 },
	{ 0xF0A59B98, 0x5D6B8 },
	{ 0xF0A59B99, 0x7B0DC },
	{ 0xF0A59B9A, 0x5D6B6 },
	{ 0xF0A59B9B, 0x7B0DD },
	{ 0xF0A59B9C, 0x4D1F7 },
	{ 0xF0A59B9D, 0x5D6B9 },
	{ 0xF0A59B9E, 0x5D6B7 },
	{ 0xF0A59B9F, 0x5D6BA },
	{ 0xF0A59BA0, 0x7A6AA },
	{ 0xF0A59BA1, 0x7B0DB },
	{ 0xF0A59BA2, 0xFD0EA },
	{ 0xF0A59BA3, 0xFD0E9 },
	{ 0xF0A59BA4, 0xFD6D1 },
	{ 0xF0A59BAE, 0x4D7C3 },
	{ 0xF0A59BAF, 0x5DCDA },
	{ 0xF0A59BB0, 0x7B9F3 },
	{ 0xF0A59BB1, 0x4D7C4 },
	{ 0xF0A59BB2, 0x7B9F6 },
	{ 0xF0A59BB3, 0x7B9F4 },
	{ 0xF0A59BB4, 0x7B0DE },
	{ 0xF0A59BB5, 0xFD0EB },
	{ 0xF0A59BB7, 0xFD6CE },
	{ 0xF0A59BB8, 0xFD6CF },
	{ 0xF0A59BB9, 0xFD6D0 },
	{ 0xF0A59BBA, 0xFD6D2 },
	{ 0xF0A59BBB, 0x7B9F1 },
	{ 0xF0A59BBC, 0x7B9F5 },
	{ 0xF0A59BBD, 0x7B9F2 },
	{ 0xF0A59BBF, 0x7B9F0 },
	{ 0xF0A59C81, 0xFDBCD },
	{ 0xF0A59C82, 0xFDBCF },
	{ 0xF0A59C83, 0x4DCB4 },
	{ 0xF0A59C84, 0x5E2FB },
	{ 0xF0A59C85, 0x7C1AC },
	{ 0xF0A59C87, 0xFDBCB },
	{ 0xF0A59C88, 0xFDBCC },
	{ 0xF0A59C89, 0xFDBCE },
	{ 0xF0A59C8A, 0xFDBD0 },
	{ 0xF0A59C8B, 0xFDBD1 },
	{ 0xF0A59C8C, 0xFDBD2 },
	{ 0xF0A59C8F, 0x7C1AB },
	{ 0xF0A59C91, 0x4DCB3 },
	{ 0xF0A59C92, 0x5E8DB },
	{ 0xF0A59C93, 0x7C8BC },
	{ 0xF0A59C94, 0x7C8BD },
	{ 0xF0A59C95, 0xFDFEA },
	{ 0xF0A59C97, 0xFDFEB },
	{ 0xF0A59C9A, 0x5ECE8 },
	{ 0xF0A59C9B, 0x4E3F7 },
	{ 0xF0A59C9E, 0xFE5DE },
	{ 0xF0A59C9F, 0x7CEDE },
	{ 0xF0A59CA0, 0x7D4A6 },
	{ 0xF0A59CA3, 0x7D4A5 },
	{ 0xF0A59CA5, 0xFE5DF },
	{ 0xF0A59CA6, 0x4E8FD },
	{ 0xF0A59CA7, 0x7D8CA },
	{ 0xF0A59CA9, 0x7D8CB },
	{ 0xF0A59CAA, 0x7DCA9 },
	{ 0xF0A59CAB, 0xFE9DD },
	{ 0xF0A59CAC, 0x7DCAA },
	{ 0xF0A59CAF, 0x7DCAB },
	{ 0xF0A59CB0, 0x5F7EE },
	{ 0xF0A59CB1, 0x7DCAC },
	{ 0xF0A59CB2, 0x5F7EF },
	{ 0xF0A59CB3, 0xFEAE7 },
	{ 0xF0A59CB4, 0x5F9B2 },
	{ 0xF0A59CB7, 0x7E2C9 },
	{ 0xF0A59CB8, 0x7E2C7 },
	{ 0xF0A59CB9, 0x7E3DD },
	{ 0xF0A59CBA, 0xFECE7 },
	{ 0xF0A59CBB, 0xFA2E9 },
	{ 0xF0A59CBC, 0x6B3CD },
	{ 0xF0A59CBD, 0x6C2E4 },
	{ 0xF0A59CBE, 0x4B9DB },
	{ 0xF0A59CBF, 0x6CCC0 },
	{ 0xF0A59D81, 0x6D5F6 },
	{ 0xF0A59D83, 0x6DFE5 },
	{ 0xF0A59D84, 0x7A6AC },
	{ 0xF0A59D85, 0x7B0DF },
	{ 0xF0A59D87, 0x7B0E0 },
	{ 0xF0A59D88, 0x7C1AD },
	{ 0xF0A59D8A, 0x5F3EB },
	{ 0xF0A59D8B, 0x7E1A8 },
	{ 0xF0A59D8C, 0x4A1FE },
	{ 0xF0A59D8D, 0x6A5C1 },
	{ 0xF0A59D8F, 0xFA2EA },
	{ 0xF0A59D90, 0x6A8EF },
	{ 0xF0A59D92, 0xFA5A5 },
	{ 0xF0A59D93, 0x6A8F0 },
	{ 0xF0A59D94, 0x4A7D5 },
	{ 0xF0A59D95, 0x5A7C8 },
	{ 0xF0A59D96, 0x4A7D7 },
	{ 0xF0A59D98, 0x5A7C7 },
	{ 0xF0A59D9A, 0xFA8BE },
	{ 0xF0A59D9B, 0xFA8BF },
	{ 0xF0A59D9C, 0xFA8C0 },
	{ 0xF0A59D9D, 0xFA8C1 },
	{ 0xF0A59D9E, 0xFA8C2 },
	{ 0xF0A59DA2, 0x6ADCA },
	{ 0xF0A59DA3, 0x6B3D1 },
	{ 0xF0A59DA4, 0x6B3D4 },
	{ 0xF0A59DA5, 0x5AAF4 },
	{ 0xF0A59DA6, 0x5AAF2 },
	{ 0xF0A59DA7, 0x4AAF0 },
	{ 0xF0A59DA8, 0x5AAF5 },
	{ 0xF0A59DA9, 0x6B3D6 },
	{ 0xF0A59DAA, 0x6B3D0 },
	{ 0xF0A59DAB, 0x6B3D2 },
	{ 0xF0A59DAC, 0x4AAED },
	{ 0xF0A59DAD, 0x6B3CF },
	{ 0xF0A59DAE, 0x5AAF3 },
	{ 0xF0A59DAF, 0x6B3D7 },
	{ 0xF0A59DB3, 0xFACEB },
	{ 0xF0A59DB4, 0xFACEC },
	{ 0xF0A59DB5, 0xFACEE },
	{ 0xF0A59DB6, 0xFACEF },
	{ 0xF0A59DB9, 0xFACF0 },
	{ 0xF0A59DBA, 0x6B3D5 },
	{ 0xF0A59DBB, 0x6B3D3 },
	{ 0xF0A59DBC, 0x6B3CE },
	{ 0xF0A59DBE, 0x5AFBC },
	{ 0xF0A59DBF, 0x5AFBB },
	{ 0xF0A59E80, 0x6BAC5 },
	{ 0xF0A59E81, 0x5AFBD },
	{ 0xF0A59E82, 0x6BAC6 },
	{ 0xF0A59E83, 0x5AFBE },
	{ 0xF0A59E84, 0x5AAF6 },
	{ 0xF0A59E85, 0x5B4BC },
	{ 0xF0A59E86, 0x6BAC7 },
	{ 0xF0A59E88, 0xFB1D5 },
	{ 0xF0A59E89, 0xFB1D6 },
	{ 0xF0A59E92, 0x6BAC2 },
	{ 0xF0A59E97, 0x6BAC4 },
	{ 0xF0A59E98, 0x5B4BA },
	{ 0xF0A59E99, 0x6C2E9 },
	{ 0xF0A59E9A, 0x5B4BF },
	{ 0xF0A59E9B, 0x4B3E8 },
	{ 0xF0A59E9C, 0x5B4BD },
	{ 0xF0A59E9D, 0x6C2E8 },
	{ 0xF0A59E9E, 0x5B4B7 },
	{ 0xF0A59E9F, 0xFB7BA },
	{ 0xF0A59EA0, 0xFB7BC },
	{ 0xF0A59EA1, 0xFB7BD },
	{ 0xF0A59EA2, 0xFB7BE },
	{ 0xF0A59EA9, 0x4B3EC },
	{ 0xF0A59EAF, 0x6C2E5 },
	{ 0xF0A59EB1, 0x6C2EA },
	{ 0xF0A59EB2, 0x4B9DF },
	{ 0xF0A59EB3, 0x5BAE4 },
	{ 0xF0A59EB4, 0x4B9E0 },
	{ 0xF0A59EB5, 0x4B9DC },
	{ 0xF0A59EB6, 0x6CCC1 },
	{ 0xF0A59EB7, 0x6CCC2 },
	{ 0xF0A59EB8, 0x6CCC5 },
	{ 0xF0A59EB9, 0x6CCC7 },
	{ 0xF0A59EBA, 0x4B9DD },
	{ 0xF0A59EBB, 0x6CCC4 },
	{ 0xF0A59EBC, 0x4BFD1 },
	{ 0xF0A59EBD, 0xFBDE5 },
	{ 0xF0A59EBE, 0xFBDE7 },
	{ 0xF0A59EBF, 0xFBDE9 },
	{ 0xF0A59F85, 0x5B4BE },
	{ 0xF0A59F87, 0xFBDE6 },
	{ 0xF0A59F8D, 0x5C1B6 },
	{ 0xF0A59F8E, 0x5C1AF },
	{ 0xF0A59F8F, 0x6D5F9 },
	{ 0xF0A59F90, 0x6D5F7 },
	{ 0xF0A59F91, 0x6D5FA },
	{ 0xF0A59F92, 0x5C1B0 },
	{ 0xF0A59F93, 0x5C1AD },
	{ 0xF0A59F94, 0x5C1B2 },
	{ 0xF0A59F95, 0x5C1B4 },
	{ 0xF0A59F96, 0x5C1B8 },
	{ 0xF0A59F97, 0x5C1B3 },
	{ 0xF0A59F98, 0x4BFCE },
	{ 0xF0A59F99, 0x6D6A1 },
	{ 0xF0A59F9A, 0x5C1AE },
	{ 0xF0A59F9B, 0x6D5FB },
	{ 0xF0A59F9C, 0x6D5FE },
	{ 0xF0A59F9E, 0x6D5FC },
	{ 0xF0A59FA2, 0xFC4B3 },
	{ 0xF0A59FA3, 0xFC4B4 },
	{ 0xF0A59FA4, 0xFC4B5 },
	{ 0xF0A59FA5, 0xFC4B6 },
	{ 0xF0A59FA6, 0xFC4B7 },
	{ 0xF0A59FA7, 0xFC4B8 },
	{ 0xF0A59FA8, 0xFC4B9 },
	{ 0xF0A59FA9, 0xFC4BA },
	{ 0xF0A59FB7, 0x6D5F8 },
	{ 0xF0A59FB8, 0x6D5FD },
	{ 0xF0A59FBA, 0x5C1B7 },
	{ 0xF0A59FBB, 0x5C1B5 },
	{ 0xF0A59FBD, 0x5C8A8 },
	{ 0xF0A59FBE, 0x6DFE9 },
	{ 0xF0A59FBF, 0x5C5AD },
	{ 0xF0A5A080, 0x5C8AD },
	{ 0xF0A5A081, 0x6DFE8 },
	{ 0xF0A5A082, 0x6DFE6 },
	{ 0xF0A5A083, 0x6DFEA },
	{ 0xF0A5A084, 0x4C5DC },
	{ 0xF0A5A085, 0x5C8AE },
	{ 0xF0A5A086, 0x5C8A9 },
	{ 0xF0A5A087, 0x6DFEE },
	{ 0xF0A5A088, 0x6DFEF },
	{ 0xF0A5A089, 0x5C8AB },
	{ 0xF0A5A08A, 0x5C8A7 },
	{ 0xF0A5A08B, 0x5C8AC },
	{ 0xF0A5A08C, 0x6DFF0 },
	{ 0xF0A5A08D, 0x5C8AA },
	{ 0xF0A5A08E, 0x6DFE7 },
	{ 0xF0A5A08F, 0xFCAE0 },
	{ 0xF0A5A090, 0xFCADB },
	{ 0xF0A5A091, 0xFCADC },
	{ 0xF0A5A092, 0xFCADD },
	{ 0xF0A5A093, 0xFCADE },
	{ 0xF0A5A094, 0xFCADF },
	{ 0xF0A5A095, 0xFCAE1 },
	{ 0xF0A5A096, 0xFCAE2 },
	{ 0xF0A5A097, 0xFCAE3 },
	{ 0xF0A5A098, 0xFCAE5 },
	{ 0xF0A5A0A1, 0x6DFED },
	{ 0xF0A5A0A2, 0x6DFEC },
	{ 0xF0A5A0B1, 0x5CEFB },
	{ 0xF0A5A0B2, 0x5CEF8 },
	{ 0xF0A5A0B3, 0x5CEFA },
	{ 0xF0A5A0B4, 0x7A6B3 },
	{ 0xF0A5A0B5, 0x7A6B0 },
	{ 0xF0A5A0B6, 0x5CEF9 },
	{ 0xF0A5A0B7, 0x4CBE9 },
	{ 0xF0A5A0B9, 0x7A6B4 },
	{ 0xF0A5A0BA, 0x7A6B1 },
	{ 0xF0A5A0BC, 0x7A6B8 },
	{ 0xF0A5A0BD, 0x5C8AF },
	{ 0xF0A5A0BE, 0x7A6AF },
	{ 0xF0A5A0BF, 0x5D6C5 },
	{ 0xF0A5A180, 0x5CEFC },
	{ 0xF0A5A181, 0x5CEFD },
	{ 0xF0A5A183, 0x4CBE7 },
	{ 0xF0A5A185, 0x4CBEA },
	{ 0xF0A5A186, 0x7A6B5 },
	{ 0xF0A5A187, 0xFD0EC },
	{ 0xF0A5A188, 0xFD0EE },
	{ 0xF0A5A189, 0xFD0EF },
	{ 0xF0A5A18A, 0xFD0F0 },
	{ 0xF0A5A18B, 0xFD0F1 },
	{ 0xF0A5A18C, 0xFD0F2 },
	{ 0xF0A5A194, 0x7A6AE },
	{ 0xF0A5A19A, 0x7A6B6 },
	{ 0xF0A5A19B, 0x7A6B7 },
	{ 0xF0A5A19C, 0x4D1FB },
	{ 0xF0A5A19D, 0x7B0ED },
	{ 0xF0A5A19F, 0x5D6BD },
	{ 0xF0A5A1A0, 0x5D6C0 },
	{ 0xF0A5A1A1, 0x7B0E9 },
	{ 0xF0A5A1A2, 0x5D6BC },
	{ 0xF0A5A1A3, 0x5D6BF },
	{ 0xF0A5A1A4, 0x5D6BE },
	{ 0xF0A5A1A5, 0x4D1FE },
	{ 0xF0A5A1A6, 0x5D6BB },
	{ 0xF0A5A1A7, 0x5D6C3 },
	{ 0xF0A5A1A8, 0x7B0E3 },
	{ 0xF0A5A1A9, 0x7B0E4 },
	{ 0xF0A5A1AA, 0x5D6C2 },
	{ 0xF0A5A1AB, 0x7B0E2 },
	{ 0xF0A5A1AC, 0x5D6C6 },
	{ 0xF0A5A1AD, 0x5DCDB },
	{ 0xF0A5A1AE, 0x5D6C7 },
	{ 0xF0A5A1AF, 0x7B0EB },
	{ 0xF0A5A1B0, 0x7B0EA },
	{ 0xF0A5A1B3, 0x7B0EC },
	{ 0xF0A5A1B4, 0x7B0E1 },
	{ 0xF0A5A1B5, 0xFD6D4 },
	{ 0xF0A5A1B6, 0xFD6D5 },
	{ 0xF0A5A1B9, 0x7B0E5 },
	{ 0xF0A5A280, 0x7B0E7 },
	{ 0xF0A5A281, 0x7B0E8 },
	{ 0xF0A5A287, 0x5D6C4 },
	{ 0xF0A5A288, 0x5D6C1 },
	{ 0xF0A5A28A, 0x5DCDE },
	{ 0xF0A5A28B, 0x5DCE1 },
	{ 0xF0A5A28C, 0x5DCE2 },
	{ 0xF0A5A28D, 0x5DCDF },
	{ 0xF0A5A28E, 0x5DCDC },
	{ 0xF0A5A28F, 0x5DCDD },
	{ 0xF0A5A291, 0x4D7CA },
	{ 0xF0A5A292, 0x7B9F7 },
	{ 0xF0A5A293, 0x5DCE4 },
	{ 0xF0A5A294, 0x4D7C6 },
	{ 0xF0A5A295, 0x5DCE0 },
	{ 0xF0A5A296, 0x7B9FA },
	{ 0xF0A5A298, 0xFDBD4 },
	{ 0xF0A5A299, 0xFDBD5 },
	{ 0xF0A5A29A, 0xFDBD6 },
	{ 0xF0A5A29B, 0xFDBD7 },
	{ 0xF0A5A29C, 0xFDBD8 },
	{ 0xF0A5A29D, 0xFDBDA },
	{ 0xF0A5A29E, 0x7B9F8 },
	{ 0xF0A5A2A7, 0xFDBD3 },
	{ 0xF0A5A2AD, 0x5D6C8 },
	{ 0xF0A5A2AE, 0x7B9F9 },
	{ 0xF0A5A2B0, 0x5DCE3 },
	{ 0xF0A5A2B1, 0xFD6D3 },
	{ 0xF0A5A2B4, 0x5E2FD },
	{ 0xF0A5A2B5, 0x5E3A6 },
	{ 0xF0A5A2B6, 0x5E3A4 },
	{ 0xF0A5A2B7, 0x5E3A1 },
	{ 0xF0A5A2B8, 0x5E3A2 },
	{ 0xF0A5A2B9, 0x5E3A5 },
	{ 0xF0A5A2BA, 0x7C1B0 },
	{ 0xF0A5A2BB, 0x5E2FE },
	{ 0xF0A5A2BC, 0x7C1AF },
	{ 0xF0A5A2BD, 0x5E3A3 },
	{ 0xF0A5A2BF, 0xFDFEC },
	{ 0xF0A5A380, 0xFDFED },
	{ 0xF0A5A381, 0xFDFEE },
	{ 0xF0A5A382, 0xFDFEF },
	{ 0xF0A5A383, 0xFDFF0 },
	{ 0xF0A5A384, 0xFDFF1 },
	{ 0xF0A5A385, 0xFDFF2 },
	{ 0xF0A5A393, 0x5E2FC },
	{ 0xF0A5A396, 0x5E8DE },
	{ 0xF0A5A397, 0x4E0C3 },
	{ 0xF0A5A398, 0x5E8DC },
	{ 0xF0A5A399, 0x4E0C4 },
	{ 0xF0A5A39A, 0x4E0C7 },
	{ 0xF0A5A39C, 0x7C8BF },
	{ 0xF0A5A39E, 0x4E0C6 },
	{ 0xF0A5A39F, 0x5E8DD },
	{ 0xF0A5A3A0, 0x7CEE2 },
	{ 0xF0A5A3A5, 0x7C8C1 },
	{ 0xF0A5A3A6, 0x7C8BE },
	{ 0xF0A5A3A7, 0xFE3B0 },
	{ 0xF0A5A3A8, 0x7C8C0 },
	{ 0xF0A5A3A9, 0x5ECEB },
	{ 0xF0A5A3AA, 0x4E3FA },
	{ 0xF0A5A3AB, 0x4E3F8 },
	{ 0xF0A5A3AC, 0x5ECEA },
	{ 0xF0A5A3AD, 0x7CEE0 },
	{ 0xF0A5A3AE, 0x4DCB8 },
	{ 0xF0A5A3AF, 0x5ECE9 },
	{ 0xF0A5A3B0, 0x5ECEC },
	{ 0xF0A5A3B1, 0x7CEDF },
	{ 0xF0A5A3B2, 0x7CEE1 },
	{ 0xF0A5A3B3, 0xFE5E0 },
	{ 0xF0A5A3B4, 0xFE5E1 },
	{ 0xF0A5A3B5, 0xFE5E3 },
	{ 0xF0A5A3B7, 0x7CEE3 },
	{ 0xF0A5A3BE, 0x5ECED },
	{ 0xF0A5A480, 0x7D4A8 },
	{ 0xF0A5A481, 0x7D4A7 },
	{ 0xF0A5A482, 0x5F0D8 },
	{ 0xF0A5A483, 0x7D4A9 },
	{ 0xF0A5A485, 0x7D8CD },
	{ 0xF0A5A486, 0x5F3EC },
	{ 0xF0A5A487, 0x7D8CE },
	{ 0xF0A5A48A, 0x5F6B0 },
	{ 0xF0A5A48B, 0x5F6B1 },
	{ 0xF0A5A48C, 0x7D8CF },
	{ 0xF0A5A48E, 0x5F7F0 },
	{ 0xF0A5A491, 0x7DCAD },
	{ 0xF0A5A492, 0x7DCAE },
	{ 0xF0A5A493, 0x7DFA8 },
	{ 0xF0A5A494, 0x7DEF1 },
	{ 0xF0A5A495, 0xFEBD7 },
	{ 0xF0A5A496, 0xFEBD8 },
	{ 0xF0A5A497, 0x4ECF7 },
	{ 0xF0A5A498, 0x5F9B3 },
	{ 0xF0A5A499, 0xFECB4 },
	{ 0xF0A5A49A, 0x4ECF8 },
	{ 0xF0A5A49C, 0x5FAAE },
	{ 0xF0A5A49E, 0x5FBE1 },
	{ 0xF0A5A49F, 0x5FBE2 },
	{ 0xF0A5A4A2, 0x6A3B7 },
	{ 0xF0A5A4A3, 0x5A4EF },
	{ 0xF0A5A4A4, 0x5A4F0 },
	{ 0xF0A5A4A7, 0x4A7D9 },
	{ 0xF0A5A4A8, 0x4A7DA },
	{ 0xF0A5A4A9, 0x4A7D8 },
	{ 0xF0A5A4AA, 0x6ADCD },
	{ 0xF0A5A4AB, 0x6ADCC },
	{ 0xF0A5A4AD, 0x6ADCF },
	{ 0xF0A5A4AE, 0x3AAC5 },
	{ 0xF0A5A4B0, 0x6ADCB },
	{ 0xF0A5A4B1, 0xFA8C3 },
	{ 0xF0A5A4B4, 0x4AAF4 },
	{ 0xF0A5A4B5, 0x6B3D9 },
	{ 0xF0A5A4B6, 0x6B3DB },
	{ 0xF0A5A4B7, 0x6B3D8 },
	{ 0xF0A5A4B8, 0x5AAF7 },
	{ 0xF0A5A4B9, 0x4AAF3 },
	{ 0xF0A5A4BA, 0x5AAF9 },
	{ 0xF0A5A4BB, 0x5AAF8 },
	{ 0xF0A5A4BC, 0x6B3DA },
	{ 0xF0A5A4BD, 0x6B3DC },
	{ 0xF0A5A4BE, 0x6B3DD },
	{ 0xF0A5A4BF, 0x5AAFA },
	{ 0xF0A5A581, 0xFACF1 },
	{ 0xF0A5A582, 0xFACF2 },
	{ 0xF0A5A583, 0xFACF3 },
	{ 0xF0A5A587, 0x5AFBF },
	{ 0xF0A5A588, 0x4AEE6 },
	{ 0xF0A5A589, 0x4AEEB },
	{ 0xF0A5A58A, 0x4AEE8 },
	{ 0xF0A5A58B, 0x5AFC3 },
	{ 0xF0A5A58C, 0x5AFC2 },
	{ 0xF0A5A58D, 0x5AFC1 },
	{ 0xF0A5A58E, 0x6BACC },
	{ 0xF0A5A58F, 0x4AEE9 },
	{ 0xF0A5A590, 0x4AEEA },
	{ 0xF0A5A591, 0x4AEE7 },
	{ 0xF0A5A592, 0x6BACA },
	{ 0xF0A5A593, 0x6BAC8 },
	{ 0xF0A5A594, 0x5AFC0 },
	{ 0xF0A5A597, 0x5AFC4 },
	{ 0xF0A5A598, 0xFB1D8 },
	{ 0xF0A5A599, 0xFB1D9 },
	{ 0xF0A5A59A, 0xFB1DA },
	{ 0xF0A5A59B, 0x6BACB },
	{ 0xF0A5A59E, 0x6BAC9 },
	{ 0xF0A5A5A0, 0x5B4C4 },
	{ 0xF0A5A5A1, 0x5B4C3 },
	{ 0xF0A5A5A2, 0x6C2EC },
	{ 0xF0A5A5A3, 0x6C2EB },
	{ 0xF0A5A5A4, 0x6C2ED },
	{ 0xF0A5A5A5, 0x5B4C1 },
	{ 0xF0A5A5A6, 0x4B3EE },
	{ 0xF0A5A5A7, 0x5B4C2 },
	{ 0xF0A5A5A8, 0x5B4C0 },
	{ 0xF0A5A5A9, 0x6C2EE },
	{ 0xF0A5A5AA, 0xFB7C0 },
	{ 0xF0A5A5AB, 0xFB7C1 },
	{ 0xF0A5A5AC, 0xFB7C2 },
	{ 0xF0A5A5AD, 0xFB7C3 },
	{ 0xF0A5A5AE, 0xFB7C4 },
	{ 0xF0A5A5B6, 0x5BAF2 },
	{ 0xF0A5A5B7, 0x4B9E6 },
	{ 0xF0A5A5B8, 0x5BAF4 },
	{ 0xF0A5A5B9, 0x6CCCE },
	{ 0xF0A5A5BA, 0x6CCCA },
	{ 0xF0A5A5BB, 0x4B9E9 },
	{ 0xF0A5A5BC, 0x6CCD2 },
	{ 0xF0A5A5BD, 0x5BAE9 },
	{ 0xF0A5A5BE, 0x5BAEF },
	{ 0xF0A5A5BF, 0x5BAF1 },
	{ 0xF0A5A680, 0x6CCD0 },
	{ 0xF0A5A681, 0x5BAE7 },
	{ 0xF0A5A682, 0x6CCD1 },
	{ 0xF0A5A683, 0x5BAE8 },
	{ 0xF0A5A684, 0x6CCCB },
	{ 0xF0A5A685, 0x5BAEA },
	{ 0xF0A5A686, 0x4B9E8 },
	{ 0xF0A5A687, 0x5BAF3 },
	{ 0xF0A5A688, 0x6CCCC },
	{ 0xF0A5A68A, 0x5BAF0 },
	{ 0xF0A5A68B, 0x6CCC9 },
	{ 0xF0A5A68C, 0x5BAE6 },
	{ 0xF0A5A68D, 0x5BAED },
	{ 0xF0A5A68E, 0x6CCCF },
	{ 0xF0A5A68F, 0x5BAEE },
	{ 0xF0A5A690, 0x5BAEB },
	{ 0xF0A5A691, 0x6CCCD },
	{ 0xF0A5A693, 0xFBDEB },
	{ 0xF0A5A69B, 0x5C1BA },
	{ 0xF0A5A69C, 0x6D6A9 },
	{ 0xF0A5A69D, 0x5C1BC },
	{ 0xF0A5A69E, 0x5C1BB },
	{ 0xF0A5A69F, 0x5C1BE },
	{ 0xF0A5A6A0, 0x6D6A2 },
	{ 0xF0A5A6A1, 0x6D6A4 },
	{ 0xF0A5A6A2, 0x5BAEC },
	{ 0xF0A5A6A4, 0x5C1BD },
	{ 0xF0A5A6A5, 0x5C1BF },
	{ 0xF0A5A6A6, 0x6D6A8 },
	{ 0xF0A5A6A7, 0x6D6AB },
	{ 0xF0A5A6A8, 0x5C1C0 },
	{ 0xF0A5A6A9, 0x6D6A6 },
	{ 0xF0A5A6AA, 0x6D6A5 },
	{ 0xF0A5A6AD, 0xFC4BB },
	{ 0xF0A5A6AE, 0xFC4BD },
	{ 0xF0A5A6AF, 0xFC4BE },
	{ 0xF0A5A6B0, 0xFC4BF },
	{ 0xF0A5A6B1, 0xFC4C0 },
	{ 0xF0A5A6B2, 0x6D6A3 },
	{ 0xF0A5A6B5, 0x6D6AA },
	{ 0xF0A5A6B6, 0x6D7A6 },
	{ 0xF0A5A6B8, 0x4C5E1 },
	{ 0xF0A5A6B9, 0x6DFF7 },
	{ 0xF0A5A6BA, 0x5C8B2 },
	{ 0xF0A5A6BB, 0x6DFF6 },
	{ 0xF0A5A6BC, 0x6DFF2 },
	{ 0xF0A5A6BD, 0x6DFF4 },
	{ 0xF0A5A6BE, 0x6DFF3 },
	{ 0xF0A5A6BF, 0x5C8B1 },
	{ 0xF0A5A785, 0x6DFF9 },
	{ 0xF0A5A786, 0xFCAE6 },
	{ 0xF0A5A787, 0x5C8B3 },
	{ 0xF0A5A78A, 0x6DFF1 },
	{ 0xF0A5A78F, 0xFC4BC },
	{ 0xF0A5A790, 0x7A6BB },
	{ 0xF0A5A792, 0x5CFA1 },
	{ 0xF0A5A793, 0x5CFA7 },
	{ 0xF0A5A794, 0x5CFAA },
	{ 0xF0A5A795, 0x5C8B0 },
	{ 0xF0A5A796, 0x7A6BA },
	{ 0xF0A5A797, 0x5CFAB },
	{ 0xF0A5A798, 0x5CFA6 },
	{ 0xF0A5A799, 0x5CFA2 },
	{ 0xF0A5A79A, 0x5CFAC },
	{ 0xF0A5A79B, 0x5CFA5 },
	{ 0xF0A5A79C, 0x7A6B9 },
	{ 0xF0A5A79D, 0x5CEFE },
	{ 0xF0A5A79E, 0x5CFA8 },
	{ 0xF0A5A79F, 0x5CFA4 },
	{ 0xF0A5A7A0, 0x5CFA9 },
	{ 0xF0A5A7A2, 0x7A7AE },
	{ 0xF0A5A7A5, 0x4CBED },
	{ 0xF0A5A7AC, 0x5D6CF },
	{ 0xF0A5A7AD, 0x5D6D1 },
	{ 0xF0A5A7AE, 0x4D2A3 },
	{ 0xF0A5A7AF, 0x5D6D0 },
	{ 0xF0A5A7B0, 0x4D2A6 },
	{ 0xF0A5A7B1, 0x5D6C9 },
	{ 0xF0A5A7B2, 0x4D2A8 },
	{ 0xF0A5A7B3, 0x7B0F0 },
	{ 0xF0A5A7B4, 0x5D6CA },
	{ 0xF0A5A7B5, 0x5D6CC },
	{ 0xF0A5A7B6, 0x5D6CB },
	{ 0xF0A5A7B7, 0x5D6D3 },
	{ 0xF0A5A7B8, 0x5D6CD },
	{ 0xF0A5A7B9, 0x5D6D4 },
	{ 0xF0A5A7BA, 0x7B0EE },
	{ 0xF0A5A7BB, 0x5D6CE },
	{ 0xF0A5A7BC, 0x5DCE5 },
	{ 0xF0A5A7BD, 0x5D6D5 },
	{ 0xF0A5A7BF, 0xFD6D6 },
	{ 0xF0A5A880, 0xFD6D7 },
	{ 0xF0A5A881, 0xFD6D8 },
	{ 0xF0A5A882, 0xFD6D9 },
	{ 0xF0A5A883, 0xFD6DA },
	{ 0xF0A5A88A, 0x7B0F1 },
	{ 0xF0A5A88D, 0x5DCEA },
	{ 0xF0A5A88E, 0x5DCE7 },
	{ 0xF0A5A88F, 0x7BAA1 },
	{ 0xF0A5A890, 0x4D7CE },
	{ 0xF0A5A891, 0x5DCE9 },
	{ 0xF0A5A892, 0x7B9FC },
	{ 0xF0A5A893, 0x7B9FD },
	{ 0xF0A5A894, 0x7B9FB },
	{ 0xF0A5A895, 0x5DCE6 },
	{ 0xF0A5A896, 0x7B9FE },
	{ 0xF0A5A897, 0x7B0F2 },
	{ 0xF0A5A898, 0x5DCE8 },
	{ 0xF0A5A89A, 0xFDBDB },
	{ 0xF0A5A8A1, 0x5E3A8 },
	{ 0xF0A5A8A2, 0x5E3A7 },
	{ 0xF0A5A8A3, 0xFDFF4 },
	{ 0xF0A5A8AA, 0x4E0CA },
	{ 0xF0A5A8AB, 0x7C8C4 },
	{ 0xF0A5A8AC, 0x7C8C3 },
	{ 0xF0A5A8AD, 0x5E8DF },
	{ 0xF0A5A8AE, 0x7C8C2 },
	{ 0xF0A5A8B0, 0x7CEE4 },
	{ 0xF0A5A8B1, 0x7CEE6 },
	{ 0xF0A5A8B2, 0x5E8E0 },
	{ 0xF0A5A8B3, 0x4E3FB },
	{ 0xF0A5A8B4, 0x5ECEE },
	{ 0xF0A5A8B5, 0x7D4AD },
	{ 0xF0A5A8B6, 0x7CEE7 },
	{ 0xF0A5A8B7, 0x7CEE5 },
	{ 0xF0A5A8B8, 0xFE5E4 },
	{ 0xF0A5A8BB, 0x5F0DB },
	{ 0xF0A5A8BC, 0x7D4AB },
	{ 0xF0A5A8BD, 0x4E6E7 },
	{ 0xF0A5A8BF, 0x4E6E6 },
	{ 0xF0A5A980, 0x5F0D9 },
	{ 0xF0A5A981, 0x7D4AC },
	{ 0xF0A5A982, 0x5F0DA },
	{ 0xF0A5A983, 0xFE8A1 },
	{ 0xF0A5A988, 0xFE5E5 },
	{ 0xF0A5A98A, 0x5F6B2 },
	{ 0xF0A5A98B, 0x7DCAF },
	{ 0xF0A5A98C, 0x5F7F1 },
	{ 0xF0A5A98E, 0x7E1AA },
	{ 0xF0A5A98F, 0xFEBD9 },
	{ 0xF0A5A990, 0x7DFA9 },
	{ 0xF0A5A992, 0x5F9B4 },
	{ 0xF0A5A993, 0x7E2CA },
	{ 0xF0A5A994, 0x5FBE3 },
	{ 0xF0A5A995, 0x6A8F2 },
	{ 0xF0A5A996, 0x6A8F1 },
	{ 0xF0A5A997, 0x5A7C9 },
	{ 0xF0A5A998, 0x5A7CA },
	{ 0xF0A5A999, 0x4AAF5 },
	{ 0xF0A5A99B, 0xFACF4 },
	{ 0xF0A5A99C, 0xFACF8 },
	{ 0xF0A5A9A0, 0x4AEEF },
	{ 0xF0A5A9A1, 0x5AFC7 },
	{ 0xF0A5A9A2, 0x5AFC8 },
	{ 0xF0A5A9A3, 0x4AEEC },
	{ 0xF0A5A9A4, 0x5AFC6 },
	{ 0xF0A5A9A5, 0x5AFC5 },
	{ 0xF0A5A9A6, 0x4AEEE },
	{ 0xF0A5A9A7, 0xFB1DC },
	{ 0xF0A5A9A8, 0xFB1DD },
	{ 0xF0A5A9A9, 0xFB1DE },
	{ 0xF0A5A9AA, 0xFB1DF },
	{ 0xF0A5A9AB, 0xFB1E1 },
	{ 0xF0A5A9AC, 0xFB1E2 },
	{ 0xF0A5A9AD, 0x6BACD },
	{ 0xF0A5A9AE, 0x6BACE },
	{ 0xF0A5A9B1, 0x6C2F2 },
	{ 0xF0A5A9B2, 0x4B3F3 },
	{ 0xF0A5A9B3, 0x6C2F1 },
	{ 0xF0A5A9B4, 0x6C2F3 },
	{ 0xF0A5A9B5, 0x6C2F0 },
	{ 0xF0A5A9B6, 0x4B3F4 },
	{ 0xF0A5A9B8, 0xFB7C5 },
	{ 0xF0A5A9B9, 0xFB7C7 },
	{ 0xF0A5A9BB, 0x5B4C7 },
	{ 0xF0A5A9BC, 0xFB7C8 },
	{ 0xF0A5A9BE, 0x4B9EB },
	{ 0xF0A5A9BF, 0x6CCD5 },
	{ 0xF0A5AA80, 0x5BAF5 },
	{ 0xF0A5AA81, 0x5BAF7 },
	{ 0xF0A5AA82, 0x5BAF6 },
	{ 0xF0A5AA83, 0x5BAF8 },
	{ 0xF0A5AA84, 0x6CCD4 },
	{ 0xF0A5AA86, 0xFBDED },
	{ 0xF0A5AA87, 0xFBDEE },
	{ 0xF0A5AA88, 0xFBDEF },
	{ 0xF0A5AA89, 0xFBDF0 },
	{ 0xF0A5AA8A, 0x4BFD6 },
	{ 0xF0A5AA8B, 0x4BFD8 },
	{ 0xF0A5AA8C, 0x5C1C2 },
	{ 0xF0A5AA8D, 0x4BFD9 },
	{ 0xF0A5AA8E, 0x6D6AC },
	{ 0xF0A5AA8F, 0x5C1C1 },
	{ 0xF0A5AA90, 0x6D6AD },
	{ 0xF0A5AA91, 0x6D6AE },
	{ 0xF0A5AA92, 0xFC4C1 },
	{ 0xF0A5AA93, 0xFC4C2 },
	{ 0xF0A5AA94, 0xFC4C3 },
	{ 0xF0A5AA95, 0x5C1C3 },
	{ 0xF0A5AA98, 0x5C8B4 },
	{ 0xF0A5AA99, 0x6DFFA },
	{ 0xF0A5AA9A, 0x5C8B5 },
	{ 0xF0A5AA9B, 0x4C5E2 },
	{ 0xF0A5AA9F, 0xFCAE7 },
	{ 0xF0A5AAA0, 0xFCAE8 },
	{ 0xF0A5AAA1, 0xFCAEA },
	{ 0xF0A5AAA4, 0xFCAE9 },
	{ 0xF0A5AAA5, 0x7A6BF },
	{ 0xF0A5AAA6, 0x4CBEE },
	{ 0xF0A5AAA7, 0x5CFAD },
	{ 0xF0A5AAA8, 0xFD0F3 },
	{ 0xF0A5AAA9, 0xFD0F4 },
	{ 0xF0A5AAAA, 0xFD0F5 },
	{ 0xF0A5AAAC, 0x7A6BD },
	{ 0xF0A5AAAD, 0xFD6DC },
	{ 0xF0A5AAAE, 0xFD6DB },
	{ 0xF0A5AAAF, 0x4D7D1 },
	{ 0xF0A5AAB0, 0x7B0F4 },
	{ 0xF0A5AAB1, 0x5D6D6 },
	{ 0xF0A5AAB2, 0xFDBDC },
	{ 0xF0A5AAB3, 0x5DCEC },
	{ 0xF0A5AAB5, 0x5DDE3 },
	{ 0xF0A5AAB6, 0x7BAA2 },
	{ 0xF0A5AABB, 0x5DCEB },
	{ 0xF0A5AABC, 0x5E3AA },
	{ 0xF0A5AABD, 0x7BAA3 },
	{ 0xF0A5AABE, 0xFDFF5 },
	{ 0xF0A5AABF, 0x7C1B1 },
	{ 0xF0A5AB83, 0x5E3A9 },
	{ 0xF0A5AB88, 0x7CEE8 },
	{ 0xF0A5AB89, 0x7D4AE },
	{ 0xF0A5AB8A, 0xFE5E6 },
	{ 0xF0A5AB8D, 0x7C8C5 },
	{ 0xF0A5AB8E, 0x5F0DC },
	{ 0xF0A5AB8F, 0xFE8A2 },
	{ 0xF0A5AB90, 0x7D8D0 },
	{ 0xF0A5AB91, 0xFE9DE },
	{ 0xF0A5AB92, 0xFEAE8 },
	{ 0xF0A5AB96, 0x7E1AB },
	{ 0xF0A5AB98, 0xFA5A6 },
	{ 0xF0A5AB99, 0x5A7CB },
	{ 0xF0A5AB9A, 0x6ADD0 },
	{ 0xF0A5AB9B, 0x5A7CD },
	{ 0xF0A5AB9C, 0x5A7CC },
	{ 0xF0A5AB9D, 0x5AAFC },
	{ 0xF0A5AB9E, 0x5AAFD },
	{ 0xF0A5AB9F, 0x5AAFB },
	{ 0xF0A5ABA0, 0x6B3DF },
	{ 0xF0A5ABA1, 0x6B3DE },
	{ 0xF0A5ABA2, 0x5AAFE },
	{ 0xF0A5ABA5, 0xFACF9 },
	{ 0xF0A5ABA6, 0xFACFA },
	{ 0xF0A5ABA7, 0xFACFB },
	{ 0xF0A5ABA8, 0xFACFC },
	{ 0xF0A5ABAD, 0xFACFD },
	{ 0xF0A5ABAE, 0xFA9A4 },
	{ 0xF0A5ABAF, 0x5AFCE },
	{ 0xF0A5ABB0, 0x5AFC9 },
	{ 0xF0A5ABB1, 0x4AEF4 },
	{ 0xF0A5ABB3, 0x5AFCA },
	{ 0xF0A5ABB4, 0x5AFCC },
	{ 0xF0A5ABB5, 0x5AFCD },
	{ 0xF0A5ABB6, 0x6BAD0 },
	{ 0xF0A5ABB7, 0x5AFD1 },
	{ 0xF0A5ABB8, 0x5AFCF },
	{ 0xF0A5ABB9, 0x5AFCB },
	{ 0xF0A5ABBA, 0x6BACF },
	{ 0xF0A5ABBB, 0x6BAD1 },
	{ 0xF0A5ABBC, 0x5AFD0 },
	{ 0xF0A5ABBD, 0x5AFD2 },
	{ 0xF0A5ABBE, 0xFB1E3 },
	{ 0xF0A5ABBF, 0xFB1E4 },
	{ 0xF0A5AC80, 0xFB1E5 },
	{ 0xF0A5AC81, 0xFB1E6 },
	{ 0xF0A5AC82, 0xFB1E7 },
	{ 0xF0A5AC83, 0xFB1E8 },
	{ 0xF0A5AC84, 0xFB1E9 },
	{ 0xF0A5AC85, 0xFB1EA },
	{ 0xF0A5AC87, 0x4AEF6 },
	{ 0xF0A5AC8C, 0x6C2F4 },
	{ 0xF0A5AC8D, 0x6C2FA },
	{ 0xF0A5AC8E, 0x5B4CA },
	{ 0xF0A5AC8F, 0x4B3F9 },
	{ 0xF0A5AC90, 0x5B4CD },
	{ 0xF0A5AC91, 0x6C2F7 },
	{ 0xF0A5AC92, 0x5B4CC },
	{ 0xF0A5AC93, 0x6C2FC },
	{ 0xF0A5AC94, 0x4B3F5 },
	{ 0xF0A5AC95, 0x5B4CE },
	{ 0xF0A5AC96, 0x6C2F5 },
	{ 0xF0A5AC97, 0x5AFD3 },
	{ 0xF0A5AC99, 0x5B4C9 },
	{ 0xF0A5AC9A, 0x6C2F9 },
	{ 0xF0A5AC9B, 0x6C2FB },
	{ 0xF0A5AC9D, 0x5B4D0 },
	{ 0xF0A5AC9E, 0x5B4D1 },
	{ 0xF0A5AC9F, 0x6C2F8 },
	{ 0xF0A5ACA1, 0xFB7C9 },
	{ 0xF0A5ACA2, 0xFB7CA },
	{ 0xF0A5ACA3, 0xFB7CB },
	{ 0xF0A5ACA4, 0xFB7CC },
	{ 0xF0A5ACA5, 0xFB7CE },
	{ 0xF0A5ACA6, 0xFB7CF },
	{ 0xF0A5ACAA, 0x5BAFC },
	{ 0xF0A5ACAB, 0x5BBA2 },
	{ 0xF0A5ACAC, 0x5BAFB },
	{ 0xF0A5ACAD, 0x5BAFE },
	{ 0xF0A5ACAE, 0x4B9EC },
	{ 0xF0A5ACAF, 0x4B9EE },
	{ 0xF0A5ACB0, 0x6CCDA },
	{ 0xF0A5ACB1, 0x5B4CB },
	{ 0xF0A5ACB2, 0x4B9F3 },
	{ 0xF0A5ACB3, 0x5BBA1 },
	{ 0xF0A5ACB4, 0x5BAFA },
	{ 0xF0A5ACB5, 0x4B9F9 },
	{ 0xF0A5ACB6, 0x4B9F7 },
	{ 0xF0A5ACB7, 0x4B9F0 },
	{ 0xF0A5ACB8, 0x6CCDD },
	{ 0xF0A5ACB9, 0x4B9F8 },
	{ 0xF0A5ACBB, 0x6CCD7 },
	{ 0xF0A5ACBC, 0x5BBA5 },
	{ 0xF0A5ACBD, 0x6CCD9 },
	{ 0xF0A5ACBE, 0x6CCDC },
	{ 0xF0A5ACBF, 0x5B4CF },
	{ 0xF0A5AD80, 0x5BAFD },
	{ 0xF0A5AD81, 0xFBDF1 },
	{ 0xF0A5AD82, 0xFBDF2 },
	{ 0xF0A5AD83, 0xFBDF3 },
	{ 0xF0A5AD84, 0xFBDF4 },
	{ 0xF0A5AD85, 0xFBDF5 },
	{ 0xF0A5AD86, 0xFBDF6 },
	{ 0xF0A5AD87, 0xFBDF8 },
	{ 0xF0A5AD88, 0xFBDF9 },
	{ 0xF0A5AD89, 0xFBDFA },
	{ 0xF0A5AD8A, 0xFBDF7 },
	{ 0xF0A5AD8B, 0x5BBA3 },
	{ 0xF0A5AD90, 0x5C1D4 },
	{ 0xF0A5AD91, 0x5C1C8 },
	{ 0xF0A5AD92, 0x5C1CF },
	{ 0xF0A5AD93, 0x4BFDC },
	{ 0xF0A5AD94, 0x5C1CD },
	{ 0xF0A5AD95, 0x5C1C5 },
	{ 0xF0A5AD96, 0x4BFE4 },
	{ 0xF0A5AD97, 0x4BFE5 },
	{ 0xF0A5AD98, 0x5C1D0 },
	{ 0xF0A5AD99, 0x4BFDF },
	{ 0xF0A5AD9A, 0x5BAF9 },
	{ 0xF0A5AD9B, 0x6D6B0 },
	{ 0xF0A5AD9C, 0x5C1C6 },
	{ 0xF0A5AD9D, 0x5C1D5 },
	{ 0xF0A5AD9E, 0x5C1CB },
	{ 0xF0A5AD9F, 0x5C1D2 },
	{ 0xF0A5ADA0, 0x5C1C4 },
	{ 0xF0A5ADA1, 0x5C1C9 },
	{ 0xF0A5ADA2, 0x5C1CC },
	{ 0xF0A5ADA3, 0x6D6B4 },
	{ 0xF0A5ADA4, 0x6D6B2 },
	{ 0xF0A5ADA5, 0x6D6B7 },
	{ 0xF0A5ADA6, 0x6D6BA },
	{ 0xF0A5ADA7, 0x6D6B3 },
	{ 0xF0A5ADA8, 0x6D6B6 },
	{ 0xF0A5ADAA, 0x6D6B8 },
	{ 0xF0A5ADAB, 0x6DFFB },
	{ 0xF0A5ADAC, 0x5C1D3 },
	{ 0xF0A5ADAD, 0x5C1D1 },
	{ 0xF0A5ADAE, 0x5C1CE },
	{ 0xF0A5ADAF, 0x5C1C7 },
	{ 0xF0A5ADB0, 0x6D6B1 },
	{ 0xF0A5ADB1, 0x6CCD8 },
	{ 0xF0A5ADB7, 0x6D6B5 },
	{ 0xF0A5ADB8, 0x6D6B9 },
	{ 0xF0A5ADB9, 0xFC4C4 },
	{ 0xF0A5ADBA, 0xFC4C6 },
	{ 0xF0A5ADBB, 0xFC4C7 },
	{ 0xF0A5ADBC, 0xFC4C8 },
	{ 0xF0A5ADBD, 0xFC4C9 },
	{ 0xF0A5ADBE, 0xFC4CA },
	{ 0xF0A5ADBF, 0xFC4CB },
	{ 0xF0A5AE80, 0xFC4CC },
	{ 0xF0A5AE81, 0xFC4CD },
	{ 0xF0A5AE82, 0xFC4CE },
	{ 0xF0A5AE83, 0xFC4CF },
	{ 0xF0A5AE84, 0xFC4D0 },
	{ 0xF0A5AE85, 0x6D6AF },
	{ 0xF0A5AE8C, 0xFC1BE },
	{ 0xF0A5AE8D, 0x5C8C5 },
	{ 0xF0A5AE8E, 0x5C1D6 },
	{ 0xF0A5AE8F, 0x4C5EC },
	{ 0xF0A5AE90, 0x5C8C3 },
	{ 0xF0A5AE91, 0x6E0A7 },
	{ 0xF0A5AE92, 0x4C5E7 },
	{ 0xF0A5AE93, 0x6DFFC },
	{ 0xF0A5AE94, 0x6DFFD },
	{ 0xF0A5AE95, 0x5C8BC },
	{ 0xF0A5AE96, 0x5C8BB },
	{ 0xF0A5AE97, 0x5C8C2 },
	{ 0xF0A5AE98, 0x4C5EF },
	{ 0xF0A5AE99, 0x6E0A8 },
	{ 0xF0A5AE9A, 0x5C8C0 },
	{ 0xF0A5AE9B, 0x6E0A6 },
	{ 0xF0A5AE9C, 0x5C8B8 },
	{ 0xF0A5AE9D, 0x5C8B9 },
	{ 0xF0A5AE9E, 0x6E0A5 },
	{ 0xF0A5AEA0, 0x6E0A1 },
	{ 0xF0A5AEA2, 0x5C8BA },
	{ 0xF0A5AEA3, 0x5C8C1 },
	{ 0xF0A5AEA4, 0x5C8B7 },
	{ 0xF0A5AEA5, 0x5C8BD },
	{ 0xF0A5AEA6, 0x6E0A2 },
	{ 0xF0A5AEA7, 0x5C1CA },
	{ 0xF0A5AEA8, 0x5C8C7 },
	{ 0xF0A5AEA9, 0x6DFFE },
	{ 0xF0A5AEAA, 0x5C8BE },
	{ 0xF0A5AEAB, 0x6E0A4 },
	{ 0xF0A5AEAD, 0x5C8BF },
	{ 0xF0A5AEAE, 0x4C5F1 },
	{ 0xF0A5AEAF, 0x5C8C4 },
	{ 0xF0A5AEB5, 0xFCAEB },
	{ 0xF0A5AEB6, 0xFCAEC },
	{ 0xF0A5AEB7, 0xFCAED },
	{ 0xF0A5AEB8, 0xFCAEE },
	{ 0xF0A5AEB9, 0xFCAEF },
	{ 0xF0A5AEBA, 0xFCAF0 },
	{ 0xF0A5AEBB, 0xFCAF3 },
	{ 0xF0A5AEBC, 0xFCAF4 },
	{ 0xF0A5AEBD, 0xFCAF5 },
	{ 0xF0A5AEBE, 0xFCAF6 },
	{ 0xF0A5AEBF, 0xFCAF7 },
	{ 0xF0A5AF80, 0xFCAF8 },
	{ 0xF0A5AF81, 0xFCAF9 },
	{ 0xF0A5AF82, 0xFCAFA },
	{ 0xF0A5AF86, 0xFCAF2 },
	{ 0xF0A5AF90, 0xFCAF1 },
	{ 0xF0A5AF91, 0x5CFBA },
	{ 0xF0A5AF92, 0x7A6C9 },
	{ 0xF0A5AF93, 0x7A6CB },
	{ 0xF0A5AF94, 0x5CFC4 },
	{ 0xF0A5AF95, 0x4CCAF },
	{ 0xF0A5AF96, 0x5CFB3 },
	{ 0xF0A5AF97, 0x7A6D1 },
	{ 0xF0A5AF98, 0x7A6CA },
	{ 0xF0A5AF99, 0x5CFBE },
	{ 0xF0A5AF9A, 0x4CBF1 },
	{ 0xF0A5AF9B, 0x4CBEF },
	{ 0xF0A5AF9C, 0x5CFC1 },
	{ 0xF0A5AF9D, 0x5CFAF },
	{ 0xF0A5AF9E, 0x5CFB4 },
	{ 0xF0A5AF9F, 0x5CFC3 },
	{ 0xF0A5AFA0, 0x7A6C2 },
	{ 0xF0A5AFA1, 0x5CFC0 },
	{ 0xF0A5AFA2, 0x5CFB1 },
	{ 0xF0A5AFA3, 0x4D2C0 },
	{ 0xF0A5AFA4, 0x5CFB9 },
	{ 0xF0A5AFA5, 0x5CFC2 },
	{ 0xF0A5AFA6, 0x4CBF2 },
	{ 0xF0A5AFA7, 0x4CCA9 },
	{ 0xF0A5AFA8, 0x4CCA3 },
	{ 0xF0A5AFA9, 0x4CBFD },
	{ 0xF0A5AFAA, 0x5CFB8 },
	{ 0xF0A5AFAB, 0x5CFB7 },
	{ 0xF0A5AFAC, 0x5CFBC },
	{ 0xF0A5AFAD, 0x7A6CE },
	{ 0xF0A5AFAE, 0x5C8C8 },
	{ 0xF0A5AFAF, 0x5CFB5 },
	{ 0xF0A5AFB0, 0x7A6D0 },
	{ 0xF0A5AFB1, 0x7A6C7 },
	{ 0xF0A5AFB2, 0x7A6C4 },
	{ 0xF0A5AFB3, 0x5CFBF },
	{ 0xF0A5AFB4, 0x7A6C0 },
	{ 0xF0A5AFB5, 0x7A6D3 },
	{ 0xF0A5AFB6, 0x4CCA4 },
	{ 0xF0A5AFB7, 0x7A6CF },
	{ 0xF0A5AFB8, 0x4CBFC },
	{ 0xF0A5AFB9, 0x7A6CC },
	{ 0xF0A5AFBA, 0x5CFBD },
	{ 0xF0A5AFBC, 0x7A6C5 },
	{ 0xF0A5AFBD, 0x7A6C3 },
	{ 0xF0A5AFBE, 0x5CFAE },
	{ 0xF0A5AFBF, 0x7A6C8 },
	{ 0xF0A5B082, 0x7A6C6 },
	{ 0xF0A5B085, 0x5CFC6 },
	{ 0xF0A5B086, 0xFD0F8 },
	{ 0xF0A5B089, 0x7A6D2 },
	{ 0xF0A5B08B, 0xFD0F7 },
	{ 0xF0A5B08C, 0xFD0FA },
	{ 0xF0A5B08D, 0xFD0FB },
	{ 0xF0A5B08E, 0xFD0FC },
	{ 0xF0A5B08F, 0xFD0FD },
	{ 0xF0A5B090, 0xFD0FE },
	{ 0xF0A5B091, 0xFD1A2 },
	{ 0xF0A5B092, 0xFD1A4 },
	{ 0xF0A5B093, 0xFD1A9 },
	{ 0xF0A5B094, 0xFD1A5 },
	{ 0xF0A5B095, 0xFD1A6 },
	{ 0xF0A5B096, 0xFD1A7 },
	{ 0xF0A5B097, 0xFD1AA },
	{ 0xF0A5B098, 0x5D6E4 },
	{ 0xF0A5B099, 0x4D2C1 },
	{ 0xF0A5B09A, 0x4D2BE },
	{ 0xF0A5B09B, 0x5D6D8 },
	{ 0xF0A5B09C, 0x5D6DE },
	{ 0xF0A5B09D, 0x5D6E6 },
	{ 0xF0A5B09E, 0x7B1AA },
	{ 0xF0A5B09F, 0x5D6DC },
	{ 0xF0A5B0A0, 0x4D2AE },
	{ 0xF0A5B0A1, 0x5D6DD },
	{ 0xF0A5B0A2, 0x4D2AC },
	{ 0xF0A5B0A3, 0x5D6E8 },
	{ 0xF0A5B0A4, 0x7A6C1 },
	{ 0xF0A5B0A5, 0x7B1A5 },
	{ 0xF0A5B0A6, 0x4D2B2 },
	{ 0xF0A5B0A7, 0x5D6E7 },
	{ 0xF0A5B0A8, 0x4D2B1 },
	{ 0xF0A5B0A9, 0x7B1A9 },
	{ 0xF0A5B0AA, 0x4D2BC },
	{ 0xF0A5B0AB, 0x7B0FE },
	{ 0xF0A5B0AC, 0x7B1A6 },
	{ 0xF0A5B0AD, 0x4D2B0 },
	{ 0xF0A5B0AE, 0x5D6E0 },
	{ 0xF0A5B0AF, 0x7B0FB },
	{ 0xF0A5B0B0, 0x4D2BF },
	{ 0xF0A5B0B1, 0x5D6DF },
	{ 0xF0A5B0B2, 0x5D6D9 },
	{ 0xF0A5B0B3, 0x7B0FA },
	{ 0xF0A5B0B4, 0x7B1A8 },
	{ 0xF0A5B0B5, 0x4D2AA },
	{ 0xF0A5B0B6, 0x5D6D7 },
	{ 0xF0A5B0B7, 0x7B1A4 },
	{ 0xF0A5B0B8, 0x4D2B5 },
	{ 0xF0A5B0B9, 0x5D6E5 },
	{ 0xF0A5B0BA, 0x7B0FD },
	{ 0xF0A5B0BB, 0x5D6E2 },
	{ 0xF0A5B0BC, 0x4D2B3 },
	{ 0xF0A5B0BD, 0x7B1AB },
	{ 0xF0A5B0BE, 0x7B0F5 },
	{ 0xF0A5B0BF, 0x7B1A7 },
	{ 0xF0A5B180, 0x5CFB0 },
	{ 0xF0A5B181, 0x5D6E3 },
	{ 0xF0A5B182, 0x5D6DA },
	{ 0xF0A5B184, 0x7B0F8 },
	{ 0xF0A5B185, 0x7B1A3 },
	{ 0xF0A5B186, 0x7B0F6 },
	{ 0xF0A5B187, 0x5D6E1 },
	{ 0xF0A5B18C, 0xFD6F2 },
	{ 0xF0A5B18D, 0x5D6DB },
	{ 0xF0A5B18E, 0x7B0FC },
	{ 0xF0A5B18F, 0x7B0F7 },
	{ 0xF0A5B190, 0x7B1A2 },
	{ 0xF0A5B191, 0xFD6DD },
	{ 0xF0A5B192, 0xFD6DE },
	{ 0xF0A5B193, 0xFD6E0 },
	{ 0xF0A5B194, 0xFD6E1 },
	{ 0xF0A5B195, 0xFD6E2 },
	{ 0xF0A5B196, 0xFD6E3 },
	{ 0xF0A5B197, 0xFD6E4 },
	{ 0xF0A5B198, 0xFD6E5 },
	{ 0xF0A5B199, 0xFD6E6 },
	{ 0xF0A5B19A, 0xFD6E7 },
	{ 0xF0A5B19B, 0xFD6E8 },
	{ 0xF0A5B19C, 0xFD6E9 },
	{ 0xF0A5B19D, 0xFD6EA },
	{ 0xF0A5B19E, 0xFD6EB },
	{ 0xF0A5B19F, 0xFD6EC },
	{ 0xF0A5B1A0, 0xFD6ED },
	{ 0xF0A5B1A1, 0xFD6EE },
	{ 0xF0A5B1A2, 0xFD6EF },
	{ 0xF0A5B1A3, 0xFD6F0 },
	{ 0xF0A5B1A4, 0xFD6F1 },
	{ 0xF0A5B1A6, 0xFD6F3 },
	{ 0xF0A5B1A9, 0x7B0F9 },
	{ 0xF0A5B1B3, 0xFD0F9 },
	{ 0xF0A5B1B5, 0x5DDA4 },
	{ 0xF0A5B1B6, 0x5DDA1 },
	{ 0xF0A5B1B7, 0x4D7DD },
	{ 0xF0A5B1B8, 0x5DCF5 },
	{ 0xF0A5B1B9, 0x5DDAD },
	{ 0xF0A5B1BA, 0x5DCF9 },
	{ 0xF0A5B1BB, 0x4D7DC },
	{ 0xF0A5B1BC, 0x4D7E3 },
	{ 0xF0A5B1BD, 0x4D7E7 },
	{ 0xF0A5B1BE, 0x7BAAC },
	{ 0xF0A5B1BF, 0x5DDAB },
	{ 0xF0A5B280, 0x4D7E0 },
	{ 0xF0A5B281, 0x5DDA2 },
	{ 0xF0A5B284, 0x5DCF0 },
	{ 0xF0A5B285, 0x5DDA3 },
	{ 0xF0A5B286, 0x5DCF2 },
	{ 0xF0A5B287, 0x5DDB1 },
	{ 0xF0A5B288, 0x5DCFB },
	{ 0xF0A5B289, 0x5DDAA },
	{ 0xF0A5B28A, 0x5DCF7 },
	{ 0xF0A5B28B, 0x5DDB4 },
	{ 0xF0A5B28C, 0x7BAA4 },
	{ 0xF0A5B28D, 0x5DCF6 },
	{ 0xF0A5B28E, 0x5DCFC },
	{ 0xF0A5B28F, 0x5DDA6 },
	{ 0xF0A5B290, 0x4D7E4 },
	{ 0xF0A5B291, 0x5DDA7 },
	{ 0xF0A5B292, 0x7BAA9 },
	{ 0xF0A5B295, 0x5E3C2 },
	{ 0xF0A5B296, 0x5DDAC },
	{ 0xF0A5B297, 0x5DCFA },
	{ 0xF0A5B298, 0x7BAAF },
	{ 0xF0A5B299, 0x7BAA8 },
	{ 0xF0A5B29A, 0x5DCEF },
	{ 0xF0A5B29B, 0x5DDB2 },
	{ 0xF0A5B29C, 0x5DDA9 },
	{ 0xF0A5B29D, 0x5DCF3 },
	{ 0xF0A5B29E, 0x7BAAB },
	{ 0xF0A5B29F, 0x5DDAE },
	{ 0xF0A5B2A0, 0x5DCF1 },
	{ 0xF0A5B2A1, 0x5DCEE },
	{ 0xF0A5B2A2, 0x5DDA8 },
	{ 0xF0A5B2A3, 0x4D7E6 },
	{ 0xF0A5B2A4, 0x4DCBC },
	{ 0xF0A5B2A5, 0x5DDB3 },
	{ 0xF0A5B2A6, 0x5DCF8 },
	{ 0xF0A5B2A7, 0x5DDAF },
	{ 0xF0A5B2A8, 0x5DDA5 },
	{ 0xF0A5B2A9, 0x7B1A1 },
	{ 0xF0A5B2AA, 0x5DCF4 },
	{ 0xF0A5B2AB, 0x7BAA7 },
	{ 0xF0A5B2AC, 0x7BAA6 },
	{ 0xF0A5B2AE, 0x7BAA5 },
	{ 0xF0A5B2AF, 0x7BAAD },
	{ 0xF0A5B2B0, 0xFDBDD },
	{ 0xF0A5B2B1, 0xFDBDE },
	{ 0xF0A5B2B2, 0xFDBE0 },
	{ 0xF0A5B2B3, 0xFDBE1 },
	{ 0xF0A5B2B4, 0xFDBE2 },
	{ 0xF0A5B2B5, 0xFDBE3 },
	{ 0xF0A5B2B6, 0xFDBE4 },
	{ 0xF0A5B2B7, 0xFDBE6 },
	{ 0xF0A5B2B8, 0xFDBE7 },
	{ 0xF0A5B2B9, 0xFDBE8 },
	{ 0xF0A5B2BA, 0xFDBE9 },
	{ 0xF0A5B2BB, 0x7BAAA },
	{ 0xF0A5B2BC, 0x7BAAE },
	{ 0xF0A5B2BD, 0x4D7E8 },
	{ 0xF0A5B380, 0xFDBE5 },
	{ 0xF0A5B386, 0x4D7E1 },
	{ 0xF0A5B387, 0x5E3CB },
	{ 0xF0A5B388, 0x5E3C7 },
	{ 0xF0A5B389, 0x5DDB5 },
	{ 0xF0A5B38A, 0x4DCD2 },
	{ 0xF0A5B38B, 0x5E3C5 },
	{ 0xF0A5B38C, 0x5E3B8 },
	{ 0xF0A5B38D, 0x5E3B3 },
	{ 0xF0A5B38E, 0x4DCC7 },
	{ 0xF0A5B38F, 0x5E3CA },
	{ 0xF0A5B390, 0x5E3C0 },
	{ 0xF0A5B391, 0x3D8CF },
	{ 0xF0A5B392, 0x5E3AE },
	{ 0xF0A5B393, 0x4DCCE },
	{ 0xF0A5B394, 0x4DCC5 },
	{ 0xF0A5B395, 0x5E3C3 },
	{ 0xF0A5B396, 0x5E3B9 },
	{ 0xF0A5B397, 0x5E3CC },
	{ 0xF0A5B398, 0x4DCBD },
	{ 0xF0A5B399, 0x7C1BB },
	{ 0xF0A5B39A, 0x5E3C6 },
	{ 0xF0A5B39B, 0x5E3B0 },
	{ 0xF0A5B39C, 0x5E3B7 },
	{ 0xF0A5B39D, 0x4DCBE },
	{ 0xF0A5B39E, 0x4DCBF },
	{ 0xF0A5B39F, 0x5E3C8 },
	{ 0xF0A5B3A0, 0x7C1B9 },
	{ 0xF0A5B3A1, 0x5E3B5 },
	{ 0xF0A5B3A2, 0x5E3B2 },
	{ 0xF0A5B3A3, 0x5E3BF },
	{ 0xF0A5B3A4, 0x7C1B5 },
	{ 0xF0A5B3A5, 0x5E3AC },
	{ 0xF0A5B3A6, 0x7C1B6 },
	{ 0xF0A5B3A7, 0x4DCC1 },
	{ 0xF0A5B3A8, 0x7C1B3 },
	{ 0xF0A5B3A9, 0x4DCD3 },
	{ 0xF0A5B3AA, 0x5E3BE },
	{ 0xF0A5B3AB, 0x7C1B8 },
	{ 0xF0A5B3AC, 0x5E3BD },
	{ 0xF0A5B3AD, 0x7C1BA },
	{ 0xF0A5B3AE, 0x7C1BE },
	{ 0xF0A5B3AF, 0x7C1B4 },
	{ 0xF0A5B3B0, 0x5E3B1 },
	{ 0xF0A5B3B1, 0x4DCCD },
	{ 0xF0A5B3B2, 0x5E3B6 },
	{ 0xF0A5B3B3, 0x5E3BA },
	{ 0xF0A5B3B4, 0x5E3C4 },
	{ 0xF0A5B3B5, 0x5E3C9 },
	{ 0xF0A5B3B6, 0x5E3BC },
	{ 0xF0A5B3B7, 0x5E3AD },
	{ 0xF0A5B3B8, 0x7C1C2 },
	{ 0xF0A5B3B9, 0x7C1C1 },
	{ 0xF0A5B3BA, 0x5E3BB },
	{ 0xF0A5B3BF, 0x5E3AB },
	{ 0xF0A5B480, 0x5E3AF },
	{ 0xF0A5B481, 0x7C1B2 },
	{ 0xF0A5B482, 0x7C1B7 },
	{ 0xF0A5B483, 0xFDFF6 },
	{ 0xF0A5B484, 0xFDFF7 },
	{ 0xF0A5B485, 0xFDFF8 },
	{ 0xF0A5B486, 0xFDFF9 },
	{ 0xF0A5B487, 0xFDFFA },
	{ 0xF0A5B488, 0xFDFFB },
	{ 0xF0A5B489, 0xFDFFC },
	{ 0xF0A5B48A, 0xFDFFD },
	{ 0xF0A5B48B, 0xFDFFE },
	{ 0xF0A5B48C, 0xFE0A1 },
	{ 0xF0A5B48D, 0xFE0A3 },
	{ 0xF0A5B48E, 0xFE0A4 },
	{ 0xF0A5B48F, 0xFE0A5 },
	{ 0xF0A5B493, 0x7C1C0 },
	{ 0xF0A5B494, 0x7C1BD },
	{ 0xF0A5B49D, 0xFDBEA },
	{ 0xF0A5B49E, 0xFE3B6 },
	{ 0xF0A5B49F, 0xFE3B7 },
	{ 0xF0A5B4A0, 0xFE0A2 },
	{ 0xF0A5B4A1, 0x5E8EA },
	{ 0xF0A5B4A2, 0x5E8EF },
	{ 0xF0A5B4A3, 0x7C8CE },
	{ 0xF0A5B4A4, 0x4E0D9 },
	{ 0xF0A5B4A5, 0x7C8CC },
	{ 0xF0A5B4A6, 0x5E8E3 },
	{ 0xF0A5B4A7, 0x4E0D4 },
	{ 0xF0A5B4A8, 0x4E0D5 },
	{ 0xF0A5B4A9, 0x4E0D1 },
	{ 0xF0A5B4AA, 0x5E8E9 },
	{ 0xF0A5B4AB, 0x4E0CF },
	{ 0xF0A5B4AC, 0x4E0D0 },
	{ 0xF0A5B4AD, 0x7C8C8 },
	{ 0xF0A5B4AE, 0x4E0D2 },
	{ 0xF0A5B4AF, 0x5E8E2 },
	{ 0xF0A5B4B0, 0x4E0D8 },
	{ 0xF0A5B4B1, 0x4E0CD },
	{ 0xF0A5B4B2, 0x7C8C7 },
	{ 0xF0A5B4B4, 0x5E8ED },
	{ 0xF0A5B4B5, 0x5E8E8 },
	{ 0xF0A5B4B6, 0x5E8F0 },
	{ 0xF0A5B4B7, 0x5E8EC },
	{ 0xF0A5B4B8, 0x5E8EB },
	{ 0xF0A5B4B9, 0x5E8E5 },
	{ 0xF0A5B4BA, 0x5E8E4 },
	{ 0xF0A5B4BB, 0x5E8E7 },
	{ 0xF0A5B4BD, 0x7C8C6 },
	{ 0xF0A5B4BE, 0x7C8CA },
	{ 0xF0A5B4BF, 0x5E8E1 },
	{ 0xF0A5B584, 0x5E8F1 },
	{ 0xF0A5B585, 0x7C8C9 },
	{ 0xF0A5B586, 0xFE3B1 },
	{ 0xF0A5B587, 0xFE3B3 },
	{ 0xF0A5B588, 0xFE3B4 },
	{ 0xF0A5B589, 0xFE3B5 },
	{ 0xF0A5B58A, 0xFE3B8 },
	{ 0xF0A5B58B, 0xFE3B9 },
	{ 0xF0A5B58C, 0xFE3BA },
	{ 0xF0A5B58D, 0xFE3BB },
	{ 0xF0A5B58E, 0xFE3BC },
	{ 0xF0A5B590, 0x7C8CB },
	{ 0xF0A5B593, 0x7C8CD },
	{ 0xF0A5B59C, 0x5ECFC },
	{ 0xF0A5B59D, 0x5ECFB },
	{ 0xF0A5B59E, 0x5ECF6 },
	{ 0xF0A5B59F, 0x4E0D7 },
	{ 0xF0A5B5A0, 0x5ECF4 },
	{ 0xF0A5B5A1, 0x7CEEC },
	{ 0xF0A5B5A2, 0x5ECFA },
	{ 0xF0A5B5A3, 0x4E3FD },
	{ 0xF0A5B5A4, 0x7CEF4 },
	{ 0xF0A5B5A5, 0x4E4A2 },
	{ 0xF0A5B5A6, 0x5ECF8 },
	{ 0xF0A5B5A7, 0x5ECF3 },
	{ 0xF0A5B5A8, 0x4E6F0 },
	{ 0xF0A5B5A9, 0x7CEEA },
	{ 0xF0A5B5AA, 0x5ECEF },
	{ 0xF0A5B5AB, 0x5ECF5 },
	{ 0xF0A5B5AC, 0x5ECF1 },
	{ 0xF0A5B5AD, 0x7CEE9 },
	{ 0xF0A5B5AE, 0x7CEF5 },
	{ 0xF0A5B5AF, 0x5ECF7 },
	{ 0xF0A5B5B0, 0x7CEED },
	{ 0xF0A5B5B1, 0x7CEEE },
	{ 0xF0A5B5B2, 0x5ECF2 },
	{ 0xF0A5B5B3, 0x7CEEF },
	{ 0xF0A5B5B4, 0x7D4B8 },
	{ 0xF0A5B5B5, 0x7CEF1 },
	{ 0xF0A5B5B6, 0x7CEF0 },
	{ 0xF0A5B5B8, 0x7CEF2 },
	{ 0xF0A5B5B9, 0x7CEF3 },
	{ 0xF0A5B5BA, 0xFE5E8 },
	{ 0xF0A5B5BB, 0xFE5E9 },
	{ 0xF0A5B5BD, 0x7CEEB },
	{ 0xF0A5B686, 0x5F0E4 },
	{ 0xF0A5B687, 0x5F0E8 },
	{ 0xF0A5B688, 0x5F0E9 },
	{ 0xF0A5B68A, 0x4E6F1 },
	{ 0xF0A5B68B, 0x4E6EB },
	{ 0xF0A5B68C, 0x5F0E6 },
	{ 0xF0A5B68D, 0x5F0EB },
	{ 0xF0A5B68E, 0x7D4AF },
	{ 0xF0A5B68F, 0x5F0DE },
	{ 0xF0A5B690, 0x5F0E3 },
	{ 0xF0A5B691, 0x5F0E0 },
	{ 0xF0A5B692, 0x4E4A1 },
	{ 0xF0A5B693, 0x5F0E7 },
	{ 0xF0A5B694, 0x5F0DF },
	{ 0xF0A5B695, 0x5ECF0 },
	{ 0xF0A5B696, 0x7D4B5 },
	{ 0xF0A5B697, 0x5F0EA },
	{ 0xF0A5B698, 0x5F0DD },
	{ 0xF0A5B699, 0x7D4B1 },
	{ 0xF0A5B69A, 0x5F0E5 },
	{ 0xF0A5B69B, 0x4E9A7 },
	{ 0xF0A5B69C, 0x5F0EC },
	{ 0xF0A5B69D, 0x7D4B6 },
	{ 0xF0A5B69E, 0x7D4B0 },
	{ 0xF0A5B69F, 0x7D4B4 },
	{ 0xF0A5B6A3, 0xFE8A3 },
	{ 0xF0A5B6A4, 0xFE8A4 },
	{ 0xF0A5B6A5, 0xFE8A5 },
	{ 0xF0A5B6A6, 0xFE8A6 },
	{ 0xF0A5B6A7, 0xFE8A7 },
	{ 0xF0A5B6A8, 0xFE8A8 },
	{ 0xF0A5B6A9, 0xFE8A9 },
	{ 0xF0A5B6AA, 0x7D4B3 },
	{ 0xF0A5B6AB, 0x7D4B9 },
	{ 0xF0A5B6B4, 0x7D4B2 },
	{ 0xF0A5B6B5, 0x7D8D5 },
	{ 0xF0A5B6B6, 0x4E9A4 },
	{ 0xF0A5B6B7, 0x4E9A3 },
	{ 0xF0A5B6B8, 0x5F3F0 },
	{ 0xF0A5B6B9, 0x5F3EE },
	{ 0xF0A5B6BA, 0x5F0E2 },
	{ 0xF0A5B6BB, 0x5F3F1 },
	{ 0xF0A5B6BC, 0x7D8D2 },
	{ 0xF0A5B6BD, 0x5F0ED },
	{ 0xF0A5B6BE, 0x7D8D1 },
	{ 0xF0A5B6BF, 0x5F3F4 },
	{ 0xF0A5B780, 0x4E9A5 },
	{ 0xF0A5B781, 0x5F3ED },
	{ 0xF0A5B782, 0x7D8D4 },
	{ 0xF0A5B783, 0x7D4B7 },
	{ 0xF0A5B784, 0x5F3F6 },
	{ 0xF0A5B785, 0x5F3F3 },
	{ 0xF0A5B786, 0x5F3EF },
	{ 0xF0A5B787, 0x5F3F5 },
	{ 0xF0A5B788, 0x5F3F2 },
	{ 0xF0A5B789, 0x7D8D6 },
	{ 0xF0A5B78C, 0xFE9DF },
	{ 0xF0A5B78D, 0xFE9E0 },
	{ 0xF0A5B78E, 0xFE9E1 },
	{ 0xF0A5B78F, 0xFE9E2 },
	{ 0xF0A5B790, 0x7D8D3 },
	{ 0xF0A5B791, 0x7D9B4 },
	{ 0xF0A5B794, 0x4EADE },
	{ 0xF0A5B795, 0x5F6B3 },
	{ 0xF0A5B796, 0x7DCB1 },
	{ 0xF0A5B797, 0x5F6B4 },
	{ 0xF0A5B798, 0x4EADF },
	{ 0xF0A5B799, 0x4EAE0 },
	{ 0xF0A5B79A, 0x4EAE2 },
	{ 0xF0A5B79B, 0x7DCB0 },
	{ 0xF0A5B79C, 0x5F6B6 },
	{ 0xF0A5B79D, 0x7DCB2 },
	{ 0xF0A5B79E, 0x5F6B5 },
	{ 0xF0A5B79F, 0x7DCB6 },
	{ 0xF0A5B7A0, 0x7DCB5 },
	{ 0xF0A5B7A1, 0xFEAE9 },
	{ 0xF0A5B7A2, 0x7DCB3 },
	{ 0xF0A5B7A3, 0x7DCB7 },
	{ 0xF0A5B7A4, 0x7DCB4 },
	{ 0xF0A5B7A8, 0x5F7F2 },
	{ 0xF0A5B7A9, 0x7DFAB },
	{ 0xF0A5B7AA, 0x7DFAE },
	{ 0xF0A5B7AB, 0x5F7F4 },
	{ 0xF0A5B7AC, 0x5F7F5 },
	{ 0xF0A5B7AD, 0x7DFAD },
	{ 0xF0A5B7AE, 0x5F6B7 },
	{ 0xF0A5B7AF, 0x7DFAC },
	{ 0xF0A5B7B0, 0x7DFAA },
	{ 0xF0A5B7B1, 0x5F7F3 },
	{ 0xF0A5B7B2, 0x7DFB1 },
	{ 0xF0A5B7B4, 0x4EBF7 },
	{ 0xF0A5B7B5, 0xFEBDA },
	{ 0xF0A5B7B6, 0xFEBDB },
	{ 0xF0A5B7B7, 0xFEBDC },
	{ 0xF0A5B7B8, 0x7DFAF },
	{ 0xF0A5B7BC, 0x5F9B5 },
	{ 0xF0A5B7BD, 0x7E1AC },
	{ 0xF0A5B7BE, 0x7E1AE },
	{ 0xF0A5B7BF, 0x7E1B1 },
	{ 0xF0A5B880, 0x4ECF9 },
	{ 0xF0A5B883, 0x7E1AF },
	{ 0xF0A5B885, 0x7DFB0 },
	{ 0xF0A5B887, 0x7E1AD },
	{ 0xF0A5B888, 0x5FAB1 },
	{ 0xF0A5B889, 0x5FAAF },
	{ 0xF0A5B88A, 0x5FAB0 },
	{ 0xF0A5B88B, 0x7E1B0 },
	{ 0xF0A5B88E, 0xFECCF },
	{ 0xF0A5B88F, 0xFECCD },
	{ 0xF0A5B890, 0x7E3DE },
	{ 0xF0A5B891, 0x7E3DF },
	{ 0xF0A5B894, 0xFECE8 },
	{ 0xF0A5B896, 0x7E3E0 },
	{ 0xF0A5B897, 0x5FBC4 },
	{ 0xF0A5B898, 0x5FBE4 },
	{ 0xF0A5B899, 0xFEDA7 },
	{ 0xF0A5B89C, 0x7E4D4 },
	{ 0xF0A5B8A1, 0x4EECE },
	{ 0xF0A5B8A2, 0x5FBFC },
	{ 0xF0A5B8A3, 0x5FCAB },
	{ 0xF0A5B8A5, 0x5A4F1 },
	{ 0xF0A5B8A6, 0xFA5A7 },
	{ 0xF0A5B8A7, 0x5A7CE },
	{ 0xF0A5B8A8, 0x6ADD1 },
	{ 0xF0A5B8A9, 0xFA8C5 },
	{ 0xF0A5B8AB, 0x6B3E1 },
	{ 0xF0A5B8AC, 0x5ABA2 },
	{ 0xF0A5B8AD, 0x6B3E0 },
	{ 0xF0A5B8AF, 0x5ABA3 },
	{ 0xF0A5B8B0, 0xFACFE },
	{ 0xF0A5B8B1, 0xFADA2 },
	{ 0xF0A5B8B3, 0x6BAD2 },
	{ 0xF0A5B8B4, 0x5AFD4 },
	{ 0xF0A5B8B5, 0x6BAD6 },
	{ 0xF0A5B8B6, 0x5AFD5 },
	{ 0xF0A5B8B7, 0x6BAD4 },
	{ 0xF0A5B8B8, 0x5AFD6 },
	{ 0xF0A5B8B9, 0xFB1EB },
	{ 0xF0A5B8BA, 0xFB1EC },
	{ 0xF0A5B8BB, 0xFB1ED },
	{ 0xF0A5B8BC, 0xFB1EE },
	{ 0xF0A5B8BD, 0x6BAD3 },
	{ 0xF0A5B8BE, 0x6BAD5 },
	{ 0xF0A5B981, 0x4B3FE },
	{ 0xF0A5B982, 0x5B4D5 },
	{ 0xF0A5B983, 0x4B4A4 },
	{ 0xF0A5B985, 0x5B4D4 },
	{ 0xF0A5B986, 0x4B4A1 },
	{ 0xF0A5B987, 0x5B4D8 },
	{ 0xF0A5B988, 0x5B4D3 },
	{ 0xF0A5B989, 0x5B4D6 },
	{ 0xF0A5B98A, 0x5B4D7 },
	{ 0xF0A5B98B, 0x4B4A3 },
	{ 0xF0A5B98C, 0x5B4DA },
	{ 0xF0A5B98D, 0x5B4D2 },
	{ 0xF0A5B98E, 0x6C2FD },
	{ 0xF0A5B98F, 0x6CCE3 },
	{ 0xF0A5B990, 0x6C3A1 },
	{ 0xF0A5B991, 0xFB7D0 },
	{ 0xF0A5B992, 0xFB7D1 },
	{ 0xF0A5B995, 0x6C2FE },
	{ 0xF0A5B996, 0xFB7D2 },
	{ 0xF0A5B99A, 0x5BBA6 },
	{ 0xF0A5B99C, 0x4B9FA },
	{ 0xF0A5B99D, 0x6CCE1 },
	{ 0xF0A5B99E, 0x6CCDE },
	{ 0xF0A5B99F, 0x6CCE5 },
	{ 0xF0A5B9A0, 0x5BBA8 },
	{ 0xF0A5B9A1, 0x4BAA1 },
	{ 0xF0A5B9A2, 0x6CCE4 },
	{ 0xF0A5B9A4, 0x6CCDF },
	{ 0xF0A5B9A6, 0xFBDFC },
	{ 0xF0A5B9A7, 0xFBDFE },
	{ 0xF0A5B9A8, 0xFBEA2 },
	{ 0xF0A5B9AB, 0xFBDFB },
	{ 0xF0A5B9AD, 0x6CCE2 },
	{ 0xF0A5B9B2, 0x5C1D7 },
	{ 0xF0A5B9B3, 0x4BFE8 },
	{ 0xF0A5B9B4, 0x6D6BD },
	{ 0xF0A5B9B5, 0x5C1D9 },
	{ 0xF0A5B9B6, 0x5C1DA },
	{ 0xF0A5B9B7, 0x5BBA7 },
	{ 0xF0A5B9B8, 0x5C1D8 },
	{ 0xF0A5B9B9, 0x6D6BF },
	{ 0xF0A5B9BA, 0x6D6BE },
	{ 0xF0A5B9BB, 0x4B9FE },
	{ 0xF0A5B9BC, 0x5C1DB },
	{ 0xF0A5B9BD, 0x5C1DD },
	{ 0xF0A5B9BE, 0x5C1DC },
	{ 0xF0A5B9BF, 0x6D6C1 },
	{ 0xF0A5BA84, 0xFC4D2 },
	{ 0xF0A5BA85, 0xFC4D3 },
	{ 0xF0A5BA86, 0xFC4D5 },
	{ 0xF0A5BA87, 0xFC4D6 },
	{ 0xF0A5BA88, 0x6D6BB },
	{ 0xF0A5BA89, 0xFC4D4 },
	{ 0xF0A5BA8B, 0x6D6C0 },
	{ 0xF0A5BA97, 0xFC4D1 },
	{ 0xF0A5BA98, 0x6E0AD },
	{ 0xF0A5BA99, 0x5C8CA },
	{ 0xF0A5BA9A, 0x6E0AB },
	{ 0xF0A5BA9B, 0x6E0AE },
	{ 0xF0A5BA9C, 0x5C8CC },
	{ 0xF0A5BA9D, 0x4C5F3 },
	{ 0xF0A5BA9E, 0x6D6BC },
	{ 0xF0A5BA9F, 0x6E0B3 },
	{ 0xF0A5BAA0, 0x6E0B2 },
	{ 0xF0A5BAA1, 0x5C8CB },
	{ 0xF0A5BAA2, 0x6E0B0 },
	{ 0xF0A5BAA3, 0x5C8C9 },
	{ 0xF0A5BAA4, 0x5C8CD },
	{ 0xF0A5BAA7, 0xFCAFC },
	{ 0xF0A5BAA8, 0xFCAFD },
	{ 0xF0A5BAA9, 0xFCAFE },
	{ 0xF0A5BAAA, 0xFCBA1 },
	{ 0xF0A5BAAB, 0xFCBA2 },
	{ 0xF0A5BAAC, 0xFCBA3 },
	{ 0xF0A5BAAD, 0xFCBA5 },
	{ 0xF0A5BAAE, 0xFCBA6 },
	{ 0xF0A5BAAF, 0xFCBA8 },
	{ 0xF0A5BAB0, 0xFCBA9 },
	{ 0xF0A5BAB1, 0xFCBAA },
	{ 0xF0A5BAB2, 0xFCBAD },
	{ 0xF0A5BAB3, 0x6E0AF },
	{ 0xF0A5BAB4, 0xFCBAC },
	{ 0xF0A5BAB6, 0x6E0A9 },
	{ 0xF0A5BAB8, 0x6E0AA },
	{ 0xF0A5BABC, 0xFCBA4 },
	{ 0xF0A5BB81, 0x7A6D8 },
	{ 0xF0A5BB82, 0x7A6D4 },
	{ 0xF0A5BB83, 0x4CCB6 },
	{ 0xF0A5BB84, 0x5CFCB },
	{ 0xF0A5BB85, 0x7A6D5 },
	{ 0xF0A5BB86, 0x7A6D9 },
	{ 0xF0A5BB87, 0x4CCB3 },
	{ 0xF0A5BB88, 0x5CFCA },
	{ 0xF0A5BB89, 0x5CFCC },
	{ 0xF0A5BB8A, 0x5CFD0 },
	{ 0xF0A5BB8B, 0x5C8CE },
	{ 0xF0A5BB8C, 0x5CFCF },
	{ 0xF0A5BB8D, 0x5CFCD },
	{ 0xF0A5BB8E, 0x7A6DB },
	{ 0xF0A5BB8F, 0x7A6D6 },
	{ 0xF0A5BB90, 0x5CFC9 },
	{ 0xF0A5BB91, 0x4CCB4 },
	{ 0xF0A5BB92, 0x5CFCE },
	{ 0xF0A5BB93, 0x4CCB2 },
	{ 0xF0A5BB94, 0x7A6DA },
	{ 0xF0A5BB95, 0x5CFC8 },
	{ 0xF0A5BB96, 0x5CFC7 },
	{ 0xF0A5BB99, 0xFD1AB },
	{ 0xF0A5BB9A, 0xFD1AC },
	{ 0xF0A5BB9B, 0xFD1AD },
	{ 0xF0A5BB9C, 0xFD1AF },
	{ 0xF0A5BBA4, 0x5D6EE },
	{ 0xF0A5BBA5, 0x5D6EC },
	{ 0xF0A5BBA6, 0x5DDBC },
	{ 0xF0A5BBA7, 0x4D2C3 },
	{ 0xF0A5BBA8, 0x5D6EB },
	{ 0xF0A5BBA9, 0x4D2C2 },
	{ 0xF0A5BBAA, 0x7B1AF },
	{ 0xF0A5BBAB, 0x7B1B0 },
	{ 0xF0A5BBAC, 0x5D6EF },
	{ 0xF0A5BBAD, 0x7B1AC },
	{ 0xF0A5BBAE, 0x5D6EA },
	{ 0xF0A5BBAF, 0x5D6ED },
	{ 0xF0A5BBB0, 0x5D6F0 },
	{ 0xF0A5BBB1, 0xFD6F4 },
	{ 0xF0A5BBB2, 0xFD6F5 },
	{ 0xF0A5BBB3, 0x7B1AE },
	{ 0xF0A5BBBF, 0x5DDB6 },
	{ 0xF0A5BC80, 0x5DDB8 },
	{ 0xF0A5BC81, 0x7BAB0 },
	{ 0xF0A5BC82, 0x5DDB9 },
	{ 0xF0A5BC83, 0x5DDB7 },
	{ 0xF0A5BC84, 0x5DDBA },
	{ 0xF0A5BC85, 0x5DDBB },
	{ 0xF0A5BC86, 0x7BAB2 },
	{ 0xF0A5BC87, 0x7BAB4 },
	{ 0xF0A5BC88, 0x7BAB5 },
	{ 0xF0A5BC89, 0x7BAB1 },
	{ 0xF0A5BC8C, 0xFDBEB },
	{ 0xF0A5BC8D, 0xFDBEC },
	{ 0xF0A5BC8E, 0xFDBED },
	{ 0xF0A5BC8F, 0xFDBEF },
	{ 0xF0A5BC90, 0xFDBF0 },
	{ 0xF0A5BC91, 0xFDBF1 },
	{ 0xF0A5BC92, 0xFDBF2 },
	{ 0xF0A5BC93, 0x4D7EC },
	{ 0xF0A5BC98, 0x5E3D2 },
	{ 0xF0A5BC99, 0x7C1C5 },
	{ 0xF0A5BC9A, 0x4DCD7 },
	{ 0xF0A5BC9B, 0x5E3D3 },
	{ 0xF0A5BC9C, 0x5E3CF },
	{ 0xF0A5BC9D, 0x7C8D6 },
	{ 0xF0A5BC9E, 0x5E3D1 },
	{ 0xF0A5BC9F, 0x5DDBD },
	{ 0xF0A5BCA0, 0x7C1C6 },
	{ 0xF0A5BCA1, 0x5E3D0 },
	{ 0xF0A5BCA2, 0x7CEF8 },
	{ 0xF0A5BCA4, 0x5E3CD },
	{ 0xF0A5BCA5, 0x7C1C3 },
	{ 0xF0A5BCA6, 0xFE0A7 },
	{ 0xF0A5BCA7, 0xFE0A8 },
	{ 0xF0A5BCA8, 0xFE0A9 },
	{ 0xF0A5BCB5, 0xFDBEE },
	{ 0xF0A5BCB6, 0x5E8F4 },
	{ 0xF0A5BCB7, 0x7C8CF },
	{ 0xF0A5BCB8, 0x7C8D0 },
	{ 0xF0A5BCB9, 0x4E0DE },
	{ 0xF0A5BCBA, 0x4E0DC },
	{ 0xF0A5BCBB, 0x5E8F3 },
	{ 0xF0A5BCBC, 0x5F0EE },
	{ 0xF0A5BCBD, 0x7C8D2 },
	{ 0xF0A5BCBE, 0x7C8D3 },
	{ 0xF0A5BCBF, 0x7C1C8 },
	{ 0xF0A5BD80, 0x4E0DF },
	{ 0xF0A5BD81, 0x4DCD8 },
	{ 0xF0A5BD82, 0x5E8F5 },
	{ 0xF0A5BD83, 0x7C1C7 },
	{ 0xF0A5BD85, 0x5E8F2 },
	{ 0xF0A5BD86, 0xFE3BE },
	{ 0xF0A5BD87, 0x7C8D1 },
	{ 0xF0A5BD89, 0x7C8D4 },
	{ 0xF0A5BD8A, 0x7C8D5 },
	{ 0xF0A5BD8B, 0xFE3BF },
	{ 0xF0A5BD8F, 0x7CEF7 },
	{ 0xF0A5BD90, 0x5ECFE },
	{ 0xF0A5BD91, 0x7CEF6 },
	{ 0xF0A5BD95, 0xFE5EA },
	{ 0xF0A5BD96, 0xFE5EB },
	{ 0xF0A5BD97, 0x4E6F3 },
	{ 0xF0A5BD98, 0x4E6F2 },
	{ 0xF0A5BD99, 0x5F0EF },
	{ 0xF0A5BD9A, 0x7D4BD },
	{ 0xF0A5BD9B, 0x7D4BC },
	{ 0xF0A5BD9D, 0xFE8AA },
	{ 0xF0A5BD9E, 0xFE8AB },
	{ 0xF0A5BDA3, 0x7D4BB },
	{ 0xF0A5BDA5, 0x5F3F7 },
	{ 0xF0A5BDA6, 0x7D8D7 },
	{ 0xF0A5BDA7, 0x5F3F8 },
	{ 0xF0A5BDAC, 0x4EAE3 },
	{ 0xF0A5BDAD, 0x4EAE4 },
	{ 0xF0A5BDAE, 0x7DCB8 },
	{ 0xF0A5BDAF, 0xFEAEA },
	{ 0xF0A5BDB0, 0x5F6B8 },
	{ 0xF0A5BDB1, 0x7DCB9 },
	{ 0xF0A5BDB2, 0x7DFB2 },
	{ 0xF0A5BDB3, 0x5F7F7 },
	{ 0xF0A5BDB4, 0x5F7F6 },
	{ 0xF0A5BDB6, 0x5F9B8 },
	{ 0xF0A5BDB7, 0x7E1B3 },
	{ 0xF0A5BDB8, 0x5F9B7 },
	{ 0xF0A5BDB9, 0x5F9B6 },
	{ 0xF0A5BDBA, 0x7E1B2 },
	{ 0xF0A5BDBB, 0x7E2CC },
	{ 0xF0A5BDBC, 0x4EDDD },
	{ 0xF0A5BDBD, 0x5FAB2 },
	{ 0xF0A5BDBE, 0x7E2CB },
	{ 0xF0A5BDBF, 0x5FAB3 },
	{ 0xF0A5BE80, 0x7E3E2 },
	{ 0xF0A5BE81, 0x7E3E1 },
	{ 0xF0A5BE82, 0x5FBFD },
	{ 0xF0A5BE84, 0x7E6B6 },
	{ 0xF0A5BE85, 0x5A7CF },
	{ 0xF0A5BE86, 0x6ADD2 },
	{ 0xF0A5BE87, 0x5A7D0 },
	{ 0xF0A5BE88, 0xFA8C7 },
	{ 0xF0A5BE89, 0xFA8C8 },
	{ 0xF0A5BE8A, 0x5A7D1 },
	{ 0xF0A5BE8C, 0x5ABA6 },
	{ 0xF0A5BE8D, 0x6B3E2 },
	{ 0xF0A5BE8E, 0x6B3E5 },
	{ 0xF0A5BE8F, 0x5ABA4 },
	{ 0xF0A5BE90, 0x5ABA5 },
	{ 0xF0A5BE91, 0x6B3E7 },
	{ 0xF0A5BE92, 0x6B3E3 },
	{ 0xF0A5BE93, 0x5ABA7 },
	{ 0xF0A5BE94, 0xFADA3 },
	{ 0xF0A5BE96, 0x6B3E8 },
	{ 0xF0A5BE99, 0x6BADB },
	{ 0xF0A5BE9A, 0x6BAD7 },
	{ 0xF0A5BE9B, 0x4AEF9 },
	{ 0xF0A5BE9C, 0x6BAE3 },
	{ 0xF0A5BE9D, 0x4AEFB },
	{ 0xF0A5BE9E, 0x6BADD },
	{ 0xF0A5BEA0, 0x6BADC },
	{ 0xF0A5BEA1, 0x6BADF },
	{ 0xF0A5BEA2, 0x5AFDA },
	{ 0xF0A5BEA3, 0x4AEFA },
	{ 0xF0A5BEA4, 0x4AFA4 },
	{ 0xF0A5BEA5, 0x6BAE4 },
	{ 0xF0A5BEA6, 0x6BAD9 },
	{ 0xF0A5BEA7, 0x4AFA3 },
	{ 0xF0A5BEA8, 0x6BADE },
	{ 0xF0A5BEA9, 0x4AFA2 },
	{ 0xF0A5BEAA, 0x6BAE0 },
	{ 0xF0A5BEAB, 0x6BAD8 },
	{ 0xF0A5BEAC, 0x5AFD9 },
	{ 0xF0A5BEAD, 0x6BAE1 },
	{ 0xF0A5BEAE, 0x5AFD8 },
	{ 0xF0A5BEAF, 0x5AFD7 },
	{ 0xF0A5BEB0, 0x6BADA },
	{ 0xF0A5BEB2, 0xFB1F1 },
	{ 0xF0A5BEB3, 0xFB1F2 },
	{ 0xF0A5BEB4, 0xFB1F3 },
	{ 0xF0A5BEB5, 0xFB1F4 },
	{ 0xF0A5BEB6, 0xFB1F5 },
	{ 0xF0A5BEB7, 0xFB1F6 },
	{ 0xF0A5BEB8, 0xFB1F7 },
	{ 0xF0A5BEBA, 0x4AFA6 },
	{ 0xF0A5BEBB, 0x6BAE2 },
	{ 0xF0A5BF83, 0x5B4DF },
	{ 0xF0A5BF84, 0x5B4DD },
	{ 0xF0A5BF85, 0x4B4B2 },
	{ 0xF0A5BF86, 0x4B4A8 },
	{ 0xF0A5BF87, 0x4B4AA },
	{ 0xF0A5BF88, 0x6C3A8 },
	{ 0xF0A5BF89, 0x4B4AF },
	{ 0xF0A5BF8A, 0x5B4DE },
	{ 0xF0A5BF8B, 0x4B4B1 },
	{ 0xF0A5BF8C, 0x6C3A9 },
	{ 0xF0A5BF8D, 0x5B4DB },
	{ 0xF0A5BF8E, 0x4B4AC },
	{ 0xF0A5BF8F, 0x6C3AB },
	{ 0xF0A5BF90, 0x6C3AA },
	{ 0xF0A5BF91, 0x6C3A5 },
	{ 0xF0A5BF92, 0x6C3A3 },
	{ 0xF0A5BF93, 0x6C3A4 },
	{ 0xF0A5BF95, 0x5B4DC },
	{ 0xF0A5BF96, 0xFB7D8 },
	{ 0xF0A5BF97, 0xFB7D9 },
	{ 0xF0A5BF98, 0xFB7DA },
	{ 0xF0A5BF99, 0xFB7DB },
	{ 0xF0A5BF9C, 0x6C3A7 },
	{ 0xF0A5BF9F, 0x6C3AC },
	{ 0xF0A5BFA1, 0xFB7D5 },
	{ 0xF0A5BFA6, 0x5BBB1 },
	{ 0xF0A5BFA7, 0x5BBB0 },
	{ 0xF0A5BFA8, 0x5BBAE },
	{ 0xF0A5BFA9, 0x5BBB2 },
	{ 0xF0A5BFAA, 0x6CCED },
	{ 0xF0A5BFAB, 0x4BAA3 },
	{ 0xF0A5BFAC, 0x6CCE6 },
	{ 0xF0A5BFAD, 0x6CCEC },
	{ 0xF0A5BFAE, 0x4BAA2 },
	{ 0xF0A5BFAF, 0x4BAA4 },
	{ 0xF0A5BFB0, 0x6CCEE },
	{ 0xF0A5BFB1, 0x6C3A6 },
	{ 0xF0A5BFB2, 0x6CCE7 },
	{ 0xF0A5BFB3, 0x6CCF0 },
	{ 0xF0A5BFB4, 0x6CCE8 },
	{ 0xF0A5BFB5, 0x5BBAD },
	{ 0xF0A5BFB6, 0x6CCEA },
	{ 0xF0A5BFB7, 0x6CCE9 },
	{ 0xF0A5BFB8, 0x6CCEF },
	{ 0xF0A5BFB9, 0x5BBAA },
	{ 0xF0A5BFBA, 0x5BBA9 },
	{ 0xF0A5BFBC, 0x5BBAB },
	{ 0xF0A5BFBD, 0xFBEA5 },
	{ 0xF0A5BFBE, 0xFBEA6 },
	{ 0xF0A5BFBF, 0xFBEA7 },
	{ 0xF0A68080, 0xFBEA8 },
	{ 0xF0A68081, 0xFBEA9 },
	{ 0xF0A68082, 0xFBEAA },
	{ 0xF0A68083, 0xFBEAB },
	{ 0xF0A68084, 0xFBEAC },
	{ 0xF0A68085, 0xFBEAD },
	{ 0xF0A68086, 0xFBEAE },
	{ 0xF0A68087, 0x6CCEB },
	{ 0xF0A68089, 0x5BBAF },
	{ 0xF0A68092, 0x6D6CB },
	{ 0xF0A68093, 0x6D6C2 },
	{ 0xF0A68094, 0x5C1DF },
	{ 0xF0A68095, 0x5C1DE },
	{ 0xF0A68096, 0x4BFEC },
	{ 0xF0A68097, 0x6D6C4 },
	{ 0xF0A68098, 0x4BFED },
	{ 0xF0A68099, 0x6D6C8 },
	{ 0xF0A6809A, 0x6D6C5 },
	{ 0xF0A6809B, 0x4BFE9 },
	{ 0xF0A6809C, 0x5C1E1 },
	{ 0xF0A6809D, 0x5C1E0 },
	{ 0xF0A6809E, 0x6D6C3 },
	{ 0xF0A6809F, 0x6D6C9 },
	{ 0xF0A680A0, 0x4BAA5 },
	{ 0xF0A680A1, 0x4BFEB },
	{ 0xF0A680A2, 0x6D6C6 },
	{ 0xF0A680A3, 0x5C1E2 },
	{ 0xF0A680A4, 0x6D6CC },
	{ 0xF0A680A5, 0x6D6CD },
	{ 0xF0A680A6, 0x4BFF2 },
	{ 0xF0A680A7, 0x6D6CA },
	{ 0xF0A680AC, 0xFC4D7 },
	{ 0xF0A680AD, 0xFC4D8 },
	{ 0xF0A680AE, 0xFC4D9 },
	{ 0xF0A680AF, 0xFC4DA },
	{ 0xF0A680B0, 0xFC4DB },
	{ 0xF0A680B1, 0xFC4DC },
	{ 0xF0A680B2, 0xFC4DD },
	{ 0xF0A680B3, 0xFC4DE },
	{ 0xF0A680B4, 0xFC4DF },
	{ 0xF0A680B5, 0xFC4E0 },
	{ 0xF0A680B6, 0xFC4E1 },
	{ 0xF0A680B7, 0xFC4E2 },
	{ 0xF0A68183, 0x6D6C7 },
	{ 0xF0A68184, 0x4BFF0 },
	{ 0xF0A68186, 0x4C5F8 },
	{ 0xF0A68188, 0x5C8D0 },
	{ 0xF0A68189, 0x4C5F6 },
	{ 0xF0A6818A, 0x5C8D2 },
	{ 0xF0A6818B, 0x6E0BF },
	{ 0xF0A6818C, 0x6E0BE },
	{ 0xF0A6818D, 0x5C8D6 },
	{ 0xF0A6818E, 0x4C5FA },
	{ 0xF0A6818F, 0x5C8D5 },
	{ 0xF0A68190, 0x4C5F7 },
	{ 0xF0A68191, 0x6E0B9 },
	{ 0xF0A68192, 0x6E0C3 },
	{ 0xF0A68193, 0x6E0C2 },
	{ 0xF0A68194, 0x6E0B6 },
	{ 0xF0A68195, 0x4C5FD },
	{ 0xF0A68196, 0x5C8CF },
	{ 0xF0A68197, 0x5C1E3 },
	{ 0xF0A68198, 0x6E0C1 },
	{ 0xF0A68199, 0x5C8D1 },
	{ 0xF0A6819A, 0x6E0BC },
	{ 0xF0A6819B, 0x6E0B4 },
	{ 0xF0A6819C, 0x5C8D3 },
	{ 0xF0A6819D, 0x5C8D7 },
	{ 0xF0A6819E, 0x6E0C0 },
	{ 0xF0A681A1, 0x6E0BB },
	{ 0xF0A681A4, 0x4C6A2 },
	{ 0xF0A681A5, 0x6E0B8 },
	{ 0xF0A681A6, 0xFCBAE },
	{ 0xF0A681A7, 0xFCBAF },
	{ 0xF0A681A8, 0xFCBB0 },
	{ 0xF0A681A9, 0xFCBB1 },
	{ 0xF0A681AA, 0xFCBB2 },
	{ 0xF0A681AB, 0xFCBB3 },
	{ 0xF0A681AC, 0xFCBB4 },
	{ 0xF0A681AD, 0xFCBB5 },
	{ 0xF0A681AE, 0xFCBB6 },
	{ 0xF0A681AF, 0xFCBB7 },
	{ 0xF0A681B0, 0x6E0B5 },
	{ 0xF0A681B1, 0x6E0B7 },
	{ 0xF0A681B4, 0x6E0BD },
	{ 0xF0A68280, 0x4CCB8 },
	{ 0xF0A68281, 0x4CCC3 },
	{ 0xF0A68282, 0x7A6E0 },
	{ 0xF0A68283, 0x4CCC2 },
	{ 0xF0A68284, 0x4CCBB },
	{ 0xF0A68285, 0x5CFDB },
	{ 0xF0A68286, 0x5CFD9 },
	{ 0xF0A68287, 0x4D2C8 },
	{ 0xF0A68288, 0x5CFD8 },
	{ 0xF0A68289, 0x5CFDD },
	{ 0xF0A6828B, 0x5CFD5 },
	{ 0xF0A6828C, 0x4CCC6 },
	{ 0xF0A6828D, 0x5CFDA },
	{ 0xF0A6828E, 0x7A6EC },
	{ 0xF0A6828F, 0x7A6DE },
	{ 0xF0A68290, 0x7A6E4 },
	{ 0xF0A68291, 0x5CFDC },
	{ 0xF0A68292, 0x5CFD2 },
	{ 0xF0A68293, 0x7A6E1 },
	{ 0xF0A68294, 0x7A6E6 },
	{ 0xF0A68295, 0x5CFD7 },
	{ 0xF0A68297, 0x4CCC1 },
	{ 0xF0A68298, 0x4CCB9 },
	{ 0xF0A68299, 0x7A6DD },
	{ 0xF0A6829A, 0x7A6E5 },
	{ 0xF0A6829B, 0x7A6DC },
	{ 0xF0A6829C, 0x7A6E7 },
	{ 0xF0A6829D, 0x6E0BA },
	{ 0xF0A6829E, 0x7A6ED },
	{ 0xF0A6829F, 0x7A6EB },
	{ 0xF0A682A0, 0x5CFD1 },
	{ 0xF0A682A1, 0x5CFD6 },
	{ 0xF0A682A2, 0x5CFDE },
	{ 0xF0A682A6, 0xFD1B0 },
	{ 0xF0A682A7, 0xFD1B1 },
	{ 0xF0A682A8, 0xFD1B2 },
	{ 0xF0A682A9, 0xFD1B3 },
	{ 0xF0A682AA, 0xFD1B4 },
	{ 0xF0A682AB, 0xFD1B5 },
	{ 0xF0A682AC, 0xFD1B8 },
	{ 0xF0A682AD, 0xFD1B9 },
	{ 0xF0A682AE, 0xFD1BA },
	{ 0xF0A682AF, 0xFD1BD },
	{ 0xF0A682B0, 0xFD1BE },
	{ 0xF0A682B1, 0xFD1BF },
	{ 0xF0A682B4, 0x7A6E2 },
	{ 0xF0A682B5, 0x7A6E8 },
	{ 0xF0A682B7, 0x7A6DF },
	{ 0xF0A68381, 0x7A6E3 },
	{ 0xF0A68383, 0x7B1C6 },
	{ 0xF0A68384, 0x4D2C6 },
	{ 0xF0A68385, 0x7B1C3 },
	{ 0xF0A68386, 0x7B1C4 },
	{ 0xF0A68387, 0x4D2CA },
	{ 0xF0A68388, 0x7B1C0 },
	{ 0xF0A68389, 0x7B1BD },
	{ 0xF0A6838A, 0x5D6F4 },
	{ 0xF0A6838B, 0x5D6F6 },
	{ 0xF0A6838C, 0x7B1B1 },
	{ 0xF0A6838D, 0x7B1C2 },
	{ 0xF0A6838E, 0x7B1B2 },
	{ 0xF0A6838F, 0x7BAB6 },
	{ 0xF0A68390, 0x7B1B3 },
	{ 0xF0A68391, 0x7B1B6 },
	{ 0xF0A68392, 0x5D6F5 },
	{ 0xF0A68393, 0x5D6F7 },
	{ 0xF0A68394, 0x5D6F3 },
	{ 0xF0A68395, 0x5DDC5 },
	{ 0xF0A68396, 0x4D2C5 },
	{ 0xF0A68397, 0x5D6F1 },
	{ 0xF0A68398, 0x5D6F2 },
	{ 0xF0A68399, 0x4D2CB },
	{ 0xF0A6839B, 0x7B1BA },
	{ 0xF0A6839C, 0x7B1B7 },
	{ 0xF0A6839D, 0x7B1B8 },
	{ 0xF0A6839E, 0x7B1C1 },
	{ 0xF0A6839F, 0x4D2CD },
	{ 0xF0A683A0, 0x7B1B5 },
	{ 0xF0A683A2, 0x5D6F9 },
	{ 0xF0A683A3, 0x7B1B4 },
	{ 0xF0A683A4, 0x7B1C5 },
	{ 0xF0A683A5, 0x7B1BB },
	{ 0xF0A683A6, 0x5D6F8 },
	{ 0xF0A683A7, 0x7B1BF },
	{ 0xF0A683A8, 0x7B1BE },
	{ 0xF0A683B0, 0x7B1B9 },
	{ 0xF0A683B1, 0x7B1BC },
	{ 0xF0A683B2, 0xFD6F6 },
	{ 0xF0A683B3, 0xFD6F7 },
	{ 0xF0A683B4, 0xFD6F8 },
	{ 0xF0A683B5, 0xFD6F9 },
	{ 0xF0A683B6, 0xFD6FA },
	{ 0xF0A683B7, 0xFD6FB },
	{ 0xF0A683B8, 0xFD6FC },
	{ 0xF0A683B9, 0xFD6FD },
	{ 0xF0A683BA, 0xFD6FE },
	{ 0xF0A68489, 0x7BAC4 },
	{ 0xF0A6848A, 0x7BAC3 },
	{ 0xF0A6848B, 0x5DDC3 },
	{ 0xF0A6848C, 0x5DDC0 },
	{ 0xF0A6848D, 0x4D7F1 },
	{ 0xF0A6848E, 0x7BAB7 },
	{ 0xF0A6848F, 0x5DDC1 },
	{ 0xF0A68490, 0x7BAC2 },
	{ 0xF0A68491, 0x4D7EF },
	{ 0xF0A68492, 0x7BABA },
	{ 0xF0A68493, 0x5DDC4 },
	{ 0xF0A68494, 0x5DDBE },
	{ 0xF0A68495, 0x7BABE },
	{ 0xF0A68496, 0x7BABB },
	{ 0xF0A68497, 0x7BABC },
	{ 0xF0A68498, 0x7BAC0 },
	{ 0xF0A68499, 0x5DDC2 },
	{ 0xF0A6849A, 0x7BAC1 },
	{ 0xF0A6849B, 0x7BABD },
	{ 0xF0A6849C, 0x5DDC7 },
	{ 0xF0A684A2, 0xFDBF3 },
	{ 0xF0A684A3, 0xFDBF4 },
	{ 0xF0A684A4, 0xFDBF5 },
	{ 0xF0A684A5, 0xFDBF7 },
	{ 0xF0A684A6, 0xFDBF8 },
	{ 0xF0A684A7, 0xFDBF9 },
	{ 0xF0A684A8, 0xFDBFA },
	{ 0xF0A684A9, 0xFDBFB },
	{ 0xF0A684AA, 0xFDBFC },
	{ 0xF0A684AB, 0xFDBFD },
	{ 0xF0A684AC, 0xFDBFE },
	{ 0xF0A684AD, 0xFDCA1 },
	{ 0xF0A684AE, 0xFDCA2 },
	{ 0xF0A684B1, 0x7BABF },
	{ 0xF0A684B2, 0x7BAB8 },
	{ 0xF0A684BC, 0x4DCE4 },
	{ 0xF0A684BD, 0x4DCDC },
	{ 0xF0A684BE, 0x7C1CE },
	{ 0xF0A684BF, 0x4DCE3 },
	{ 0xF0A68580, 0x4DCDD },
	{ 0xF0A68581, 0x7C1CD },
	{ 0xF0A68582, 0x7C1D4 },
	{ 0xF0A68583, 0x4DCE1 },
	{ 0xF0A68584, 0x4D7F0 },
	{ 0xF0A68585, 0x7C1C9 },
	{ 0xF0A68586, 0x5E3D5 },
	{ 0xF0A68587, 0x5E3D8 },
	{ 0xF0A68588, 0x5E3D7 },
	{ 0xF0A68589, 0x7C1CB },
	{ 0xF0A6858A, 0x7C1D1 },
	{ 0xF0A6858B, 0x5E3D6 },
	{ 0xF0A6858C, 0x7C1CA },
	{ 0xF0A6858D, 0x7C1CF },
	{ 0xF0A6858E, 0x7C1D2 },
	{ 0xF0A6858F, 0x7C1CC },
	{ 0xF0A68590, 0x7C1D7 },
	{ 0xF0A68591, 0x7C1D5 },
	{ 0xF0A68592, 0x7C1D0 },
	{ 0xF0A68593, 0x7C1DB },
	{ 0xF0A68594, 0x5E3DA },
	{ 0xF0A68595, 0x7C1D6 },
	{ 0xF0A6859D, 0xFE0AA },
	{ 0xF0A6859E, 0xFE0AB },
	{ 0xF0A6859F, 0xFE0AC },
	{ 0xF0A685A0, 0xFE0AD },
	{ 0xF0A685A1, 0xFE0AE },
	{ 0xF0A685A2, 0xFE0AF },
	{ 0xF0A685A3, 0xFE0B0 },
	{ 0xF0A685A4, 0xFE0B1 },
	{ 0xF0A685A5, 0xFE0B2 },
	{ 0xF0A685A7, 0x5E3D9 },
	{ 0xF0A685A8, 0x7C1DC },
	{ 0xF0A685AA, 0x7C1DA },
	{ 0xF0A685AC, 0x7C1D8 },
	{ 0xF0A685B3, 0x7C1D3 },
	{ 0xF0A685B5, 0x4E0E4 },
	{ 0xF0A685B6, 0x4E0E5 },
	{ 0xF0A685B7, 0x7C8DF },
	{ 0xF0A685B8, 0x4E0E9 },
	{ 0xF0A685B9, 0x7C8E7 },
	{ 0xF0A685BA, 0x5E8F6 },
	{ 0xF0A685BB, 0x7C8E4 },
	{ 0xF0A685BC, 0x4E0E7 },
	{ 0xF0A685BD, 0x7C8E6 },
	{ 0xF0A685BE, 0x4E0EB },
	{ 0xF0A685BF, 0x5E8F9 },
	{ 0xF0A68680, 0x4E0E0 },
	{ 0xF0A68681, 0x5E8FA },
	{ 0xF0A68682, 0x7C8E1 },
	{ 0xF0A68683, 0x7C7CB },
	{ 0xF0A68684, 0x4E0E1 },
	{ 0xF0A68685, 0x7C8DD },
	{ 0xF0A68686, 0x5E8F7 },
	{ 0xF0A68688, 0x7C8E3 },
	{ 0xF0A68689, 0x7C8DB },
	{ 0xF0A6868A, 0x7C8E2 },
	{ 0xF0A6868B, 0x5E8F8 },
	{ 0xF0A6868C, 0x7C8D9 },
	{ 0xF0A6868D, 0x7C8DA },
	{ 0xF0A6868E, 0x7C8E0 },
	{ 0xF0A6868F, 0x7C8DE },
	{ 0xF0A68690, 0xFE3C0 },
	{ 0xF0A68691, 0xFE3C1 },
	{ 0xF0A68692, 0xFE3C3 },
	{ 0xF0A68693, 0xFE3C4 },
	{ 0xF0A68694, 0xFE3C5 },
	{ 0xF0A68695, 0x7CAF3 },
	{ 0xF0A68696, 0x7C8DC },
	{ 0xF0A68697, 0x7C8E5 },
	{ 0xF0A6869B, 0x4E0EA },
	{ 0xF0A6869C, 0x7CEFD },
	{ 0xF0A6869D, 0x7CEFC },
	{ 0xF0A6869E, 0x5EDA3 },
	{ 0xF0A6869F, 0x5EDA1 },
	{ 0xF0A686A0, 0x4E4A5 },
	{ 0xF0A686A1, 0x7CEFE },
	{ 0xF0A686A2, 0x7CFA3 },
	{ 0xF0A686A3, 0x7CEFB },
	{ 0xF0A686A4, 0x7D4C2 },
	{ 0xF0A686A5, 0x7C8D8 },
	{ 0xF0A686A6, 0x5EDA4 },
	{ 0xF0A686A7, 0x7CFA4 },
	{ 0xF0A686A9, 0x7CFA6 },
	{ 0xF0A686AA, 0x7CEFA },
	{ 0xF0A686AB, 0x4E6F9 },
	{ 0xF0A686AC, 0x7CFA2 },
	{ 0xF0A686AF, 0x7CEF9 },
	{ 0xF0A686B0, 0x7CFA5 },
	{ 0xF0A686B1, 0xFE5EC },
	{ 0xF0A686B2, 0xFE5ED },
	{ 0xF0A686B3, 0xFE5EE },
	{ 0xF0A686B4, 0xFE5F0 },
	{ 0xF0A686B5, 0xFE5F1 },
	{ 0xF0A686B6, 0x7CFA1 },
	{ 0xF0A686BB, 0x5F0F2 },
	{ 0xF0A686BC, 0x4E6F5 },
	{ 0xF0A686BD, 0x7D4C3 },
	{ 0xF0A686BE, 0x5F0F3 },
	{ 0xF0A686BF, 0x4E6F8 },
	{ 0xF0A68780, 0x4E6F6 },
	{ 0xF0A68781, 0x4E6F7 },
	{ 0xF0A68782, 0x7D8DE },
	{ 0xF0A68783, 0x7CFA7 },
	{ 0xF0A68784, 0x7D4BF },
	{ 0xF0A68785, 0x7D4BE },
	{ 0xF0A68788, 0x7D4C1 },
	{ 0xF0A68789, 0xFE8AC },
	{ 0xF0A6878A, 0xFE8AD },
	{ 0xF0A6878B, 0xFE8AE },
	{ 0xF0A6878C, 0xFE8AF },
	{ 0xF0A6878E, 0x4E6F4 },
	{ 0xF0A6878F, 0x7D4C0 },
	{ 0xF0A68791, 0x5F0F1 },
	{ 0xF0A68793, 0x7D4C4 },
	{ 0xF0A68794, 0x5F3FB },
	{ 0xF0A68795, 0x7D8D9 },
	{ 0xF0A68796, 0x5F3FC },
	{ 0xF0A68797, 0x5F3F9 },
	{ 0xF0A68798, 0x4E9A9 },
	{ 0xF0A68799, 0x5F6BA },
	{ 0xF0A6879A, 0x7D8DD },
	{ 0xF0A6879B, 0x5F3FA },
	{ 0xF0A6879C, 0x7D8DB },
	{ 0xF0A6879E, 0xFE9E3 },
	{ 0xF0A6879F, 0xFE9E4 },
	{ 0xF0A687A0, 0xFE9E5 },
	{ 0xF0A687A1, 0xFE9E6 },
	{ 0xF0A687A2, 0x7D8DA },
	{ 0xF0A687A3, 0x7D8DC },
	{ 0xF0A687A5, 0x4E9CB },
	{ 0xF0A687A7, 0x4EAE7 },
	{ 0xF0A687A8, 0x7D8DF },
	{ 0xF0A687A9, 0x7DCBA },
	{ 0xF0A687AA, 0x7DCBB },
	{ 0xF0A687AB, 0x4EAE8 },
	{ 0xF0A687AC, 0x4EAE9 },
	{ 0xF0A687B0, 0x4EBFA },
	{ 0xF0A687B1, 0x5F7F8 },
	{ 0xF0A687B2, 0x7DFB7 },
	{ 0xF0A687B3, 0x7DFB5 },
	{ 0xF0A687B4, 0xFEBDD },
	{ 0xF0A687B6, 0x7DFB6 },
	{ 0xF0A687B7, 0x7DFB8 },
	{ 0xF0A687B8, 0x5F9BA },
	{ 0xF0A687B9, 0x7DFB4 },
	{ 0xF0A687BA, 0x5F9B9 },
	{ 0xF0A687BB, 0x7E1B4 },
	{ 0xF0A687BC, 0x7E2CF },
	{ 0xF0A687BD, 0x7E2CE },
	{ 0xF0A687BE, 0x7E3E3 },
	{ 0xF0A687BF, 0xFECE9 },
	{ 0xF0A68880, 0x7E3E5 },
	{ 0xF0A68881, 0x7E3E4 },
	{ 0xF0A68883, 0x7E4D5 },
	{ 0xF0A68885, 0x5FBE5 },
	{ 0xF0A68886, 0xFEDB0 },
	{ 0xF0A68887, 0x7E5F5 },
	{ 0xF0A688A2, 0x6A5C2 },
	{ 0xF0A688A3, 0x4AAF8 },
	{ 0xF0A688A5, 0x5ABA8 },
	{ 0xF0A688A6, 0x4AFA8 },
	{ 0xF0A688A7, 0x6BAE6 },
	{ 0xF0A688A8, 0x5AFDB },
	{ 0xF0A688A9, 0x5B4E1 },
	{ 0xF0A688AB, 0x6C3AD },
	{ 0xF0A688AC, 0x5BBB4 },
	{ 0xF0A688AD, 0x6C3AF },
	{ 0xF0A688AE, 0x6C3AE },
	{ 0xF0A688AF, 0x6CCF4 },
	{ 0xF0A688B0, 0x4BAA9 },
	{ 0xF0A688B1, 0x6CCF3 },
	{ 0xF0A688B2, 0x5BBB3 },
	{ 0xF0A688B3, 0xFBEAF },
	{ 0xF0A688B4, 0x6D6D0 },
	{ 0xF0A688B5, 0x6D6CF },
	{ 0xF0A688B6, 0x4BFF4 },
	{ 0xF0A688B8, 0x4C6A4 },
	{ 0xF0A688B9, 0x6E0C5 },
	{ 0xF0A688BA, 0x5C8D8 },
	{ 0xF0A688BB, 0x6E0C4 },
	{ 0xF0A688BC, 0x7A6EE },
	{ 0xF0A688BE, 0xFCBB9 },
	{ 0xF0A688BF, 0xFCBBA },
	{ 0xF0A68980, 0xFCBBB },
	{ 0xF0A68981, 0x7A6F0 },
	{ 0xF0A68982, 0x4CCC7 },
	{ 0xF0A68984, 0xFD1C0 },
	{ 0xF0A68985, 0xFD1C1 },
	{ 0xF0A68987, 0x7A6EF },
	{ 0xF0A68988, 0x5D6FB },
	{ 0xF0A68989, 0x5D6FA },
	{ 0xF0A6898B, 0xFD7A2 },
	{ 0xF0A6898C, 0xFD7A1 },
	{ 0xF0A6898E, 0x5DDC9 },
	{ 0xF0A6898F, 0x7BAC5 },
	{ 0xF0A68990, 0x5DDC8 },
	{ 0xF0A68991, 0xFDAD8 },
	{ 0xF0A68992, 0xFDCA3 },
	{ 0xF0A68993, 0xFDCA4 },
	{ 0xF0A68995, 0x7C1DD },
	{ 0xF0A68996, 0x7C1DE },
	{ 0xF0A68997, 0xFE0B3 },
	{ 0xF0A68999, 0x7C8E8 },
	{ 0xF0A6899A, 0x4E0EC },
	{ 0xF0A6899B, 0xFE3C6 },
	{ 0xF0A6899D, 0x5F0F4 },
	{ 0xF0A6899E, 0x4E4A7 },
	{ 0xF0A6899F, 0x4E6FA },
	{ 0xF0A689A0, 0x7D4C5 },
	{ 0xF0A689A2, 0x4EAEA },
	{ 0xF0A689A3, 0x7DCBC },
	{ 0xF0A689A4, 0xFEAEB },
	{ 0xF0A689A5, 0x7DFBA },
	{ 0xF0A689A6, 0x7DFB9 },
	{ 0xF0A689A7, 0x5FAB4 },
	{ 0xF0A689A9, 0x7E6AA },
	{ 0xF0A689AA, 0x6A2A9 },
	{ 0xF0A689AB, 0x6A2A8 },
	{ 0xF0A689AC, 0x4A4EA },
	{ 0xF0A689AD, 0x6A5C4 },
	{ 0xF0A689AE, 0x6A5C5 },
	{ 0xF0A689AF, 0x6A8F3 },
	{ 0xF0A689B2, 0xFA1FC },
	{ 0xF0A689B3, 0x6A5C3 },
	{ 0xF0A689B4, 0xFA5A8 },
	{ 0xF0A689B5, 0xFA5AA },
	{ 0xF0A689B7, 0x6ADD3 },
	{ 0xF0A689B8, 0x6B3EA },
	{ 0xF0A689B9, 0x4A7DD },
	{ 0xF0A689BB, 0x6B3E9 },
	{ 0xF0A689BC, 0x6ADD4 },
	{ 0xF0A689BE, 0x4A7DE },
	{ 0xF0A689BF, 0x6A8F4 },
	{ 0xF0A68A80, 0x4A4EB },
	{ 0xF0A68A81, 0x6B3EB },
	{ 0xF0A68A82, 0x4AAFA },
	{ 0xF0A68A83, 0x4AAFC },
	{ 0xF0A68A87, 0xFA5D6 },
	{ 0xF0A68A88, 0x5ABA9 },
	{ 0xF0A68A89, 0xFA8C9 },
	{ 0xF0A68A8B, 0x5A7D2 },
	{ 0xF0A68A8D, 0x6BAE7 },
	{ 0xF0A68A8E, 0x6BAE8 },
	{ 0xF0A68A8F, 0x6BAE9 },
	{ 0xF0A68A90, 0x5AFDF },
	{ 0xF0A68A91, 0x6BAEC },
	{ 0xF0A68A92, 0x6BAEA },
	{ 0xF0A68A93, 0x4AFAC },
	{ 0xF0A68A94, 0x4AFAB },
	{ 0xF0A68A95, 0x6B3EE },
	{ 0xF0A68A96, 0x6B3EC },
	{ 0xF0A68A97, 0x6B3EF },
	{ 0xF0A68A98, 0x6C3B5 },
	{ 0xF0A68A99, 0xFA9B9 },
	{ 0xF0A68A9C, 0x5AFDD },
	{ 0xF0A68A9D, 0x6C3B0 },
	{ 0xF0A68A9E, 0x6C3B1 },
	{ 0xF0A68A9F, 0x6C3B2 },
	{ 0xF0A68AA0, 0x6C3B4 },
	{ 0xF0A68AA1, 0x6C3B6 },
	{ 0xF0A68AA2, 0xFB1F9 },
	{ 0xF0A68AA3, 0x6B3ED },
	{ 0xF0A68AA4, 0x6B6FA },
	{ 0xF0A68AA7, 0x5ABAA },
	{ 0xF0A68AA8, 0x4AAFD },
	{ 0xF0A68AA9, 0x6C3B3 },
	{ 0xF0A68AAA, 0x6CCF7 },
	{ 0xF0A68AAB, 0x6C3B7 },
	{ 0xF0A68AAD, 0x6BAED },
	{ 0xF0A68AAE, 0x6CCF6 },
	{ 0xF0A68AAF, 0x6C3B8 },
	{ 0xF0A68AB3, 0x5AFDE },
	{ 0xF0A68AB4, 0x5B4E2 },
	{ 0xF0A68AB5, 0xFB7DC },
	{ 0xF0A68AB6, 0x6CCF5 },
	{ 0xF0A68ABC, 0x5BBB6 },
	{ 0xF0A68ABD, 0x5BBB5 },
	{ 0xF0A68ABE, 0x4BAAC },
	{ 0xF0A68ABF, 0x6CCF8 },
	{ 0xF0A68B82, 0xFBEB0 },
	{ 0xF0A68B84, 0x6D6D2 },
	{ 0xF0A68B85, 0x5C1E7 },
	{ 0xF0A68B86, 0x6D6D4 },
	{ 0xF0A68B87, 0x6CCFA },
	{ 0xF0A68B88, 0x5C1E4 },
	{ 0xF0A68B89, 0x5C1E6 },
	{ 0xF0A68B8A, 0x6D6D3 },
	{ 0xF0A68B8B, 0x6D6D5 },
	{ 0xF0A68B8C, 0x6CCF9 },
	{ 0xF0A68B8D, 0x6D6D6 },
	{ 0xF0A68B90, 0xFBEB1 },
	{ 0xF0A68B91, 0x6D6D1 },
	{ 0xF0A68B92, 0xFC4E3 },
	{ 0xF0A68B96, 0x6E0C6 },
	{ 0xF0A68B97, 0x6E0C8 },
	{ 0xF0A68B98, 0x6E0C9 },
	{ 0xF0A68B99, 0x6E0CA },
	{ 0xF0A68B9A, 0x6E0CB },
	{ 0xF0A68B9B, 0x6E0CC },
	{ 0xF0A68B9C, 0x6E0CD },
	{ 0xF0A68B9D, 0x6E0D0 },
	{ 0xF0A68B9E, 0x5C8DB },
	{ 0xF0A68B9F, 0x7A6F5 },
	{ 0xF0A68BA0, 0x6E0CE },
	{ 0xF0A68BA1, 0x5C8DA },
	{ 0xF0A68BA2, 0x6D6D7 },
	{ 0xF0A68BA3, 0x5C8D9 },
	{ 0xF0A68BA4, 0x6E0CF },
	{ 0xF0A68BA7, 0x6E0C7 },
	{ 0xF0A68BA8, 0xFCBBC },
	{ 0xF0A68BAB, 0x7A6F1 },
	{ 0xF0A68BAC, 0x7A6F2 },
	{ 0xF0A68BAD, 0x7A6F3 },
	{ 0xF0A68BAE, 0x7A6F4 },
	{ 0xF0A68BAF, 0x5CFE2 },
	{ 0xF0A68BB0, 0x5CFDF },
	{ 0xF0A68BB1, 0x6E0D2 },
	{ 0xF0A68BB2, 0x7A6F6 },
	{ 0xF0A68BB3, 0x5CFE0 },
	{ 0xF0A68BB4, 0x5CFE1 },
	{ 0xF0A68BB5, 0x6E0D1 },
	{ 0xF0A68BB7, 0xFD1C2 },
	{ 0xF0A68BB8, 0xFD1C3 },
	{ 0xF0A68BB9, 0x7A5F3 },
	{ 0xF0A68BBB, 0x7B1C7 },
	{ 0xF0A68BBC, 0x7B1C8 },
	{ 0xF0A68BBD, 0x7B1CC },
	{ 0xF0A68BBE, 0x7B1C9 },
	{ 0xF0A68BBF, 0x5D6FC },
	{ 0xF0A68C80, 0x7B1CB },
	{ 0xF0A68C81, 0x4D2D1 },
	{ 0xF0A68C82, 0x7BACE },
	{ 0xF0A68C83, 0x7B1CA },
	{ 0xF0A68C85, 0x7B1CD },
	{ 0xF0A68C86, 0x5CFE3 },
	{ 0xF0A68C89, 0x5D6FD },
	{ 0xF0A68C8A, 0x4D2D0 },
	{ 0xF0A68C8D, 0x7A6F7 },
	{ 0xF0A68C8E, 0x7A6F8 },
	{ 0xF0A68C8F, 0x7BAC7 },
	{ 0xF0A68C90, 0x7BAC8 },
	{ 0xF0A68C91, 0x7BACB },
	{ 0xF0A68C92, 0x5DDCA },
	{ 0xF0A68C93, 0x7B1CE },
	{ 0xF0A68C94, 0x4D7F4 },
	{ 0xF0A68C95, 0x5E3DB },
	{ 0xF0A68C96, 0x7BACC },
	{ 0xF0A68C97, 0x7BACD },
	{ 0xF0A68C99, 0xFDCA5 },
	{ 0xF0A68C9B, 0xFD7A3 },
	{ 0xF0A68C9C, 0x7C1DF },
	{ 0xF0A68C9D, 0x7C1E0 },
	{ 0xF0A68C9E, 0x7C1E2 },
	{ 0xF0A68C9F, 0x7C1E4 },
	{ 0xF0A68CA0, 0x4DCE7 },
	{ 0xF0A68CA1, 0x4DCE6 },
	{ 0xF0A68CA2, 0x5E3DC },
	{ 0xF0A68CA3, 0x7C1E3 },
	{ 0xF0A68CA4, 0x7C8E9 },
	{ 0xF0A68CA8, 0x7BACA },
	{ 0xF0A68CA9, 0x5E3DE },
	{ 0xF0A68CAA, 0x5E8FB },
	{ 0xF0A68CAB, 0x7C8EC },
	{ 0xF0A68CAC, 0x4E0EE },
	{ 0xF0A68CAD, 0x7C8EA },
	{ 0xF0A68CAE, 0x7C8EB },
	{ 0xF0A68CB1, 0x7CFA8 },
	{ 0xF0A68CB2, 0x7CFA9 },
	{ 0xF0A68CB3, 0x7CFAA },
	{ 0xF0A68CB4, 0x7CFAB },
	{ 0xF0A68CB5, 0x5EDA5 },
	{ 0xF0A68CB6, 0x5EDA7 },
	{ 0xF0A68CB7, 0x7CFAC },
	{ 0xF0A68CB8, 0x5EDA6 },
	{ 0xF0A68CBA, 0x5EDA8 },
	{ 0xF0A68CBB, 0x7D4C6 },
	{ 0xF0A68CBC, 0x7CFAD },
	{ 0xF0A68CBE, 0x5F7FA },
	{ 0xF0A68CBF, 0x4EBFC },
	{ 0xF0A68D80, 0x7DFBB },
	{ 0xF0A68D81, 0x5F7FB },
	{ 0xF0A68D82, 0x5F7F9 },
	{ 0xF0A68D83, 0x7E1B5 },
	{ 0xF0A68D86, 0x7E2D0 },
	{ 0xF0A68D87, 0x7E3E6 },
	{ 0xF0A68D88, 0x7E4D6 },
	{ 0xF0A68D8A, 0x7E5BC },
	{ 0xF0A68D8B, 0x4A4EC },
	{ 0xF0A68D8C, 0x4A3AC },
	{ 0xF0A68D8D, 0xFA1E0 },
	{ 0xF0A68D8E, 0x6ADD6 },
	{ 0xF0A68D8F, 0x5A7D3 },
	{ 0xF0A68D90, 0x6ADD5 },
	{ 0xF0A68D91, 0xFADA4 },
	{ 0xF0A68D92, 0x6B3F1 },
	{ 0xF0A68D94, 0x6B3F0 },
	{ 0xF0A68D95, 0x4AAFE },
	{ 0xF0A68D96, 0xFA8CB },
	{ 0xF0A68D97, 0x6BAEE },
	{ 0xF0A68D98, 0x6BAEF },
	{ 0xF0A68D9A, 0x6C3BB },
	{ 0xF0A68D9B, 0x6BAF3 },
	{ 0xF0A68D9C, 0x6BAF2 },
	{ 0xF0A68D9D, 0x6BAF1 },
	{ 0xF0A68D9E, 0x6BAF0 },
	{ 0xF0A68D9F, 0x6C3BA },
	{ 0xF0A68DA1, 0xFB1FA },
	{ 0xF0A68DA2, 0xFB1FB },
	{ 0xF0A68DA5, 0x6C3BD },
	{ 0xF0A68DA6, 0x5B4E4 },
	{ 0xF0A68DA7, 0x4BAAE },
	{ 0xF0A68DA8, 0x6C3BE },
	{ 0xF0A68DA9, 0x4B4B9 },
	{ 0xF0A68DAA, 0x5B4E5 },
	{ 0xF0A68DAC, 0xFB7DD },
	{ 0xF0A68DAD, 0x5B4E3 },
	{ 0xF0A68DAE, 0x6C3B9 },
	{ 0xF0A68DAF, 0xFB7DE },
	{ 0xF0A68DB0, 0xFB7DF },
	{ 0xF0A68DB2, 0x6C3BF },
	{ 0xF0A68DB9, 0x5BBB9 },
	{ 0xF0A68DBA, 0x5BBB7 },
	{ 0xF0A68DBB, 0x6CCFD },
	{ 0xF0A68DBC, 0x4BAAF },
	{ 0xF0A68DBD, 0x6CDA1 },
	{ 0xF0A68DBE, 0x5BBB8 },
	{ 0xF0A68DBF, 0x6CCFE },
	{ 0xF0A68E80, 0x6CCFC },
	{ 0xF0A68E83, 0x6CDA2 },
	{ 0xF0A68E85, 0x6C7A1 },
	{ 0xF0A68E86, 0x6D6DA },
	{ 0xF0A68E87, 0x5C1E8 },
	{ 0xF0A68E88, 0x6D6DB },
	{ 0xF0A68E89, 0x6D6D8 },
	{ 0xF0A68E8A, 0x5C1E9 },
	{ 0xF0A68E8B, 0x6D6D9 },
	{ 0xF0A68E8D, 0x6D6DC },
	{ 0xF0A68E94, 0x5C1EA },
	{ 0xF0A68E95, 0xFBEB3 },
	{ 0xF0A68E96, 0xFBEB4 },
	{ 0xF0A68E97, 0x5C8DC },
	{ 0xF0A68E98, 0x6E0D3 },
	{ 0xF0A68E99, 0x6E0D5 },
	{ 0xF0A68E9A, 0x5C8DD },
	{ 0xF0A68E9D, 0x6E0D4 },
	{ 0xF0A68EA2, 0x5CFE4 },
	{ 0xF0A68EA3, 0x4CCCA },
	{ 0xF0A68EA4, 0x7A6FB },
	{ 0xF0A68EA5, 0x7A6FC },
	{ 0xF0A68EA6, 0x4CCCB },
	{ 0xF0A68EA7, 0x7B1CF },
	{ 0xF0A68EA9, 0x7A6FA },
	{ 0xF0A68EAB, 0x4CCC8 },
	{ 0xF0A68EAF, 0x5D7A1 },
	{ 0xF0A68EB0, 0x5D6FE },
	{ 0xF0A68EB1, 0x4D2D2 },
	{ 0xF0A68EB3, 0xFD7A5 },
	{ 0xF0A68EB4, 0x7B1D0 },
	{ 0xF0A68EB7, 0x4D7F8 },
	{ 0xF0A68EB8, 0x4D7F6 },
	{ 0xF0A68EB9, 0x5DDCB },
	{ 0xF0A68EBA, 0x7BAD0 },
	{ 0xF0A68EBB, 0x7BACF },
	{ 0xF0A68EBC, 0x7BAD2 },
	{ 0xF0A68EBF, 0xFDCA6 },
	{ 0xF0A68F81, 0x4D2D4 },
	{ 0xF0A68F83, 0x7BAD1 },
	{ 0xF0A68F85, 0x5E3DD },
	{ 0xF0A68F86, 0x4DCE9 },
	{ 0xF0A68F87, 0x5E3DF },
	{ 0xF0A68F88, 0x7C1E9 },
	{ 0xF0A68F89, 0x7C1EA },
	{ 0xF0A68F8A, 0x4DCED },
	{ 0xF0A68F8B, 0x7C1E7 },
	{ 0xF0A68F8C, 0x7C1E8 },
	{ 0xF0A68F8D, 0x7C1E6 },
	{ 0xF0A68F8E, 0xFD7A4 },
	{ 0xF0A68F8F, 0xFE0B4 },
	{ 0xF0A68F90, 0xFE0B5 },
	{ 0xF0A68F91, 0x4DCEC },
	{ 0xF0A68F95, 0x5E8FC },
	{ 0xF0A68F96, 0x7C8F0 },
	{ 0xF0A68F97, 0x5F6BB },
	{ 0xF0A68F98, 0x7C8EF },
	{ 0xF0A68F99, 0x7CFAE },
	{ 0xF0A68F9A, 0x7C8EE },
	{ 0xF0A68F9C, 0x5EDA9 },
	{ 0xF0A68F9D, 0x7CFAF },
	{ 0xF0A68F9E, 0x7CFB0 },
	{ 0xF0A68F9F, 0x7CFB1 },
	{ 0xF0A68FA0, 0x7CFB2 },
	{ 0xF0A68FA1, 0x7C1E5 },
	{ 0xF0A68FA2, 0x5F0F5 },
	{ 0xF0A68FA3, 0x7D4C7 },
	{ 0xF0A68FA7, 0x7D4C8 },
	{ 0xF0A68FA8, 0x5F3FD },
	{ 0xF0A68FA9, 0x7D8E0 },
	{ 0xF0A68FAA, 0x7DCBE },
	{ 0xF0A68FAB, 0x7DCBD },
	{ 0xF0A68FAD, 0x7E1B6 },
	{ 0xF0A68FAF, 0x7E3E7 },
	{ 0xF0A68FB0, 0x7E5DE },
	{ 0xF0A68FB2, 0x6ADD7 },
	{ 0xF0A68FB4, 0x6B3F5 },
	{ 0xF0A68FB5, 0x6B3F2 },
	{ 0xF0A68FB6, 0x6B3F6 },
	{ 0xF0A68FB7, 0x5ABAB },
	{ 0xF0A68FB8, 0x4ABA2 },
	{ 0xF0A68FB9, 0x4ABA1 },
	{ 0xF0A68FBA, 0x4ABA4 },
	{ 0xF0A68FBB, 0x6B3F4 },
	{ 0xF0A68FBC, 0x4ABA3 },
	{ 0xF0A68FBD, 0xFADA5 },
	{ 0xF0A68FBE, 0xFADA6 },
	{ 0xF0A69080, 0x6B3F3 },
	{ 0xF0A69082, 0x4AFB3 },
	{ 0xF0A69083, 0x6BAF6 },
	{ 0xF0A69084, 0x5AFE1 },
	{ 0xF0A69085, 0x5AFE3 },
	{ 0xF0A69086, 0x5AFE0 },
	{ 0xF0A69087, 0x4AFB1 },
	{ 0xF0A69088, 0x4AFB6 },
	{ 0xF0A69089, 0x4AFB5 },
	{ 0xF0A6908A, 0x6BAF5 },
	{ 0xF0A6908B, 0x5AFE2 },
	{ 0xF0A6908C, 0x4AFB4 },
	{ 0xF0A6908D, 0x4AFB2 },
	{ 0xF0A6908E, 0x6BAF7 },
	{ 0xF0A69090, 0xFAFE3 },
	{ 0xF0A69091, 0xFAFE4 },
	{ 0xF0A69093, 0x4AFB7 },
	{ 0xF0A69094, 0xFB1FC },
	{ 0xF0A69095, 0x5B4E6 },
	{ 0xF0A69096, 0x6C3C1 },
	{ 0xF0A69097, 0x6C3C0 },
	{ 0xF0A69098, 0x6C3C2 },
	{ 0xF0A69099, 0x6C3C3 },
	{ 0xF0A6909A, 0x6C3C4 },
	{ 0xF0A6909B, 0x6C3C6 },
	{ 0xF0A6909C, 0x6C3C7 },
	{ 0xF0A6909E, 0x4B4BF },
	{ 0xF0A690A2, 0x6C3C5 },
	{ 0xF0A690A3, 0x5BBBB },
	{ 0xF0A690A4, 0x4BAB2 },
	{ 0xF0A690A5, 0x6CDA6 },
	{ 0xF0A690A6, 0x6CDA7 },
	{ 0xF0A690A7, 0x6CDAD },
	{ 0xF0A690A8, 0x5BBBD },
	{ 0xF0A690A9, 0x4BAB6 },
	{ 0xF0A690AA, 0x6CDAE },
	{ 0xF0A690AC, 0x6CDA8 },
	{ 0xF0A690AD, 0x6CDA5 },
	{ 0xF0A690AE, 0x6CDAF },
	{ 0xF0A690AF, 0x6CDB0 },
	{ 0xF0A690B0, 0x5BBBC },
	{ 0xF0A690B1, 0x6CDAA },
	{ 0xF0A690B2, 0x6CDAC },
	{ 0xF0A690B3, 0x6CDAB },
	{ 0xF0A690B5, 0xFBEB5 },
	{ 0xF0A690B6, 0xFBEB6 },
	{ 0xF0A690B7, 0x6CDA9 },
	{ 0xF0A690B8, 0x5C1EE },
	{ 0xF0A690B9, 0x5C1EB },
	{ 0xF0A690BA, 0x4BFF9 },
	{ 0xF0A690BB, 0x6D6DD },
	{ 0xF0A690BC, 0x6D6DE },
	{ 0xF0A690BD, 0x6D6DF },
	{ 0xF0A690BE, 0x5C1ED },
	{ 0xF0A69180, 0x5C1EC },
	{ 0xF0A69184, 0xFC4E4 },
	{ 0xF0A69186, 0x6CDA4 },
	{ 0xF0A69187, 0x5C8E5 },
	{ 0xF0A69188, 0x5C8DE },
	{ 0xF0A69189, 0x6E0D7 },
	{ 0xF0A6918A, 0x5C8DF },
	{ 0xF0A6918B, 0x5C8E3 },
	{ 0xF0A6918C, 0x5C8E0 },
	{ 0xF0A6918D, 0x5C8E4 },
	{ 0xF0A6918E, 0x5C8E1 },
	{ 0xF0A6918F, 0x5C8E2 },
	{ 0xF0A69190, 0x6E0D6 },
	{ 0xF0A69191, 0x5C8E6 },
	{ 0xF0A69192, 0xFCBBD },
	{ 0xF0A69193, 0xFCBBE },
	{ 0xF0A69194, 0xFCBBF },
	{ 0xF0A69195, 0xFCBC0 },
	{ 0xF0A69198, 0x5CFEA },
	{ 0xF0A69199, 0x5CFEB },
	{ 0xF0A6919A, 0x7A6FE },
	{ 0xF0A6919B, 0x5CFE8 },
	{ 0xF0A6919C, 0x4CCCC },
	{ 0xF0A6919D, 0x5CFEC },
	{ 0xF0A6919E, 0x5CFE5 },
	{ 0xF0A6919F, 0x7A6FD },
	{ 0xF0A691A0, 0x5CFE7 },
	{ 0xF0A691A1, 0xFD1C6 },
	{ 0xF0A691A2, 0x6E0D9 },
	{ 0xF0A691A3, 0x5CFE6 },
	{ 0xF0A691A4, 0x7A7A4 },
	{ 0xF0A691A5, 0x7A7A5 },
	{ 0xF0A691A6, 0x7A7A1 },
	{ 0xF0A691A7, 0x4CCCE },
	{ 0xF0A691A8, 0x7A7A2 },
	{ 0xF0A691A9, 0x4CCCD },
	{ 0xF0A691AA, 0x7A7A3 },
	{ 0xF0A691AB, 0xFD1C4 },
	{ 0xF0A691AC, 0xFD1C5 },
	{ 0xF0A691B0, 0x7B1D1 },
	{ 0xF0A691B1, 0x7B1D3 },
	{ 0xF0A691B2, 0x5D7A5 },
	{ 0xF0A691B3, 0x7B1D6 },
	{ 0xF0A691B4, 0x7B1D2 },
	{ 0xF0A691B5, 0x7B1D4 },
	{ 0xF0A691B6, 0x4D2D7 },
	{ 0xF0A691B8, 0x5D7A3 },
	{ 0xF0A691B9, 0x5D7A6 },
	{ 0xF0A691BA, 0x5D7A4 },
	{ 0xF0A691BB, 0x5CFE9 },
	{ 0xF0A691BC, 0x5D7A2 },
	{ 0xF0A691BD, 0x7B1D5 },
	{ 0xF0A691BE, 0x5D7A7 },
	{ 0xF0A691BF, 0xFD7A6 },
	{ 0xF0A69283, 0x4D7F9 },
	{ 0xF0A69284, 0x7BAD4 },
	{ 0xF0A69285, 0x5DDCC },
	{ 0xF0A69286, 0x7BAD5 },
	{ 0xF0A69287, 0x7C8F1 },
	{ 0xF0A69288, 0x5DDCD },
	{ 0xF0A6928A, 0x7BAD3 },
	{ 0xF0A6928B, 0xFDCA7 },
	{ 0xF0A6928C, 0xFDCA8 },
	{ 0xF0A6928D, 0x5E3E0 },
	{ 0xF0A6928E, 0x4DCEE },
	{ 0xF0A6928F, 0x7C1F1 },
	{ 0xF0A69290, 0x5DDCE },
	{ 0xF0A69291, 0x4DCEF },
	{ 0xF0A69292, 0x7C1ED },
	{ 0xF0A69293, 0x7C1EF },
	{ 0xF0A69294, 0x7C1EC },
	{ 0xF0A69295, 0x7C1F0 },
	{ 0xF0A69296, 0x7C1EE },
	{ 0xF0A69299, 0xFE0B6 },
	{ 0xF0A6929A, 0xFE0B7 },
	{ 0xF0A6929B, 0x7C1EB },
	{ 0xF0A6929C, 0x4E0F0 },
	{ 0xF0A6929D, 0x5E8FE },
	{ 0xF0A6929F, 0x5E8FD },
	{ 0xF0A692A0, 0x7C8F2 },
	{ 0xF0A692A2, 0x7CFB5 },
	{ 0xF0A692A3, 0x7CFB6 },
	{ 0xF0A692A4, 0xFE5F2 },
	{ 0xF0A692A5, 0x7CFB3 },
	{ 0xF0A692A6, 0x4E6FC },
	{ 0xF0A692A8, 0x7D4C9 },
	{ 0xF0A692A9, 0x7D4CB },
	{ 0xF0A692AA, 0x7CFB4 },
	{ 0xF0A692AC, 0x7D4CA },
	{ 0xF0A692AD, 0x7D8E2 },
	{ 0xF0A692AE, 0x7D8E3 },
	{ 0xF0A692AF, 0x7D8E1 },
	{ 0xF0A692B1, 0x6A5C6 },
	{ 0xF0A692B2, 0x6ADD8 },
	{ 0xF0A692B3, 0x6A8F5 },
	{ 0xF0A692B6, 0x4A7DF },
	{ 0xF0A692B7, 0x4A7E0 },
	{ 0xF0A692B8, 0x6BAF8 },
	{ 0xF0A692BA, 0x4B4C0 },
	{ 0xF0A692BB, 0x5ABAC },
	{ 0xF0A692BC, 0xFB7E0 },
	{ 0xF0A692BD, 0xFB7E1 },
	{ 0xF0A692BE, 0x6C3C8 },
	{ 0xF0A69380, 0x6CDB1 },
	{ 0xF0A69381, 0x7A7A6 },
	{ 0xF0A69383, 0x7B1D8 },
	{ 0xF0A69384, 0x7B1D7 },
	{ 0xF0A6938C, 0xFEBDE },
	{ 0xF0A6938E, 0x6ADD9 },
	{ 0xF0A6938F, 0x6ADDA },
	{ 0xF0A69390, 0x5A1F9 },
	{ 0xF0A69391, 0xFA8CC },
	{ 0xF0A69392, 0x4AFB9 },
	{ 0xF0A69393, 0x5B4E7 },
	{ 0xF0A69394, 0x5BBBE },
	{ 0xF0A69396, 0x5C1EF },
	{ 0xF0A69397, 0x6E0DA },
	{ 0xF0A69398, 0x7A7A7 },
	{ 0xF0A69399, 0x7A7A9 },
	{ 0xF0A6939A, 0x5C8E7 },
	{ 0xF0A6939D, 0x7B1DA },
	{ 0xF0A6939E, 0x7B1D9 },
	{ 0xF0A693A0, 0x7BAD6 },
	{ 0xF0A693A4, 0x5A3A1 },
	{ 0xF0A693A5, 0x6ADDB },
	{ 0xF0A693A6, 0xFA8CD },
	{ 0xF0A693A8, 0x6B3F7 },
	{ 0xF0A693A9, 0xFADA7 },
	{ 0xF0A693AA, 0x6B3F8 },
	{ 0xF0A693AB, 0xFB1FE },
	{ 0xF0A693AC, 0x5B4E8 },
	{ 0xF0A693AD, 0xFB7E2 },
	{ 0xF0A693AE, 0x6C3C9 },
	{ 0xF0A693AF, 0x4BAB7 },
	{ 0xF0A693B0, 0x5BBC1 },
	{ 0xF0A693B1, 0x5BBC0 },
	{ 0xF0A693B4, 0x4BFFB },
	{ 0xF0A693B5, 0x6D6E0 },
	{ 0xF0A693B7, 0x6E0DC },
	{ 0xF0A693B8, 0x5C8EC },
	{ 0xF0A693B9, 0x5C8E8 },
	{ 0xF0A693BA, 0x5C8ED },
	{ 0xF0A693BB, 0x5C8EA },
	{ 0xF0A693BC, 0x5C8E9 },
	{ 0xF0A693BD, 0x5C8EB },
	{ 0xF0A693BE, 0x4C6B1 },
	{ 0xF0A69480, 0xFC4E5 },
	{ 0xF0A69481, 0x6E0DB },
	{ 0xF0A69482, 0x5CFEF },
	{ 0xF0A69483, 0x5CFF0 },
	{ 0xF0A69484, 0x5CFF1 },
	{ 0xF0A69485, 0x5CFED },
	{ 0xF0A69486, 0x5CFEE },
	{ 0xF0A69489, 0x7A7AA },
	{ 0xF0A6948B, 0x5D7A9 },
	{ 0xF0A6948C, 0x5D7A8 },
	{ 0xF0A6948D, 0x4D2D8 },
	{ 0xF0A6948E, 0x4D2D9 },
	{ 0xF0A6948F, 0x7B1DC },
	{ 0xF0A69490, 0x7B1DD },
	{ 0xF0A69491, 0x7B1DB },
	{ 0xF0A69492, 0xFD1C7 },
	{ 0xF0A69493, 0x5DDCF },
	{ 0xF0A69494, 0x4D7FC },
	{ 0xF0A69495, 0x7BADA },
	{ 0xF0A69497, 0x7BAD7 },
	{ 0xF0A69498, 0x7BAD8 },
	{ 0xF0A6949A, 0xFD7A9 },
	{ 0xF0A6949B, 0x5E3E1 },
	{ 0xF0A6949C, 0x4D7FE },
	{ 0xF0A6949D, 0x7C1F2 },
	{ 0xF0A6949E, 0x7BAD9 },
	{ 0xF0A6949F, 0x7C8F5 },
	{ 0xF0A694A0, 0x5E3E2 },
	{ 0xF0A694A1, 0x7C1F4 },
	{ 0xF0A694A2, 0x7C1F3 },
	{ 0xF0A694A3, 0xFDCA9 },
	{ 0xF0A694A4, 0xFDCAA },
	{ 0xF0A694A5, 0x7C8F4 },
	{ 0xF0A694A6, 0x5E9A1 },
	{ 0xF0A694A8, 0x7C8F3 },
	{ 0xF0A694A9, 0x4E6FE },
	{ 0xF0A694AA, 0x7D4CC },
	{ 0xF0A694AB, 0x4EAEC },
	{ 0xF0A694AC, 0x5F7FC },
	{ 0xF0A694AD, 0x5F9BB },
	{ 0xF0A694AF, 0x5A7D5 },
	{ 0xF0A694B0, 0x5A7D4 },
	{ 0xF0A694B1, 0x6ADDE },
	{ 0xF0A694B2, 0xFA8CE },
	{ 0xF0A694B3, 0xFA8CF },
	{ 0xF0A694B5, 0x6ADDD },
	{ 0xF0A694B7, 0x5ABAF },
	{ 0xF0A694B8, 0x5ABAD },
	{ 0xF0A694B9, 0x5ABAE },
	{ 0xF0A694BC, 0x4AFBC },
	{ 0xF0A694BD, 0x6BAFE },
	{ 0xF0A694BE, 0x4AFBB },
	{ 0xF0A694BF, 0x6BAFA },
	{ 0xF0A69580, 0x5AFE4 },
	{ 0xF0A69581, 0x6BBA2 },
	{ 0xF0A69582, 0xFB2A1 },
	{ 0xF0A69583, 0xFB2A4 },
	{ 0xF0A69584, 0xFB2A6 },
	{ 0xF0A69585, 0xFB2A7 },
	{ 0xF0A69587, 0x6BAFB },
	{ 0xF0A69588, 0xFB2A2 },
	{ 0xF0A6958A, 0x6BAFD },
	{ 0xF0A6958B, 0x6BAFC },
	{ 0xF0A6958C, 0x6BBA3 },
	{ 0xF0A6958D, 0x6BAF9 },
	{ 0xF0A6958E, 0xFB2A5 },
	{ 0xF0A6958F, 0x5AFE5 },
	{ 0xF0A69590, 0x6C3CB },
	{ 0xF0A69591, 0x4B4C3 },
	{ 0xF0A69592, 0x4B4C2 },
	{ 0xF0A69593, 0x4B4C4 },
	{ 0xF0A69594, 0x6C3CD },
	{ 0xF0A69595, 0x5B4E9 },
	{ 0xF0A69596, 0x6C3CF },
	{ 0xF0A69597, 0x6C3CE },
	{ 0xF0A69598, 0x6C3CC },
	{ 0xF0A6959A, 0x6C3CA },
	{ 0xF0A6959B, 0xFB7E3 },
	{ 0xF0A6959C, 0xFB7E4 },
	{ 0xF0A6959D, 0xFB7E5 },
	{ 0xF0A6959E, 0xFB7E6 },
	{ 0xF0A695A0, 0x5BBC2 },
	{ 0xF0A695A1, 0x6CDB3 },
	{ 0xF0A695A2, 0x6CDB4 },
	{ 0xF0A695A5, 0x5BBC3 },
	{ 0xF0A695A6, 0x6CDB5 },
	{ 0xF0A695A7, 0xFBEB7 },
	{ 0xF0A695A8, 0xFBEB8 },
	{ 0xF0A695A9, 0xFBEB9 },
	{ 0xF0A695AA, 0xFBEBA },
	{ 0xF0A695AB, 0xFBEBC },
	{ 0xF0A695AC, 0xFBEBD },
	{ 0xF0A695AD, 0xFBEBE },
	{ 0xF0A695AE, 0xFBEBF },
	{ 0xF0A695AF, 0xFBEC0 },
	{ 0xF0A695B1, 0x6CDB2 },
	{ 0xF0A695B2, 0xFBEBB },
	{ 0xF0A695B5, 0x6D6E2 },
	{ 0xF0A695B6, 0x6D6E6 },
	{ 0xF0A695B7, 0x5C1F1 },
	{ 0xF0A695B8, 0x5C1F2 },
	{ 0xF0A695B9, 0x6D6E1 },
	{ 0xF0A695BA, 0x6D6EB },
	{ 0xF0A695BB, 0x6D6E9 },
	{ 0xF0A695BC, 0x6D6E7 },
	{ 0xF0A695BD, 0x5C1F3 },
	{ 0xF0A695BE, 0x6D6E8 },
	{ 0xF0A695BF, 0x6D6E4 },
	{ 0xF0A69680, 0x6D6EA },
	{ 0xF0A69682, 0x6D6E3 },
	{ 0xF0A69683, 0xFC4E6 },
	{ 0xF0A69684, 0xFC4E7 },
	{ 0xF0A69685, 0x6D6E5 },
	{ 0xF0A69688, 0x5C8F0 },
	{ 0xF0A69689, 0x5C8F1 },
	{ 0xF0A6968A, 0x5C8EE },
	{ 0xF0A6968B, 0x4CCD0 },
	{ 0xF0A6968C, 0x6E0DE },
	{ 0xF0A6968D, 0x5C8F2 },
	{ 0xF0A6968E, 0x5C8EF },
	{ 0xF0A69690, 0x5C8F3 },
	{ 0xF0A69691, 0xFCBC1 },
	{ 0xF0A69692, 0xFCBC2 },
	{ 0xF0A69693, 0xFCBC3 },
	{ 0xF0A69694, 0xFCBC4 },
	{ 0xF0A69695, 0xFCBC5 },
	{ 0xF0A69696, 0xFCBC6 },
	{ 0xF0A69697, 0xFCBC7 },
	{ 0xF0A69698, 0xFCBC8 },
	{ 0xF0A69699, 0xFCBCA },
	{ 0xF0A6969A, 0xFCBCB },
	{ 0xF0A6969B, 0xFCBCC },
	{ 0xF0A6969C, 0x6E0DF },
	{ 0xF0A696A2, 0x5CFF2 },
	{ 0xF0A696A3, 0x7A7AC },
	{ 0xF0A696A4, 0x5CFF5 },
	{ 0xF0A696A5, 0x7A7AF },
	{ 0xF0A696A6, 0x5CFF4 },
	{ 0xF0A696A7, 0x5CFF3 },
	{ 0xF0A696A8, 0x4CCD1 },
	{ 0xF0A696A9, 0x5CFF7 },
	{ 0xF0A696AA, 0x7A7AB },
	{ 0xF0A696AB, 0x7A7B0 },
	{ 0xF0A696AC, 0x5CFF6 },
	{ 0xF0A696AF, 0xFD1C8 },
	{ 0xF0A696B0, 0xFD1C9 },
	{ 0xF0A696B1, 0xFD1CA },
	{ 0xF0A696B2, 0xFD1CB },
	{ 0xF0A696B3, 0xFD1CC },
	{ 0xF0A696B4, 0xFD1CD },
	{ 0xF0A696B5, 0xFD1CE },
	{ 0xF0A696B6, 0xFD1CF },
	{ 0xF0A696B9, 0x7A7AD },
	{ 0xF0A696BC, 0x5D7AC },
	{ 0xF0A696BD, 0x5D7AF },
	{ 0xF0A696BE, 0x5D7AB },
	{ 0xF0A696BF, 0x5D7AD },
	{ 0xF0A69780, 0x5D7AE },
	{ 0xF0A69781, 0x7B1E1 },
	{ 0xF0A69782, 0x7B1DF },
	{ 0xF0A69783, 0x7B1DE },
	{ 0xF0A69784, 0xFD7AA },
	{ 0xF0A69785, 0xFD7AB },
	{ 0xF0A69786, 0xFD7AC },
	{ 0xF0A69787, 0xFD7AD },
	{ 0xF0A69788, 0xFD7AE },
	{ 0xF0A69789, 0xFD7AF },
	{ 0xF0A6978A, 0x7B1E0 },
	{ 0xF0A6978D, 0x5D7AA },
	{ 0xF0A69790, 0x5DDD0 },
	{ 0xF0A69791, 0x5DDD1 },
	{ 0xF0A69792, 0x5DDD2 },
	{ 0xF0A69793, 0x7BADB },
	{ 0xF0A69794, 0x4D8A5 },
	{ 0xF0A69795, 0x4D8A6 },
	{ 0xF0A69796, 0x5DDD4 },
	{ 0xF0A69797, 0x5DDD3 },
	{ 0xF0A69798, 0xFDCAC },
	{ 0xF0A69799, 0x7BADD },
	{ 0xF0A6979A, 0x7BADC },
	{ 0xF0A6979F, 0x3D8E3 },
	{ 0xF0A697A0, 0x7C1F7 },
	{ 0xF0A697A1, 0x5E3E6 },
	{ 0xF0A697A2, 0x5E3E3 },
	{ 0xF0A697A3, 0x4DCF2 },
	{ 0xF0A697A4, 0x7C1F9 },
	{ 0xF0A697A5, 0x5DDD5 },
	{ 0xF0A697A6, 0x7C1F8 },
	{ 0xF0A697A7, 0x5E3E4 },
	{ 0xF0A697A8, 0x5E3E5 },
	{ 0xF0A697A9, 0x7C1F5 },
	{ 0xF0A697AA, 0xFE0B8 },
	{ 0xF0A697AB, 0xFE0B9 },
	{ 0xF0A697AC, 0xFE0BA },
	{ 0xF0A697AF, 0x7C1F6 },
	{ 0xF0A697B1, 0xFDCAB },
	{ 0xF0A697B2, 0xFE3C7 },
	{ 0xF0A697B3, 0x7C8F6 },
	{ 0xF0A697B4, 0x5E9A2 },
	{ 0xF0A697B5, 0x5E9A3 },
	{ 0xF0A697B6, 0x7C8F8 },
	{ 0xF0A697B7, 0x7C8F7 },
	{ 0xF0A697B8, 0xFE3C8 },
	{ 0xF0A697B9, 0xFE3C9 },
	{ 0xF0A697BE, 0x7CFB9 },
	{ 0xF0A69880, 0xFE5F3 },
	{ 0xF0A69881, 0xFE5F4 },
	{ 0xF0A69882, 0xFE5F5 },
	{ 0xF0A69883, 0x7CFB8 },
	{ 0xF0A69884, 0x7CFB7 },
	{ 0xF0A69885, 0x5F0F6 },
	{ 0xF0A69886, 0xFE8B0 },
	{ 0xF0A69887, 0xFE8B1 },
	{ 0xF0A69888, 0x7D4CD },
	{ 0xF0A69889, 0x7D4CE },
	{ 0xF0A6988A, 0x5F3FE },
	{ 0xF0A6988B, 0x7D8E4 },
	{ 0xF0A6988D, 0x4EAED },
	{ 0xF0A6988E, 0xFEAEC },
	{ 0xF0A6988F, 0xFEBDF },
	{ 0xF0A69890, 0xFECB6 },
	{ 0xF0A69891, 0xFECD0 },
	{ 0xF0A69892, 0x5A1FA },
	{ 0xF0A69893, 0x6ADDF },
	{ 0xF0A69894, 0x5ABB0 },
	{ 0xF0A69895, 0x6C3D0 },
	{ 0xF0A69898, 0x6CDB6 },
	{ 0xF0A6989B, 0x6C8EA },
	{ 0xF0A6989D, 0x6D6EE },
	{ 0xF0A6989E, 0x6E0E2 },
	{ 0xF0A6989F, 0x6E0E1 },
	{ 0xF0A698A0, 0x7A7B1 },
	{ 0xF0A698A2, 0xFD1D0 },
	{ 0xF0A698A3, 0x7B1E2 },
	{ 0xF0A698A8, 0x7CFBA },
	{ 0xF0A698A9, 0x5A3A5 },
	{ 0xF0A698AA, 0x5A3A3 },
	{ 0xF0A698AB, 0x6ADE0 },
	{ 0xF0A698AC, 0x6ADE1 },
	{ 0xF0A698AD, 0x6A5C8 },
	{ 0xF0A698AE, 0xFA2EC },
	{ 0xF0A698AF, 0xFA2ED },
	{ 0xF0A698B2, 0x5A3A4 },
	{ 0xF0A698B3, 0x5A3A2 },
	{ 0xF0A698B4, 0x5A4F3 },
	{ 0xF0A698B5, 0x5A4F2 },
	{ 0xF0A698B6, 0x6A8F9 },
	{ 0xF0A698B7, 0x6A8F8 },
	{ 0xF0A698B8, 0x6A8F7 },
	{ 0xF0A698BA, 0x6A8F6 },
	{ 0xF0A698BB, 0x6B3FB },
	{ 0xF0A698BD, 0x6B3FA },
	{ 0xF0A698BE, 0x6B3F9 },
	{ 0xF0A698BF, 0x5A7DA },
	{ 0xF0A69980, 0x5A7DE },
	{ 0xF0A69981, 0x6ADE4 },
	{ 0xF0A69982, 0x4AFC3 },
	{ 0xF0A69983, 0x6ADED },
	{ 0xF0A69984, 0x6ADEE },
	{ 0xF0A69985, 0x6ADE2 },
	{ 0xF0A69986, 0x5A7DD },
	{ 0xF0A69987, 0x6ADE6 },
	{ 0xF0A69988, 0x5A7D9 },
	{ 0xF0A69989, 0x5A7D7 },
	{ 0xF0A6998A, 0x6ADEB },
	{ 0xF0A6998B, 0x5A7DB },
	{ 0xF0A6998D, 0x4A7EB },
	{ 0xF0A69990, 0x6ADE8 },
	{ 0xF0A69991, 0x6ADEF },
	{ 0xF0A69992, 0xFA8D0 },
	{ 0xF0A69993, 0xFA8D1 },
	{ 0xF0A69994, 0xFA8D3 },
	{ 0xF0A69995, 0xFA8D4 },
	{ 0xF0A69996, 0x6ADEC },
	{ 0xF0A69997, 0x4A6E4 },
	{ 0xF0A69998, 0x6ADE5 },
	{ 0xF0A6999B, 0x6ADE7 },
	{ 0xF0A6999C, 0x5A7DC },
	{ 0xF0A6999F, 0x6ADEA },
	{ 0xF0A699A0, 0x6ADE3 },
	{ 0xF0A699A1, 0x6BBA7 },
	{ 0xF0A699A2, 0x6BBA5 },
	{ 0xF0A699A7, 0x4AFBD },
	{ 0xF0A699A8, 0x5A7D6 },
	{ 0xF0A699A9, 0x6BBA6 },
	{ 0xF0A699AA, 0x6B4AD },
	{ 0xF0A699AB, 0x4ABAD },
	{ 0xF0A699AC, 0x5ABB4 },
	{ 0xF0A699AD, 0x6B4A8 },
	{ 0xF0A699AE, 0x5ABB1 },
	{ 0xF0A699AF, 0x5ABB8 },
	{ 0xF0A699B0, 0x6B4A9 },
	{ 0xF0A699B1, 0x4ABAE },
	{ 0xF0A699B2, 0x6C3D4 },
	{ 0xF0A699B3, 0x6B4A7 },
	{ 0xF0A699B4, 0x4ABAB },
	{ 0xF0A699B5, 0x6B4AB },
	{ 0xF0A699B6, 0x4ABB0 },
	{ 0xF0A699B7, 0x6B4A5 },
	{ 0xF0A699B8, 0x5ABB6 },
	{ 0xF0A699B9, 0x6B4A6 },
	{ 0xF0A699BA, 0x5ABB7 },
	{ 0xF0A699BB, 0x5ABB2 },
	{ 0xF0A699BC, 0x4AFC8 },
	{ 0xF0A699BF, 0x5ABB5 },
	{ 0xF0A69A80, 0x6B3FC },
	{ 0xF0A69A81, 0x6B4A1 },
	{ 0xF0A69A82, 0x6B4A2 },
	{ 0xF0A69A83, 0x6B4A4 },
	{ 0xF0A69A84, 0xFADAA },
	{ 0xF0A69A85, 0xFADAF },
	{ 0xF0A69A86, 0xFB7E7 },
	{ 0xF0A69A87, 0xFB7E8 },
	{ 0xF0A69A88, 0x6B3FE },
	{ 0xF0A69A89, 0x6B4AF },
	{ 0xF0A69A8C, 0x6B4AC },
	{ 0xF0A69A8D, 0x6B4AA },
	{ 0xF0A69A8E, 0x6B4B0 },
	{ 0xF0A69A91, 0x6B4AE },
	{ 0xF0A69A92, 0x6C3D3 },
	{ 0xF0A69A93, 0x6C3D2 },
	{ 0xF0A69A94, 0xFADAB },
	{ 0xF0A69A98, 0x6C3D5 },
	{ 0xF0A69A99, 0x6C3D6 },
	{ 0xF0A69A9A, 0x6BBB0 },
	{ 0xF0A69A9B, 0x6C3D1 },
	{ 0xF0A69A9C, 0xFADAD },
	{ 0xF0A69A9D, 0x5AFE7 },
	{ 0xF0A69A9E, 0x4AFBE },
	{ 0xF0A69A9F, 0x4B4C5 },
	{ 0xF0A69AA0, 0x4AFC5 },
	{ 0xF0A69AA1, 0x6BBB2 },
	{ 0xF0A69AA2, 0x5AFEC },
	{ 0xF0A69AA3, 0x4AFC4 },
	{ 0xF0A69AA4, 0x6BBAE },
	{ 0xF0A69AA5, 0x5AFEE },
	{ 0xF0A69AA6, 0x6BBAA },
	{ 0xF0A69AA7, 0x5AFF0 },
	{ 0xF0A69AA8, 0x5BBC4 },
	{ 0xF0A69AA9, 0x5AFEF },
	{ 0xF0A69AAA, 0x6BBA9 },
	{ 0xF0A69AAB, 0x5AFE6 },
	{ 0xF0A69AAC, 0x6BBAB },
	{ 0xF0A69AAD, 0x4AFC0 },
	{ 0xF0A69AAE, 0x6CDBB },
	{ 0xF0A69AB2, 0x5AFE9 },
	{ 0xF0A69AB3, 0xFADA9 },
	{ 0xF0A69AB4, 0xFB2A8 },
	{ 0xF0A69AB5, 0xFB2A9 },
	{ 0xF0A69AB6, 0xFB2AD },
	{ 0xF0A69AB7, 0xFBECC },
	{ 0xF0A69AB8, 0x5AFE8 },
	{ 0xF0A69AB9, 0x5AEA4 },
	{ 0xF0A69ABA, 0x6BBAF },
	{ 0xF0A69ABB, 0x6BBAD },
	{ 0xF0A69ABD, 0x6BBAC },
	{ 0xF0A69B81, 0x6BBB3 },
	{ 0xF0A69B82, 0x6CDBA },
	{ 0xF0A69B83, 0x6CDB8 },
	{ 0xF0A69B84, 0x6CDB9 },
	{ 0xF0A69B85, 0x6CDB7 },
	{ 0xF0A69B8E, 0x6B4A3 },
	{ 0xF0A69B8F, 0x5AFEB },
	{ 0xF0A69B90, 0x5AFF1 },
	{ 0xF0A69B92, 0x5AFEA },
	{ 0xF0A69B93, 0x5B4F4 },
	{ 0xF0A69B94, 0x6C3DB },
	{ 0xF0A69B95, 0x6C3D9 },
	{ 0xF0A69B96, 0x5B4EB },
	{ 0xF0A69B97, 0x4B4CE },
	{ 0xF0A69B98, 0x5B4EC },
	{ 0xF0A69B99, 0x4AFC2 },
	{ 0xF0A69B9A, 0x5B4F1 },
	{ 0xF0A69B9B, 0x4B4C6 },
	{ 0xF0A69B9C, 0x4B4D5 },
	{ 0xF0A69B9D, 0x5C1F4 },
	{ 0xF0A69B9E, 0x4B4D4 },
	{ 0xF0A69B9F, 0x6C3D7 },
	{ 0xF0A69BA0, 0x5B4EE },
	{ 0xF0A69BA1, 0x6C3DF },
	{ 0xF0A69BA3, 0x4B4C9 },
	{ 0xF0A69BA4, 0x5B4F5 },
	{ 0xF0A69BA5, 0x5B4F6 },
	{ 0xF0A69BA6, 0x6C3E0 },
	{ 0xF0A69BA7, 0x6C3DE },
	{ 0xF0A69BA9, 0x4B4CF },
	{ 0xF0A69BAA, 0x5B4F2 },
	{ 0xF0A69BAB, 0x6C3E1 },
	{ 0xF0A69BAC, 0x6C3E2 },
	{ 0xF0A69BAD, 0xFB7E9 },
	{ 0xF0A69BAE, 0xFB7EB },
	{ 0xF0A69BB3, 0x6C3DC },
	{ 0xF0A69BB4, 0x6C3DD },
	{ 0xF0A69BB6, 0x6D6EF },
	{ 0xF0A69BB7, 0x6D6F0 },
	{ 0xF0A69BB9, 0x6D6F1 },
	{ 0xF0A69C82, 0x5B4F3 },
	{ 0xF0A69C83, 0x5B4EF },
	{ 0xF0A69C84, 0x5B4F0 },
	{ 0xF0A69C86, 0x6CDC3 },
	{ 0xF0A69C87, 0x5BBC8 },
	{ 0xF0A69C88, 0x6CDBD },
	{ 0xF0A69C8A, 0x5BBC5 },
	{ 0xF0A69C8B, 0x6CDCB },
	{ 0xF0A69C8C, 0x6CDC2 },
	{ 0xF0A69C8D, 0x4BABC },
	{ 0xF0A69C8E, 0x5BBCA },
	{ 0xF0A69C8F, 0x6CDCF },
	{ 0xF0A69C90, 0x6CDBC },
	{ 0xF0A69C91, 0x6E0E5 },
	{ 0xF0A69C92, 0x5BBC7 },
	{ 0xF0A69C93, 0x6CDD0 },
	{ 0xF0A69C94, 0x6D6F5 },
	{ 0xF0A69C95, 0x4BAC8 },
	{ 0xF0A69C96, 0x5BBCC },
	{ 0xF0A69C97, 0x6CDD5 },
	{ 0xF0A69C98, 0x6CDCE },
	{ 0xF0A69C99, 0x6CDCC },
	{ 0xF0A69C9A, 0x6CDD3 },
	{ 0xF0A69C9B, 0x5BBC6 },
	{ 0xF0A69C9C, 0x5C8F5 },
	{ 0xF0A69C9F, 0x6CDBE },
	{ 0xF0A69CA0, 0x6CDC7 },
	{ 0xF0A69CA1, 0x6CDCA },
	{ 0xF0A69CA2, 0xFBEC1 },
	{ 0xF0A69CA3, 0xFBEC4 },
	{ 0xF0A69CA4, 0xFBEC6 },
	{ 0xF0A69CA5, 0xFBEC7 },
	{ 0xF0A69CA6, 0xFBEC8 },
	{ 0xF0A69CA7, 0xFBEC9 },
	{ 0xF0A69CA8, 0xFBECA },
	{ 0xF0A69CA9, 0xFBECB },
	{ 0xF0A69CAA, 0x6CDC4 },
	{ 0xF0A69CAC, 0x6CDC9 },
	{ 0xF0A69CB3, 0xFBBE3 },
	{ 0xF0A69CB5, 0x6CDCD },
	{ 0xF0A69CB6, 0x6CDC1 },
	{ 0xF0A69CB9, 0x6CDD2 },
	{ 0xF0A69CBA, 0x6CDBF },
	{ 0xF0A69CBB, 0x6CDC0 },
	{ 0xF0A69CBD, 0x6E0E3 },
	{ 0xF0A69CBE, 0x6E0E7 },
	{ 0xF0A69CBF, 0x6E0E4 },
	{ 0xF0A69D81, 0xFBEC5 },
	{ 0xF0A69D8F, 0x5BBC9 },
	{ 0xF0A69D90, 0x6CDC6 },
	{ 0xF0A69D91, 0x5B4ED },
	{ 0xF0A69D92, 0x5BBCB },
	{ 0xF0A69D93, 0x5BBCE },
	{ 0xF0A69D94, 0x5BBCF },
	{ 0xF0A69D95, 0x6CDD1 },
	{ 0xF0A69D96, 0x5BBD1 },
	{ 0xF0A69D97, 0x6CDC5 },
	{ 0xF0A69D98, 0x6E0E8 },
	{ 0xF0A69D99, 0x6E0E6 },
	{ 0xF0A69D9A, 0x5C1FD },
	{ 0xF0A69D9B, 0x4C0A1 },
	{ 0xF0A69D9C, 0x5C2A6 },
	{ 0xF0A69D9D, 0x5C2A1 },
	{ 0xF0A69D9E, 0x5C1F5 },
	{ 0xF0A69D9F, 0x5C1F9 },
	{ 0xF0A69DA0, 0x5C2A7 },
	{ 0xF0A69DA1, 0x6D6FD },
	{ 0xF0A69DA2, 0x4BFFE },
	{ 0xF0A69DA3, 0x6D6F2 },
	{ 0xF0A69DA4, 0x4BAC6 },
	{ 0xF0A69DA5, 0x5C2A2 },
	{ 0xF0A69DA6, 0x5C1F8 },
	{ 0xF0A69DA7, 0x6D6F7 },
	{ 0xF0A69DA8, 0x4C0A4 },
	{ 0xF0A69DA9, 0x6D6F9 },
	{ 0xF0A69DAA, 0x4C0A2 },
	{ 0xF0A69DAB, 0x6D7A1 },
	{ 0xF0A69DAC, 0x6D6F3 },
	{ 0xF0A69DAD, 0x5C2A9 },
	{ 0xF0A69DAE, 0x6D6F4 },
	{ 0xF0A69DAF, 0x6D6F8 },
	{ 0xF0A69DB0, 0x5C2A3 },
	{ 0xF0A69DB1, 0x6D6FC },
	{ 0xF0A69DB2, 0x5C1FB },
	{ 0xF0A69DB3, 0x5C1FA },
	{ 0xF0A69DB4, 0x5C2A5 },
	{ 0xF0A69DB5, 0x5C2A4 },
	{ 0xF0A69DB6, 0x6D6FA },
	{ 0xF0A69DB7, 0x5C1F6 },
	{ 0xF0A69DB8, 0x6D6FE },
	{ 0xF0A69DBA, 0xFC4E9 },
	{ 0xF0A69DBB, 0xFC4EA },
	{ 0xF0A69DBC, 0xFC4EB },
	{ 0xF0A69DBD, 0xFC4EC },
	{ 0xF0A69DBE, 0xFC4ED },
	{ 0xF0A69DBF, 0xFC4EF },
	{ 0xF0A69E80, 0xFC4F1 },
	{ 0xF0A69E81, 0x4C0AB },
	{ 0xF0A69E84, 0x6D7A3 },
	{ 0xF0A69E85, 0x6D7A2 },
	{ 0xF0A69E87, 0xFC4F0 },
	{ 0xF0A69E89, 0x7A7B2 },
	{ 0xF0A69E8B, 0x7A7B3 },
	{ 0xF0A69E95, 0x6D6FB },
	{ 0xF0A69E96, 0x5C1FE },
	{ 0xF0A69E97, 0x5C1FC },
	{ 0xF0A69E99, 0x4C6C4 },
	{ 0xF0A69E9A, 0x5C8FB },
	{ 0xF0A69E9B, 0x4C6CC },
	{ 0xF0A69E9C, 0x4C6C3 },
	{ 0xF0A69E9D, 0x5C9A3 },
	{ 0xF0A69E9E, 0x6E0EA },
	{ 0xF0A69E9F, 0x5C8FA },
	{ 0xF0A69EA0, 0x4C6CA },
	{ 0xF0A69EA1, 0x5C9A4 },
	{ 0xF0A69EA2, 0x5C9A1 },
	{ 0xF0A69EA3, 0x4C6C9 },
	{ 0xF0A69EA4, 0x5C8F7 },
	{ 0xF0A69EA5, 0x5C8FD },
	{ 0xF0A69EA6, 0x4C6BA },
	{ 0xF0A69EA7, 0x4C6CB },
	{ 0xF0A69EA8, 0x5C8F8 },
	{ 0xF0A69EA9, 0x6E0F1 },
	{ 0xF0A69EAA, 0x6E0EC },
	{ 0xF0A69EAB, 0x5C8F6 },
	{ 0xF0A69EAC, 0x6E0EE },
	{ 0xF0A69EAD, 0x5C8F9 },
	{ 0xF0A69EAF, 0x6E0ED },
	{ 0xF0A69EB0, 0x5C8FC },
	{ 0xF0A69EB1, 0x7B1E3 },
	{ 0xF0A69EB2, 0x5C9A2 },
	{ 0xF0A69EB5, 0x4C6C8 },
	{ 0xF0A69EB6, 0x6E0EB },
	{ 0xF0A69EB7, 0xFCBCD },
	{ 0xF0A69EB8, 0xFCBCE },
	{ 0xF0A69EB9, 0xFCBCF },
	{ 0xF0A69EBA, 0xFCBD1 },
	{ 0xF0A69EBB, 0xFCBD2 },
	{ 0xF0A69EBC, 0xFCBD5 },
	{ 0xF0A69EBD, 0xFCBD3 },
	{ 0xF0A69F80, 0x6E0F0 },
	{ 0xF0A69F81, 0x6DDDC },
	{ 0xF0A69F94, 0x5C1F7 },
	{ 0xF0A69F95, 0x5C8FE },
	{ 0xF0A69F98, 0x4CCD3 },
	{ 0xF0A69F99, 0x5CFFB },
	{ 0xF0A69F9B, 0x7A7B4 },
	{ 0xF0A69F9C, 0x4CCD7 },
	{ 0xF0A69F9D, 0x7A7BB },
	{ 0xF0A69F9F, 0x5CFFA },
	{ 0xF0A69FA0, 0x4CCD9 },
	{ 0xF0A69FA1, 0x7BAE0 },
	{ 0xF0A69FA2, 0x7A7B7 },
	{ 0xF0A69FA3, 0x5CFFC },
	{ 0xF0A69FA4, 0x7A7B5 },
	{ 0xF0A69FA5, 0x4CCDA },
	{ 0xF0A69FA6, 0x7BADE },
	{ 0xF0A69FA7, 0x5CFF8 },
	{ 0xF0A69FA9, 0x7A7B8 },
	{ 0xF0A69FAA, 0xFD1D1 },
	{ 0xF0A69FAB, 0xFD1D2 },
	{ 0xF0A69FAC, 0xFD1D3 },
	{ 0xF0A69FAD, 0xFD1D4 },
	{ 0xF0A69FAF, 0x7A7B6 },
	{ 0xF0A69FB0, 0x7A7B9 },
	{ 0xF0A69FB3, 0x7A7BA },
	{ 0xF0A69FB4, 0x7BADF },
	{ 0xF0A6A080, 0x6E0E9 },
	{ 0xF0A6A081, 0x5CFF9 },
	{ 0xF0A6A082, 0xFDCB5 },
	{ 0xF0A6A083, 0x7B1EC },
	{ 0xF0A6A084, 0x5D7B7 },
	{ 0xF0A6A085, 0x5D7B2 },
	{ 0xF0A6A086, 0x4D2E8 },
	{ 0xF0A6A087, 0x4D2DD },
	{ 0xF0A6A088, 0x5D7B1 },
	{ 0xF0A6A089, 0x4D2DF },
	{ 0xF0A6A08A, 0x7B1E7 },
	{ 0xF0A6A08B, 0x7B1EE },
	{ 0xF0A6A08C, 0x5D7B5 },
	{ 0xF0A6A08D, 0x5D7B6 },
	{ 0xF0A6A08E, 0x4D2E5 },
	{ 0xF0A6A08F, 0x5CFFD },
	{ 0xF0A6A090, 0x5D7B4 },
	{ 0xF0A6A091, 0x7B1E5 },
	{ 0xF0A6A092, 0x7B1ED },
	{ 0xF0A6A093, 0x5D7B9 },
	{ 0xF0A6A094, 0x7B1EA },
	{ 0xF0A6A095, 0x5E9A4 },
	{ 0xF0A6A096, 0x4D2E0 },
	{ 0xF0A6A097, 0x7B1EF },
	{ 0xF0A6A099, 0xFD7B1 },
	{ 0xF0A6A09A, 0xFD7B3 },
	{ 0xF0A6A09C, 0xFD7B2 },
	{ 0xF0A6A09E, 0x7A7BC },
	{ 0xF0A6A09F, 0x7B1E8 },
	{ 0xF0A6A0A0, 0x7B1E9 },
	{ 0xF0A6A0A4, 0x7B1E4 },
	{ 0xF0A6A0A5, 0x7B1E6 },
	{ 0xF0A6A0A8, 0x7B1EB },
	{ 0xF0A6A0A9, 0x7C1FA },
	{ 0xF0A6A0AB, 0x7C8F9 },
	{ 0xF0A6A0AC, 0x7C1FB },
	{ 0xF0A6A0B7, 0x5D7BA },
	{ 0xF0A6A0B8, 0x5D7B0 },
	{ 0xF0A6A0B9, 0x5D7BB },
	{ 0xF0A6A0BA, 0x5D7B8 },
	{ 0xF0A6A0BB, 0x5D7B3 },
	{ 0xF0A6A0BC, 0x7C2A1 },
	{ 0xF0A6A0BE, 0x5DDDA },
	{ 0xF0A6A0BF, 0x5DDD9 },
	{ 0xF0A6A180, 0x7BAE2 },
	{ 0xF0A6A181, 0x4D8AE },
	{ 0xF0A6A182, 0x4D8AA },
	{ 0xF0A6A183, 0x4D8A9 },
	{ 0xF0A6A185, 0x5DDD8 },
	{ 0xF0A6A186, 0x5DDD6 },
	{ 0xF0A6A187, 0x4E0F1 },
	{ 0xF0A6A188, 0x7C8FB },
	{ 0xF0A6A18C, 0x5DDDE },
	{ 0xF0A6A18D, 0x7BAE5 },
	{ 0xF0A6A18E, 0xFDCAE },
	{ 0xF0A6A18F, 0xFDCAF },
	{ 0xF0A6A190, 0xFDCB1 },
	{ 0xF0A6A191, 0xFDCB2 },
	{ 0xF0A6A192, 0xFDCB3 },
	{ 0xF0A6A193, 0xFDCB4 },
	{ 0xF0A6A194, 0xFDCB6 },
	{ 0xF0A6A195, 0xFDCB0 },
	{ 0xF0A6A197, 0x7B7FE },
	{ 0xF0A6A198, 0x7BAE3 },
	{ 0xF0A6A19B, 0x7C8FA },
	{ 0xF0A6A19C, 0x7C8FD },
	{ 0xF0A6A1A8, 0x5DDDD },
	{ 0xF0A6A1A9, 0x7BAE1 },
	{ 0xF0A6A1AA, 0x5DDDC },
	{ 0xF0A6A1AB, 0x5DDD7 },
	{ 0xF0A6A1AC, 0x7BAE4 },
	{ 0xF0A6A1AD, 0x7C8FE },
	{ 0xF0A6A1B0, 0x4DCF5 },
	{ 0xF0A6A1B1, 0x5E3EA },
	{ 0xF0A6A1B2, 0x5E3E7 },
	{ 0xF0A6A1B4, 0x5E3E9 },
	{ 0xF0A6A1B5, 0x5E3EC },
	{ 0xF0A6A1B6, 0x7C1FC },
	{ 0xF0A6A1B7, 0x5E3EE },
	{ 0xF0A6A1B8, 0x7C1FE },
	{ 0xF0A6A1B9, 0x5E3EB },
	{ 0xF0A6A1BA, 0x7C2A3 },
	{ 0xF0A6A1BB, 0x5E3E8 },
	{ 0xF0A6A1BC, 0x5EDAA },
	{ 0xF0A6A1BD, 0x5E3EF },
	{ 0xF0A6A1BE, 0xFE0BB },
	{ 0xF0A6A1BF, 0xFE0BC },
	{ 0xF0A6A280, 0xFE0BD },
	{ 0xF0A6A281, 0xFE0C0 },
	{ 0xF0A6A282, 0xFE0C1 },
	{ 0xF0A6A283, 0x7C1FD },
	{ 0xF0A6A285, 0x7C2ED },
	{ 0xF0A6A288, 0x4DCF3 },
	{ 0xF0A6A28A, 0x4E0F2 },
	{ 0xF0A6A28C, 0x7C9A3 },
	{ 0xF0A6A28D, 0x7C9A9 },
	{ 0xF0A6A28E, 0x5E9A5 },
	{ 0xF0A6A28F, 0x5E9A6 },
	{ 0xF0A6A290, 0x5E3ED },
	{ 0xF0A6A291, 0x7C9A4 },
	{ 0xF0A6A294, 0xFE3CA },
	{ 0xF0A6A295, 0x7C9A8 },
	{ 0xF0A6A296, 0x7C9AA },
	{ 0xF0A6A297, 0xFE3CC },
	{ 0xF0A6A298, 0xFE3CD },
	{ 0xF0A6A299, 0x7C9A2 },
	{ 0xF0A6A29A, 0x7C9A6 },
	{ 0xF0A6A29B, 0x7C9A5 },
	{ 0xF0A6A29C, 0x7C9A7 },
	{ 0xF0A6A29D, 0x7C9A1 },
	{ 0xF0A6A2A4, 0xFE3CB },
	{ 0xF0A6A2A5, 0x7C9AB },
	{ 0xF0A6A2A6, 0x7CFBD },
	{ 0xF0A6A2A7, 0x5EDAE },
	{ 0xF0A6A2A8, 0x5EDAD },
	{ 0xF0A6A2A9, 0x4E4AB },
	{ 0xF0A6A2AA, 0x4E4A9 },
	{ 0xF0A6A2AB, 0x5EDAB },
	{ 0xF0A6A2AC, 0xFE5F6 },
	{ 0xF0A6A2AD, 0x7CFBC },
	{ 0xF0A6A2AF, 0x7CFBB },
	{ 0xF0A6A2B8, 0x4E7A6 },
	{ 0xF0A6A2B9, 0x7D4CF },
	{ 0xF0A6A2BA, 0x5F0F7 },
	{ 0xF0A6A2BB, 0x7DCC0 },
	{ 0xF0A6A2BC, 0x7D5BA },
	{ 0xF0A6A2BD, 0x7DCBF },
	{ 0xF0A6A2BF, 0x4E9B1 },
	{ 0xF0A6A380, 0x4E9AF },
	{ 0xF0A6A381, 0x7D8E5 },
	{ 0xF0A6A385, 0xFE8B3 },
	{ 0xF0A6A386, 0x7DCC1 },
	{ 0xF0A6A387, 0x5F6BD },
	{ 0xF0A6A388, 0x7DCC3 },
	{ 0xF0A6A389, 0x7DCC5 },
	{ 0xF0A6A38A, 0x7DCC6 },
	{ 0xF0A6A38B, 0x5F6BC },
	{ 0xF0A6A38C, 0x7DCC2 },
	{ 0xF0A6A38D, 0x4EAEE },
	{ 0xF0A6A38F, 0x7DCC7 },
	{ 0xF0A6A390, 0x7DCC8 },
	{ 0xF0A6A391, 0x7DFBD },
	{ 0xF0A6A392, 0x5F7FD },
	{ 0xF0A6A393, 0x7DFBE },
	{ 0xF0A6A396, 0x5F9BC },
	{ 0xF0A6A39A, 0x7E4D7 },
	{ 0xF0A6A39B, 0x5FAEF },
	{ 0xF0A6A39C, 0x5FBC5 },
	{ 0xF0A6A39D, 0x6A8FC },
	{ 0xF0A6A39E, 0x4A4F1 },
	{ 0xF0A6A39F, 0xFAAC9 },
	{ 0xF0A6A3A0, 0x6BBB4 },
	{ 0xF0A6A3A1, 0xFB2AF },
	{ 0xF0A6A3A4, 0x6CDD6 },
	{ 0xF0A6A3A9, 0x6CDD7 },
	{ 0xF0A6A3AB, 0xFCBD8 },
	{ 0xF0A6A3AC, 0xFCBD9 },
	{ 0xF0A6A3AD, 0xFD1D6 },
	{ 0xF0A6A3AE, 0x6E0F3 },
	{ 0xF0A6A3B1, 0xFDCB7 },
	{ 0xF0A6A3B2, 0x7C2A5 },
	{ 0xF0A6A3B3, 0xFE0C2 },
	{ 0xF0A6A3B4, 0x5F0F9 },
	{ 0xF0A6A3B5, 0xFE8B4 },
	{ 0xF0A6A3B6, 0xFE9E7 },
	{ 0xF0A6A3B7, 0x7E5BD },
	{ 0xF0A6A3B8, 0x5FCAC },
	{ 0xF0A6A3B9, 0x6A5CA },
	{ 0xF0A6A3BA, 0x6A8FE },
	{ 0xF0A6A3BB, 0x4A4F2 },
	{ 0xF0A6A3BC, 0x6A8FD },
	{ 0xF0A6A3BD, 0x6ADF0 },
	{ 0xF0A6A3BE, 0x5ABBA },
	{ 0xF0A6A3BF, 0x6B4B2 },
	{ 0xF0A6A480, 0xFADB0 },
	{ 0xF0A6A482, 0x5AFF2 },
	{ 0xF0A6A483, 0x6BBB6 },
	{ 0xF0A6A484, 0x4AFC9 },
	{ 0xF0A6A485, 0xFB2B0 },
	{ 0xF0A6A486, 0x6BBB7 },
	{ 0xF0A6A48A, 0x6BBB5 },
	{ 0xF0A6A48C, 0x6C3E6 },
	{ 0xF0A6A48D, 0x6C3E5 },
	{ 0xF0A6A48E, 0xFB7ED },
	{ 0xF0A6A48F, 0xFB7EE },
	{ 0xF0A6A490, 0x6CDD9 },
	{ 0xF0A6A492, 0x6CDDA },
	{ 0xF0A6A494, 0x6D7A4 },
	{ 0xF0A6A495, 0x5C9A5 },
	{ 0xF0A6A496, 0xFCBDA },
	{ 0xF0A6A498, 0x4CCE0 },
	{ 0xF0A6A499, 0x4CCE1 },
	{ 0xF0A6A49A, 0x5CFFE },
	{ 0xF0A6A49B, 0xFD1D7 },
	{ 0xF0A6A49D, 0x7A7BD },
	{ 0xF0A6A49E, 0x4D2E9 },
	{ 0xF0A6A49F, 0x5D7BC },
	{ 0xF0A6A4A1, 0x7BAE6 },
	{ 0xF0A6A4A2, 0x5DDE0 },
	{ 0xF0A6A4A3, 0x5DDDF },
	{ 0xF0A6A4A4, 0xFDCB8 },
	{ 0xF0A6A4A5, 0xFE0C3 },
	{ 0xF0A6A4A6, 0x5E9A7 },
	{ 0xF0A6A4A7, 0x4E0F5 },
	{ 0xF0A6A4A8, 0x5EDB1 },
	{ 0xF0A6A4A9, 0xFE3CE },
	{ 0xF0A6A4AA, 0x7C9AC },
	{ 0xF0A6A4AB, 0x5EDAF },
	{ 0xF0A6A4AC, 0x5EDB0 },
	{ 0xF0A6A4B2, 0x7E2D1 },
	{ 0xF0A6A4B3, 0x6A9A1 },
	{ 0xF0A6A4B4, 0x6ADF1 },
	{ 0xF0A6A4B5, 0x6ADF2 },
	{ 0xF0A6A4B6, 0x6BBBA },
	{ 0xF0A6A4B7, 0xFADB1 },
	{ 0xF0A6A4B9, 0x6BBB8 },
	{ 0xF0A6A4BA, 0x6BBB9 },
	{ 0xF0A6A4BB, 0x5B4F7 },
	{ 0xF0A6A4BC, 0x4B4D6 },
	{ 0xF0A6A4BF, 0x6CDDB },
	{ 0xF0A6A581, 0x5C2AA },
	{ 0xF0A6A582, 0x5C9A6 },
	{ 0xF0A6A584, 0xFCBDB },
	{ 0xF0A6A585, 0x5D0A1 },
	{ 0xF0A6A586, 0x7A7BE },
	{ 0xF0A6A587, 0xFD1D8 },
	{ 0xF0A6A588, 0x5D0A2 },
	{ 0xF0A6A589, 0x7B1F1 },
	{ 0xF0A6A58A, 0x4D2EA },
	{ 0xF0A6A58B, 0x5D7BD },
	{ 0xF0A6A58C, 0xFD7B4 },
	{ 0xF0A6A58E, 0x4D8AF },
	{ 0xF0A6A58F, 0x5E3F0 },
	{ 0xF0A6A590, 0x5E3F1 },
	{ 0xF0A6A591, 0x4A4F4 },
	{ 0xF0A6A592, 0x6A5CB },
	{ 0xF0A6A593, 0x6A3E4 },
	{ 0xF0A6A594, 0x6ADF3 },
	{ 0xF0A6A595, 0x6ADF4 },
	{ 0xF0A6A597, 0xFADB2 },
	{ 0xF0A6A598, 0x4AFCB },
	{ 0xF0A6A599, 0x6B4B3 },
	{ 0xF0A6A59B, 0x6BBBB },
	{ 0xF0A6A59D, 0x6BBC1 },
	{ 0xF0A6A59E, 0x6BBBD },
	{ 0xF0A6A59F, 0x6BBBC },
	{ 0xF0A6A5A0, 0x4AFCC },
	{ 0xF0A6A5A1, 0x6BBBF },
	{ 0xF0A6A5A2, 0x6BBC0 },
	{ 0xF0A6A5A5, 0x6C3E9 },
	{ 0xF0A6A5A6, 0x5B4F8 },
	{ 0xF0A6A5A7, 0x6BBBE },
	{ 0xF0A6A5A8, 0x6C3E8 },
	{ 0xF0A6A5A9, 0x6C3EB },
	{ 0xF0A6A5AB, 0x6C3EA },
	{ 0xF0A6A5AD, 0x5BBD2 },
	{ 0xF0A6A5AE, 0x6CDDC },
	{ 0xF0A6A5B2, 0x5BBD3 },
	{ 0xF0A6A5B3, 0x5C9A7 },
	{ 0xF0A6A5B4, 0x6D7A8 },
	{ 0xF0A6A5B5, 0x6D7A7 },
	{ 0xF0A6A5B6, 0x6D7A5 },
	{ 0xF0A6A5B7, 0x6E0F4 },
	{ 0xF0A6A5B8, 0x6E0FA },
	{ 0xF0A6A5B9, 0x6E0F5 },
	{ 0xF0A6A5BA, 0x6E0F6 },
	{ 0xF0A6A5BB, 0x5D0A3 },
	{ 0xF0A6A5BC, 0x7A7BF },
	{ 0xF0A6A5BD, 0x6E0F7 },
	{ 0xF0A6A5BE, 0x6E0FB },
	{ 0xF0A6A5BF, 0x6E0F8 },
	{ 0xF0A6A680, 0x7A7C0 },
	{ 0xF0A6A681, 0x7A7C1 },
	{ 0xF0A6A682, 0x7A7C2 },
	{ 0xF0A6A683, 0x6E0F9 },
	{ 0xF0A6A684, 0x5C9A8 },
	{ 0xF0A6A685, 0x5D0A4 },
	{ 0xF0A6A686, 0x5D0A5 },
	{ 0xF0A6A687, 0x7A7C3 },
	{ 0xF0A6A688, 0x7A7C4 },
	{ 0xF0A6A689, 0x7B1F2 },
	{ 0xF0A6A68A, 0x7A7C5 },
	{ 0xF0A6A68C, 0x7A7C6 },
	{ 0xF0A6A68E, 0xFD7B5 },
	{ 0xF0A6A68F, 0x7B1F4 },
	{ 0xF0A6A690, 0x7B1F3 },
	{ 0xF0A6A691, 0x5DDE2 },
	{ 0xF0A6A693, 0x7B1F7 },
	{ 0xF0A6A695, 0x7B1F6 },
	{ 0xF0A6A696, 0x7B1F5 },
	{ 0xF0A6A697, 0x5DDE1 },
	{ 0xF0A6A698, 0x5DDE4 },
	{ 0xF0A6A699, 0x7BAE7 },
	{ 0xF0A6A69A, 0x7C2A8 },
	{ 0xF0A6A69B, 0x7C2A7 },
	{ 0xF0A6A69C, 0x5DDE5 },
	{ 0xF0A6A69D, 0x4DCF7 },
	{ 0xF0A6A69E, 0x7C2A6 },
	{ 0xF0A6A69F, 0xFE0C4 },
	{ 0xF0A6A6A0, 0xFE0C5 },
	{ 0xF0A6A6A1, 0x7C9AD },
	{ 0xF0A6A6A2, 0x5E3F3 },
	{ 0xF0A6A6A3, 0x5E3F2 },
	{ 0xF0A6A6A4, 0x7C9AE },
	{ 0xF0A6A6A5, 0x7CFBF },
	{ 0xF0A6A6A7, 0x5E9A8 },
	{ 0xF0A6A6A9, 0x5EDB3 },
	{ 0xF0A6A6AA, 0x5EDB4 },
	{ 0xF0A6A6AB, 0x5EDB5 },
	{ 0xF0A6A6AC, 0x7CFBE },
	{ 0xF0A6A6AD, 0x7C9AF },
	{ 0xF0A6A6AE, 0xFE3CF },
	{ 0xF0A6A6AF, 0x5E9A9 },
	{ 0xF0A6A6B0, 0x7CFC0 },
	{ 0xF0A6A6B1, 0x7CFC1 },
	{ 0xF0A6A6B2, 0x5F0FA },
	{ 0xF0A6A6B3, 0xFE5F8 },
	{ 0xF0A6A6B4, 0xFE8B5 },
	{ 0xF0A6A6B5, 0xFE8B7 },
	{ 0xF0A6A6B6, 0x7D8E6 },
	{ 0xF0A6A6B8, 0xFE8B6 },
	{ 0xF0A6A6B9, 0x7D8E7 },
	{ 0xF0A6A6BA, 0x7DCC9 },
	{ 0xF0A6A6BB, 0x5F7FE },
	{ 0xF0A6A6BC, 0x7E1B7 },
	{ 0xF0A6A6BD, 0x5F9BD },
	{ 0xF0A6A6BE, 0x5F9BF },
	{ 0xF0A6A6BF, 0x5F9BE },
	{ 0xF0A6A780, 0xFECEA },
	{ 0xF0A6A781, 0x7E5BE },
	{ 0xF0A6A782, 0x7E5BF },
	{ 0xF0A6A784, 0x7E6D3 },
	{ 0xF0A6A785, 0x5FCD0 },
	{ 0xF0A6A786, 0xFA5AB },
	{ 0xF0A6A787, 0x6B4B4 },
	{ 0xF0A6A788, 0x4AFCE },
	{ 0xF0A6A789, 0x4AFCD },
	{ 0xF0A6A78A, 0x6BBC2 },
	{ 0xF0A6A78C, 0x6BBC3 },
	{ 0xF0A6A78E, 0x6BBC4 },
	{ 0xF0A6A78F, 0x5AFF3 },
	{ 0xF0A6A790, 0x5AFF4 },
	{ 0xF0A6A791, 0x6C3EC },
	{ 0xF0A6A793, 0x6C3ED },
	{ 0xF0A6A794, 0x6C1FD },
	{ 0xF0A6A795, 0x6CDE0 },
	{ 0xF0A6A796, 0x6CDDF },
	{ 0xF0A6A797, 0x6CDE1 },
	{ 0xF0A6A79A, 0xFBED0 },
	{ 0xF0A6A79D, 0x5C9A9 },
	{ 0xF0A6A79F, 0x4C6CD },
	{ 0xF0A6A7A0, 0x5C5D3 },
	{ 0xF0A6A7A1, 0x4C6CE },
	{ 0xF0A6A7A2, 0x6D7A9 },
	{ 0xF0A6A7A3, 0xFCBDC },
	{ 0xF0A6A7A4, 0x6E0FC },
	{ 0xF0A6A7A5, 0x6E0FE },
	{ 0xF0A6A7A6, 0x6E0FD },
	{ 0xF0A6A7A7, 0x7A7C7 },
	{ 0xF0A6A7A8, 0xFD1D9 },
	{ 0xF0A6A7AA, 0x7A7C9 },
	{ 0xF0A6A7AB, 0x7A7C8 },
	{ 0xF0A6A7AD, 0x7B1F8 },
	{ 0xF0A6A7AE, 0x5D7BE },
	{ 0xF0A6A7B0, 0x7B1F9 },
	{ 0xF0A6A7B1, 0x7BAE8 },
	{ 0xF0A6A7B3, 0xFE0C6 },
	{ 0xF0A6A7B4, 0x5E3F4 },
	{ 0xF0A6A7B5, 0x7C2AA },
	{ 0xF0A6A7B6, 0x7C2A9 },
	{ 0xF0A6A7B8, 0x5EDB6 },
	{ 0xF0A6A7B9, 0x5F0FB },
	{ 0xF0A6A7BB, 0x7DCCA },
	{ 0xF0A6A7BC, 0x5F6BE },
	{ 0xF0A6A7BE, 0x5D0A6 },
	{ 0xF0A6A7BF, 0x5D0A7 },
	{ 0xF0A6A880, 0xFE0C7 },
	{ 0xF0A6A881, 0x7CFC2 },
	{ 0xF0A6A883, 0x7DCCB },
	{ 0xF0A6A884, 0x7DFBF },
	{ 0xF0A6A885, 0x7E1B9 },
	{ 0xF0A6A886, 0x5FAF0 },
	{ 0xF0A6A887, 0x5A4F4 },
	{ 0xF0A6A888, 0x4A7F1 },
	{ 0xF0A6A889, 0x4A7F0 },
	{ 0xF0A6A88A, 0x6ADF7 },
	{ 0xF0A6A88B, 0x6ADF6 },
	{ 0xF0A6A88C, 0x6ADF5 },
	{ 0xF0A6A88D, 0x5A7DF },
	{ 0xF0A6A88E, 0x4ABB1 },
	{ 0xF0A6A88F, 0x4ABB5 },
	{ 0xF0A6A890, 0x4ABB4 },
	{ 0xF0A6A892, 0x6B4B5 },
	{ 0xF0A6A893, 0x6B4B7 },
	{ 0xF0A6A894, 0x6B4B6 },
	{ 0xF0A6A895, 0x6BBCA },
	{ 0xF0A6A896, 0x5AFF5 },
	{ 0xF0A6A897, 0x6BBC9 },
	{ 0xF0A6A898, 0x6BBC5 },
	{ 0xF0A6A899, 0x5AFF6 },
	{ 0xF0A6A89A, 0x4AFD2 },
	{ 0xF0A6A89C, 0x4AFD1 },
	{ 0xF0A6A89D, 0x6BBC6 },
	{ 0xF0A6A89F, 0x6BBC7 },
	{ 0xF0A6A8A0, 0x6BBC8 },
	{ 0xF0A6A8A1, 0x5B4FA },
	{ 0xF0A6A8A2, 0x4B4D9 },
	{ 0xF0A6A8A3, 0x4B4DB },
	{ 0xF0A6A8A4, 0x6C3F2 },
	{ 0xF0A6A8A6, 0x5B4FB },
	{ 0xF0A6A8A7, 0x6C3EE },
	{ 0xF0A6A8A8, 0x6C3EF },
	{ 0xF0A6A8AA, 0xFB7F1 },
	{ 0xF0A6A8AC, 0x5B4F9 },
	{ 0xF0A6A8AD, 0xFB7F0 },
	{ 0xF0A6A8AE, 0xFB7F2 },
	{ 0xF0A6A8AF, 0x5BBD4 },
	{ 0xF0A6A8B0, 0x6CDE5 },
	{ 0xF0A6A8B1, 0x6CDE4 },
	{ 0xF0A6A8B2, 0x4B4DA },
	{ 0xF0A6A8B4, 0x4BAD2 },
	{ 0xF0A6A8B5, 0x4BAD0 },
	{ 0xF0A6A8B6, 0x4BAD1 },
	{ 0xF0A6A8B7, 0x4BAD3 },
	{ 0xF0A6A8BA, 0x6CDE6 },
	{ 0xF0A6A8BC, 0x5C2AB },
	{ 0xF0A6A8BD, 0x6D7AC },
	{ 0xF0A6A8BE, 0x5C2AC },
	{ 0xF0A6A8BF, 0x6D7AA },
	{ 0xF0A6A983, 0xFC4F2 },
	{ 0xF0A6A984, 0x6D7AB },
	{ 0xF0A6A987, 0x6D7AD },
	{ 0xF0A6A988, 0x6D7AE },
	{ 0xF0A6A989, 0x5C2AE },
	{ 0xF0A6A98A, 0x6E1A7 },
	{ 0xF0A6A98B, 0x5C9AD },
	{ 0xF0A6A98C, 0x5C9AB },
	{ 0xF0A6A98D, 0x4C6D2 },
	{ 0xF0A6A98E, 0x6E1A2 },
	{ 0xF0A6A98F, 0x6E1A6 },
	{ 0xF0A6A993, 0xFCBDE },
	{ 0xF0A6A994, 0xFCBDF },
	{ 0xF0A6A998, 0xFCBDD },
	{ 0xF0A6A999, 0x6E1A3 },
	{ 0xF0A6A99C, 0x5C9AA },
	{ 0xF0A6A99D, 0x5D0AF },
	{ 0xF0A6A99E, 0x4CCE7 },
	{ 0xF0A6A99F, 0x4CCE6 },
	{ 0xF0A6A9A0, 0x5D0AE },
	{ 0xF0A6A9A1, 0x5D0AB },
	{ 0xF0A6A9A2, 0x5D0AC },
	{ 0xF0A6A9A3, 0x5D0B0 },
	{ 0xF0A6A9A4, 0x5D0A8 },
	{ 0xF0A6A9A5, 0x7A7CF },
	{ 0xF0A6A9A6, 0x7A7CD },
	{ 0xF0A6A9A7, 0x5D0B1 },
	{ 0xF0A6A9A8, 0x7A7CA },
	{ 0xF0A6A9A9, 0x7A7CC },
	{ 0xF0A6A9AA, 0x7A7CE },
	{ 0xF0A6A9AB, 0x7A7CB },
	{ 0xF0A6A9AC, 0x5D0AD },
	{ 0xF0A6A9B1, 0x5D0A9 },
	{ 0xF0A6A9B2, 0x5D0AA },
	{ 0xF0A6A9B4, 0x5D7C2 },
	{ 0xF0A6A9B5, 0x5D7BF },
	{ 0xF0A6A9B6, 0x5D7C3 },
	{ 0xF0A6A9B7, 0x7B1FC },
	{ 0xF0A6A9B8, 0x5D7C0 },
	{ 0xF0A6A9B9, 0x7B2A1 },
	{ 0xF0A6A9BA, 0x7B1FD },
	{ 0xF0A6A9BB, 0x7B2A3 },
	{ 0xF0A6A9BC, 0x5D7C1 },
	{ 0xF0A6A9BD, 0x7B2A2 },
	{ 0xF0A6A9BE, 0xFD7B6 },
	{ 0xF0A6AA84, 0x7B1FE },
	{ 0xF0A6AA85, 0x7B1FB },
	{ 0xF0A6AA86, 0x7BAEA },
	{ 0xF0A6AA87, 0x4D8B1 },
	{ 0xF0A6AA88, 0x5DDEC },
	{ 0xF0A6AA89, 0x5DDE6 },
	{ 0xF0A6AA8A, 0x5DDE9 },
	{ 0xF0A6AA8B, 0x5DDE8 },
	{ 0xF0A6AA8D, 0x5DDEA },
	{ 0xF0A6AA8E, 0x5DDEB },
	{ 0xF0A6AA91, 0x4DCF9 },
	{ 0xF0A6AA92, 0x5E3FB },
	{ 0xF0A6AA93, 0x7C2AC },
	{ 0xF0A6AA94, 0x5E3F5 },
	{ 0xF0A6AA95, 0x5E3FA },
	{ 0xF0A6AA96, 0x5E3FD },
	{ 0xF0A6AA97, 0x5E3F9 },
	{ 0xF0A6AA98, 0x4DCFA },
	{ 0xF0A6AA99, 0x4DCFB },
	{ 0xF0A6AA9A, 0x5E3F6 },
	{ 0xF0A6AA9B, 0x5E3F7 },
	{ 0xF0A6AA9C, 0x5E3FC },
	{ 0xF0A6AA9D, 0x4DCF8 },
	{ 0xF0A6AAA4, 0x7C2AD },
	{ 0xF0A6AAA5, 0x7C2AB },
	{ 0xF0A6AAA7, 0x5E3F8 },
	{ 0xF0A6AAA9, 0x7C9B0 },
	{ 0xF0A6AAAA, 0x5E9AD },
	{ 0xF0A6AAAB, 0x5E9AC },
	{ 0xF0A6AAAC, 0x5E9AB },
	{ 0xF0A6AAAD, 0x5E9AA },
	{ 0xF0A6AAAE, 0x7C9B1 },
	{ 0xF0A6AAAF, 0xFE3D0 },
	{ 0xF0A6AAB0, 0x7C9B2 },
	{ 0xF0A6AAB1, 0x5EDB7 },
	{ 0xF0A6AAB2, 0x7CFC3 },
	{ 0xF0A6AAB6, 0x5F0FD },
	{ 0xF0A6AAB7, 0x5F0FC },
	{ 0xF0A6AAB8, 0x7D4D2 },
	{ 0xF0A6AABD, 0x5F4A1 },
	{ 0xF0A6AABE, 0x5F4A2 },
	{ 0xF0A6AABF, 0x4E9B2 },
	{ 0xF0A6AB80, 0x7D8E8 },
	{ 0xF0A6AB81, 0x7D4D0 },
	{ 0xF0A6AB82, 0x7D4D1 },
	{ 0xF0A6AB83, 0x4EAEF },
	{ 0xF0A6AB84, 0x7DCCC },
	{ 0xF0A6AB85, 0x7E1BB },
	{ 0xF0A6AB86, 0x7E1BA },
	{ 0xF0A6AB87, 0x7E2D2 },
	{ 0xF0A6AB88, 0x5FAF1 },
	{ 0xF0A6AB8A, 0x4EECF },
	{ 0xF0A6AB8B, 0x6B4B8 },
	{ 0xF0A6AB8C, 0xFB7F3 },
	{ 0xF0A6AB8E, 0x5BBBF },
	{ 0xF0A6AB8F, 0xFBED1 },
	{ 0xF0A6AB90, 0xFD1DA },
	{ 0xF0A6AB91, 0xFDCB9 },
	{ 0xF0A6AB92, 0x7CFC4 },
	{ 0xF0A6AB94, 0x5B4FC },
	{ 0xF0A6AB95, 0x5B4FD },
	{ 0xF0A6AB97, 0x6C3F3 },
	{ 0xF0A6AB99, 0x5B4FE },
	{ 0xF0A6AB9A, 0xFBED2 },
	{ 0xF0A6AB9B, 0x6D7AF },
	{ 0xF0A6AB9C, 0x6D7B0 },
	{ 0xF0A6AB9D, 0x6D7B1 },
	{ 0xF0A6AB9E, 0x6E1A9 },
	{ 0xF0A6ABA0, 0xFCBE0 },
	{ 0xF0A6ABA2, 0x6E1AA },
	{ 0xF0A6ABA3, 0x6E1A8 },
	{ 0xF0A6ABA4, 0x7A7D1 },
	{ 0xF0A6ABA5, 0x7A7D0 },
	{ 0xF0A6ABA6, 0x7A7D2 },
	{ 0xF0A6ABA7, 0xFD1DB },
	{ 0xF0A6ABA8, 0xFD1DC },
	{ 0xF0A6ABA9, 0xFD1DD },
	{ 0xF0A6ABAA, 0x5D7C4 },
	{ 0xF0A6ABAB, 0x5D7C5 },
	{ 0xF0A6ABAC, 0x7B2A5 },
	{ 0xF0A6ABAD, 0x7B2A4 },
	{ 0xF0A6ABAF, 0x5EDB9 },
	{ 0xF0A6ABB0, 0x5EDB8 },
	{ 0xF0A6ABB1, 0x7CFC5 },
	{ 0xF0A6ABB2, 0xFECB7 },
	{ 0xF0A6ABB3, 0x5A1FB },
	{ 0xF0A6ABB4, 0x6A3B8 },
	{ 0xF0A6ABB6, 0x4A3AE },
	{ 0xF0A6ABB7, 0x6A5D0 },
	{ 0xF0A6ABB8, 0x6A5D1 },
	{ 0xF0A6ABB9, 0x6ADF8 },
	{ 0xF0A6ABBA, 0x6A5CE },
	{ 0xF0A6ABBB, 0x5A3A6 },
	{ 0xF0A6ABBC, 0x6A5CD },
	{ 0xF0A6ABBD, 0xFA2EF },
	{ 0xF0A6ABBE, 0xFA2F0 },
	{ 0xF0A6ABBF, 0xFA2EE },
	{ 0xF0A6AC80, 0x6A5CC },
	{ 0xF0A6AC81, 0x4A4F7 },
	{ 0xF0A6AC82, 0x4A4F8 },
	{ 0xF0A6AC83, 0x4A4FC },
	{ 0xF0A6AC84, 0x6A9A2 },
	{ 0xF0A6AC85, 0x4A4FA },
	{ 0xF0A6AC86, 0x6A9A5 },
	{ 0xF0A6AC87, 0x6A9A3 },
	{ 0xF0A6AC88, 0x6A9A4 },
	{ 0xF0A6AC89, 0x6A9A6 },
	{ 0xF0A6AC8B, 0xFA5AC },
	{ 0xF0A6AC8C, 0xFA5AD },
	{ 0xF0A6AC8D, 0xFA5AE },
	{ 0xF0A6AC8E, 0xFA5AF },
	{ 0xF0A6AC8F, 0xFA5B0 },
	{ 0xF0A6AC90, 0xFA5B1 },
	{ 0xF0A6AC93, 0x6ADFB },
	{ 0xF0A6AC94, 0x4A7FC },
	{ 0xF0A6AC95, 0x4A7F7 },
	{ 0xF0A6AC96, 0x4A7F9 },
	{ 0xF0A6AC97, 0x5A7E2 },
	{ 0xF0A6AC98, 0x4A7FD },
	{ 0xF0A6AC99, 0x4A7F8 },
	{ 0xF0A6AC9A, 0x4A7F5 },
	{ 0xF0A6AC9B, 0x5A7E0 },
	{ 0xF0A6AC9C, 0x6ADFC },
	{ 0xF0A6AC9D, 0x5A7E1 },
	{ 0xF0A6AC9E, 0x4A7F4 },
	{ 0xF0A6AC9F, 0x6BBCB },
	{ 0xF0A6ACA0, 0x6A7CC },
	{ 0xF0A6ACA1, 0x6AEA1 },
	{ 0xF0A6ACA2, 0x5A7E4 },
	{ 0xF0A6ACA3, 0x4A7F6 },
	{ 0xF0A6ACA4, 0x6ADFA },
	{ 0xF0A6ACA5, 0x6ADFE },
	{ 0xF0A6ACA6, 0x6BBCD },
	{ 0xF0A6ACA7, 0x6BBCC },
	{ 0xF0A6ACA9, 0xFA8D7 },
	{ 0xF0A6ACAA, 0xFA8D8 },
	{ 0xF0A6ACAB, 0xFA8D9 },
	{ 0xF0A6ACAC, 0xFA8DA },
	{ 0xF0A6ACAD, 0xFA8DB },
	{ 0xF0A6ACAE, 0xFA8DD },
	{ 0xF0A6ACAF, 0xFA8DE },
	{ 0xF0A6ACB0, 0xFA8DF },
	{ 0xF0A6ACB1, 0xFA8E0 },
	{ 0xF0A6ACB2, 0xFA8E1 },
	{ 0xF0A6ACB3, 0xFA8E2 },
	{ 0xF0A6ACB4, 0xFA8E4 },
	{ 0xF0A6ACB5, 0x6ADF9 },
	{ 0xF0A6ACB7, 0x4ABBB },
	{ 0xF0A6ACB8, 0x4ABB7 },
	{ 0xF0A6ACB9, 0x4ABB8 },
	{ 0xF0A6ACBA, 0x4ABB9 },
	{ 0xF0A6ACBB, 0x5ABBF },
	{ 0xF0A6ACBC, 0x6B4C3 },
	{ 0xF0A6ACBD, 0x6B4BB },
	{ 0xF0A6ACBE, 0x4ABBC },
	{ 0xF0A6ACBF, 0x6B4C1 },
	{ 0xF0A6AD80, 0x6B4BD },
	{ 0xF0A6AD81, 0x5ABBD },
	{ 0xF0A6AD82, 0x6B4B9 },
	{ 0xF0A6AD83, 0x6B4C0 },
	{ 0xF0A6AD84, 0x6B4BE },
	{ 0xF0A6AD85, 0x6B4C2 },
	{ 0xF0A6AD86, 0x6B4C5 },
	{ 0xF0A6AD87, 0x6B4C6 },
	{ 0xF0A6AD88, 0x5ABBB },
	{ 0xF0A6AD89, 0x5ABBE },
	{ 0xF0A6AD8B, 0x5ABBC },
	{ 0xF0A6AD94, 0xFADB3 },
	{ 0xF0A6AD95, 0xFADB5 },
	{ 0xF0A6AD96, 0xFADB7 },
	{ 0xF0A6AD97, 0xFADB8 },
	{ 0xF0A6AD98, 0xFADB9 },
	{ 0xF0A6AD99, 0xFADBA },
	{ 0xF0A6AD9A, 0xFADBB },
	{ 0xF0A6AD9B, 0xFADBC },
	{ 0xF0A6AD9C, 0xFADB6 },
	{ 0xF0A6AD9D, 0x6B3BE },
	{ 0xF0A6ADA2, 0x6B4BF },
	{ 0xF0A6ADA8, 0xFADB4 },
	{ 0xF0A6ADA9, 0x6ADFD },
	{ 0xF0A6ADAB, 0x6CDE8 },
	{ 0xF0A6ADAC, 0xFAAD2 },
	{ 0xF0A6ADAD, 0x5AFFC },
	{ 0xF0A6ADAE, 0x4AFD6 },
	{ 0xF0A6ADAF, 0x4AFD7 },
	{ 0xF0A6ADB0, 0x4AFE2 },
	{ 0xF0A6ADB1, 0x5AFF8 },
	{ 0xF0A6ADB2, 0x5AFFA },
	{ 0xF0A6ADB3, 0x5AFFE },
	{ 0xF0A6ADB4, 0x4AFD4 },
	{ 0xF0A6ADB5, 0x5AFF7 },
	{ 0xF0A6ADB6, 0x5B0A3 },
	{ 0xF0A6ADB7, 0x4AFDB },
	{ 0xF0A6ADB8, 0x5B0A7 },
	{ 0xF0A6ADB9, 0x4AFD8 },
	{ 0xF0A6ADBA, 0x4AFE5 },
	{ 0xF0A6ADBB, 0x5B0A4 },
	{ 0xF0A6ADBC, 0x4AFE0 },
	{ 0xF0A6ADBD, 0x6BBDE },
	{ 0xF0A6ADBE, 0x6BBDF },
	{ 0xF0A6ADBF, 0x5B0A5 },
	{ 0xF0A6AE80, 0x6BBE1 },
	{ 0xF0A6AE81, 0x5B0A2 },
	{ 0xF0A6AE82, 0x4AFE6 },
	{ 0xF0A6AE83, 0x6BBD9 },
	{ 0xF0A6AE84, 0x6BBD8 },
	{ 0xF0A6AE85, 0x6CDE7 },
	{ 0xF0A6AE86, 0x6C4A2 },
	{ 0xF0A6AE87, 0x6BBD5 },
	{ 0xF0A6AE88, 0x5AFFD },
	{ 0xF0A6AE89, 0x6BBD4 },
	{ 0xF0A6AE8A, 0x6BBD1 },
	{ 0xF0A6AE8B, 0x6BBCF },
	{ 0xF0A6AE8C, 0x6BBDA },
	{ 0xF0A6AE8D, 0x6BBDC },
	{ 0xF0A6AE8E, 0x5AFFB },
	{ 0xF0A6AE8F, 0x6BBD7 },
	{ 0xF0A6AE90, 0x5B0A6 },
	{ 0xF0A6AE91, 0x5AFF9 },
	{ 0xF0A6AE92, 0x6BBD3 },
	{ 0xF0A6AE93, 0x6BBDB },
	{ 0xF0A6AE98, 0x6BBDD },
	{ 0xF0A6AE99, 0x6BBE2 },
	{ 0xF0A6AE9A, 0xFB2B3 },
	{ 0xF0A6AE9B, 0xFB2B5 },
	{ 0xF0A6AE9C, 0xFB2B6 },
	{ 0xF0A6AE9D, 0xFB2B7 },
	{ 0xF0A6AE9E, 0xFB2B8 },
	{ 0xF0A6AE9F, 0xFB2B9 },
	{ 0xF0A6AEA0, 0xFB2BB },
	{ 0xF0A6AEA1, 0xFB2BC },
	{ 0xF0A6AEA2, 0xFB2BD },
	{ 0xF0A6AEA3, 0xFB2BF },
	{ 0xF0A6AEA4, 0xFB2C0 },
	{ 0xF0A6AEA5, 0xFB2C2 },
	{ 0xF0A6AEA6, 0xFB2C3 },
	{ 0xF0A6AEA7, 0xFB2C4 },
	{ 0xF0A6AEA8, 0xFB2C5 },
	{ 0xF0A6AEA9, 0xFB2C7 },
	{ 0xF0A6AEAA, 0xFB2C8 },
	{ 0xF0A6AEAB, 0xFB2C9 },
	{ 0xF0A6AEAC, 0xFB2CA },
	{ 0xF0A6AEAD, 0xFB2CB },
	{ 0xF0A6AEAE, 0x6BBD0 },
	{ 0xF0A6AEAF, 0xFB2C6 },
	{ 0xF0A6AEB3, 0xFB2CC },
	{ 0xF0A6AEB5, 0xFB2BE },
	{ 0xF0A6AEB7, 0x5B5AB },
	{ 0xF0A6AEB8, 0x5B5AE },
	{ 0xF0A6AEB9, 0x5B5A7 },
	{ 0xF0A6AEBA, 0x4B4F0 },
	{ 0xF0A6AEBB, 0x5B5AC },
	{ 0xF0A6AEBC, 0x4B4E1 },
	{ 0xF0A6AEBD, 0x4B4EE },
	{ 0xF0A6AEBE, 0x4B4E8 },
	{ 0xF0A6AEBF, 0x6C4B2 },
	{ 0xF0A6AF80, 0x4B4F2 },
	{ 0xF0A6AF81, 0x4B4F5 },
	{ 0xF0A6AF82, 0x6C4A6 },
	{ 0xF0A6AF83, 0x6C3FB },
	{ 0xF0A6AF84, 0x6C4A3 },
	{ 0xF0A6AF85, 0x5B5A3 },
	{ 0xF0A6AF86, 0x6C3F9 },
	{ 0xF0A6AF87, 0x6C3F5 },
	{ 0xF0A6AF88, 0x4B4E0 },
	{ 0xF0A6AF89, 0x5B5B2 },
	{ 0xF0A6AF8A, 0x6C3F4 },
	{ 0xF0A6AF8B, 0x6C4A1 },
	{ 0xF0A6AF8C, 0x6C4B8 },
	{ 0xF0A6AF8D, 0x4B4E4 },
	{ 0xF0A6AF8E, 0x6C4B6 },
	{ 0xF0A6AF8F, 0x6CEBA },
	{ 0xF0A6AF91, 0x6C4B4 },
	{ 0xF0A6AF92, 0x6BBE0 },
	{ 0xF0A6AF93, 0x6CDF8 },
	{ 0xF0A6AF94, 0x4B4DF },
	{ 0xF0A6AF95, 0x5B5A1 },
	{ 0xF0A6AF96, 0x4B4EB },
	{ 0xF0A6AF98, 0x6C3F7 },
	{ 0xF0A6AF99, 0x6C4A4 },
	{ 0xF0A6AF9A, 0x5B5B0 },
	{ 0xF0A6AF9B, 0x6C4AF },
	{ 0xF0A6AF9C, 0x6C4B5 },
	{ 0xF0A6AF9D, 0x6C4AE },
	{ 0xF0A6AF9E, 0x6C4A9 },
	{ 0xF0A6AF9F, 0x5B5AF },
	{ 0xF0A6AFA0, 0x6C4B3 },
	{ 0xF0A6AFA1, 0x6C3F8 },
	{ 0xF0A6AFA2, 0x6C4A7 },
	{ 0xF0A6AFA3, 0x5B5B1 },
	{ 0xF0A6AFA4, 0x5C2AF },
	{ 0xF0A6AFA5, 0x6D7B2 },
	{ 0xF0A6AFA6, 0x6D7B3 },
	{ 0xF0A6AFA8, 0x6C4B0 },
	{ 0xF0A6AFA9, 0x6C4B1 },
	{ 0xF0A6AFAA, 0x6C3FE },
	{ 0xF0A6AFAB, 0x5B5A2 },
	{ 0xF0A6AFAC, 0x5B5B3 },
	{ 0xF0A6AFAD, 0x6C4AA },
	{ 0xF0A6AFAE, 0x5B5A9 },
	{ 0xF0A6AFAF, 0x5B5AD },
	{ 0xF0A6AFB0, 0x5B5A6 },
	{ 0xF0A6AFB1, 0x6CEB7 },
	{ 0xF0A6AFB2, 0x6C4B9 },
	{ 0xF0A6AFB3, 0x6C4BA },
	{ 0xF0A6AFB4, 0x6C3FC },
	{ 0xF0A6AFB8, 0x6C3FA },
	{ 0xF0A6AFB9, 0xFB7F4 },
	{ 0xF0A6AFBA, 0xFB7F5 },
	{ 0xF0A6AFBB, 0xFB7F6 },
	{ 0xF0A6AFBC, 0xFB7F7 },
	{ 0xF0A6AFBD, 0xFB7F9 },
	{ 0xF0A6AFBE, 0xFB7FB },
	{ 0xF0A6AFBF, 0xFB7FC },
	{ 0xF0A6B080, 0xFB7FD },
	{ 0xF0A6B081, 0xFB7FE },
	{ 0xF0A6B082, 0xFB8A1 },
	{ 0xF0A6B083, 0xFB8A2 },
	{ 0xF0A6B084, 0xFB8A4 },
	{ 0xF0A6B085, 0xFB8A5 },
	{ 0xF0A6B086, 0xFB8A6 },
	{ 0xF0A6B087, 0xFB8A7 },
	{ 0xF0A6B088, 0xFB8A8 },
	{ 0xF0A6B089, 0xFB8A9 },
	{ 0xF0A6B08A, 0xFB8AA },
	{ 0xF0A6B08B, 0xFB8AB },
	{ 0xF0A6B08C, 0xFB8AC },
	{ 0xF0A6B08D, 0xFB8AD },
	{ 0xF0A6B08E, 0xFB8AE },
	{ 0xF0A6B08F, 0xFB8AF },
	{ 0xF0A6B090, 0xFB8B0 },
	{ 0xF0A6B091, 0xFB8B1 },
	{ 0xF0A6B092, 0xFB8B2 },
	{ 0xF0A6B093, 0xFB8B3 },
	{ 0xF0A6B094, 0xFB8B4 },
	{ 0xF0A6B095, 0xFB8B5 },
	{ 0xF0A6B096, 0x5BBDD },
	{ 0xF0A6B097, 0x6C3FD },
	{ 0xF0A6B098, 0x5B5A8 },
	{ 0xF0A6B099, 0x6C4A5 },
	{ 0xF0A6B09B, 0xFB7FA },
	{ 0xF0A6B09D, 0x6C4AD },
	{ 0xF0A6B09E, 0x6C4B7 },
	{ 0xF0A6B0A1, 0xFB8A3 },
	{ 0xF0A6B0A7, 0x5B5A5 },
	{ 0xF0A6B0AA, 0x5BBD5 },
	{ 0xF0A6B0AB, 0x4BAD5 },
	{ 0xF0A6B0AC, 0x5BBE9 },
	{ 0xF0A6B0AD, 0x5BBEA },
	{ 0xF0A6B0AE, 0x5BBE2 },
	{ 0xF0A6B0AF, 0x5BBEC },
	{ 0xF0A6B0B0, 0x5BBED },
	{ 0xF0A6B0B1, 0x5BBE3 },
	{ 0xF0A6B0B2, 0x4BADD },
	{ 0xF0A6B0B3, 0x6CDFA },
	{ 0xF0A6B0B4, 0x6CDF2 },
	{ 0xF0A6B0B5, 0x6CEAB },
	{ 0xF0A6B0B6, 0x6CDF0 },
	{ 0xF0A6B0B7, 0x6CDEB },
	{ 0xF0A6B0B8, 0x5BBDF },
	{ 0xF0A6B0B9, 0x5BBE7 },
	{ 0xF0A6B0BA, 0x5BBE8 },
	{ 0xF0A6B0BB, 0x6CDFB },
	{ 0xF0A6B0BC, 0x6CDF9 },
	{ 0xF0A6B0BD, 0x5BBDE },
	{ 0xF0A6B0BE, 0x5BBEE },
	{ 0xF0A6B0BF, 0x5BBEB },
	{ 0xF0A6B180, 0x4B4EA },
	{ 0xF0A6B181, 0x4BAD7 },
	{ 0xF0A6B182, 0x4BADA },
	{ 0xF0A6B183, 0x4BAD8 },
	{ 0xF0A6B184, 0x4BAE2 },
	{ 0xF0A6B185, 0x5BBDA },
	{ 0xF0A6B187, 0x4BAD4 },
	{ 0xF0A6B188, 0x6CDE9 },
	{ 0xF0A6B189, 0x6CEB5 },
	{ 0xF0A6B18A, 0x4BAE3 },
	{ 0xF0A6B18B, 0x6CDEA },
	{ 0xF0A6B18C, 0x5BBE4 },
	{ 0xF0A6B18D, 0x6CDFC },
	{ 0xF0A6B18E, 0x6CEB6 },
	{ 0xF0A6B18F, 0x6CDFD },
	{ 0xF0A6B190, 0x6CEAF },
	{ 0xF0A6B191, 0x6CEB0 },
	{ 0xF0A6B192, 0x4BAEB },
	{ 0xF0A6B193, 0x6CEA6 },
	{ 0xF0A6B194, 0x4BAE9 },
	{ 0xF0A6B195, 0x6CEA3 },
	{ 0xF0A6B196, 0x5BBDC },
	{ 0xF0A6B197, 0x6CEA8 },
	{ 0xF0A6B198, 0x6CDF5 },
	{ 0xF0A6B199, 0x6CEAD },
	{ 0xF0A6B19A, 0x6CDF4 },
	{ 0xF0A6B19B, 0x6CEA2 },
	{ 0xF0A6B19C, 0x6CEB1 },
	{ 0xF0A6B19E, 0x6CEA9 },
	{ 0xF0A6B19F, 0x5BBE5 },
	{ 0xF0A6B1A0, 0x6E1B2 },
	{ 0xF0A6B1A1, 0x6E1AD },
	{ 0xF0A6B1A2, 0x6E1AE },
	{ 0xF0A6B1A3, 0x5BBD7 },
	{ 0xF0A6B1A4, 0x6CEA4 },
	{ 0xF0A6B1A5, 0x6CDEF },
	{ 0xF0A6B1A6, 0x6CEAE },
	{ 0xF0A6B1A7, 0x5C9AE },
	{ 0xF0A6B1A8, 0x6CDF3 },
	{ 0xF0A6B1A9, 0x6CEAC },
	{ 0xF0A6B1AA, 0x6CDF7 },
	{ 0xF0A6B1AB, 0x6CEA5 },
	{ 0xF0A6B1AC, 0x6CDED },
	{ 0xF0A6B1AD, 0x6CEAA },
	{ 0xF0A6B1AE, 0x4BAEA },
	{ 0xF0A6B1AF, 0x5BBE0 },
	{ 0xF0A6B1B0, 0x5BBDB },
	{ 0xF0A6B1B2, 0x6CDF6 },
	{ 0xF0A6B1B3, 0x6CEB8 },
	{ 0xF0A6B1B4, 0x6E1AB },
	{ 0xF0A6B1B5, 0x5BBE6 },
	{ 0xF0A6B1B6, 0x6E1AF },
	{ 0xF0A6B1B7, 0x5BBE1 },
	{ 0xF0A6B1B8, 0x6CEB4 },
	{ 0xF0A6B1B9, 0x6E1B1 },
	{ 0xF0A6B1BA, 0x6E1B0 },
	{ 0xF0A6B1BB, 0x6CDEC },
	{ 0xF0A6B1BC, 0x6CDFE },
	{ 0xF0A6B283, 0x6CCFB },
	{ 0xF0A6B284, 0x5BBD8 },
	{ 0xF0A6B285, 0x6CDEE },
	{ 0xF0A6B286, 0x6CDF1 },
	{ 0xF0A6B287, 0x6CEB3 },
	{ 0xF0A6B288, 0x6CEB9 },
	{ 0xF0A6B289, 0xFBED3 },
	{ 0xF0A6B28A, 0xFBED5 },
	{ 0xF0A6B28B, 0xFBED6 },
	{ 0xF0A6B28C, 0xFBED8 },
	{ 0xF0A6B28D, 0xFBEDA },
	{ 0xF0A6B28E, 0xFBEDB },
	{ 0xF0A6B28F, 0xFBEDC },
	{ 0xF0A6B290, 0xFBEDD },
	{ 0xF0A6B291, 0xFBEDE },
	{ 0xF0A6B292, 0xFBEDF },
	{ 0xF0A6B293, 0xFBEE0 },
	{ 0xF0A6B294, 0xFBEE1 },
	{ 0xF0A6B295, 0xFBEE3 },
	{ 0xF0A6B296, 0xFBEE4 },
	{ 0xF0A6B297, 0xFBEE5 },
	{ 0xF0A6B298, 0xFBEE8 },
	{ 0xF0A6B299, 0xFBEE9 },
	{ 0xF0A6B29A, 0xFBEEA },
	{ 0xF0A6B29B, 0xFBEED },
	{ 0xF0A6B29C, 0xFBEEF },
	{ 0xF0A6B29D, 0xFBEF0 },
	{ 0xF0A6B29E, 0xFBEF1 },
	{ 0xF0A6B29F, 0xFBEF2 },
	{ 0xF0A6B2A0, 0xFBEF4 },
	{ 0xF0A6B2A1, 0xFBEF5 },
	{ 0xF0A6B2A2, 0xFBEF6 },
	{ 0xF0A6B2A3, 0xFBEF7 },
	{ 0xF0A6B2A4, 0xFBEF8 },
	{ 0xF0A6B2A5, 0xFBEF9 },
	{ 0xF0A6B2A6, 0xFBEFA },
	{ 0xF0A6B2A7, 0xFBEFB },
	{ 0xF0A6B2A8, 0xFBEFC },
	{ 0xF0A6B2A9, 0xFBEFD },
	{ 0xF0A6B2AA, 0xFBEFE },
	{ 0xF0A6B2AC, 0x6E1AC },
	{ 0xF0A6B2AF, 0x5BBD9 },
	{ 0xF0A6B2B0, 0x6CEA1 },
	{ 0xF0A6B2B6, 0xFBEE2 },
	{ 0xF0A6B2B7, 0xFBED4 },
	{ 0xF0A6B2BD, 0xFBEEE },
	{ 0xF0A6B380, 0xFBEF3 },
	{ 0xF0A6B381, 0x4C0C3 },
	{ 0xF0A6B382, 0x6D7B4 },
	{ 0xF0A6B383, 0x6D7C6 },
	{ 0xF0A6B384, 0x5C2CE },
	{ 0xF0A6B385, 0x6D7BA },
	{ 0xF0A6B386, 0x6D7BB },
	{ 0xF0A6B387, 0x5C2B4 },
	{ 0xF0A6B388, 0x4C0BD },
	{ 0xF0A6B389, 0x6D7C9 },
	{ 0xF0A6B38A, 0x6D7DA },
	{ 0xF0A6B38B, 0x4C0C0 },
	{ 0xF0A6B38C, 0x4C0C2 },
	{ 0xF0A6B38D, 0x5C2C5 },
	{ 0xF0A6B38E, 0x6D7DE },
	{ 0xF0A6B38F, 0x5C2BA },
	{ 0xF0A6B390, 0x4C0B7 },
	{ 0xF0A6B391, 0x4C0B4 },
	{ 0xF0A6B392, 0x6D7C1 },
	{ 0xF0A6B393, 0x6D7E3 },
	{ 0xF0A6B394, 0x5C2B3 },
	{ 0xF0A6B395, 0x6D7D1 },
	{ 0xF0A6B396, 0x6D7D5 },
	{ 0xF0A6B397, 0x5C2C3 },
	{ 0xF0A6B398, 0x6D7CA },
	{ 0xF0A6B399, 0x4C0B8 },
	{ 0xF0A6B39A, 0x4C0BB },
	{ 0xF0A6B39B, 0x5C2B6 },
	{ 0xF0A6B39C, 0x6D7C3 },
	{ 0xF0A6B39D, 0x4C0BC },
	{ 0xF0A6B39E, 0x4C0C5 },
	{ 0xF0A6B39F, 0x5C2C1 },
	{ 0xF0A6B3A0, 0x4C0CD },
	{ 0xF0A6B3A1, 0x5C2CF },
	{ 0xF0A6B3A2, 0x4C0BE },
	{ 0xF0A6B3A3, 0x5C2C6 },
	{ 0xF0A6B3A4, 0x6D7DD },
	{ 0xF0A6B3A5, 0x5C2BF },
	{ 0xF0A6B3A6, 0x4C0B3 },
	{ 0xF0A6B3A7, 0x4C0B1 },
	{ 0xF0A6B3A8, 0x6D7E5 },
	{ 0xF0A6B3A9, 0x4C0BF },
	{ 0xF0A6B3AA, 0x6D7C2 },
	{ 0xF0A6B3AB, 0x5C2C8 },
	{ 0xF0A6B3AC, 0x5C2C2 },
	{ 0xF0A6B3AD, 0x5C2B8 },
	{ 0xF0A6B3AE, 0x5C2BE },
	{ 0xF0A6B3B0, 0x6D7B8 },
	{ 0xF0A6B3B1, 0x6D7D3 },
	{ 0xF0A6B3B2, 0x6D7CF },
	{ 0xF0A6B3B3, 0x6D7C0 },
	{ 0xF0A6B3B4, 0x6D7E7 },
	{ 0xF0A6B3B5, 0x5C2BD },
	{ 0xF0A6B3B6, 0x6D7B9 },
	{ 0xF0A6B3B7, 0x6D7E4 },
	{ 0xF0A6B3B8, 0x6D7B7 },
	{ 0xF0A6B3B9, 0x5C2D0 },
	{ 0xF0A6B3BA, 0x6D7CE },
	{ 0xF0A6B3BB, 0x6D7C5 },
	{ 0xF0A6B3BC, 0x6D7BC },
	{ 0xF0A6B3BD, 0x5C2C9 },
	{ 0xF0A6B3BE, 0x5C2CD },
	{ 0xF0A6B3BF, 0x5C2BB },
	{ 0xF0A6B480, 0x5C2C7 },
	{ 0xF0A6B481, 0x6D7D2 },
	{ 0xF0A6B482, 0x6D7E0 },
	{ 0xF0A6B485, 0x6D7DC },
	{ 0xF0A6B487, 0x6D7C8 },
	{ 0xF0A6B488, 0x6D7D6 },
	{ 0xF0A6B489, 0x5C2B9 },
	{ 0xF0A6B48A, 0x4C0B9 },
	{ 0xF0A6B48B, 0x6D7D7 },
	{ 0xF0A6B48C, 0x5C2B0 },
	{ 0xF0A6B48D, 0x5C2C0 },
	{ 0xF0A6B48E, 0x5C2B2 },
	{ 0xF0A6B48F, 0x5C2CA },
	{ 0xF0A6B490, 0x6D7BF },
	{ 0xF0A6B491, 0x4C0B5 },
	{ 0xF0A6B492, 0x4C0CB },
	{ 0xF0A6B493, 0x6D7CC },
	{ 0xF0A6B494, 0x5C2B5 },
	{ 0xF0A6B495, 0x5C2B1 },
	{ 0xF0A6B496, 0x6D7C7 },
	{ 0xF0A6B497, 0x6D7D8 },
	{ 0xF0A6B498, 0x7A7D3 },
	{ 0xF0A6B499, 0x6D7E1 },
	{ 0xF0A6B49A, 0x5C2BC },
	{ 0xF0A6B49B, 0x6D7C4 },
	{ 0xF0A6B49C, 0x6D7D4 },
	{ 0xF0A6B49D, 0x6D7B6 },
	{ 0xF0A6B49E, 0x6D7E2 },
	{ 0xF0A6B49F, 0x6D7E6 },
	{ 0xF0A6B4A0, 0x6D7D9 },
	{ 0xF0A6B4AB, 0x4C0CE },
	{ 0xF0A6B4AC, 0x5C2C4 },
	{ 0xF0A6B4AD, 0x5C2CB },
	{ 0xF0A6B4AE, 0x6D7B5 },
	{ 0xF0A6B4AF, 0x6D7BE },
	{ 0xF0A6B4B0, 0x6D7CB },
	{ 0xF0A6B4B1, 0x6D7CD },
	{ 0xF0A6B4B2, 0x6D7DB },
	{ 0xF0A6B4B3, 0x6D7DF },
	{ 0xF0A6B4B4, 0xFC4F3 },
	{ 0xF0A6B4B5, 0xFC4F5 },
	{ 0xF0A6B4B6, 0xFC4F6 },
	{ 0xF0A6B4B7, 0xFC4F7 },
	{ 0xF0A6B4B8, 0xFC4F8 },
	{ 0xF0A6B4B9, 0xFC4F9 },
	{ 0xF0A6B4BA, 0xFC4FA },
	{ 0xF0A6B4BB, 0xFC4FB },
	{ 0xF0A6B4BC, 0xFC4FC },
	{ 0xF0A6B4BD, 0xFC4FD },
	{ 0xF0A6B4BE, 0xFC4FE },
	{ 0xF0A6B4BF, 0xFC5A1 },
	{ 0xF0A6B580, 0xFC5A2 },
	{ 0xF0A6B581, 0xFC5A3 },
	{ 0xF0A6B582, 0xFC5A4 },
	{ 0xF0A6B583, 0xFC5A5 },
	{ 0xF0A6B584, 0xFC5A6 },
	{ 0xF0A6B585, 0xFC5A7 },
	{ 0xF0A6B586, 0xFC5A8 },
	{ 0xF0A6B587, 0xFC5A9 },
	{ 0xF0A6B588, 0xFC5AA },
	{ 0xF0A6B589, 0xFC5AB },
	{ 0xF0A6B58A, 0xFC5AC },
	{ 0xF0A6B58B, 0xFC5AE },
	{ 0xF0A6B58C, 0xFC5AF },
	{ 0xF0A6B58D, 0xFC5B0 },
	{ 0xF0A6B58E, 0xFC5B1 },
	{ 0xF0A6B590, 0x5C2CC },
	{ 0xF0A6B591, 0x4C0CA },
	{ 0xF0A6B592, 0x6D7BD },
	{ 0xF0A6B59D, 0x6CEB2 },
	{ 0xF0A6B59E, 0xFBED7 },
	{ 0xF0A6B59F, 0x5C2B7 },
	{ 0xF0A6B5A1, 0x4C6E6 },
	{ 0xF0A6B5A2, 0x6E1E0 },
	{ 0xF0A6B5A3, 0x5C9C5 },
	{ 0xF0A6B5A4, 0x6E1B3 },
	{ 0xF0A6B5A5, 0x6E1C3 },
	{ 0xF0A6B5A6, 0x5C9CB },
	{ 0xF0A6B5A7, 0x4C6E3 },
	{ 0xF0A6B5A8, 0x6E1D6 },
	{ 0xF0A6B5A9, 0x4C6D6 },
	{ 0xF0A6B5AA, 0x6E1C5 },
	{ 0xF0A6B5AB, 0x4C6D9 },
	{ 0xF0A6B5AC, 0x6E1BC },
	{ 0xF0A6B5AD, 0x5C9C1 },
	{ 0xF0A6B5AE, 0x6E1CA },
	{ 0xF0A6B5AF, 0x4C6D5 },
	{ 0xF0A6B5B0, 0x6E1D2 },
	{ 0xF0A6B5B1, 0x5C9BD },
	{ 0xF0A6B5B2, 0x6E1C0 },
	{ 0xF0A6B5B3, 0x6E1D9 },
	{ 0xF0A6B5B4, 0x5C9C9 },
	{ 0xF0A6B5B5, 0x5C9C6 },
	{ 0xF0A6B5B6, 0x6E1CC },
	{ 0xF0A6B5B7, 0x5C9BA },
	{ 0xF0A6B5B8, 0x4C6DA },
	{ 0xF0A6B5B9, 0x6E1B9 },
	{ 0xF0A6B5BA, 0x6E1D5 },
	{ 0xF0A6B5BB, 0x6E1CD },
	{ 0xF0A6B5BC, 0x6E1BF },
	{ 0xF0A6B5BD, 0x5C9C4 },
	{ 0xF0A6B5BE, 0x5C9B9 },
	{ 0xF0A6B5BF, 0x5C9B0 },
	{ 0xF0A6B680, 0x4C6E2 },
	{ 0xF0A6B681, 0x6E1C1 },
	{ 0xF0A6B682, 0x4C6DE },
	{ 0xF0A6B684, 0x6E1B6 },
	{ 0xF0A6B685, 0x4C6DD },
	{ 0xF0A6B686, 0x4C6EB },
	{ 0xF0A6B687, 0x4C6DB },
	{ 0xF0A6B688, 0x5C9BF },
	{ 0xF0A6B689, 0x7A7D8 },
	{ 0xF0A6B68A, 0x6E1B7 },
	{ 0xF0A6B68B, 0x5C9B2 },
	{ 0xF0A6B68C, 0x5C9B7 },
	{ 0xF0A6B68D, 0x5C9B1 },
	{ 0xF0A6B68E, 0x5C9C8 },
	{ 0xF0A6B68F, 0x5D0BB },
	{ 0xF0A6B690, 0x4C6DF },
	{ 0xF0A6B691, 0x5C9C3 },
	{ 0xF0A6B692, 0x6E1B8 },
	{ 0xF0A6B693, 0x4C6E8 },
	{ 0xF0A6B694, 0x6E1D0 },
	{ 0xF0A6B695, 0x5C9B8 },
	{ 0xF0A6B696, 0x6E1D7 },
	{ 0xF0A6B697, 0x6E1C6 },
	{ 0xF0A6B698, 0x6E1BB },
	{ 0xF0A6B699, 0x5C9C0 },
	{ 0xF0A6B69A, 0x5C9B6 },
	{ 0xF0A6B69B, 0x7B2A7 },
	{ 0xF0A6B6A8, 0x5C9AF },
	{ 0xF0A6B6A9, 0x5C9B4 },
	{ 0xF0A6B6AA, 0x6E1C7 },
	{ 0xF0A6B6AB, 0x6E1C9 },
	{ 0xF0A6B6AC, 0x6E1CB },
	{ 0xF0A6B6AD, 0x6E1CE },
	{ 0xF0A6B6AE, 0x6E1DA },
	{ 0xF0A6B6AF, 0x6E1DD },
	{ 0xF0A6B6B0, 0x6E1DE },
	{ 0xF0A6B6B1, 0xFCBE1 },
	{ 0xF0A6B6B2, 0xFCBE2 },
	{ 0xF0A6B6B3, 0xFCBE3 },
	{ 0xF0A6B6B4, 0xFCBE6 },
	{ 0xF0A6B6B5, 0xFCBE8 },
	{ 0xF0A6B6B6, 0xFCBE9 },
	{ 0xF0A6B6B7, 0xFCBEA },
	{ 0xF0A6B6B8, 0xFCBEB },
	{ 0xF0A6B6B9, 0xFCBEC },
	{ 0xF0A6B6BA, 0xFCBED },
	{ 0xF0A6B6BB, 0xFCBEE },
	{ 0xF0A6B6BC, 0xFCBEF },
	{ 0xF0A6B6BD, 0xFCBF0 },
	{ 0xF0A6B6BE, 0xFCBF1 },
	{ 0xF0A6B6BF, 0xFCBF2 },
	{ 0xF0A6B780, 0xFCBF3 },
	{ 0xF0A6B781, 0xFCBF4 },
	{ 0xF0A6B782, 0xFCBF5 },
	{ 0xF0A6B783, 0xFCBF6 },
	{ 0xF0A6B784, 0xFCBF8 },
	{ 0xF0A6B785, 0xFCBF9 },
	{ 0xF0A6B786, 0xFCBFA },
	{ 0xF0A6B787, 0xFCBFC },
	{ 0xF0A6B788, 0xFCBFD },
	{ 0xF0A6B789, 0xFCBFE },
	{ 0xF0A6B78A, 0xFCCA1 },
	{ 0xF0A6B78B, 0xFCCA2 },
	{ 0xF0A6B78C, 0xFCCA3 },
	{ 0xF0A6B78D, 0xFCCA5 },
	{ 0xF0A6B78E, 0xFCCA6 },
	{ 0xF0A6B78F, 0xFCCA7 },
	{ 0xF0A6B790, 0xFCCA8 },
	{ 0xF0A6B791, 0xFCCA9 },
	{ 0xF0A6B792, 0xFCCAA },
	{ 0xF0A6B793, 0x6E1C8 },
	{ 0xF0A6B794, 0x5C9C2 },
	{ 0xF0A6B795, 0x6E1D3 },
	{ 0xF0A6B797, 0x6E1D1 },
	{ 0xF0A6B798, 0x6D7E8 },
	{ 0xF0A6B799, 0x5C9CA },
	{ 0xF0A6B79A, 0x6E1DC },
	{ 0xF0A6B79B, 0x6E1DF },
	{ 0xF0A6B79D, 0x6E1DB },
	{ 0xF0A6B79E, 0x6E1BA },
	{ 0xF0A6B79F, 0x6E1B5 },
	{ 0xF0A6B7A0, 0x6E1C2 },
	{ 0xF0A6B7A1, 0x6E1BD },
	{ 0xF0A6B7A3, 0x6D7D0 },
	{ 0xF0A6B7AA, 0xFCBE4 },
	{ 0xF0A6B7B0, 0xFCBE7 },
	{ 0xF0A6B7B1, 0x6E1D4 },
	{ 0xF0A6B7B2, 0x4C6EA },
	{ 0xF0A6B7B3, 0x4C6D4 },
	{ 0xF0A6B7B4, 0x5C9B5 },
	{ 0xF0A6B7B5, 0x5C9CD },
	{ 0xF0A6B7B6, 0x7B2A6 },
	{ 0xF0A6B7B7, 0x5C9B3 },
	{ 0xF0A6B7B8, 0x6E1E1 },
	{ 0xF0A6B7B9, 0x5C9C7 },
	{ 0xF0A6B7BA, 0x5C9CC },
	{ 0xF0A6B7BB, 0x5D7C6 },
	{ 0xF0A6B7BC, 0xFCBFB },
	{ 0xF0A6B7BD, 0x5C9BE },
	{ 0xF0A6B7BF, 0x7A7EC },
	{ 0xF0A6B880, 0x4CCFE },
	{ 0xF0A6B881, 0x5D0B2 },
	{ 0xF0A6B882, 0x4CCE9 },
	{ 0xF0A6B883, 0x4CCFC },
	{ 0xF0A6B884, 0x7A8A1 },
	{ 0xF0A6B886, 0x5D0B5 },
	{ 0xF0A6B887, 0x7A8A4 },
	{ 0xF0A6B888, 0x7A7F7 },
	{ 0xF0A6B889, 0x7A7DC },
	{ 0xF0A6B88A, 0x5D0B9 },
	{ 0xF0A6B88B, 0x7A7E9 },
	{ 0xF0A6B88C, 0x7A7F8 },
	{ 0xF0A6B88D, 0x7A7F9 },
	{ 0xF0A6B88E, 0x7A7EA },
	{ 0xF0A6B88F, 0x7A7F3 },
	{ 0xF0A6B890, 0x5D0BA },
	{ 0xF0A6B891, 0x7A7EF },
	{ 0xF0A6B892, 0x4CCF5 },
	{ 0xF0A6B893, 0x5D0BD },
	{ 0xF0A6B894, 0x5D0C2 },
	{ 0xF0A6B895, 0x7A7E0 },
	{ 0xF0A6B896, 0x7A8A2 },
	{ 0xF0A6B897, 0x5D0C0 },
	{ 0xF0A6B898, 0x5D0BF },
	{ 0xF0A6B899, 0x5D7C7 },
	{ 0xF0A6B89A, 0x5D0C1 },
	{ 0xF0A6B89B, 0x5D0CB },
	{ 0xF0A6B89C, 0x7A7EB },
	{ 0xF0A6B89D, 0x7A7F6 },
	{ 0xF0A6B89E, 0x7A7D9 },
	{ 0xF0A6B89F, 0x7A7F2 },
	{ 0xF0A6B8A0, 0x7A7E5 },
	{ 0xF0A6B8A1, 0x5D0C8 },
	{ 0xF0A6B8A2, 0x5D0B7 },
	{ 0xF0A6B8A3, 0x4CCFB },
	{ 0xF0A6B8A4, 0x7A7D4 },
	{ 0xF0A6B8A6, 0x7A7DB },
	{ 0xF0A6B8A7, 0x7A7E4 },
	{ 0xF0A6B8A8, 0x7A7E3 },
	{ 0xF0A6B8A9, 0x7A7E7 },
	{ 0xF0A6B8AA, 0x5D0B3 },
	{ 0xF0A6B8AB, 0x7A7E6 },
	{ 0xF0A6B8AC, 0x7A7FD },
	{ 0xF0A6B8AD, 0x7A7DE },
	{ 0xF0A6B8AE, 0x5D0BE },
	{ 0xF0A6B8AF, 0x7A7D6 },
	{ 0xF0A6B8B0, 0x5D0B4 },
	{ 0xF0A6B8B1, 0x5D0CA },
	{ 0xF0A6B8B2, 0x7A7FC },
	{ 0xF0A6B8B3, 0x7A7E2 },
	{ 0xF0A6B8B4, 0x7A7DD },
	{ 0xF0A6B8B5, 0x7A7EE },
	{ 0xF0A6B8B6, 0x4CCF6 },
	{ 0xF0A6B8B7, 0x5D0C9 },
	{ 0xF0A6B8B8, 0x5D0C5 },
	{ 0xF0A6B8B9, 0x7A7F4 },
	{ 0xF0A6B8BA, 0x5D7D8 },
	{ 0xF0A6B986, 0x4CDA2 },
	{ 0xF0A6B987, 0x5D0C3 },
	{ 0xF0A6B988, 0x7A7D5 },
	{ 0xF0A6B989, 0x7A7DA },
	{ 0xF0A6B98A, 0x7A7DF },
	{ 0xF0A6B98B, 0x7A7F0 },
	{ 0xF0A6B98C, 0x7A7F1 },
	{ 0xF0A6B98D, 0x7A8A3 },
	{ 0xF0A6B98E, 0xFD1DE },
	{ 0xF0A6B98F, 0xFD1DF },
	{ 0xF0A6B990, 0xFD1E0 },
	{ 0xF0A6B991, 0xFD1E2 },
	{ 0xF0A6B992, 0xFD1E3 },
	{ 0xF0A6B993, 0xFD1E6 },
	{ 0xF0A6B994, 0xFD1E7 },
	{ 0xF0A6B995, 0xFD1E8 },
	{ 0xF0A6B996, 0xFD1E9 },
	{ 0xF0A6B997, 0xFD1EA },
	{ 0xF0A6B998, 0xFD1EC },
	{ 0xF0A6B999, 0xFD1ED },
	{ 0xF0A6B99A, 0xFD1EE },
	{ 0xF0A6B99B, 0xFD1EF },
	{ 0xF0A6B99C, 0xFD1F0 },
	{ 0xF0A6B99D, 0xFD1F2 },
	{ 0xF0A6B99E, 0xFD1F5 },
	{ 0xF0A6B99F, 0xFD1F7 },
	{ 0xF0A6B9A1, 0x4CDA3 },
	{ 0xF0A6B9A2, 0x7A7FA },
	{ 0xF0A6B9A3, 0x5D0C4 },
	{ 0xF0A6B9A4, 0x7A7FE },
	{ 0xF0A6B9A8, 0x7A7F5 },
	{ 0xF0A6B9AA, 0x7A7E8 },
	{ 0xF0A6B9AE, 0xFD1F1 },
	{ 0xF0A6B9B2, 0xFD1E1 },
	{ 0xF0A6B9B7, 0xFD1EB },
	{ 0xF0A6B9BD, 0x5D0B6 },
	{ 0xF0A6B9BE, 0x7A7D7 },
	{ 0xF0A6B9BF, 0x5D0C7 },
	{ 0xF0A6BA80, 0x5D0BC },
	{ 0xF0A6BA81, 0x6E1B4 },
	{ 0xF0A6BA82, 0x7C2AE },
	{ 0xF0A6BA84, 0xFCCA4 },
	{ 0xF0A6BA86, 0x7B2D1 },
	{ 0xF0A6BA87, 0x4D3AD },
	{ 0xF0A6BA88, 0x7B2B2 },
	{ 0xF0A6BA89, 0x4D3AA },
	{ 0xF0A6BA8A, 0x4D3B4 },
	{ 0xF0A6BA8B, 0x7B2D3 },
	{ 0xF0A6BA8C, 0x5D7C9 },
	{ 0xF0A6BA8D, 0x4D3AB },
	{ 0xF0A6BA8E, 0x5D7DD },
	{ 0xF0A6BA8F, 0x7B2C3 },
	{ 0xF0A6BA90, 0x5D7D4 },
	{ 0xF0A6BA91, 0x4D2F1 },
	{ 0xF0A6BA92, 0x4D3B0 },
	{ 0xF0A6BA93, 0x5D7D1 },
	{ 0xF0A6BA94, 0x5D7DB },
	{ 0xF0A6BA95, 0x7B2BC },
	{ 0xF0A6BA96, 0x4D2F5 },
	{ 0xF0A6BA97, 0x5D7DA },
	{ 0xF0A6BA98, 0x5D7CB },
	{ 0xF0A6BA99, 0x5D7DF },
	{ 0xF0A6BA9A, 0x7B2B3 },
	{ 0xF0A6BA9B, 0x5D7E1 },
	{ 0xF0A6BA9C, 0x4D3AF },
	{ 0xF0A6BA9D, 0x7B2A8 },
	{ 0xF0A6BA9E, 0x5D7CD },
	{ 0xF0A6BA9F, 0x5D7CF },
	{ 0xF0A6BAA0, 0x7B2CC },
	{ 0xF0A6BAA1, 0x5D7D5 },
	{ 0xF0A6BAA2, 0x5D7E2 },
	{ 0xF0A6BAA3, 0x7B2BD },
	{ 0xF0A6BAA4, 0x7B2BB },
	{ 0xF0A6BAA5, 0x5D0CC },
	{ 0xF0A6BAA6, 0x4D2F0 },
	{ 0xF0A6BAA7, 0x5D7C8 },
	{ 0xF0A6BAA8, 0x5D7DE },
	{ 0xF0A6BAA9, 0x7B2C5 },
	{ 0xF0A6BAAA, 0x7B2CB },
	{ 0xF0A6BAAB, 0x7B2C1 },
	{ 0xF0A6BAAC, 0x5D7E4 },
	{ 0xF0A6BAAD, 0x5D7E0 },
	{ 0xF0A6BAAE, 0x7A8A5 },
	{ 0xF0A6BAAF, 0x7A7FB },
	{ 0xF0A6BAB0, 0x7B2D2 },
	{ 0xF0A6BAB1, 0x5DDFA },
	{ 0xF0A6BAB2, 0x4D3A6 },
	{ 0xF0A6BAB3, 0x7B2AE },
	{ 0xF0A6BAB4, 0x4D3A9 },
	{ 0xF0A6BAB5, 0x7B2B6 },
	{ 0xF0A6BAB6, 0x5D7D3 },
	{ 0xF0A6BAB7, 0x4D3A8 },
	{ 0xF0A6BAB8, 0x4D2F4 },
	{ 0xF0A6BAB9, 0x5D0B8 },
	{ 0xF0A6BABA, 0x7B2AF },
	{ 0xF0A6BABB, 0x5D7D2 },
	{ 0xF0A6BABC, 0x7B2B8 },
	{ 0xF0A6BABD, 0x5D7D6 },
	{ 0xF0A6BABE, 0x5D7CC },
	{ 0xF0A6BABF, 0x7B2AD },
	{ 0xF0A6BB80, 0x7B2D7 },
	{ 0xF0A6BB81, 0x7B2CE },
	{ 0xF0A6BB82, 0x4D3AE },
	{ 0xF0A6BB83, 0x5D7DC },
	{ 0xF0A6BB84, 0x7B2AA },
	{ 0xF0A6BB85, 0x4D2F8 },
	{ 0xF0A6BB86, 0x7B2B9 },
	{ 0xF0A6BB87, 0x7C2AF },
	{ 0xF0A6BB88, 0x7B2AB },
	{ 0xF0A6BB89, 0x7B2D5 },
	{ 0xF0A6BB8A, 0x4D3B2 },
	{ 0xF0A6BB8B, 0x7B2C2 },
	{ 0xF0A6BB8C, 0x7B2B5 },
	{ 0xF0A6BB8D, 0x7B2BF },
	{ 0xF0A6BB98, 0xFD7BE },
	{ 0xF0A6BB99, 0xFD7BF },
	{ 0xF0A6BB9A, 0xFD7C0 },
	{ 0xF0A6BB9B, 0xFD7C1 },
	{ 0xF0A6BB9C, 0x5D7CA },
	{ 0xF0A6BB9D, 0x5D7D0 },
	{ 0xF0A6BB9E, 0x5D7D7 },
	{ 0xF0A6BB9F, 0x7B2AC },
	{ 0xF0A6BBA0, 0x7B2B4 },
	{ 0xF0A6BBA1, 0x7B2B7 },
	{ 0xF0A6BBA2, 0x7B2BE },
	{ 0xF0A6BBA3, 0x7B2C0 },
	{ 0xF0A6BBA4, 0x7B2C7 },
	{ 0xF0A6BBA5, 0x7B2C9 },
	{ 0xF0A6BBA6, 0x7B2CD },
	{ 0xF0A6BBA7, 0x7B2CF },
	{ 0xF0A6BBA8, 0x7B2D4 },
	{ 0xF0A6BBA9, 0x7B2D9 },
	{ 0xF0A6BBAA, 0x7B2DA },
	{ 0xF0A6BBAB, 0xFD7B7 },
	{ 0xF0A6BBAC, 0xFD7B8 },
	{ 0xF0A6BBAD, 0xFD7B9 },
	{ 0xF0A6BBAE, 0xFD7BA },
	{ 0xF0A6BBAF, 0xFD7BB },
	{ 0xF0A6BBB0, 0xFD7BC },
	{ 0xF0A6BBB1, 0xFD7BD },
	{ 0xF0A6BBB2, 0xFD7C2 },
	{ 0xF0A6BBB3, 0xFD7C3 },
	{ 0xF0A6BBB4, 0xFD7C4 },
	{ 0xF0A6BBB5, 0xFD7C9 },
	{ 0xF0A6BBB6, 0xFD7CC },
	{ 0xF0A6BBB7, 0xFD7CD },
	{ 0xF0A6BBB8, 0xFD7CE },
	{ 0xF0A6BBB9, 0xFD7CF },
	{ 0xF0A6BBBA, 0xFD7D0 },
	{ 0xF0A6BBBB, 0xFD7D1 },
	{ 0xF0A6BBBC, 0xFD7D2 },
	{ 0xF0A6BBBD, 0xFD7D3 },
	{ 0xF0A6BBBE, 0xFD7D4 },
	{ 0xF0A6BBBF, 0xFD7D6 },
	{ 0xF0A6BC80, 0xFD7D7 },
	{ 0xF0A6BC81, 0xFD7D8 },
	{ 0xF0A6BC82, 0xFD7D9 },
	{ 0xF0A6BC83, 0xFD7DA },
	{ 0xF0A6BC84, 0xFD7DB },
	{ 0xF0A6BC85, 0xFD7DC },
	{ 0xF0A6BC86, 0x7B2B1 },
	{ 0xF0A6BC87, 0xFD7C5 },
	{ 0xF0A6BC8A, 0x4D2FD },
	{ 0xF0A6BC8B, 0x7B2BA },
	{ 0xF0A6BC8C, 0x7B2D8 },
	{ 0xF0A6BC8D, 0x7B2D0 },
	{ 0xF0A6BC8E, 0x5D7E5 },
	{ 0xF0A6BC8F, 0x5D7CE },
	{ 0xF0A6BC90, 0x7B2B0 },
	{ 0xF0A6BC91, 0x7B2A9 },
	{ 0xF0A6BC92, 0x7B2C8 },
	{ 0xF0A6BC95, 0xFD7CA },
	{ 0xF0A6BC99, 0x7B2D6 },
	{ 0xF0A6BCA1, 0x5D7E3 },
	{ 0xF0A6BCA2, 0x5D7D9 },
	{ 0xF0A6BCA4, 0x7B2C6 },
	{ 0xF0A6BCA9, 0x7BAF6 },
	{ 0xF0A6BCAA, 0x4D8BA },
	{ 0xF0A6BCAB, 0x4D8BF },
	{ 0xF0A6BCAC, 0x7BAEE },
	{ 0xF0A6BCAD, 0x7C2BB },
	{ 0xF0A6BCAE, 0x7BAF8 },
	{ 0xF0A6BCAF, 0x4D8C8 },
	{ 0xF0A6BCB0, 0x4D8C9 },
	{ 0xF0A6BCB1, 0x5D7E6 },
	{ 0xF0A6BCB2, 0x5DDF5 },
	{ 0xF0A6BCB3, 0x5DDFD },
	{ 0xF0A6BCB4, 0x5DDF3 },
	{ 0xF0A6BCB5, 0x7BBAB },
	{ 0xF0A6BCB6, 0x7BBAF },
	{ 0xF0A6BCB7, 0x5DDEF },
	{ 0xF0A6BCB8, 0x4D8CA },
	{ 0xF0A6BCB9, 0x4D8B7 },
	{ 0xF0A6BCBA, 0x7BAFB },
	{ 0xF0A6BCBB, 0x4D8C5 },
	{ 0xF0A6BCBC, 0x5DEA1 },
	{ 0xF0A6BCBD, 0x7BAFC },
	{ 0xF0A6BCBE, 0x7BBA3 },
	{ 0xF0A6BCBF, 0x7BBB3 },
	{ 0xF0A6BD80, 0x5DDFE },
	{ 0xF0A6BD81, 0x5DEA5 },
	{ 0xF0A6BD82, 0x7BBB1 },
	{ 0xF0A6BD83, 0x5DEA2 },
	{ 0xF0A6BD84, 0x5DDEE },
	{ 0xF0A6BD85, 0x5DDF8 },
	{ 0xF0A6BD86, 0x7BAFE },
	{ 0xF0A6BD87, 0x5DDFC },
	{ 0xF0A6BD88, 0x7BAF3 },
	{ 0xF0A6BD89, 0x7BBA4 },
	{ 0xF0A6BD8A, 0x7BBAA },
	{ 0xF0A6BD8B, 0x5DDFB },
	{ 0xF0A6BD8C, 0x4D8CB },
	{ 0xF0A6BD8E, 0x5DDED },
	{ 0xF0A6BD8F, 0x5DEA3 },
	{ 0xF0A6BD90, 0x4D8C1 },
	{ 0xF0A6BD91, 0x7BBB0 },
	{ 0xF0A6BD92, 0x5DDF7 },
	{ 0xF0A6BD93, 0x4D8C6 },
	{ 0xF0A6BD94, 0x5DDF1 },
	{ 0xF0A6BD95, 0x5DEA4 },
	{ 0xF0A6BD96, 0x7BBA5 },
	{ 0xF0A6BD97, 0x5DDF6 },
	{ 0xF0A6BD98, 0x7BAF0 },
	{ 0xF0A6BD99, 0x7BAF5 },
	{ 0xF0A6BD9A, 0x7C2B9 },
	{ 0xF0A6BD9B, 0x7BAEB },
	{ 0xF0A6BD9C, 0x7BAEC },
	{ 0xF0A6BD9D, 0x7BBB5 },
	{ 0xF0A6BD9E, 0x7BAFD },
	{ 0xF0A6BD9F, 0x4D8C7 },
	{ 0xF0A6BDA0, 0x7BBAE },
	{ 0xF0A6BDA1, 0x7BAF2 },
	{ 0xF0A6BDA2, 0x7BAF7 },
	{ 0xF0A6BDA3, 0x7C9B4 },
	{ 0xF0A6BDA4, 0x7BAF1 },
	{ 0xF0A6BDA5, 0x7BBA2 },
	{ 0xF0A6BDA6, 0x7BBA9 },
	{ 0xF0A6BDA7, 0x7B2CA },
	{ 0xF0A6BDA8, 0x7BAF9 },
	{ 0xF0A6BDA9, 0x7BBA1 },
	{ 0xF0A6BDAA, 0x7BBB7 },
	{ 0xF0A6BDAB, 0x5DDF4 },
	{ 0xF0A6BDAC, 0x5D0CD },
	{ 0xF0A6BDAE, 0x4D8C3 },
	{ 0xF0A6BDB1, 0x7C9B5 },
	{ 0xF0A6BDB5, 0x5DDF0 },
	{ 0xF0A6BDB6, 0x5DDF2 },
	{ 0xF0A6BDB7, 0x7BAED },
	{ 0xF0A6BDB8, 0x7BBA7 },
	{ 0xF0A6BDB9, 0x7BBA8 },
	{ 0xF0A6BDBA, 0x7BBAC },
	{ 0xF0A6BDBB, 0x7BBB4 },
	{ 0xF0A6BDBC, 0xFDCBA },
	{ 0xF0A6BDBD, 0xFDCBB },
	{ 0xF0A6BDBE, 0xFDCBC },
	{ 0xF0A6BDBF, 0xFDCBD },
	{ 0xF0A6BE80, 0xFDCBE },
	{ 0xF0A6BE81, 0xFDCC0 },
	{ 0xF0A6BE82, 0xFDCC1 },
	{ 0xF0A6BE83, 0xFDCC2 },
	{ 0xF0A6BE84, 0xFDCC3 },
	{ 0xF0A6BE85, 0xFDCC4 },
	{ 0xF0A6BE86, 0xFDCC5 },
	{ 0xF0A6BE87, 0xFDCC6 },
	{ 0xF0A6BE88, 0xFDCC7 },
	{ 0xF0A6BE89, 0xFDCC9 },
	{ 0xF0A6BE8A, 0xFDCCA },
	{ 0xF0A6BE8B, 0xFDCCB },
	{ 0xF0A6BE8C, 0xFDCCC },
	{ 0xF0A6BE8D, 0xFDCCF },
	{ 0xF0A6BE8E, 0xFDCD0 },
	{ 0xF0A6BE8F, 0x4D8B9 },
	{ 0xF0A6BE90, 0x7BAFA },
	{ 0xF0A6BE92, 0x7BBAD },
	{ 0xF0A6BE94, 0x7BBB6 },
	{ 0xF0A6BE97, 0x7BAF4 },
	{ 0xF0A6BE9B, 0xFDCC8 },
	{ 0xF0A6BE9F, 0xFDCBF },
	{ 0xF0A6BEA1, 0xFDCCE },
	{ 0xF0A6BEA7, 0xFD7D5 },
	{ 0xF0A6BEAA, 0xFE3DB },
	{ 0xF0A6BEAC, 0x5E4AC },
	{ 0xF0A6BEAD, 0x7C2CB },
	{ 0xF0A6BEAE, 0x4DDA4 },
	{ 0xF0A6BEAF, 0x7C2CC },
	{ 0xF0A6BEB0, 0x5E4A2 },
	{ 0xF0A6BEB1, 0x4DDA5 },
	{ 0xF0A6BEB2, 0x5DEA6 },
	{ 0xF0A6BEB3, 0x5E4AF },
	{ 0xF0A6BEB4, 0x7C2C8 },
	{ 0xF0A6BEB5, 0x5E4A5 },
	{ 0xF0A6BEB6, 0x5E3FE },
	{ 0xF0A6BEB7, 0x7C2B0 },
	{ 0xF0A6BEB8, 0x5E4A1 },
	{ 0xF0A6BEB9, 0x5E4A9 },
	{ 0xF0A6BEBA, 0x5E4B6 },
	{ 0xF0A6BEBB, 0x5E4B9 },
	{ 0xF0A6BEBC, 0x7C2B6 },
	{ 0xF0A6BEBD, 0x5E4B3 },
	{ 0xF0A6BEBE, 0x7C2C6 },
	{ 0xF0A6BEBF, 0x4DDA2 },
	{ 0xF0A6BF80, 0x5DEA7 },
	{ 0xF0A6BF81, 0x5E4B8 },
	{ 0xF0A6BF82, 0x5E4A6 },
	{ 0xF0A6BF83, 0x5E4B0 },
	{ 0xF0A6BF84, 0x7C2BD },
	{ 0xF0A6BF85, 0x5E4A4 },
	{ 0xF0A6BF86, 0x5E4AE },
	{ 0xF0A6BF88, 0x7C2CD },
	{ 0xF0A6BF89, 0x4DDB0 },
	{ 0xF0A6BF8A, 0x5E4B1 },
	{ 0xF0A6BF8B, 0x4DDAE },
	{ 0xF0A6BF8C, 0x4DDA6 },
	{ 0xF0A6BF8D, 0x4DDAA },
	{ 0xF0A6BF8E, 0x5E4B4 },
	{ 0xF0A6BF8F, 0x5E4B2 },
	{ 0xF0A6BF90, 0x7C2BE },
	{ 0xF0A6BF91, 0x7CFC6 },
	{ 0xF0A6BF92, 0x7C2BA },
	{ 0xF0A6BF93, 0x7C2B7 },
	{ 0xF0A6BF94, 0x4DDAF },
	{ 0xF0A6BF95, 0x7C9C4 },
	{ 0xF0A6BF96, 0x5E4AB },
	{ 0xF0A6BF97, 0x7C2B3 },
	{ 0xF0A6BF98, 0x7C2C5 },
	{ 0xF0A6BF99, 0x7C2C9 },
	{ 0xF0A6BFA0, 0x4DDAD },
	{ 0xF0A6BFA1, 0x7BBA6 },
	{ 0xF0A6BFA2, 0x7C2B2 },
	{ 0xF0A6BFA3, 0x7C2B4 },
	{ 0xF0A6BFA4, 0x7C2B5 },
	{ 0xF0A6BFA5, 0x7C2BF },
	{ 0xF0A6BFA6, 0x7C2C2 },
	{ 0xF0A6BFA7, 0x7C2C4 },
	{ 0xF0A6BFA8, 0x7C2CA },
	{ 0xF0A6BFA9, 0x7C2CE },
	{ 0xF0A6BFAA, 0x7C2CF },
	{ 0xF0A6BFAB, 0xFE0C8 },
	{ 0xF0A6BFAC, 0xFE0C9 },
	{ 0xF0A6BFAD, 0xFE0CA },
	{ 0xF0A6BFAE, 0xFE0CB },
	{ 0xF0A6BFAF, 0xFE0CC },
	{ 0xF0A6BFB0, 0xFE0CF },
	{ 0xF0A6BFB1, 0xFE0D0 },
	{ 0xF0A6BFB2, 0xFE0D1 },
	{ 0xF0A6BFB3, 0xFE0D2 },
	{ 0xF0A6BFB4, 0xFE0D3 },
	{ 0xF0A6BFB5, 0xFE0D4 },
	{ 0xF0A6BFB9, 0xFE0D5 },
	{ 0xF0A6BFBA, 0xFE0D6 },
	{ 0xF0A6BFBB, 0xFE0D7 },
	{ 0xF0A6BFBC, 0xFE0D8 },
	{ 0xF0A6BFBD, 0xFE0D9 },
	{ 0xF0A6BFBE, 0xFE0DA },
	{ 0xF0A6BFBF, 0xFE0DB },
	{ 0xF0A78080, 0xFE0DC },
	{ 0xF0A78081, 0xFE0DE },
	{ 0xF0A78082, 0xFE0DF },
	{ 0xF0A78084, 0x4DDA7 },
	{ 0xF0A78085, 0x7C2C0 },
	{ 0xF0A78086, 0x5E4A7 },
	{ 0xF0A78087, 0x7C2C1 },
	{ 0xF0A7808D, 0x7C9B3 },
	{ 0xF0A78094, 0x5E4B5 },
	{ 0xF0A78095, 0x5E4AA },
	{ 0xF0A78096, 0x4DDA9 },
	{ 0xF0A78097, 0x7C2C7 },
	{ 0xF0A78098, 0x5E4A3 },
	{ 0xF0A78099, 0x5E4A8 },
	{ 0xF0A7809A, 0x5E4B7 },
	{ 0xF0A7809B, 0x7C2C3 },
	{ 0xF0A7809D, 0x7C2B1 },
	{ 0xF0A780A0, 0x5E9BE },
	{ 0xF0A780A1, 0x5E9AF },
	{ 0xF0A780A2, 0x7CFDD },
	{ 0xF0A780A3, 0x5E9B0 },
	{ 0xF0A780A4, 0x5E9BA },
	{ 0xF0A780A5, 0x5E9B6 },
	{ 0xF0A780A6, 0x4E0FD },
	{ 0xF0A780A7, 0x4E0F9 },
	{ 0xF0A780A8, 0x5E9BF },
	{ 0xF0A780A9, 0x5E9B7 },
	{ 0xF0A780AA, 0x7C9B8 },
	{ 0xF0A780AB, 0x7C9C5 },
	{ 0xF0A780AC, 0x5E9BB },
	{ 0xF0A780AD, 0x5E9B5 },
	{ 0xF0A780AE, 0x4E0FC },
	{ 0xF0A780AF, 0x5E9AE },
	{ 0xF0A780B0, 0x5EDC2 },
	{ 0xF0A780B1, 0x7C9C3 },
	{ 0xF0A780B2, 0x5E9B8 },
	{ 0xF0A780B3, 0x7C9C6 },
	{ 0xF0A780B4, 0x5E9B9 },
	{ 0xF0A780B5, 0x7C9C1 },
	{ 0xF0A780B7, 0x7C9D4 },
	{ 0xF0A780B8, 0x7C9D1 },
	{ 0xF0A780B9, 0x7C9BC },
	{ 0xF0A780BA, 0x5E9B3 },
	{ 0xF0A780BB, 0x5E9BD },
	{ 0xF0A780BC, 0x7C9CB },
	{ 0xF0A780BD, 0x7C9CE },
	{ 0xF0A780BE, 0x7C9BE },
	{ 0xF0A780BF, 0x7C9BD },
	{ 0xF0A78180, 0x7C9C2 },
	{ 0xF0A78181, 0x7C9C7 },
	{ 0xF0A78182, 0x7CFD4 },
	{ 0xF0A78183, 0x7C9CD },
	{ 0xF0A78184, 0x7C9B9 },
	{ 0xF0A78185, 0x7C9CC },
	{ 0xF0A78186, 0x7C9CA },
	{ 0xF0A78187, 0x7CFC7 },
	{ 0xF0A78188, 0x5E9B4 },
	{ 0xF0A78189, 0x5E9B2 },
	{ 0xF0A7818A, 0x4E0F6 },
	{ 0xF0A7818B, 0x5E9BC },
	{ 0xF0A7818C, 0x7C9C9 },
	{ 0xF0A7818D, 0x7C9C0 },
	{ 0xF0A7818F, 0x7C9BF },
	{ 0xF0A78191, 0x7C9B6 },
	{ 0xF0A78194, 0x7C9B7 },
	{ 0xF0A78195, 0x7C9BA },
	{ 0xF0A78196, 0x7C9C8 },
	{ 0xF0A78197, 0x7C9D0 },
	{ 0xF0A78198, 0x7C9D2 },
	{ 0xF0A78199, 0xFE3D1 },
	{ 0xF0A7819A, 0xFE3D2 },
	{ 0xF0A7819B, 0xFE3D4 },
	{ 0xF0A7819C, 0xFE3D5 },
	{ 0xF0A7819D, 0xFE3D6 },
	{ 0xF0A7819E, 0xFE3D7 },
	{ 0xF0A7819F, 0xFE3D8 },
	{ 0xF0A781A0, 0xFE3D9 },
	{ 0xF0A781A1, 0xFE3DA },
	{ 0xF0A781A2, 0xFE3DC },
	{ 0xF0A781A3, 0xFE3DD },
	{ 0xF0A781A4, 0xFE3DE },
	{ 0xF0A781A5, 0xFE3DF },
	{ 0xF0A781A6, 0xFE3E0 },
	{ 0xF0A781A7, 0xFE3E1 },
	{ 0xF0A781A8, 0xFE3E2 },
	{ 0xF0A781A9, 0xFE3E3 },
	{ 0xF0A781AA, 0xFE3E4 },
	{ 0xF0A781AB, 0xFE3E5 },
	{ 0xF0A781AC, 0xFE3E6 },
	{ 0xF0A781AD, 0xFE3E7 },
	{ 0xF0A781AE, 0xFE3E8 },
	{ 0xF0A781AF, 0xFE3E9 },
	{ 0xF0A781B0, 0x7C9CF },
	{ 0xF0A781BB, 0x7CFDE },
	{ 0xF0A781BC, 0x7CFD5 },
	{ 0xF0A781BD, 0x7CFCE },
	{ 0xF0A781BE, 0x5EDC0 },
	{ 0xF0A781BF, 0x5EDC7 },
	{ 0xF0A78280, 0x7CFE1 },
	{ 0xF0A78281, 0x5EDC1 },
	{ 0xF0A78282, 0x5EDC4 },
	{ 0xF0A78283, 0x4E4B9 },
	{ 0xF0A78284, 0x7CFD8 },
	{ 0xF0A78285, 0x5EDC6 },
	{ 0xF0A78286, 0x4E4B5 },
	{ 0xF0A78288, 0x5EDBF },
	{ 0xF0A78289, 0x5F0FE },
	{ 0xF0A7828A, 0x7CFDF },
	{ 0xF0A7828B, 0x5EDBB },
	{ 0xF0A7828C, 0x7CFD1 },
	{ 0xF0A7828D, 0x7CFD0 },
	{ 0xF0A7828E, 0x7CFCC },
	{ 0xF0A7828F, 0x5EDBE },
	{ 0xF0A78290, 0x5EDC5 },
	{ 0xF0A78291, 0x7CFCD },
	{ 0xF0A78292, 0x4E4B1 },
	{ 0xF0A78293, 0x7CFE7 },
	{ 0xF0A78294, 0x5EDBC },
	{ 0xF0A78295, 0x7CFCB },
	{ 0xF0A78296, 0x7CFD3 },
	{ 0xF0A78297, 0x7CFE2 },
	{ 0xF0A78298, 0x7CFDB },
	{ 0xF0A78299, 0x7C9BB },
	{ 0xF0A7829A, 0x7CFE5 },
	{ 0xF0A7829B, 0x5EDC3 },
	{ 0xF0A7829C, 0x4E4AE },
	{ 0xF0A7829D, 0x7CFD9 },
	{ 0xF0A7829E, 0x5EDBD },
	{ 0xF0A7829F, 0x7CFE6 },
	{ 0xF0A782A1, 0x7CFDA },
	{ 0xF0A782A3, 0x5E9B1 },
	{ 0xF0A782A4, 0x7D4E7 },
	{ 0xF0A782A5, 0x7D8E9 },
	{ 0xF0A782A7, 0x7CFC9 },
	{ 0xF0A782A8, 0x5EDBA },
	{ 0xF0A782A9, 0x5EDC8 },
	{ 0xF0A782B0, 0x7CFD2 },
	{ 0xF0A782B1, 0x7CFD6 },
	{ 0xF0A782B2, 0x7CFD7 },
	{ 0xF0A782B3, 0x7CFDC },
	{ 0xF0A782B4, 0x7CFE3 },
	{ 0xF0A782B5, 0x7CFE4 },
	{ 0xF0A782B6, 0xFE5F9 },
	{ 0xF0A782B7, 0xFE5FA },
	{ 0xF0A782B8, 0xFE5FB },
	{ 0xF0A782B9, 0xFE5FC },
	{ 0xF0A782BA, 0xFE5FD },
	{ 0xF0A782BB, 0xFE5FE },
	{ 0xF0A782BC, 0xFE6A1 },
	{ 0xF0A782BD, 0xFE6A2 },
	{ 0xF0A782BE, 0xFE6A3 },
	{ 0xF0A782BF, 0xFE6A4 },
	{ 0xF0A78380, 0xFE6A5 },
	{ 0xF0A78381, 0xFE6A6 },
	{ 0xF0A78382, 0xFE6A7 },
	{ 0xF0A78383, 0xFE6A8 },
	{ 0xF0A78384, 0xFE6A9 },
	{ 0xF0A78385, 0xFE6AA },
	{ 0xF0A78386, 0xFE6AB },
	{ 0xF0A78387, 0xFE6AC },
	{ 0xF0A78388, 0x7CFCA },
	{ 0xF0A78389, 0x7CFC8 },
	{ 0xF0A7838E, 0x7CFE0 },
	{ 0xF0A7838F, 0x7D4E3 },
	{ 0xF0A78390, 0x4E9B5 },
	{ 0xF0A78391, 0x5F1A8 },
	{ 0xF0A78392, 0x7D4E6 },
	{ 0xF0A78393, 0x7D4DF },
	{ 0xF0A78394, 0x5F1A4 },
	{ 0xF0A78395, 0x4E7AC },
	{ 0xF0A78396, 0x4E7AA },
	{ 0xF0A78397, 0x7D4D9 },
	{ 0xF0A78398, 0x4E7AE },
	{ 0xF0A78399, 0x5F1A2 },
	{ 0xF0A7839A, 0x7D4E4 },
	{ 0xF0A7839B, 0x5F1A5 },
	{ 0xF0A7839C, 0x7D4E5 },
	{ 0xF0A7839D, 0x4E7A9 },
	{ 0xF0A7839E, 0x5EDC9 },
	{ 0xF0A7839F, 0x5F1A7 },
	{ 0xF0A783A0, 0x7D4DB },
	{ 0xF0A783A1, 0x7D4D3 },
	{ 0xF0A783A2, 0x5F1A6 },
	{ 0xF0A783A3, 0x7D4E2 },
	{ 0xF0A783A4, 0x7D4D7 },
	{ 0xF0A783A5, 0x7D4D5 },
	{ 0xF0A783A6, 0x7D4E0 },
	{ 0xF0A783A7, 0x4E7AD },
	{ 0xF0A783A8, 0x5F1A3 },
	{ 0xF0A783A9, 0x5F1A9 },
	{ 0xF0A783AA, 0x5F1AA },
	{ 0xF0A783AB, 0x7D4D4 },
	{ 0xF0A783AC, 0x7D4DC },
	{ 0xF0A783AE, 0x7CFCF },
	{ 0xF0A783AF, 0x7D4DA },
	{ 0xF0A783B0, 0x7D8F6 },
	{ 0xF0A783B9, 0x5F1A1 },
	{ 0xF0A783BA, 0x7D4D6 },
	{ 0xF0A783BB, 0x7D4DD },
	{ 0xF0A783BC, 0x7D4E1 },
	{ 0xF0A783BD, 0xFE8B8 },
	{ 0xF0A783BE, 0xFE8BA },
	{ 0xF0A783BF, 0xFE8BB },
	{ 0xF0A78480, 0xFE8BC },
	{ 0xF0A78481, 0xFE8BD },
	{ 0xF0A78482, 0xFE8BE },
	{ 0xF0A78483, 0xFE8BF },
	{ 0xF0A78484, 0xFE8C1 },
	{ 0xF0A78485, 0xFE8C2 },
	{ 0xF0A78486, 0xFE8C3 },
	{ 0xF0A78487, 0xFE8C4 },
	{ 0xF0A78489, 0xFE8C0 },
	{ 0xF0A7848B, 0x7D4D8 },
	{ 0xF0A7848D, 0x5F4A4 },
	{ 0xF0A7848E, 0x4E9B6 },
	{ 0xF0A7848F, 0x5F4A5 },
	{ 0xF0A78490, 0x5F4A7 },
	{ 0xF0A78491, 0x5F4A8 },
	{ 0xF0A78492, 0x7D8F0 },
	{ 0xF0A78493, 0x5F4A9 },
	{ 0xF0A78494, 0x4E9BB },
	{ 0xF0A78495, 0x4E9BA },
	{ 0xF0A78496, 0x7D8F7 },
	{ 0xF0A78497, 0x7D8F5 },
	{ 0xF0A78498, 0x7D8ED },
	{ 0xF0A78499, 0x7DCD3 },
	{ 0xF0A7849A, 0x5F4A3 },
	{ 0xF0A7849B, 0x5F4A6 },
	{ 0xF0A7849C, 0x7D8EF },
	{ 0xF0A7849D, 0x4E9B8 },
	{ 0xF0A7849E, 0x4E9B9 },
	{ 0xF0A7849F, 0x7D8EE },
	{ 0xF0A784A0, 0x4E9B4 },
	{ 0xF0A784A1, 0x7D8F3 },
	{ 0xF0A784A2, 0x7D8EB },
	{ 0xF0A784A3, 0x7D8F8 },
	{ 0xF0A784A8, 0x7D8EA },
	{ 0xF0A784A9, 0x7D8EC },
	{ 0xF0A784AA, 0x7D8F1 },
	{ 0xF0A784AB, 0x7D8F4 },
	{ 0xF0A784AC, 0xFE9E8 },
	{ 0xF0A784AD, 0xFE9EB },
	{ 0xF0A784AE, 0xFE9EC },
	{ 0xF0A784B6, 0x7DCCF },
	{ 0xF0A784B7, 0x7DCDA },
	{ 0xF0A784B8, 0x4EAF5 },
	{ 0xF0A784B9, 0x5F6C0 },
	{ 0xF0A784BA, 0x4EAF4 },
	{ 0xF0A784BB, 0x5F6BF },
	{ 0xF0A784BC, 0x4EAF1 },
	{ 0xF0A784BD, 0x4EAF3 },
	{ 0xF0A784BE, 0x4EAF2 },
	{ 0xF0A784BF, 0x4EAF0 },
	{ 0xF0A78580, 0x5F6C3 },
	{ 0xF0A78581, 0x7DCD1 },
	{ 0xF0A78582, 0x7DCDB },
	{ 0xF0A78583, 0x5F6C2 },
	{ 0xF0A78584, 0x5F9C0 },
	{ 0xF0A78585, 0x7DCD5 },
	{ 0xF0A78586, 0x5F6C4 },
	{ 0xF0A78587, 0x7DCD7 },
	{ 0xF0A78588, 0x7DCD8 },
	{ 0xF0A78589, 0x7DCCD },
	{ 0xF0A7858A, 0x7DCD0 },
	{ 0xF0A7858B, 0x5F6C1 },
	{ 0xF0A7858C, 0x7DCD6 },
	{ 0xF0A7858D, 0x7DCD4 },
	{ 0xF0A7858E, 0x7DCD2 },
	{ 0xF0A7858F, 0x7DCD9 },
	{ 0xF0A78590, 0xFEAED },
	{ 0xF0A78591, 0xFEAEE },
	{ 0xF0A78592, 0xFEAEF },
	{ 0xF0A78593, 0x7DCCE },
	{ 0xF0A78594, 0xFE9EA },
	{ 0xF0A78596, 0x5F8A3 },
	{ 0xF0A78597, 0x5F8A2 },
	{ 0xF0A78598, 0x5F8A1 },
	{ 0xF0A78599, 0x7DFC0 },
	{ 0xF0A7859A, 0x5F8A4 },
	{ 0xF0A7859B, 0x7DFC2 },
	{ 0xF0A7859C, 0x7DFC6 },
	{ 0xF0A7859D, 0x7DFC3 },
	{ 0xF0A7859E, 0x7DFC4 },
	{ 0xF0A7859F, 0x7DFC9 },
	{ 0xF0A785A0, 0x7DFC1 },
	{ 0xF0A785A1, 0x7DFC7 },
	{ 0xF0A785A2, 0x5F9C2 },
	{ 0xF0A785A6, 0xFEBE0 },
	{ 0xF0A785A7, 0xFEBE1 },
	{ 0xF0A785A8, 0xFEBE3 },
	{ 0xF0A785A9, 0x7DFC5 },
	{ 0xF0A785AA, 0x7DFC8 },
	{ 0xF0A785AE, 0x5F9C3 },
	{ 0xF0A785AF, 0x7E2D5 },
	{ 0xF0A785B0, 0x5F9C1 },
	{ 0xF0A785B1, 0x7E2D3 },
	{ 0xF0A785B2, 0x7E1BE },
	{ 0xF0A785B3, 0x7E1BD },
	{ 0xF0A785B4, 0x7E1BC },
	{ 0xF0A785B6, 0xFECB8 },
	{ 0xF0A785B7, 0xFECB9 },
	{ 0xF0A785B8, 0x7E1BF },
	{ 0xF0A785BA, 0x5FAB5 },
	{ 0xF0A785BB, 0x5FAB6 },
	{ 0xF0A785BC, 0x7E2D9 },
	{ 0xF0A785BD, 0x7E2D7 },
	{ 0xF0A785BE, 0x7E2D6 },
	{ 0xF0A78681, 0x7E2D8 },
	{ 0xF0A78683, 0x7E2D4 },
	{ 0xF0A78685, 0xFECD1 },
	{ 0xF0A78686, 0x7E2C8 },
	{ 0xF0A78687, 0x4EDFA },
	{ 0xF0A78688, 0x7E3E8 },
	{ 0xF0A78689, 0x5FAF2 },
	{ 0xF0A7868A, 0x4EDDF },
	{ 0xF0A7868B, 0x4EDFC },
	{ 0xF0A7868D, 0xFECEB },
	{ 0xF0A7868E, 0xFECED },
	{ 0xF0A7868F, 0x5FBC6 },
	{ 0xF0A78690, 0x4EEB5 },
	{ 0xF0A78691, 0x7E4D8 },
	{ 0xF0A78692, 0x7E4D9 },
	{ 0xF0A78693, 0x5FCC9 },
	{ 0xF0A78694, 0x7E5C0 },
	{ 0xF0A78695, 0x5FBE6 },
	{ 0xF0A78696, 0x7E5E0 },
	{ 0xF0A78697, 0x7E5F6 },
	{ 0xF0A78698, 0x5FCCF },
	{ 0xF0A78699, 0x5FCBD },
	{ 0xF0A7869A, 0x7E5DF },
	{ 0xF0A7869B, 0xFA8E5 },
	{ 0xF0A7869C, 0x4ABBF },
	{ 0xF0A7869D, 0x6B4C9 },
	{ 0xF0A7869E, 0x6B4C8 },
	{ 0xF0A786A0, 0xFB2CE },
	{ 0xF0A786A3, 0x5B5B6 },
	{ 0xF0A786A4, 0x5B5B4 },
	{ 0xF0A786A5, 0x4B4F7 },
	{ 0xF0A786A6, 0x4B4F6 },
	{ 0xF0A786A7, 0x6C4C1 },
	{ 0xF0A786A8, 0x4B4F8 },
	{ 0xF0A786A9, 0x6C4C2 },
	{ 0xF0A786AA, 0x6C4C0 },
	{ 0xF0A786AB, 0x6C4BF },
	{ 0xF0A786AC, 0x6BBE3 },
	{ 0xF0A786B1, 0x6CEBC },
	{ 0xF0A786B2, 0x5BBF1 },
	{ 0xF0A786B3, 0x6CEBD },
	{ 0xF0A786B4, 0xFBFA2 },
	{ 0xF0A786B5, 0xFBFA3 },
	{ 0xF0A786B6, 0xFBFA4 },
	{ 0xF0A786BA, 0x5C2D5 },
	{ 0xF0A786BB, 0x5C2D1 },
	{ 0xF0A786BC, 0x5C2D2 },
	{ 0xF0A786BD, 0x6D7EB },
	{ 0xF0A786BE, 0x6D7EA },
	{ 0xF0A786BF, 0x6D7E9 },
	{ 0xF0A78781, 0x5C9CF },
	{ 0xF0A78782, 0x6E1E2 },
	{ 0xF0A78783, 0x6E1E6 },
	{ 0xF0A78784, 0x4C6EF },
	{ 0xF0A78785, 0x6E1E5 },
	{ 0xF0A78786, 0x6E1E7 },
	{ 0xF0A78787, 0x6E1E3 },
	{ 0xF0A78788, 0x6E1E4 },
	{ 0xF0A78789, 0x5C9D0 },
	{ 0xF0A7878A, 0xFCCAB },
	{ 0xF0A7878B, 0xFCCAC },
	{ 0xF0A7878D, 0x4C6EE },
	{ 0xF0A78790, 0x7A8A9 },
	{ 0xF0A78791, 0x7A8A7 },
	{ 0xF0A78792, 0x7B2DF },
	{ 0xF0A78793, 0x5D0CE },
	{ 0xF0A78794, 0x7A8A6 },
	{ 0xF0A78795, 0x7A8A8 },
	{ 0xF0A78797, 0xFD1F9 },
	{ 0xF0A78798, 0x7A6A9 },
	{ 0xF0A7879C, 0x5D7EA },
	{ 0xF0A7879D, 0x5D7EB },
	{ 0xF0A7879E, 0x5D7E8 },
	{ 0xF0A7879F, 0x5D7E9 },
	{ 0xF0A787A0, 0x4D3B5 },
	{ 0xF0A787A1, 0x5D7E7 },
	{ 0xF0A787A2, 0x7B2E0 },
	{ 0xF0A787A3, 0x7B2DC },
	{ 0xF0A787A4, 0x7B2DD },
	{ 0xF0A787A5, 0x4D3B8 },
	{ 0xF0A787A6, 0x4D3B7 },
	{ 0xF0A787A7, 0x5D7ED },
	{ 0xF0A787A8, 0x7B2DE },
	{ 0xF0A787A9, 0xFD7DD },
	{ 0xF0A787AA, 0xFD7DE },
	{ 0xF0A787AB, 0xFD7DF },
	{ 0xF0A787AC, 0x5D7EC },
	{ 0xF0A787AD, 0x7B2DB },
	{ 0xF0A787B1, 0x4D8CC },
	{ 0xF0A787B2, 0x7BBB9 },
	{ 0xF0A787B3, 0xFDCD1 },
	{ 0xF0A787B4, 0xFDCD2 },
	{ 0xF0A787B5, 0xFDCD3 },
	{ 0xF0A787BB, 0x7C2D1 },
	{ 0xF0A787BC, 0x5E4BD },
	{ 0xF0A787BD, 0x4DDB3 },
	{ 0xF0A787BE, 0x7C2D0 },
	{ 0xF0A787BF, 0x4DDB1 },
	{ 0xF0A78880, 0x7C2D2 },
	{ 0xF0A78881, 0x5E4BC },
	{ 0xF0A78883, 0xFE0E0 },
	{ 0xF0A78886, 0x7C9D6 },
	{ 0xF0A78887, 0x7C9D5 },
	{ 0xF0A78888, 0x4E0FE },
	{ 0xF0A78889, 0x7C9D7 },
	{ 0xF0A7888B, 0x7CFE9 },
	{ 0xF0A7888D, 0x5EDCA },
	{ 0xF0A7888E, 0x7CFEA },
	{ 0xF0A78890, 0x7CCA6 },
	{ 0xF0A78891, 0x5F1AC },
	{ 0xF0A78892, 0x7CFE8 },
	{ 0xF0A78893, 0x5F1AB },
	{ 0xF0A78895, 0x5F0CD },
	{ 0xF0A78896, 0x7D4EA },
	{ 0xF0A78897, 0x7D4E9 },
	{ 0xF0A78898, 0x5F4AA },
	{ 0xF0A7889A, 0x7DCA4 },
	{ 0xF0A7889C, 0x4EEB8 },
	{ 0xF0A7889D, 0x5A4F5 },
	{ 0xF0A7889E, 0x6A9A9 },
	{ 0xF0A7889F, 0x4A8A2 },
	{ 0xF0A788A0, 0x6AEA5 },
	{ 0xF0A788A3, 0xFA8E6 },
	{ 0xF0A788A4, 0xFA8E7 },
	{ 0xF0A788A5, 0xFA8E9 },
	{ 0xF0A788A7, 0xFA8EA },
	{ 0xF0A788A8, 0x4ABC3 },
	{ 0xF0A788A9, 0x6B4CB },
	{ 0xF0A788AA, 0x4ABC0 },
	{ 0xF0A788AB, 0x4ABC2 },
	{ 0xF0A788AC, 0x6B4CA },
	{ 0xF0A788AD, 0x5ABC0 },
	{ 0xF0A788AE, 0x6B4CD },
	{ 0xF0A788AF, 0x6B4CC },
	{ 0xF0A788B0, 0x6B4CE },
	{ 0xF0A788B4, 0xFADBD },
	{ 0xF0A788B5, 0xFADBF },
	{ 0xF0A788B6, 0xFADC2 },
	{ 0xF0A788B7, 0xFADC3 },
	{ 0xF0A788B8, 0xFADC4 },
	{ 0xF0A788B9, 0xFADC1 },
	{ 0xF0A788BA, 0x4ABC1 },
	{ 0xF0A788BB, 0x5B0B0 },
	{ 0xF0A788BC, 0x6BBE8 },
	{ 0xF0A788BD, 0x5B0AC },
	{ 0xF0A788BE, 0x5B0B3 },
	{ 0xF0A788BF, 0x6BBE7 },
	{ 0xF0A78980, 0x5B0AD },
	{ 0xF0A78981, 0x5B0B2 },
	{ 0xF0A78982, 0x6BBE6 },
	{ 0xF0A78983, 0x4AFEC },
	{ 0xF0A78984, 0x4AFEA },
	{ 0xF0A78985, 0x4AFEE },
	{ 0xF0A78986, 0x5B0AE },
	{ 0xF0A78987, 0x6BBF0 },
	{ 0xF0A78988, 0x5B0A9 },
	{ 0xF0A78989, 0x6BBEB },
	{ 0xF0A7898A, 0x5B0B1 },
	{ 0xF0A7898B, 0x5B0A8 },
	{ 0xF0A7898C, 0x6BBEA },
	{ 0xF0A7898D, 0x5B0AF },
	{ 0xF0A7898E, 0x5B0B4 },
	{ 0xF0A7898F, 0x6BBEE },
	{ 0xF0A78990, 0x6BBE4 },
	{ 0xF0A78991, 0x5B0AB },
	{ 0xF0A78995, 0x6BBE5 },
	{ 0xF0A78996, 0xFB2CF },
	{ 0xF0A78997, 0x6BBEC },
	{ 0xF0A78998, 0x6BBED },
	{ 0xF0A7899B, 0x5B0AA },
	{ 0xF0A7899C, 0x6BBEF },
	{ 0xF0A7899E, 0x5B5B7 },
	{ 0xF0A7899F, 0x4B4FD },
	{ 0xF0A789A0, 0x6C4C5 },
	{ 0xF0A789A1, 0x5B5B8 },
	{ 0xF0A789A2, 0x5B5B9 },
	{ 0xF0A789A3, 0x5B5BA },
	{ 0xF0A789A4, 0x5B5C0 },
	{ 0xF0A789A5, 0x4B5A2 },
	{ 0xF0A789A6, 0xFB8BD },
	{ 0xF0A789A7, 0x4B5A3 },
	{ 0xF0A789A8, 0x6C4CC },
	{ 0xF0A789A9, 0x5B5BC },
	{ 0xF0A789AA, 0x4B5A1 },
	{ 0xF0A789AB, 0x5B5BD },
	{ 0xF0A789AC, 0x6C4C6 },
	{ 0xF0A789AD, 0x5B5C1 },
	{ 0xF0A789AE, 0x6C4C9 },
	{ 0xF0A789AF, 0x4B5A4 },
	{ 0xF0A789B0, 0x4B4FE },
	{ 0xF0A789B3, 0x6C4C7 },
	{ 0xF0A789B4, 0x6C4CA },
	{ 0xF0A789B5, 0x6C4C4 },
	{ 0xF0A789B6, 0x6C4CB },
	{ 0xF0A789B7, 0x6C4CD },
	{ 0xF0A789BB, 0xFB8B6 },
	{ 0xF0A789BC, 0xFB8B7 },
	{ 0xF0A789BD, 0xFB8B8 },
	{ 0xF0A789BE, 0xFB8B9 },
	{ 0xF0A789BF, 0xFB8BB },
	{ 0xF0A78A80, 0xFB8BC },
	{ 0xF0A78A81, 0xFB8BE },
	{ 0xF0A78A82, 0xFB8BF },
	{ 0xF0A78A83, 0xFB8C0 },
	{ 0xF0A78A85, 0x5B5BE },
	{ 0xF0A78A86, 0x6C4CE },
	{ 0xF0A78A87, 0x4B5A5 },
	{ 0xF0A78A88, 0x6C4C3 },
	{ 0xF0A78A8D, 0x5B5BF },
	{ 0xF0A78A8E, 0x5B5BB },
	{ 0xF0A78A8F, 0x5BBF3 },
	{ 0xF0A78A90, 0x6CEC0 },
	{ 0xF0A78A91, 0xFBFA8 },
	{ 0xF0A78A92, 0x4BAF3 },
	{ 0xF0A78A93, 0x6CEC8 },
	{ 0xF0A78A94, 0x5BCA8 },
	{ 0xF0A78A95, 0x5BBF8 },
	{ 0xF0A78A96, 0x5BBF5 },
	{ 0xF0A78A97, 0x5BBF7 },
	{ 0xF0A78A98, 0x5BBFA },
	{ 0xF0A78A99, 0x5BCA3 },
	{ 0xF0A78A9A, 0x5BBFD },
	{ 0xF0A78A9B, 0x6CEC9 },
	{ 0xF0A78A9C, 0x6CEBE },
	{ 0xF0A78A9D, 0x6CEC3 },
	{ 0xF0A78A9E, 0x5BBF6 },
	{ 0xF0A78A9F, 0x5BCA7 },
	{ 0xF0A78AA0, 0x6CEC2 },
	{ 0xF0A78AA1, 0x6CECB },
	{ 0xF0A78AA2, 0x6CECA },
	{ 0xF0A78AA3, 0x5BBFC },
	{ 0xF0A78AA4, 0x6CEBF },
	{ 0xF0A78AA5, 0x5BBF9 },
	{ 0xF0A78AA6, 0x5BCA1 },
	{ 0xF0A78AA7, 0x6CECD },
	{ 0xF0A78AA8, 0x6CEC4 },
	{ 0xF0A78AA9, 0x6CEC5 },
	{ 0xF0A78AAB, 0x6D7EE },
	{ 0xF0A78AAC, 0x5BCA5 },
	{ 0xF0A78AAD, 0x5BBFE },
	{ 0xF0A78AAE, 0x6D7F8 },
	{ 0xF0A78AAF, 0x5BCA4 },
	{ 0xF0A78AB0, 0x6CECC },
	{ 0xF0A78AB1, 0x6CEC7 },
	{ 0xF0A78AB6, 0x5BCA2 },
	{ 0xF0A78AB7, 0x5BBF2 },
	{ 0xF0A78AB8, 0x6CEC1 },
	{ 0xF0A78AB9, 0xFBFA5 },
	{ 0xF0A78ABA, 0xFBFA6 },
	{ 0xF0A78ABB, 0xFBFA7 },
	{ 0xF0A78ABC, 0xFBFA9 },
	{ 0xF0A78ABF, 0x4BAF7 },
	{ 0xF0A78B88, 0x6D7F0 },
	{ 0xF0A78B89, 0x6D7EF },
	{ 0xF0A78B8A, 0x4C0DA },
	{ 0xF0A78B8B, 0x4C0DC },
	{ 0xF0A78B8C, 0x6D7F4 },
	{ 0xF0A78B8D, 0x4C0D4 },
	{ 0xF0A78B8E, 0x5C2D8 },
	{ 0xF0A78B8F, 0x5C2DB },
	{ 0xF0A78B90, 0x5C2D6 },
	{ 0xF0A78B91, 0x4C0D1 },
	{ 0xF0A78B92, 0x4C0D3 },
	{ 0xF0A78B93, 0x5C2DC },
	{ 0xF0A78B94, 0x5C2DE },
	{ 0xF0A78B95, 0x5C2DA },
	{ 0xF0A78B96, 0x5C2D7 },
	{ 0xF0A78B97, 0x4C0DE },
	{ 0xF0A78B98, 0x4C0D0 },
	{ 0xF0A78B99, 0x6D7F2 },
	{ 0xF0A78B9B, 0x6D7F3 },
	{ 0xF0A78B9C, 0x6D7EC },
	{ 0xF0A78B9D, 0x6D7ED },
	{ 0xF0A78B9E, 0x6E1E8 },
	{ 0xF0A78B9F, 0x6D7F1 },
	{ 0xF0A78BA0, 0x6D7F5 },
	{ 0xF0A78BA1, 0x5C2D9 },
	{ 0xF0A78BA7, 0xFC5B2 },
	{ 0xF0A78BA8, 0xFC5B3 },
	{ 0xF0A78BA9, 0xFC5B4 },
	{ 0xF0A78BAA, 0xFC5B5 },
	{ 0xF0A78BAB, 0xFC5B6 },
	{ 0xF0A78BAC, 0xFC5B7 },
	{ 0xF0A78BAD, 0xFC5B8 },
	{ 0xF0A78BAE, 0xFC5B9 },
	{ 0xF0A78BAF, 0x6D7F6 },
	{ 0xF0A78BB0, 0x7C9EB },
	{ 0xF0A78BB3, 0x6D7F7 },
	{ 0xF0A78C81, 0x6D7F9 },
	{ 0xF0A78C83, 0x5C9D1 },
	{ 0xF0A78C84, 0x5C9D6 },
	{ 0xF0A78C85, 0x5C9DB },
	{ 0xF0A78C86, 0x5C9D7 },
	{ 0xF0A78C87, 0x5C9DC },
	{ 0xF0A78C88, 0x4C7A1 },
	{ 0xF0A78C89, 0x5C9D5 },
	{ 0xF0A78C8A, 0x4C6FD },
	{ 0xF0A78C8B, 0x6E2A3 },
	{ 0xF0A78C8C, 0x5C9DF },
	{ 0xF0A78C8D, 0x4C6F7 },
	{ 0xF0A78C8E, 0x5C9D9 },
	{ 0xF0A78C8F, 0x4C6F4 },
	{ 0xF0A78C90, 0x6E1F6 },
	{ 0xF0A78C91, 0x6E1EA },
	{ 0xF0A78C92, 0x6E1F5 },
	{ 0xF0A78C93, 0x4C7A2 },
	{ 0xF0A78C94, 0x5C9DE },
	{ 0xF0A78C95, 0x6E1EB },
	{ 0xF0A78C96, 0x6E1F1 },
	{ 0xF0A78C97, 0x5C9D4 },
	{ 0xF0A78C98, 0x6E1FC },
	{ 0xF0A78C99, 0x5C9DD },
	{ 0xF0A78C9A, 0x5C9D8 },
	{ 0xF0A78C9B, 0x6E1FB },
	{ 0xF0A78C9C, 0x6E2A1 },
	{ 0xF0A78C9D, 0x5C9E0 },
	{ 0xF0A78C9F, 0x6E1F4 },
	{ 0xF0A78CA0, 0x6E1FD },
	{ 0xF0A78CA1, 0x6E1ED },
	{ 0xF0A78CA2, 0x5C9E1 },
	{ 0xF0A78CA3, 0x5C9E2 },
	{ 0xF0A78CA4, 0x6E1F2 },
	{ 0xF0A78CA6, 0x6E2A2 },
	{ 0xF0A78CA7, 0x5C9DA },
	{ 0xF0A78CA8, 0x6E1EC },
	{ 0xF0A78CA9, 0x6E1F9 },
	{ 0xF0A78CAA, 0x6E1FA },
	{ 0xF0A78CAB, 0x6E1F0 },
	{ 0xF0A78CAC, 0x5C9D2 },
	{ 0xF0A78CAD, 0x6E1EE },
	{ 0xF0A78CB4, 0x5C9D3 },
	{ 0xF0A78CB5, 0x6E1F3 },
	{ 0xF0A78CB6, 0xFCCAD },
	{ 0xF0A78CB7, 0xFCCAE },
	{ 0xF0A78CB8, 0xFCCB0 },
	{ 0xF0A78CB9, 0xFCCB1 },
	{ 0xF0A78CBA, 0xFCCB2 },
	{ 0xF0A78CBB, 0x6E1F8 },
	{ 0xF0A78CBD, 0x4C0D8 },
	{ 0xF0A78CBF, 0x6E1FE },
	{ 0xF0A78D91, 0x6E1EF },
	{ 0xF0A78D92, 0x4CDAD },
	{ 0xF0A78D93, 0x7A8C3 },
	{ 0xF0A78D94, 0x5D0D3 },
	{ 0xF0A78D95, 0x4CDAE },
	{ 0xF0A78D96, 0x4CDAB },
	{ 0xF0A78D97, 0x7A8B8 },
	{ 0xF0A78D98, 0x4CDB4 },
	{ 0xF0A78D99, 0x5D0DF },
	{ 0xF0A78D9A, 0x7A8B7 },
	{ 0xF0A78D9B, 0x7A8AC },
	{ 0xF0A78D9C, 0x5D0D1 },
	{ 0xF0A78D9D, 0x7A8AB },
	{ 0xF0A78D9E, 0x7A8B5 },
	{ 0xF0A78D9F, 0x7A8BF },
	{ 0xF0A78DA0, 0x5D0D7 },
	{ 0xF0A78DA1, 0x4CDB2 },
	{ 0xF0A78DA2, 0x4CDAA },
	{ 0xF0A78DA3, 0x7A8C0 },
	{ 0xF0A78DA4, 0x7A8B4 },
	{ 0xF0A78DA5, 0x5D0D6 },
	{ 0xF0A78DA6, 0x7A8BB },
	{ 0xF0A78DA7, 0x7A8B1 },
	{ 0xF0A78DA8, 0x7A8BE },
	{ 0xF0A78DA9, 0x5D7EE },
	{ 0xF0A78DAA, 0x4CDAC },
	{ 0xF0A78DAB, 0x4CDA9 },
	{ 0xF0A78DAC, 0x5D0DC },
	{ 0xF0A78DAD, 0x5D0DA },
	{ 0xF0A78DAE, 0x5D0D0 },
	{ 0xF0A78DAF, 0x5D0D9 },
	{ 0xF0A78DB0, 0x5D0D8 },
	{ 0xF0A78DB1, 0x7A8AA },
	{ 0xF0A78DB2, 0x5D0DB },
	{ 0xF0A78DB3, 0x4C6FA },
	{ 0xF0A78DB4, 0x5D0D2 },
	{ 0xF0A78DB5, 0x5D0DE },
	{ 0xF0A78DB6, 0x5D0DD },
	{ 0xF0A78DB7, 0x4CDB5 },
	{ 0xF0A78DB8, 0x7A8C6 },
	{ 0xF0A78DB9, 0x7A8B0 },
	{ 0xF0A78DBA, 0x7A8AD },
	{ 0xF0A78DBB, 0x7A8C4 },
	{ 0xF0A78DBC, 0x7A8B9 },
	{ 0xF0A78DBD, 0x7A8C5 },
	{ 0xF0A78DBE, 0x7A8BC },
	{ 0xF0A78DBF, 0x7A8AF },
	{ 0xF0A78E80, 0x6E1F7 },
	{ 0xF0A78E81, 0x7A8B6 },
	{ 0xF0A78E82, 0x7A8BD },
	{ 0xF0A78E83, 0x5D0D4 },
	{ 0xF0A78E84, 0x4CDA7 },
	{ 0xF0A78E88, 0x5D0CF },
	{ 0xF0A78E89, 0xFD1FA },
	{ 0xF0A78E8A, 0xFD1FB },
	{ 0xF0A78E8B, 0xFD1FE },
	{ 0xF0A78E8C, 0xFD2A1 },
	{ 0xF0A78E8D, 0xFD2A2 },
	{ 0xF0A78E8E, 0xFD2A3 },
	{ 0xF0A78E8F, 0xFD2A5 },
	{ 0xF0A78E90, 0xFD2A8 },
	{ 0xF0A78E91, 0xFD2A9 },
	{ 0xF0A78E92, 0xFD2AA },
	{ 0xF0A78E93, 0xFD2AB },
	{ 0xF0A78E94, 0x7A8B3 },
	{ 0xF0A78E97, 0x7A8C1 },
	{ 0xF0A78E98, 0x7A8BA },
	{ 0xF0A78E9A, 0xFD2A7 },
	{ 0xF0A78E9E, 0x7A8B2 },
	{ 0xF0A78E9F, 0xFCCAF },
	{ 0xF0A78EA1, 0x5D7F0 },
	{ 0xF0A78EA2, 0x4D3C5 },
	{ 0xF0A78EA3, 0x5D7F6 },
	{ 0xF0A78EA4, 0x5D7F5 },
	{ 0xF0A78EA5, 0x4D3BA },
	{ 0xF0A78EA6, 0x5D7F4 },
	{ 0xF0A78EA8, 0x5D7F1 },
	{ 0xF0A78EA9, 0x7B2EE },
	{ 0xF0A78EAA, 0x7B2FD },
	{ 0xF0A78EAB, 0x5D7F7 },
	{ 0xF0A78EAC, 0x4D3C8 },
	{ 0xF0A78EAD, 0x5D7FB },
	{ 0xF0A78EAE, 0x4D3C9 },
	{ 0xF0A78EAF, 0x4D3C0 },
	{ 0xF0A78EB0, 0x4D3C2 },
	{ 0xF0A78EB1, 0x5D7FC },
	{ 0xF0A78EB2, 0x7B2ED },
	{ 0xF0A78EB3, 0x4D3BB },
	{ 0xF0A78EB4, 0x7B2E7 },
	{ 0xF0A78EB5, 0x4D3BF },
	{ 0xF0A78EB6, 0x7B2FC },
	{ 0xF0A78EB7, 0x5D7F9 },
	{ 0xF0A78EB8, 0x5D7EF },
	{ 0xF0A78EB9, 0x5D8A1 },
	{ 0xF0A78EBA, 0x5D7F2 },
	{ 0xF0A78EBB, 0x7BBBA },
	{ 0xF0A78EBC, 0x5D7F8 },
	{ 0xF0A78EBD, 0x7B2E9 },
	{ 0xF0A78EBE, 0x4D3C6 },
	{ 0xF0A78EBF, 0x5D7FA },
	{ 0xF0A78F80, 0x7B2F0 },
	{ 0xF0A78F81, 0x7B3A2 },
	{ 0xF0A78F82, 0x5D7F3 },
	{ 0xF0A78F83, 0x7B2E4 },
	{ 0xF0A78F84, 0x5D7FE },
	{ 0xF0A78F85, 0x7B2F4 },
	{ 0xF0A78F86, 0x4D3C7 },
	{ 0xF0A78F87, 0x5D0E0 },
	{ 0xF0A78F88, 0x7B2EB },
	{ 0xF0A78F89, 0x7B2E5 },
	{ 0xF0A78F8A, 0x5D7FD },
	{ 0xF0A78F8B, 0x7B2F6 },
	{ 0xF0A78F8C, 0x4D3C3 },
	{ 0xF0A78F8D, 0x7B2FB },
	{ 0xF0A78F8E, 0x7B3A4 },
	{ 0xF0A78F8F, 0x7B2E2 },
	{ 0xF0A78F90, 0x7B2F7 },
	{ 0xF0A78F91, 0x7B2E3 },
	{ 0xF0A78F92, 0x7B2F8 },
	{ 0xF0A78F93, 0x7B2EF },
	{ 0xF0A78F94, 0x7B2FE },
	{ 0xF0A78F95, 0x7B2F2 },
	{ 0xF0A78F9C, 0x7B2E8 },
	{ 0xF0A78F9D, 0x7B3A3 },
	{ 0xF0A78F9E, 0xFD7E0 },
	{ 0xF0A78F9F, 0xFD7E1 },
	{ 0xF0A78FA0, 0xFD7E3 },
	{ 0xF0A78FA1, 0xFD7E4 },
	{ 0xF0A78FA2, 0xFD7E5 },
	{ 0xF0A78FA3, 0xFD7E6 },
	{ 0xF0A78FA4, 0x7B2F9 },
	{ 0xF0A78FA6, 0x7B2EA },
	{ 0xF0A78FA8, 0x7B2FA },
	{ 0xF0A78FA9, 0x7B2F1 },
	{ 0xF0A78FAA, 0x7B2E6 },
	{ 0xF0A78FAC, 0x7B2EC },
	{ 0xF0A78FB8, 0x4D8D9 },
	{ 0xF0A78FB9, 0x5DEA9 },
	{ 0xF0A78FBA, 0x5DEAC },
	{ 0xF0A78FBB, 0x4D8D5 },
	{ 0xF0A78FBC, 0x7BBD2 },
	{ 0xF0A78FBD, 0x7BBC4 },
	{ 0xF0A78FBE, 0x4D8E0 },
	{ 0xF0A78FBF, 0x4D8DC },
	{ 0xF0A79080, 0x7BBC8 },
	{ 0xF0A79081, 0x7BBC2 },
	{ 0xF0A79082, 0x7BBD5 },
	{ 0xF0A79084, 0x4D8DE },
	{ 0xF0A79085, 0x7BBC6 },
	{ 0xF0A79086, 0x7A8C7 },
	{ 0xF0A79087, 0x4D8D0 },
	{ 0xF0A79088, 0x5DEB1 },
	{ 0xF0A79089, 0x7BBD0 },
	{ 0xF0A7908A, 0x7BBBF },
	{ 0xF0A7908B, 0x4D8DD },
	{ 0xF0A7908C, 0x7BBCF },
	{ 0xF0A7908D, 0x5DEAB },
	{ 0xF0A7908E, 0x5DEAF },
	{ 0xF0A7908F, 0x7BBD3 },
	{ 0xF0A79090, 0x4D8DA },
	{ 0xF0A79091, 0x7BBC7 },
	{ 0xF0A79092, 0x7BBC1 },
	{ 0xF0A79093, 0x5DEB3 },
	{ 0xF0A79094, 0x4D8D3 },
	{ 0xF0A79095, 0x7BBC0 },
	{ 0xF0A79096, 0x4D8D1 },
	{ 0xF0A79097, 0x7BBBE },
	{ 0xF0A79098, 0x7BBD4 },
	{ 0xF0A79099, 0x5DEAA },
	{ 0xF0A7909A, 0x7BBBC },
	{ 0xF0A7909B, 0x7BBBB },
	{ 0xF0A7909C, 0x7BBC9 },
	{ 0xF0A7909D, 0x4D8DB },
	{ 0xF0A7909E, 0x5DEAD },
	{ 0xF0A7909F, 0x5DEAE },
	{ 0xF0A790A3, 0x7BBC5 },
	{ 0xF0A790A4, 0xFDCD4 },
	{ 0xF0A790A5, 0xFDCD5 },
	{ 0xF0A790A6, 0xFDCD6 },
	{ 0xF0A790A7, 0xFDCD7 },
	{ 0xF0A790A8, 0xFDCD8 },
	{ 0xF0A790A9, 0xFDCD9 },
	{ 0xF0A790AA, 0xFDCDA },
	{ 0xF0A790AB, 0xFDCDC },
	{ 0xF0A790AD, 0x7BBC3 },
	{ 0xF0A790AE, 0x7BBCB },
	{ 0xF0A790AF, 0x7BBCE },
	{ 0xF0A790B1, 0x7BBD1 },
	{ 0xF0A790B3, 0x7BBBD },
	{ 0xF0A790B4, 0x5DEA8 },
	{ 0xF0A790B5, 0x7BBCA },
	{ 0xF0A790B6, 0x7BBCC },
	{ 0xF0A79180, 0x5DEB0 },
	{ 0xF0A79184, 0x4DDBD },
	{ 0xF0A79185, 0x4DDB7 },
	{ 0xF0A79186, 0x7C2D5 },
	{ 0xF0A79187, 0x7C2E1 },
	{ 0xF0A79188, 0x7C2D8 },
	{ 0xF0A79189, 0x7C2E8 },
	{ 0xF0A7918A, 0x5E4C3 },
	{ 0xF0A7918B, 0x5E4C4 },
	{ 0xF0A7918C, 0x5DEB4 },
	{ 0xF0A7918D, 0x4DDB8 },
	{ 0xF0A7918E, 0x5E4D0 },
	{ 0xF0A7918F, 0x7C2D9 },
	{ 0xF0A79190, 0x4DDB6 },
	{ 0xF0A79191, 0x5E4C5 },
	{ 0xF0A79192, 0x4DDB5 },
	{ 0xF0A79193, 0x4DDBA },
	{ 0xF0A79194, 0x5E4BF },
	{ 0xF0A79195, 0x5E4C2 },
	{ 0xF0A79196, 0x5E4CD },
	{ 0xF0A79197, 0x4DDB4 },
	{ 0xF0A79198, 0x5E4CA },
	{ 0xF0A79199, 0x7C2D6 },
	{ 0xF0A7919A, 0x5E4BE },
	{ 0xF0A7919C, 0x5E4C1 },
	{ 0xF0A7919D, 0x5E4CB },
	{ 0xF0A7919E, 0x7C2D7 },
	{ 0xF0A7919F, 0x7C2DC },
	{ 0xF0A791A0, 0x7C2DB },
	{ 0xF0A791A1, 0x5E4C0 },
	{ 0xF0A791A2, 0x7C2EF },
	{ 0xF0A791A3, 0x7C2EB },
	{ 0xF0A791A4, 0x5E4CF },
	{ 0xF0A791A5, 0x7C2EE },
	{ 0xF0A791A6, 0x5E4C9 },
	{ 0xF0A791A7, 0x5E4CC },
	{ 0xF0A791A8, 0x7C2E9 },
	{ 0xF0A791A9, 0x5E4C6 },
	{ 0xF0A791AA, 0x7C2EC },
	{ 0xF0A791AB, 0x5E4C7 },
	{ 0xF0A791AC, 0x7C2E5 },
	{ 0xF0A791AD, 0x7C2E2 },
	{ 0xF0A791AE, 0x7C2DD },
	{ 0xF0A791AF, 0x7C2E3 },
	{ 0xF0A791B0, 0x7C2D4 },
	{ 0xF0A791B1, 0x7C2DA },
	{ 0xF0A791B2, 0x7C2D3 },
	{ 0xF0A791B3, 0x7C2DE },
	{ 0xF0A791B4, 0x7C2EA },
	{ 0xF0A791B8, 0x7C2E6 },
	{ 0xF0A791B9, 0xFE0E2 },
	{ 0xF0A791BA, 0xFE0E4 },
	{ 0xF0A791BB, 0xFE0E5 },
	{ 0xF0A791BC, 0xFE0E6 },
	{ 0xF0A791BD, 0xFE0E8 },
	{ 0xF0A791BE, 0xFE0E9 },
	{ 0xF0A791BF, 0xFE0EA },
	{ 0xF0A79281, 0x7C2E4 },
	{ 0xF0A79282, 0x4DDBC },
	{ 0xF0A79283, 0x7C2E7 },
	{ 0xF0A79284, 0xFE0E7 },
	{ 0xF0A79286, 0xFE0E1 },
	{ 0xF0A79288, 0x5E4CE },
	{ 0xF0A7928E, 0x4E1A8 },
	{ 0xF0A7928F, 0x7C9EA },
	{ 0xF0A79290, 0x7C9D9 },
	{ 0xF0A79291, 0x7C9E0 },
	{ 0xF0A79292, 0x7C9EC },
	{ 0xF0A79293, 0x7C9DA },
	{ 0xF0A79294, 0x7C9E9 },
	{ 0xF0A79295, 0x7C9ED },
	{ 0xF0A79296, 0x4E1A3 },
	{ 0xF0A79297, 0x5E9C2 },
	{ 0xF0A79298, 0x5E9C0 },
	{ 0xF0A7929A, 0x7C9E2 },
	{ 0xF0A7929B, 0x7C9E7 },
	{ 0xF0A7929C, 0x7C9E5 },
	{ 0xF0A7929D, 0x5E9C4 },
	{ 0xF0A7929E, 0x7C9DD },
	{ 0xF0A7929F, 0x7C9E8 },
	{ 0xF0A792A1, 0x7C9E4 },
	{ 0xF0A792A2, 0x7C9E6 },
	{ 0xF0A792A3, 0x7CFEB },
	{ 0xF0A792A4, 0x7C9E1 },
	{ 0xF0A792A5, 0x7C9EE },
	{ 0xF0A792A6, 0x7C9EF },
	{ 0xF0A792A7, 0x7C9E3 },
	{ 0xF0A792A8, 0x5E9C5 },
	{ 0xF0A792A9, 0x7C9DC },
	{ 0xF0A792AA, 0x7C9DF },
	{ 0xF0A792AB, 0x7C9D8 },
	{ 0xF0A792B2, 0xFE3EB },
	{ 0xF0A792B3, 0xFE3EC },
	{ 0xF0A792B4, 0xFE3ED },
	{ 0xF0A792B5, 0xFE3EF },
	{ 0xF0A792B6, 0xFE3F0 },
	{ 0xF0A792B7, 0xFE3F1 },
	{ 0xF0A792B8, 0xFE3F2 },
	{ 0xF0A792B9, 0xFE3F3 },
	{ 0xF0A792BA, 0xFE3F4 },
	{ 0xF0A792BB, 0xFE3F5 },
	{ 0xF0A792BC, 0x7C9DB },
	{ 0xF0A792BD, 0x4E1A2 },
	{ 0xF0A792BE, 0x4E1A7 },
	{ 0xF0A792BF, 0x7C9DE },
	{ 0xF0A79388, 0x7C2F0 },
	{ 0xF0A79389, 0x7CFF5 },
	{ 0xF0A7938A, 0x7CFFA },
	{ 0xF0A7938B, 0x5EDCD },
	{ 0xF0A7938C, 0x7CFEC },
	{ 0xF0A7938E, 0x4E4C2 },
	{ 0xF0A7938F, 0x5EDCC },
	{ 0xF0A79390, 0x5EDD1 },
	{ 0xF0A79391, 0x7CFF8 },
	{ 0xF0A79392, 0x7CFF0 },
	{ 0xF0A79393, 0x5EDD0 },
	{ 0xF0A79394, 0x7CFF4 },
	{ 0xF0A79395, 0x5EDD2 },
	{ 0xF0A79396, 0x5EDD3 },
	{ 0xF0A79397, 0x7CFF3 },
	{ 0xF0A79398, 0x5EDCE },
	{ 0xF0A79399, 0x7CFF2 },
	{ 0xF0A7939A, 0x7CFF7 },
	{ 0xF0A7939B, 0x7CFF1 },
	{ 0xF0A7939C, 0x7CFED },
	{ 0xF0A7939D, 0x5EDCF },
	{ 0xF0A7939E, 0x7CFEF },
	{ 0xF0A7939F, 0x7D4F7 },
	{ 0xF0A793A1, 0x7CFEE },
	{ 0xF0A793A2, 0x7CFFB },
	{ 0xF0A793A3, 0xFE6AD },
	{ 0xF0A793A4, 0xFE6AE },
	{ 0xF0A793A5, 0xFE6AF },
	{ 0xF0A793A6, 0xFE6B0 },
	{ 0xF0A793A7, 0xFE6B1 },
	{ 0xF0A793AB, 0x7CFF6 },
	{ 0xF0A793AC, 0x4E7AF },
	{ 0xF0A793B1, 0x4E7B4 },
	{ 0xF0A793B2, 0x7D4EB },
	{ 0xF0A793B3, 0x7D4F0 },
	{ 0xF0A793B4, 0x5F1AF },
	{ 0xF0A793B5, 0x7D4F5 },
	{ 0xF0A793B6, 0x7D4EE },
	{ 0xF0A793B7, 0x7D4F1 },
	{ 0xF0A793B8, 0x5F1AE },
	{ 0xF0A793B9, 0x7D4F3 },
	{ 0xF0A793BA, 0x5F1AD },
	{ 0xF0A793BB, 0x5F1B0 },
	{ 0xF0A793BC, 0x7D4EC },
	{ 0xF0A793BD, 0x4E7B3 },
	{ 0xF0A793BE, 0x7D4EF },
	{ 0xF0A793BF, 0x4E7B5 },
	{ 0xF0A79480, 0x4E7B1 },
	{ 0xF0A79481, 0x7D4F2 },
	{ 0xF0A79482, 0x5F1B2 },
	{ 0xF0A79483, 0x7D4F8 },
	{ 0xF0A79484, 0x7CFF9 },
	{ 0xF0A79486, 0x7D4F4 },
	{ 0xF0A79487, 0x4E7B2 },
	{ 0xF0A79488, 0x7D4F9 },
	{ 0xF0A7948E, 0x5F1B1 },
	{ 0xF0A7948F, 0x5F1B3 },
	{ 0xF0A79490, 0x7D4F6 },
	{ 0xF0A79491, 0xFE8C5 },
	{ 0xF0A79492, 0xFE8C6 },
	{ 0xF0A79493, 0xFE8C7 },
	{ 0xF0A79494, 0xFE8C8 },
	{ 0xF0A79495, 0xFE8C9 },
	{ 0xF0A79498, 0x7D4ED },
	{ 0xF0A7949D, 0x5F4AE },
	{ 0xF0A7949E, 0x4E9BC },
	{ 0xF0A7949F, 0x5F4AC },
	{ 0xF0A794A0, 0x5F4AB },
	{ 0xF0A794A1, 0x7D9A3 },
	{ 0xF0A794A2, 0x7D8FC },
	{ 0xF0A794A3, 0x5F4AD },
	{ 0xF0A794A4, 0x5F4B1 },
	{ 0xF0A794A5, 0x5F4B0 },
	{ 0xF0A794A6, 0x7D8FA },
	{ 0xF0A794A7, 0x5F4B3 },
	{ 0xF0A794A8, 0x5F4B5 },
	{ 0xF0A794AA, 0x5F4B2 },
	{ 0xF0A794AB, 0x7D8F9 },
	{ 0xF0A794AC, 0x4E9BD },
	{ 0xF0A794AE, 0x7D9A6 },
	{ 0xF0A794AF, 0x7D9A8 },
	{ 0xF0A794B0, 0x7D9A7 },
	{ 0xF0A794B1, 0x7D8FE },
	{ 0xF0A794B2, 0x7D9A1 },
	{ 0xF0A794B3, 0x5F4B4 },
	{ 0xF0A794B4, 0x5F4B6 },
	{ 0xF0A794B5, 0x7D9A4 },
	{ 0xF0A794B6, 0x7D9A9 },
	{ 0xF0A794B7, 0x5F4AF },
	{ 0xF0A794BA, 0x7D8FD },
	{ 0xF0A794BD, 0x7D8FB },
	{ 0xF0A79581, 0xFE9ED },
	{ 0xF0A79582, 0xFE9EE },
	{ 0xF0A79583, 0x5F6C6 },
	{ 0xF0A79584, 0x4EAF6 },
	{ 0xF0A79585, 0x4EAF7 },
	{ 0xF0A79586, 0x7DCDD },
	{ 0xF0A79587, 0x5F6C7 },
	{ 0xF0A79588, 0x4EAF9 },
	{ 0xF0A79589, 0x7DCDF },
	{ 0xF0A7958A, 0x7DCDC },
	{ 0xF0A7958B, 0x5F6C8 },
	{ 0xF0A7958C, 0x7DCE2 },
	{ 0xF0A7958D, 0x5F6C5 },
	{ 0xF0A7958E, 0x7DFCA },
	{ 0xF0A7958F, 0x7DCE0 },
	{ 0xF0A79590, 0x4EAFA },
	{ 0xF0A79591, 0x7DCE1 },
	{ 0xF0A79592, 0x5F6CA },
	{ 0xF0A79594, 0x7D9A2 },
	{ 0xF0A79595, 0x5F6C9 },
	{ 0xF0A79596, 0xFEAF0 },
	{ 0xF0A79597, 0xFEAF1 },
	{ 0xF0A79598, 0xFEAF2 },
	{ 0xF0A7959B, 0x5F8AC },
	{ 0xF0A7959C, 0x7DFCB },
	{ 0xF0A7959D, 0x4EBFE },
	{ 0xF0A7959E, 0x5F8AB },
	{ 0xF0A7959F, 0x5F8A9 },
	{ 0xF0A795A0, 0x7DFCC },
	{ 0xF0A795A1, 0x5F8A6 },
	{ 0xF0A795A2, 0x4ECA2 },
	{ 0xF0A795A3, 0x7DFCD },
	{ 0xF0A795A4, 0x5F8AA },
	{ 0xF0A795A5, 0x5F8A8 },
	{ 0xF0A795A6, 0x4ECA4 },
	{ 0xF0A795A7, 0x5F8AD },
	{ 0xF0A795A8, 0x5F8A7 },
	{ 0xF0A795AE, 0x5F9C4 },
	{ 0xF0A795AF, 0x4ECFE },
	{ 0xF0A795B0, 0x5F9C8 },
	{ 0xF0A795B1, 0x5F9CA },
	{ 0xF0A795B2, 0x4ECA1 },
	{ 0xF0A795B3, 0x7E1C0 },
	{ 0xF0A795B4, 0x5F9C6 },
	{ 0xF0A795B5, 0x7E1C4 },
	{ 0xF0A795B6, 0x7E1C3 },
	{ 0xF0A795B7, 0x7E1C5 },
	{ 0xF0A795B8, 0x5F9C7 },
	{ 0xF0A795B9, 0x5F9C9 },
	{ 0xF0A795BA, 0x7E1C1 },
	{ 0xF0A795BC, 0x5F9C5 },
	{ 0xF0A795BD, 0x7E2DD },
	{ 0xF0A795BE, 0x7E2DB },
	{ 0xF0A795BF, 0x7E2DE },
	{ 0xF0A79680, 0x7E2DC },
	{ 0xF0A79682, 0x7E2DF },
	{ 0xF0A79684, 0x7E3EE },
	{ 0xF0A79685, 0x7E3EC },
	{ 0xF0A79686, 0x5FAF3 },
	{ 0xF0A79687, 0x7E3EB },
	{ 0xF0A79688, 0x7E3EF },
	{ 0xF0A7968A, 0x7E2DA },
	{ 0xF0A7968B, 0x7E3E9 },
	{ 0xF0A7968C, 0x7E3F1 },
	{ 0xF0A7968D, 0x7E3EA },
	{ 0xF0A7968E, 0x7E3F0 },
	{ 0xF0A7968F, 0x7E3ED },
	{ 0xF0A79691, 0x7E4DC },
	{ 0xF0A79692, 0x4EEBA },
	{ 0xF0A79693, 0x7E4DD },
	{ 0xF0A79694, 0x5FBC7 },
	{ 0xF0A79695, 0x5FBC8 },
	{ 0xF0A79696, 0x7E4DA },
	{ 0xF0A79697, 0x7E4DB },
	{ 0xF0A79698, 0x5FBE7 },
	{ 0xF0A79699, 0x7E5C1 },
	{ 0xF0A7969A, 0x7E5C2 },
	{ 0xF0A7969B, 0x5FBE8 },
	{ 0xF0A7969C, 0x4EED0 },
	{ 0xF0A7969D, 0x7E5E2 },
	{ 0xF0A7969E, 0x7E5E1 },
	{ 0xF0A7969F, 0xFEDB1 },
	{ 0xF0A796A4, 0x7E6AB },
	{ 0xF0A796A7, 0x5A7E5 },
	{ 0xF0A796A8, 0x6AEA7 },
	{ 0xF0A796A9, 0x6AEA6 },
	{ 0xF0A796AA, 0x4ABC4 },
	{ 0xF0A796AB, 0x6BBF2 },
	{ 0xF0A796AC, 0x5B0B5 },
	{ 0xF0A796AD, 0x6BBF5 },
	{ 0xF0A796AF, 0x6BBF4 },
	{ 0xF0A796B2, 0xFB8C1 },
	{ 0xF0A796B3, 0x6CECE },
	{ 0xF0A796B4, 0x6CED0 },
	{ 0xF0A796B5, 0x5C2DF },
	{ 0xF0A796B6, 0x6D7FC },
	{ 0xF0A796B7, 0x6D7FA },
	{ 0xF0A796B8, 0x6D7FD },
	{ 0xF0A796B9, 0x6D7FB },
	{ 0xF0A796BA, 0x5C9E5 },
	{ 0xF0A796BB, 0x5C9E3 },
	{ 0xF0A796BC, 0x5C9E4 },
	{ 0xF0A796BD, 0x6E2A6 },
	{ 0xF0A796BE, 0x6E2A4 },
	{ 0xF0A79780, 0x7A8C8 },
	{ 0xF0A79781, 0x5D0E1 },
	{ 0xF0A79782, 0x7A8C9 },
	{ 0xF0A79783, 0x7A8CA },
	{ 0xF0A79784, 0x6E2A5 },
	{ 0xF0A79786, 0x5D8A3 },
	{ 0xF0A79787, 0x5D8A4 },
	{ 0xF0A79788, 0x5D8A2 },
	{ 0xF0A79789, 0x7B3A5 },
	{ 0xF0A7978A, 0x7B3A6 },
	{ 0xF0A7978B, 0x5DEB7 },
	{ 0xF0A7978C, 0x5DEB6 },
	{ 0xF0A7978D, 0xFDCDD },
	{ 0xF0A7978E, 0x4DDBE },
	{ 0xF0A7978F, 0x4DDBF },
	{ 0xF0A79790, 0x7C2F1 },
	{ 0xF0A79791, 0x7C2F3 },
	{ 0xF0A79792, 0x4DDC0 },
	{ 0xF0A79794, 0x7C2F2 },
	{ 0xF0A79795, 0x5E9C6 },
	{ 0xF0A79796, 0x5EDD4 },
	{ 0xF0A79797, 0x7CFFC },
	{ 0xF0A79798, 0x7D4FA },
	{ 0xF0A79799, 0x7D9AB },
	{ 0xF0A7979A, 0x7D9AA },
	{ 0xF0A7979B, 0x7DFCE },
	{ 0xF0A7979C, 0x7E5E3 },
	{ 0xF0A7979D, 0x4A8A3 },
	{ 0xF0A7979E, 0x6AEA8 },
	{ 0xF0A7979F, 0x4A8A4 },
	{ 0xF0A797A1, 0x6B4CF },
	{ 0xF0A797A2, 0x6B4D0 },
	{ 0xF0A797A3, 0x5ABC1 },
	{ 0xF0A797A5, 0xFADC5 },
	{ 0xF0A797A6, 0x5B0B6 },
	{ 0xF0A797A7, 0x6BBF7 },
	{ 0xF0A797A8, 0x6BBF6 },
	{ 0xF0A797A9, 0x5B0B7 },
	{ 0xF0A797AA, 0x6C4CF },
	{ 0xF0A797AB, 0x5BCA9 },
	{ 0xF0A797AC, 0x6CED3 },
	{ 0xF0A797AD, 0x6CED2 },
	{ 0xF0A797AE, 0xFBFAA },
	{ 0xF0A797AF, 0xFBFAB },
	{ 0xF0A797B1, 0x6CED1 },
	{ 0xF0A797B2, 0x6D8A3 },
	{ 0xF0A797B3, 0x6D8A1 },
	{ 0xF0A797B4, 0x4C0DF },
	{ 0xF0A797B5, 0x6D8A2 },
	{ 0xF0A797B6, 0x6D7FE },
	{ 0xF0A797B7, 0xFC5BA },
	{ 0xF0A797B8, 0x4C7A4 },
	{ 0xF0A797B9, 0x5D0E2 },
	{ 0xF0A797BA, 0x6E2A7 },
	{ 0xF0A797BB, 0x6E2A8 },
	{ 0xF0A797BF, 0x4D8E1 },
	{ 0xF0A79880, 0x7BBD6 },
	{ 0xF0A79881, 0xFDCDE },
	{ 0xF0A79882, 0x4DDC1 },
	{ 0xF0A79883, 0x7C2F4 },
	{ 0xF0A79884, 0x7C9F0 },
	{ 0xF0A79885, 0x7D4FB },
	{ 0xF0A79886, 0x7DCE4 },
	{ 0xF0A79888, 0x5A7E6 },
	{ 0xF0A79889, 0x6AEA9 },
	{ 0xF0A7988A, 0x6AEAA },
	{ 0xF0A7988B, 0x6AEAB },
	{ 0xF0A7988D, 0x5ABC3 },
	{ 0xF0A7988E, 0x6B4D1 },
	{ 0xF0A7988F, 0x4ABC5 },
	{ 0xF0A79890, 0x4ABC7 },
	{ 0xF0A79891, 0x5ABC5 },
	{ 0xF0A79892, 0x6B4D3 },
	{ 0xF0A79893, 0x5ABC4 },
	{ 0xF0A79896, 0xFA8EB },
	{ 0xF0A79899, 0x6B4D2 },
	{ 0xF0A7989A, 0x5ABC2 },
	{ 0xF0A7989C, 0x5ABC6 },
	{ 0xF0A7989D, 0x6BBFD },
	{ 0xF0A7989E, 0x5B0BC },
	{ 0xF0A7989F, 0x4AFF1 },
	{ 0xF0A798A0, 0x6BCA1 },
	{ 0xF0A798A1, 0x6BCA5 },
	{ 0xF0A798A2, 0x5B0BF },
	{ 0xF0A798A3, 0x6BCA6 },
	{ 0xF0A798A4, 0x6BCA7 },
	{ 0xF0A798A5, 0x4AFF0 },
	{ 0xF0A798A6, 0x6BBF9 },
	{ 0xF0A798A7, 0x5B0C0 },
	{ 0xF0A798A8, 0x6BBFB },
	{ 0xF0A798A9, 0x5B0B8 },
	{ 0xF0A798AA, 0x6BCA2 },
	{ 0xF0A798AB, 0x6BBFC },
	{ 0xF0A798AC, 0x6BCA3 },
	{ 0xF0A798AD, 0x6BBFE },
	{ 0xF0A798AE, 0x5B0BB },
	{ 0xF0A798AF, 0x6BBFA },
	{ 0xF0A798B0, 0x6BBF8 },
	{ 0xF0A798B3, 0x5B0BA },
	{ 0xF0A798B4, 0xFB2D0 },
	{ 0xF0A798B5, 0x6BCA4 },
	{ 0xF0A798B6, 0x6BCA8 },
	{ 0xF0A798B7, 0x6BCA9 },
	{ 0xF0A798BA, 0xFADC8 },
	{ 0xF0A798BB, 0xFADC9 },
	{ 0xF0A798BC, 0xFB2D2 },
	{ 0xF0A798BD, 0x4B5A8 },
	{ 0xF0A798BE, 0x5BCB2 },
	{ 0xF0A79980, 0x4B5AB },
	{ 0xF0A79981, 0x4BAFC },
	{ 0xF0A79982, 0x5B5C6 },
	{ 0xF0A79983, 0x4B5A9 },
	{ 0xF0A79984, 0x6C4D8 },
	{ 0xF0A79985, 0x5B5C7 },
	{ 0xF0A79986, 0x5B5CA },
	{ 0xF0A79987, 0x5B5C4 },
	{ 0xF0A79988, 0x5B5C5 },
	{ 0xF0A79989, 0x5B5C3 },
	{ 0xF0A7998A, 0x6C4D9 },
	{ 0xF0A7998B, 0x6C4DA },
	{ 0xF0A7998C, 0x5B5C2 },
	{ 0xF0A7998D, 0x6C4D3 },
	{ 0xF0A7998E, 0x6C4D5 },
	{ 0xF0A7998F, 0x6C4D4 },
	{ 0xF0A79990, 0x6C4D1 },
	{ 0xF0A79991, 0x6C4D0 },
	{ 0xF0A79992, 0x6C4D7 },
	{ 0xF0A79998, 0x6C4D2 },
	{ 0xF0A79999, 0xFADC6 },
	{ 0xF0A7999A, 0xFB8C5 },
	{ 0xF0A7999B, 0x5B5C8 },
	{ 0xF0A7999C, 0x6C4D6 },
	{ 0xF0A7999D, 0x5B5C9 },
	{ 0xF0A7999E, 0x5BCB1 },
	{ 0xF0A7999F, 0x6CEDB },
	{ 0xF0A799A0, 0x6CED9 },
	{ 0xF0A799A1, 0x5BCAE },
	{ 0xF0A799A2, 0x6CED7 },
	{ 0xF0A799A3, 0x5BCAF },
	{ 0xF0A799A4, 0x5BCB3 },
	{ 0xF0A799A5, 0x4BAFE },
	{ 0xF0A799A7, 0x6CED8 },
	{ 0xF0A799A8, 0x6CED4 },
	{ 0xF0A799A9, 0x4BAFD },
	{ 0xF0A799AA, 0x6CED6 },
	{ 0xF0A799AB, 0x5BCB0 },
	{ 0xF0A799AC, 0x5BCAD },
	{ 0xF0A799AD, 0x5BCAB },
	{ 0xF0A799AE, 0x5C2E4 },
	{ 0xF0A799AF, 0x5BCAA },
	{ 0xF0A799B2, 0xFB8C4 },
	{ 0xF0A799B3, 0xFBFAE },
	{ 0xF0A799B5, 0x6CED5 },
	{ 0xF0A799B7, 0x6CEDA },
	{ 0xF0A799B9, 0x6CEDC },
	{ 0xF0A799BE, 0x5BCAC },
	{ 0xF0A799BF, 0xFB8C3 },
	{ 0xF0A79A80, 0x5C2EA },
	{ 0xF0A79A81, 0x5C2E2 },
	{ 0xF0A79A82, 0x5C2E6 },
	{ 0xF0A79A83, 0x4C0E5 },
	{ 0xF0A79A84, 0x5C2EB },
	{ 0xF0A79A85, 0x5C2E3 },
	{ 0xF0A79A86, 0x5C2E7 },
	{ 0xF0A79A87, 0x4C0E3 },
	{ 0xF0A79A88, 0x5C2E5 },
	{ 0xF0A79A89, 0x5C2E9 },
	{ 0xF0A79A8A, 0x6D8AF },
	{ 0xF0A79A8B, 0x4C0E4 },
	{ 0xF0A79A8C, 0x6D8AA },
	{ 0xF0A79A8D, 0x6D8A8 },
	{ 0xF0A79A8E, 0x6D8B0 },
	{ 0xF0A79A8F, 0x5C2E8 },
	{ 0xF0A79A90, 0x5C2E0 },
	{ 0xF0A79A91, 0x6D8A4 },
	{ 0xF0A79A92, 0x6D8A7 },
	{ 0xF0A79A95, 0x6D8AD },
	{ 0xF0A79A96, 0xFBFAC },
	{ 0xF0A79A97, 0xFBFAD },
	{ 0xF0A79A98, 0xFBFAF },
	{ 0xF0A79A99, 0xFBFB0 },
	{ 0xF0A79A9A, 0xFC5BB },
	{ 0xF0A79A9B, 0x6D8A6 },
	{ 0xF0A79A9C, 0x6D8B1 },
	{ 0xF0A79A9D, 0x6D8A5 },
	{ 0xF0A79A9E, 0x6D8A9 },
	{ 0xF0A79AA1, 0x5C2E1 },
	{ 0xF0A79AA3, 0xFC5BE },
	{ 0xF0A79AA4, 0x4C7B0 },
	{ 0xF0A79AA5, 0x4C7AC },
	{ 0xF0A79AA6, 0x6E2AD },
	{ 0xF0A79AA7, 0x6E2B3 },
	{ 0xF0A79AA8, 0x4C7A9 },
	{ 0xF0A79AA9, 0x5C9E6 },
	{ 0xF0A79AAA, 0x5C9E9 },
	{ 0xF0A79AAB, 0x4C7A8 },
	{ 0xF0A79AAC, 0x5C9E8 },
	{ 0xF0A79AAD, 0x5BCB4 },
	{ 0xF0A79AAE, 0x6E2B4 },
	{ 0xF0A79AAF, 0x5C9EA },
	{ 0xF0A79AB0, 0x6E2AB },
	{ 0xF0A79AB1, 0x6E2A9 },
	{ 0xF0A79AB2, 0x6E2AA },
	{ 0xF0A79AB3, 0x6E2B2 },
	{ 0xF0A79AB4, 0x6E2B1 },
	{ 0xF0A79AB5, 0x5C9E7 },
	{ 0xF0A79AB6, 0x6E2AF },
	{ 0xF0A79AB7, 0x5C9EB },
	{ 0xF0A79AB8, 0x6E2B0 },
	{ 0xF0A79AB9, 0x6E2AC },
	{ 0xF0A79ABA, 0x4C7B3 },
	{ 0xF0A79ABC, 0x6E2B5 },
	{ 0xF0A79ABD, 0x6E2AE },
	{ 0xF0A79ABE, 0xFCCB4 },
	{ 0xF0A79ABF, 0xFCCB6 },
	{ 0xF0A79B80, 0xFCCB7 },
	{ 0xF0A79B83, 0x4C7AF },
	{ 0xF0A79B8D, 0xFC5BC },
	{ 0xF0A79B8E, 0xFC5BF },
	{ 0xF0A79B8F, 0x5D0E6 },
	{ 0xF0A79B90, 0x7A8D4 },
	{ 0xF0A79B91, 0x4CDC1 },
	{ 0xF0A79B92, 0x5D0E9 },
	{ 0xF0A79B93, 0x7A8D7 },
	{ 0xF0A79B94, 0x4C7B2 },
	{ 0xF0A79B95, 0x7A8D6 },
	{ 0xF0A79B96, 0x5D0E5 },
	{ 0xF0A79B97, 0x4CDB8 },
	{ 0xF0A79B98, 0x7A8D5 },
	{ 0xF0A79B99, 0x7B3A8 },
	{ 0xF0A79B9A, 0x5D0E7 },
	{ 0xF0A79B9B, 0x7A8DA },
	{ 0xF0A79B9C, 0x7A8CB },
	{ 0xF0A79B9D, 0x4CDC5 },
	{ 0xF0A79B9E, 0x4CDBB },
	{ 0xF0A79B9F, 0x4CDBD },
	{ 0xF0A79BA0, 0x7A8D3 },
	{ 0xF0A79BA1, 0x4CDC4 },
	{ 0xF0A79BA2, 0x4CDC3 },
	{ 0xF0A79BA3, 0x5D0E3 },
	{ 0xF0A79BA4, 0x7A8D8 },
	{ 0xF0A79BA5, 0x7A8D2 },
	{ 0xF0A79BA6, 0x7A8CC },
	{ 0xF0A79BA7, 0x5D0E4 },
	{ 0xF0A79BA8, 0x7A8CF },
	{ 0xF0A79BA9, 0x5D0E8 },
	{ 0xF0A79BAA, 0x7A8D1 },
	{ 0xF0A79BAB, 0x7A8D0 },
	{ 0xF0A79BAC, 0x7A8CD },
	{ 0xF0A79BB0, 0xFCCB5 },
	{ 0xF0A79BB1, 0xFD2AD },
	{ 0xF0A79BB2, 0x7A8CE },
	{ 0xF0A79BB3, 0x7A8D9 },
	{ 0xF0A79BB8, 0x5D8AC },
	{ 0xF0A79BB9, 0x5D8AB },
	{ 0xF0A79BBA, 0x7B3AB },
	{ 0xF0A79BBB, 0x5D8A7 },
	{ 0xF0A79BBC, 0x5D8AA },
	{ 0xF0A79BBD, 0x7B3A7 },
	{ 0xF0A79BBE, 0x4D3D1 },
	{ 0xF0A79BBF, 0x7B3A9 },
	{ 0xF0A79C80, 0x4D3D4 },
	{ 0xF0A79C81, 0x7BBE2 },
	{ 0xF0A79C82, 0x5D8A9 },
	{ 0xF0A79C83, 0x5D8A8 },
	{ 0xF0A79C84, 0x7B3AA },
	{ 0xF0A79C85, 0x4D3CE },
	{ 0xF0A79C86, 0x7B3AC },
	{ 0xF0A79C87, 0x7B3AF },
	{ 0xF0A79C88, 0x4D3CD },
	{ 0xF0A79C8A, 0x5D8A5 },
	{ 0xF0A79C8B, 0x7B3B0 },
	{ 0xF0A79C8D, 0x5D8A6 },
	{ 0xF0A79C91, 0x7B3AE },
	{ 0xF0A79C92, 0xFD2AC },
	{ 0xF0A79C95, 0x7B3AD },
	{ 0xF0A79C9D, 0x5DEBE },
	{ 0xF0A79C9E, 0x5DEBF },
	{ 0xF0A79C9F, 0x7BBD7 },
	{ 0xF0A79CA0, 0x5DEBB },
	{ 0xF0A79CA1, 0x7BBDD },
	{ 0xF0A79CA2, 0x7BBE4 },
	{ 0xF0A79CA3, 0x4D8E6 },
	{ 0xF0A79CA4, 0x5DEB8 },
	{ 0xF0A79CA5, 0x5DEB9 },
	{ 0xF0A79CA6, 0x5DEBD },
	{ 0xF0A79CA7, 0x5DEBC },
	{ 0xF0A79CA9, 0x7BBDF },
	{ 0xF0A79CAB, 0x7BBDB },
	{ 0xF0A79CAC, 0x7BBE3 },
	{ 0xF0A79CAD, 0x7C2FB },
	{ 0xF0A79CAE, 0x7BBDC },
	{ 0xF0A79CAF, 0x7A8DB },
	{ 0xF0A79CB0, 0x7BBDE },
	{ 0xF0A79CB1, 0x7BBE0 },
	{ 0xF0A79CB2, 0x5DEC0 },
	{ 0xF0A79CB7, 0x7BBD8 },
	{ 0xF0A79CB8, 0x7BBDA },
	{ 0xF0A79CBD, 0x5DEBA },
	{ 0xF0A79CBE, 0xFD7E7 },
	{ 0xF0A79CBF, 0xFD7E8 },
	{ 0xF0A79D80, 0xFD7E9 },
	{ 0xF0A79D81, 0xFD7EA },
	{ 0xF0A79D82, 0x7C2F5 },
	{ 0xF0A79D83, 0x4DDC5 },
	{ 0xF0A79D84, 0x7C2FC },
	{ 0xF0A79D85, 0x7C2FE },
	{ 0xF0A79D86, 0x5E4DB },
	{ 0xF0A79D87, 0x5E4D7 },
	{ 0xF0A79D88, 0x7C2FD },
	{ 0xF0A79D89, 0x4DDCB },
	{ 0xF0A79D8A, 0x5E4D4 },
	{ 0xF0A79D8B, 0x5E4D5 },
	{ 0xF0A79D8C, 0x5E4DF },
	{ 0xF0A79D8D, 0x4DDCD },
	{ 0xF0A79D8F, 0x4DDC2 },
	{ 0xF0A79D90, 0x7C2FA },
	{ 0xF0A79D91, 0x5E4D3 },
	{ 0xF0A79D92, 0x4DDC7 },
	{ 0xF0A79D93, 0x4DDCC },
	{ 0xF0A79D94, 0x5E4DD },
	{ 0xF0A79D95, 0x7C2F9 },
	{ 0xF0A79D96, 0x7C2F7 },
	{ 0xF0A79D97, 0x5E4D1 },
	{ 0xF0A79D98, 0x4DDC3 },
	{ 0xF0A79D99, 0x5DEC2 },
	{ 0xF0A79D9A, 0x5E4D2 },
	{ 0xF0A79D9B, 0x7C2F8 },
	{ 0xF0A79DA2, 0x7C3A3 },
	{ 0xF0A79DA3, 0x7C2F6 },
	{ 0xF0A79DAA, 0x5E4D9 },
	{ 0xF0A79DAB, 0x5E4DA },
	{ 0xF0A79DAC, 0x5DEC1 },
	{ 0xF0A79DAD, 0x5E4DC },
	{ 0xF0A79DAE, 0x5E4DE },
	{ 0xF0A79DAF, 0x5E4D8 },
	{ 0xF0A79DB0, 0xFDCE0 },
	{ 0xF0A79DB1, 0x7C9F6 },
	{ 0xF0A79DB2, 0x5E9C9 },
	{ 0xF0A79DB3, 0x5E9CA },
	{ 0xF0A79DB4, 0x4E1A9 },
	{ 0xF0A79DB5, 0x7C9FB },
	{ 0xF0A79DB6, 0x7C9FC },
	{ 0xF0A79DB7, 0x5E9C7 },
	{ 0xF0A79DB8, 0x5E9C8 },
	{ 0xF0A79DB9, 0x7C9F2 },
	{ 0xF0A79DBA, 0x7C9F3 },
	{ 0xF0A79DBB, 0x7C9F5 },
	{ 0xF0A79DBC, 0x7C9F9 },
	{ 0xF0A79DBD, 0x7C9FA },
	{ 0xF0A79DBE, 0x7C9F4 },
	{ 0xF0A79DBF, 0x7C9F8 },
	{ 0xF0A79E80, 0x4E1AB },
	{ 0xF0A79E81, 0x7C9F7 },
	{ 0xF0A79E82, 0x7C3A1 },
	{ 0xF0A79E86, 0xFE0EB },
	{ 0xF0A79E87, 0xFE0EC },
	{ 0xF0A79E88, 0xFE3F6 },
	{ 0xF0A79E8C, 0x7CFFD },
	{ 0xF0A79E8D, 0x5EDD8 },
	{ 0xF0A79E8E, 0x7D0A6 },
	{ 0xF0A79E8F, 0x5EDDB },
	{ 0xF0A79E90, 0x5F1B4 },
	{ 0xF0A79E92, 0x5EDD5 },
	{ 0xF0A79E93, 0x4E4C5 },
	{ 0xF0A79E94, 0x7D0A3 },
	{ 0xF0A79E95, 0x5EDD6 },
	{ 0xF0A79E96, 0x7D0A2 },
	{ 0xF0A79E97, 0x7D4FC },
	{ 0xF0A79E99, 0x7CFFE },
	{ 0xF0A79E9B, 0x5EDD9 },
	{ 0xF0A79E9C, 0x7C9F1 },
	{ 0xF0A79E9D, 0x5EDDA },
	{ 0xF0A79E9E, 0x5EDDC },
	{ 0xF0A79E9F, 0x7D0A4 },
	{ 0xF0A79EA1, 0xFE6B4 },
	{ 0xF0A79EA2, 0x7D0A1 },
	{ 0xF0A79EA6, 0x5EDDD },
	{ 0xF0A79EA7, 0x7D5A2 },
	{ 0xF0A79EA8, 0x7D5A4 },
	{ 0xF0A79EA9, 0x5F1B6 },
	{ 0xF0A79EAA, 0x4E7B6 },
	{ 0xF0A79EAB, 0x7D5A6 },
	{ 0xF0A79EAC, 0x7D5A5 },
	{ 0xF0A79EAD, 0x5F1B5 },
	{ 0xF0A79EAE, 0x7D4FE },
	{ 0xF0A79EAF, 0x7D5A1 },
	{ 0xF0A79EB0, 0x4E7B7 },
	{ 0xF0A79EB1, 0x7D5A3 },
	{ 0xF0A79EB2, 0x7D9B1 },
	{ 0xF0A79EB3, 0x7D4FD },
	{ 0xF0A79EB5, 0xFE6B3 },
	{ 0xF0A79EB6, 0x4E9C1 },
	{ 0xF0A79EB7, 0x7D9AE },
	{ 0xF0A79EB8, 0x4E9C0 },
	{ 0xF0A79EB9, 0x4E9BF },
	{ 0xF0A79EBA, 0x5F4B7 },
	{ 0xF0A79EBB, 0x7D9AC },
	{ 0xF0A79EBC, 0x7D9AD },
	{ 0xF0A79EBD, 0x7D9B0 },
	{ 0xF0A79F82, 0x7D9AF },
	{ 0xF0A79F83, 0x5F8AE },
	{ 0xF0A79F87, 0xFE9EF },
	{ 0xF0A79F88, 0x7DFD1 },
	{ 0xF0A79F89, 0x7DFD0 },
	{ 0xF0A79F8A, 0x7DFCF },
	{ 0xF0A79F8C, 0x5F9CB },
	{ 0xF0A79F8D, 0x7E1C8 },
	{ 0xF0A79F8E, 0x7E1C7 },
	{ 0xF0A79F8F, 0x7E1C6 },
	{ 0xF0A79F90, 0x7E2E1 },
	{ 0xF0A79F91, 0x5FAB7 },
	{ 0xF0A79F92, 0x7E2E2 },
	{ 0xF0A79F94, 0x7E2E0 },
	{ 0xF0A79F95, 0x7E4DF },
	{ 0xF0A79F96, 0x7E3F3 },
	{ 0xF0A79F97, 0x7E3F2 },
	{ 0xF0A79F98, 0x7E4DE },
	{ 0xF0A79F99, 0x5FBFE },
	{ 0xF0A79F9A, 0x7E5E4 },
	{ 0xF0A79F9B, 0x7E6AC },
	{ 0xF0A79F9E, 0x5FCCB },
	{ 0xF0A79F9F, 0x7E6CD },
	{ 0xF0A79FA1, 0x5A4F6 },
	{ 0xF0A79FA3, 0x6AEAC },
	{ 0xF0A79FA6, 0x4ABC8 },
	{ 0xF0A79FA7, 0x5B0C1 },
	{ 0xF0A79FA8, 0x4AFF4 },
	{ 0xF0A79FA9, 0x6BCAA },
	{ 0xF0A79FAA, 0x6C4DB },
	{ 0xF0A79FAB, 0xFB8C6 },
	{ 0xF0A79FAD, 0xFBFB1 },
	{ 0xF0A79FAE, 0xFBFB2 },
	{ 0xF0A79FAF, 0x6D8B2 },
	{ 0xF0A79FB1, 0x4C7B4 },
	{ 0xF0A79FB2, 0x6E2B6 },
	{ 0xF0A79FB3, 0x6E2B7 },
	{ 0xF0A79FB4, 0x6E2B8 },
	{ 0xF0A79FB7, 0xFCCB8 },
	{ 0xF0A79FB8, 0xFCCB9 },
	{ 0xF0A79FB9, 0x7A8DC },
	{ 0xF0A79FBA, 0xFCCBA },
	{ 0xF0A79FBB, 0xFD2B0 },
	{ 0xF0A79FBC, 0x7B3B1 },
	{ 0xF0A79FBD, 0x7B3B2 },
	{ 0xF0A79FBE, 0xFD2AF },
	{ 0xF0A79FBF, 0x7BBE5 },
	{ 0xF0A7A080, 0xFE0ED },
	{ 0xF0A7A081, 0xFE0EE },
	{ 0xF0A7A082, 0x5E9CB },
	{ 0xF0A7A083, 0x7D0A7 },
	{ 0xF0A7A084, 0x7D5A7 },
	{ 0xF0A7A086, 0x5A7E7 },
	{ 0xF0A7A087, 0x6AEAD },
	{ 0xF0A7A089, 0x4AFF7 },
	{ 0xF0A7A08B, 0x5B0C2 },
	{ 0xF0A7A08C, 0xFB2D3 },
	{ 0xF0A7A08E, 0x5B5CD },
	{ 0xF0A7A08F, 0x5B5CE },
	{ 0xF0A7A090, 0x6C4DC },
	{ 0xF0A7A091, 0x6C4DD },
	{ 0xF0A7A092, 0x5B5D0 },
	{ 0xF0A7A093, 0x5B5CB },
	{ 0xF0A7A095, 0xFB8C7 },
	{ 0xF0A7A096, 0xFB8C9 },
	{ 0xF0A7A097, 0xFB8CB },
	{ 0xF0A7A098, 0x4B5B2 },
	{ 0xF0A7A099, 0x4B5B6 },
	{ 0xF0A7A09A, 0x5B5CC },
	{ 0xF0A7A09B, 0x5B5CF },
	{ 0xF0A7A09C, 0x6CEDF },
	{ 0xF0A7A09D, 0x4BBA5 },
	{ 0xF0A7A09E, 0x6CEE2 },
	{ 0xF0A7A09F, 0x6CEE1 },
	{ 0xF0A7A0A0, 0x5BCB6 },
	{ 0xF0A7A0A1, 0x6CEDE },
	{ 0xF0A7A0A2, 0x4BBA4 },
	{ 0xF0A7A0A3, 0x6CEDD },
	{ 0xF0A7A0A8, 0x6D8B6 },
	{ 0xF0A7A0A9, 0x5C2ED },
	{ 0xF0A7A0AA, 0x5C2EF },
	{ 0xF0A7A0AB, 0x5C2EE },
	{ 0xF0A7A0AD, 0x6D8B3 },
	{ 0xF0A7A0AE, 0x6D8B7 },
	{ 0xF0A7A0B0, 0x5C2F0 },
	{ 0xF0A7A0B1, 0xFC5C0 },
	{ 0xF0A7A0B2, 0xFC5C1 },
	{ 0xF0A7A0B3, 0xFC5C2 },
	{ 0xF0A7A0B5, 0x6D8B5 },
	{ 0xF0A7A0BB, 0x6E2B9 },
	{ 0xF0A7A0BC, 0x5C9F1 },
	{ 0xF0A7A0BD, 0x5C9EE },
	{ 0xF0A7A0BE, 0x5C9F2 },
	{ 0xF0A7A0BF, 0x4C7B7 },
	{ 0xF0A7A180, 0x6E2BA },
	{ 0xF0A7A183, 0xFCCBB },
	{ 0xF0A7A184, 0xFCCBC },
	{ 0xF0A7A185, 0x5C9EF },
	{ 0xF0A7A186, 0x6E2BB },
	{ 0xF0A7A188, 0x5C9F0 },
	{ 0xF0A7A18B, 0x4CDC9 },
	{ 0xF0A7A18C, 0x7A8DF },
	{ 0xF0A7A18D, 0x5D0EC },
	{ 0xF0A7A18E, 0x4CDCB },
	{ 0xF0A7A18F, 0x5D0EB },
	{ 0xF0A7A190, 0x7A8E3 },
	{ 0xF0A7A191, 0x5D0ED },
	{ 0xF0A7A192, 0x6D8B4 },
	{ 0xF0A7A193, 0x7A8E2 },
	{ 0xF0A7A195, 0x5D0EA },
	{ 0xF0A7A196, 0x5D0EE },
	{ 0xF0A7A197, 0xFD2B1 },
	{ 0xF0A7A198, 0x7A8E0 },
	{ 0xF0A7A19B, 0x7A8DE },
	{ 0xF0A7A19D, 0x7A8DD },
	{ 0xF0A7A1A0, 0x7A8E1 },
	{ 0xF0A7A1A1, 0x5D8B0 },
	{ 0xF0A7A1A2, 0x5D8AF },
	{ 0xF0A7A1A3, 0x5D8AE },
	{ 0xF0A7A1A4, 0x4D3D7 },
	{ 0xF0A7A1A5, 0x7B3B4 },
	{ 0xF0A7A1A6, 0x5D8B4 },
	{ 0xF0A7A1A7, 0x7BBE7 },
	{ 0xF0A7A1A8, 0x4D3D8 },
	{ 0xF0A7A1A9, 0x4D3DE },
	{ 0xF0A7A1AA, 0x4D3DD },
	{ 0xF0A7A1AB, 0x5D8B1 },
	{ 0xF0A7A1AC, 0x5D8B5 },
	{ 0xF0A7A1AD, 0x7B3B3 },
	{ 0xF0A7A1AE, 0x5D8AD },
	{ 0xF0A7A1AF, 0x5D8B3 },
	{ 0xF0A7A1B1, 0xFD7EB },
	{ 0xF0A7A1B2, 0xFD7EC },
	{ 0xF0A7A1B3, 0xFD7ED },
	{ 0xF0A7A1B7, 0x7BBE6 },
	{ 0xF0A7A1B8, 0x5E4E0 },
	{ 0xF0A7A1B9, 0x5DEC5 },
	{ 0xF0A7A1BA, 0x5DEC4 },
	{ 0xF0A7A1BB, 0x7BBEA },
	{ 0xF0A7A1BD, 0x7BBE9 },
	{ 0xF0A7A1BE, 0x7BBEB },
	{ 0xF0A7A1BF, 0x7BBE8 },
	{ 0xF0A7A280, 0xFDCE1 },
	{ 0xF0A7A281, 0xFDCE2 },
	{ 0xF0A7A282, 0x5E4E2 },
	{ 0xF0A7A283, 0x4DDD1 },
	{ 0xF0A7A284, 0x4DDCF },
	{ 0xF0A7A285, 0x7C3A4 },
	{ 0xF0A7A286, 0x5E4E1 },
	{ 0xF0A7A288, 0xFE0EF },
	{ 0xF0A7A289, 0xFE0F0 },
	{ 0xF0A7A28A, 0xFE0F1 },
	{ 0xF0A7A28D, 0x7C3A5 },
	{ 0xF0A7A28E, 0x7C9FD },
	{ 0xF0A7A28F, 0x7C9FE },
	{ 0xF0A7A292, 0x5EDDF },
	{ 0xF0A7A293, 0x7D0A9 },
	{ 0xF0A7A294, 0x7D0A8 },
	{ 0xF0A7A295, 0xFE6B5 },
	{ 0xF0A7A296, 0x5EDDE },
	{ 0xF0A7A298, 0xFE8CB },
	{ 0xF0A7A299, 0xFE8CC },
	{ 0xF0A7A29A, 0x7D5A8 },
	{ 0xF0A7A29C, 0x4E9C3 },
	{ 0xF0A7A29D, 0x5F4B9 },
	{ 0xF0A7A29E, 0x4E9C2 },
	{ 0xF0A7A2A0, 0xFE9F0 },
	{ 0xF0A7A2A1, 0xFE9F1 },
	{ 0xF0A7A2A2, 0x5F8AF },
	{ 0xF0A7A2A3, 0x7DFD3 },
	{ 0xF0A7A2A4, 0xFEBE4 },
	{ 0xF0A7A2A5, 0x7DFD2 },
	{ 0xF0A7A2A6, 0x5F9CD },
	{ 0xF0A7A2A7, 0x5F9CC },
	{ 0xF0A7A2A8, 0x7E1C9 },
	{ 0xF0A7A2AB, 0x4EDA1 },
	{ 0xF0A7A2AD, 0x5FAF4 },
	{ 0xF0A7A2AE, 0x4EEBB },
	{ 0xF0A7A2AF, 0x5FCC4 },
	{ 0xF0A7A2B1, 0x7E6D4 },
	{ 0xF0A7A2B2, 0x6AEAE },
	{ 0xF0A7A2B3, 0x6AEAF },
	{ 0xF0A7A2B4, 0x6B4D4 },
	{ 0xF0A7A2B5, 0x5ABC8 },
	{ 0xF0A7A2B7, 0x4AFF8 },
	{ 0xF0A7A2B8, 0x6BCAC },
	{ 0xF0A7A2B9, 0x4AFF9 },
	{ 0xF0A7A2BA, 0x6BCAB },
	{ 0xF0A7A2BB, 0x6C4E7 },
	{ 0xF0A7A2BC, 0x4B5BB },
	{ 0xF0A7A2BD, 0x5B5D3 },
	{ 0xF0A7A2BE, 0x5B5D2 },
	{ 0xF0A7A2BF, 0x6C4DF },
	{ 0xF0A7A380, 0x6C4E3 },
	{ 0xF0A7A381, 0x4B5B7 },
	{ 0xF0A7A382, 0x6C4E4 },
	{ 0xF0A7A383, 0x5B5D1 },
	{ 0xF0A7A384, 0x6C4E0 },
	{ 0xF0A7A385, 0xFB8CD },
	{ 0xF0A7A386, 0xFB8CE },
	{ 0xF0A7A387, 0xFB8CF },
	{ 0xF0A7A388, 0x4B5BC },
	{ 0xF0A7A389, 0x6C4E6 },
	{ 0xF0A7A38D, 0x6C4DE },
	{ 0xF0A7A38E, 0x6C4E2 },
	{ 0xF0A7A38F, 0x6C4E5 },
	{ 0xF0A7A390, 0x6C4E1 },
	{ 0xF0A7A391, 0x5BCB7 },
	{ 0xF0A7A392, 0x4BBA6 },
	{ 0xF0A7A393, 0x6CEE4 },
	{ 0xF0A7A394, 0x6CEE7 },
	{ 0xF0A7A395, 0x5BCB8 },
	{ 0xF0A7A396, 0x6CEE3 },
	{ 0xF0A7A397, 0x6CEE6 },
	{ 0xF0A7A398, 0x6CEE9 },
	{ 0xF0A7A399, 0x6CEE5 },
	{ 0xF0A7A39A, 0x4BBA7 },
	{ 0xF0A7A39B, 0x4BBA8 },
	{ 0xF0A7A39C, 0x6CEE8 },
	{ 0xF0A7A39E, 0xFBFB3 },
	{ 0xF0A7A3A1, 0x5C2F3 },
	{ 0xF0A7A3A2, 0x5C2F1 },
	{ 0xF0A7A3A3, 0x5C2F2 },
	{ 0xF0A7A3A5, 0x6D8B8 },
	{ 0xF0A7A3A8, 0x6E2BE },
	{ 0xF0A7A3A9, 0x5C9F5 },
	{ 0xF0A7A3AA, 0x4C7B9 },
	{ 0xF0A7A3AB, 0x6E2C0 },
	{ 0xF0A7A3AC, 0x5C9F3 },
	{ 0xF0A7A3AD, 0x5C9F4 },
	{ 0xF0A7A3AE, 0x6E2BD },
	{ 0xF0A7A3AF, 0x6E2C1 },
	{ 0xF0A7A3B0, 0x6E2BC },
	{ 0xF0A7A3B1, 0x6E2BF },
	{ 0xF0A7A3B4, 0x7A8E6 },
	{ 0xF0A7A3B5, 0x5D0F5 },
	{ 0xF0A7A3B6, 0x7A8E7 },
	{ 0xF0A7A3B7, 0x5D0F4 },
	{ 0xF0A7A3B8, 0x5D0F0 },
	{ 0xF0A7A3B9, 0x5D0EF },
	{ 0xF0A7A3BA, 0x4CDD0 },
	{ 0xF0A7A3BB, 0x4CDD2 },
	{ 0xF0A7A3BC, 0x4CDCD },
	{ 0xF0A7A3BD, 0x7A8E9 },
	{ 0xF0A7A3BE, 0x4CDD4 },
	{ 0xF0A7A483, 0x5D0F2 },
	{ 0xF0A7A484, 0x7A8E8 },
	{ 0xF0A7A485, 0x7A8EA },
	{ 0xF0A7A486, 0x5D0F1 },
	{ 0xF0A7A487, 0x7A8E4 },
	{ 0xF0A7A488, 0x7A8E5 },
	{ 0xF0A7A489, 0x5D0F3 },
	{ 0xF0A7A48B, 0x7B3B8 },
	{ 0xF0A7A48C, 0x7B3B7 },
	{ 0xF0A7A48D, 0x4D3DF },
	{ 0xF0A7A48E, 0x5D8B6 },
	{ 0xF0A7A48F, 0x4D3E3 },
	{ 0xF0A7A490, 0x5D8B9 },
	{ 0xF0A7A491, 0x5D8BB },
	{ 0xF0A7A492, 0x4D3E0 },
	{ 0xF0A7A493, 0x7B3B6 },
	{ 0xF0A7A494, 0x7B3B5 },
	{ 0xF0A7A495, 0x5D8B7 },
	{ 0xF0A7A496, 0x5D8B8 },
	{ 0xF0A7A497, 0x5D8BA },
	{ 0xF0A7A498, 0x7B3B9 },
	{ 0xF0A7A49B, 0x5DEC6 },
	{ 0xF0A7A49C, 0x7BBED },
	{ 0xF0A7A49D, 0x7BBF3 },
	{ 0xF0A7A49E, 0x7BBEC },
	{ 0xF0A7A49F, 0x5DECA },
	{ 0xF0A7A4A0, 0x5DEC9 },
	{ 0xF0A7A4A1, 0x7BBEE },
	{ 0xF0A7A4A2, 0x7B3BA },
	{ 0xF0A7A4A3, 0x5DEC8 },
	{ 0xF0A7A4A6, 0x7BBEF },
	{ 0xF0A7A4A7, 0x7BBF0 },
	{ 0xF0A7A4A9, 0x7BBF1 },
	{ 0xF0A7A4AA, 0x4D8EC },
	{ 0xF0A7A4AB, 0x7BBF4 },
	{ 0xF0A7A4AC, 0x7BBF2 },
	{ 0xF0A7A4AE, 0x5DEC7 },
	{ 0xF0A7A4AF, 0x7C3A7 },
	{ 0xF0A7A4B1, 0x7C3A8 },
	{ 0xF0A7A4B2, 0x4DDD2 },
	{ 0xF0A7A4B6, 0x7C3A6 },
	{ 0xF0A7A4B7, 0x7C3A9 },
	{ 0xF0A7A4BA, 0x4E1B5 },
	{ 0xF0A7A4BB, 0x5E9CC },
	{ 0xF0A7A4BC, 0x4E1B2 },
	{ 0xF0A7A4BD, 0x4E1B3 },
	{ 0xF0A7A4BE, 0x7CAA1 },
	{ 0xF0A7A4BF, 0x7CAA2 },
	{ 0xF0A7A580, 0x7CAA3 },
	{ 0xF0A7A581, 0x7CAA4 },
	{ 0xF0A7A582, 0x4E1B6 },
	{ 0xF0A7A584, 0x7D0AA },
	{ 0xF0A7A588, 0x5F1B7 },
	{ 0xF0A7A58A, 0x7D5A9 },
	{ 0xF0A7A58C, 0x5F4BA },
	{ 0xF0A7A58D, 0x4E9C4 },
	{ 0xF0A7A591, 0x7DCE5 },
	{ 0xF0A7A593, 0x5F8B0 },
	{ 0xF0A7A595, 0x7E2E3 },
	{ 0xF0A7A596, 0x4EDE0 },
	{ 0xF0A7A597, 0x7E4E0 },
	{ 0xF0A7A598, 0x7E4E1 },
	{ 0xF0A7A599, 0x5FBE9 },
	{ 0xF0A7A59A, 0x7E5C3 },
	{ 0xF0A7A59B, 0x5A3A7 },
	{ 0xF0A7A59C, 0x5A3A8 },
	{ 0xF0A7A59D, 0x6AEB0 },
	{ 0xF0A7A5A1, 0x6BCB3 },
	{ 0xF0A7A5A2, 0x4B0A1 },
	{ 0xF0A7A5A3, 0x4AFFB },
	{ 0xF0A7A5A4, 0x4AFFA },
	{ 0xF0A7A5A5, 0x4B0A2 },
	{ 0xF0A7A5A6, 0x5B0C3 },
	{ 0xF0A7A5A8, 0x6BCB0 },
	{ 0xF0A7A5A9, 0x6BCB1 },
	{ 0xF0A7A5AA, 0x6BCAF },
	{ 0xF0A7A5AB, 0x6BCB2 },
	{ 0xF0A7A5AD, 0x6BCAE },
	{ 0xF0A7A5AE, 0x4B5C0 },
	{ 0xF0A7A5AF, 0x6C4EA },
	{ 0xF0A7A5B0, 0x6C4F3 },
	{ 0xF0A7A5B1, 0x4B5BE },
	{ 0xF0A7A5B3, 0x6C4EF },
	{ 0xF0A7A5B4, 0x5B5DC },
	{ 0xF0A7A5B5, 0x5B5D9 },
	{ 0xF0A7A5B7, 0x6C4F1 },
	{ 0xF0A7A5B8, 0x4B5C2 },
	{ 0xF0A7A5B9, 0x5B5D4 },
	{ 0xF0A7A5BA, 0x4B5C6 },
	{ 0xF0A7A5BB, 0x6C4F9 },
	{ 0xF0A7A5BC, 0x5B5D5 },
	{ 0xF0A7A5BD, 0x6C4F7 },
	{ 0xF0A7A5BE, 0x6C4EB },
	{ 0xF0A7A5BF, 0x6C4F8 },
	{ 0xF0A7A680, 0x5B5D8 },
	{ 0xF0A7A681, 0x6C4F4 },
	{ 0xF0A7A682, 0x6C4F5 },
	{ 0xF0A7A686, 0x6C4EE },
	{ 0xF0A7A687, 0x6C4FA },
	{ 0xF0A7A688, 0xFB8D0 },
	{ 0xF0A7A689, 0xFB8D1 },
	{ 0xF0A7A68A, 0xFB8D3 },
	{ 0xF0A7A68B, 0xFB8D4 },
	{ 0xF0A7A68C, 0xFB8D5 },
	{ 0xF0A7A68D, 0xFB8D6 },
	{ 0xF0A7A68F, 0x6C4F2 },
	{ 0xF0A7A692, 0x6C4E9 },
	{ 0xF0A7A697, 0x6C4E8 },
	{ 0xF0A7A699, 0x6C4F6 },
	{ 0xF0A7A69A, 0x6C4EC },
	{ 0xF0A7A69B, 0x5B5DA },
	{ 0xF0A7A69C, 0x6CEF4 },
	{ 0xF0A7A69D, 0x4BBB2 },
	{ 0xF0A7A69E, 0x4BBAE },
	{ 0xF0A7A69F, 0x5BCBB },
	{ 0xF0A7A6A0, 0x6CEEF },
	{ 0xF0A7A6A1, 0x6CEEE },
	{ 0xF0A7A6A2, 0x6CEF1 },
	{ 0xF0A7A6A3, 0x6CEEA },
	{ 0xF0A7A6A4, 0x4BBAD },
	{ 0xF0A7A6A5, 0x6CEF8 },
	{ 0xF0A7A6A6, 0x4BBB8 },
	{ 0xF0A7A6A7, 0x4BBB9 },
	{ 0xF0A7A6A8, 0x5BCBC },
	{ 0xF0A7A6A9, 0x6CEED },
	{ 0xF0A7A6AA, 0x6CEF6 },
	{ 0xF0A7A6AB, 0x6CEF0 },
	{ 0xF0A7A6AC, 0x6CEF7 },
	{ 0xF0A7A6AD, 0x4BBB7 },
	{ 0xF0A7A6AE, 0x5BCB9 },
	{ 0xF0A7A6AF, 0x5BCBA },
	{ 0xF0A7A6B0, 0xFBFB4 },
	{ 0xF0A7A6B1, 0xFBFB5 },
	{ 0xF0A7A6B2, 0xFBFB6 },
	{ 0xF0A7A6B3, 0xFBFB7 },
	{ 0xF0A7A6B4, 0xFBFB8 },
	{ 0xF0A7A6B5, 0xFBFB9 },
	{ 0xF0A7A6B6, 0xFBFBA },
	{ 0xF0A7A6B7, 0xFBFBC },
	{ 0xF0A7A6BA, 0x6CEF2 },
	{ 0xF0A7A6BB, 0x6CEF5 },
	{ 0xF0A7A6BE, 0x6CEEC },
	{ 0xF0A7A781, 0x6CEF9 },
	{ 0xF0A7A782, 0x6CEF3 },
	{ 0xF0A7A784, 0x5C2F5 },
	{ 0xF0A7A785, 0x4C0E8 },
	{ 0xF0A7A786, 0x4C0EA },
	{ 0xF0A7A788, 0x6D8C6 },
	{ 0xF0A7A789, 0x5C2F6 },
	{ 0xF0A7A78A, 0x5BCBD },
	{ 0xF0A7A78B, 0x5C2F9 },
	{ 0xF0A7A78C, 0x4C0F1 },
	{ 0xF0A7A78D, 0x4C0F0 },
	{ 0xF0A7A78E, 0x6D8C0 },
	{ 0xF0A7A78F, 0x6D8CB },
	{ 0xF0A7A790, 0x6D8BD },
	{ 0xF0A7A791, 0x6D8C9 },
	{ 0xF0A7A792, 0x4C0E9 },
	{ 0xF0A7A793, 0x4C0EB },
	{ 0xF0A7A794, 0x5C2FC },
	{ 0xF0A7A795, 0x5C2F4 },
	{ 0xF0A7A796, 0x4C0F3 },
	{ 0xF0A7A797, 0x6D8C3 },
	{ 0xF0A7A798, 0x6D8BC },
	{ 0xF0A7A799, 0x6D8C7 },
	{ 0xF0A7A79A, 0x6D8C2 },
	{ 0xF0A7A79B, 0x6D8BF },
	{ 0xF0A7A79C, 0x4C0F2 },
	{ 0xF0A7A79D, 0x5C2FA },
	{ 0xF0A7A79E, 0x6D8C8 },
	{ 0xF0A7A79F, 0x5C2F8 },
	{ 0xF0A7A7A0, 0x5C2F7 },
	{ 0xF0A7A7A1, 0x6D8C4 },
	{ 0xF0A7A7A4, 0xFC5C3 },
	{ 0xF0A7A7A5, 0xFC5C5 },
	{ 0xF0A7A7A6, 0xFC5C6 },
	{ 0xF0A7A7A7, 0x6D8CA },
	{ 0xF0A7A7A8, 0x5C2FB },
	{ 0xF0A7A7AA, 0x6D8B9 },
	{ 0xF0A7A7AB, 0x6D8BB },
	{ 0xF0A7A7B0, 0x4C0EF },
	{ 0xF0A7A7B1, 0x6D8BA },
	{ 0xF0A7A7B2, 0x6D8C5 },
	{ 0xF0A7A7B3, 0x6D8BE },
	{ 0xF0A7A7B4, 0x6E2CE },
	{ 0xF0A7A7B5, 0x4C7BF },
	{ 0xF0A7A7B6, 0x5C9FA },
	{ 0xF0A7A7B7, 0x4C7BB },
	{ 0xF0A7A7B8, 0x5C9F8 },
	{ 0xF0A7A7B9, 0x5C9FB },
	{ 0xF0A7A7BA, 0x4C7BE },
	{ 0xF0A7A7BB, 0x4C7C8 },
	{ 0xF0A7A7BC, 0x6E2C2 },
	{ 0xF0A7A7BD, 0x6E2CC },
	{ 0xF0A7A7BE, 0x4C7C1 },
	{ 0xF0A7A7BF, 0x6E2D3 },
	{ 0xF0A7A880, 0x4C7C4 },
	{ 0xF0A7A881, 0x6E2CF },
	{ 0xF0A7A882, 0x4C7C7 },
	{ 0xF0A7A883, 0x6E2C6 },
	{ 0xF0A7A884, 0x5C9F9 },
	{ 0xF0A7A885, 0x6E2D1 },
	{ 0xF0A7A886, 0x6E2C5 },
	{ 0xF0A7A887, 0x4C7C9 },
	{ 0xF0A7A888, 0x6E2D0 },
	{ 0xF0A7A889, 0x6E2C4 },
	{ 0xF0A7A88A, 0x5C9F6 },
	{ 0xF0A7A88B, 0x5C9F7 },
	{ 0xF0A7A88F, 0xFCCBD },
	{ 0xF0A7A890, 0xFCCBE },
	{ 0xF0A7A891, 0xFCCBF },
	{ 0xF0A7A892, 0xFCCC0 },
	{ 0xF0A7A893, 0xFCCC2 },
	{ 0xF0A7A894, 0xFCCC3 },
	{ 0xF0A7A895, 0xFCCC4 },
	{ 0xF0A7A896, 0xFCCC5 },
	{ 0xF0A7A899, 0x6E2C8 },
	{ 0xF0A7A89A, 0x4C7CB },
	{ 0xF0A7A89B, 0x6E2CA },
	{ 0xF0A7A89C, 0x5C2FD },
	{ 0xF0A7A89D, 0x6E2CB },
	{ 0xF0A7A89E, 0x6E2CD },
	{ 0xF0A7A8A0, 0x6E2C3 },
	{ 0xF0A7A8A3, 0x6E2D2 },
	{ 0xF0A7A8A4, 0x6E2C9 },
	{ 0xF0A7A8A6, 0x7A9A1 },
	{ 0xF0A7A8A7, 0x5D1AA },
	{ 0xF0A7A8A8, 0x7A8EB },
	{ 0xF0A7A8A9, 0x5D0FA },
	{ 0xF0A7A8AA, 0x5D1A2 },
	{ 0xF0A7A8AB, 0x7A8F1 },
	{ 0xF0A7A8AC, 0x7A8F4 },
	{ 0xF0A7A8AD, 0x7A9A2 },
	{ 0xF0A7A8AE, 0x7A8FC },
	{ 0xF0A7A8AF, 0x7A8F0 },
	{ 0xF0A7A8B0, 0x5D1A7 },
	{ 0xF0A7A8B1, 0x4CDD7 },
	{ 0xF0A7A8B2, 0x5D1A9 },
	{ 0xF0A7A8B3, 0x5D1A3 },
	{ 0xF0A7A8B4, 0x5D0FB },
	{ 0xF0A7A8B5, 0x5D0FE },
	{ 0xF0A7A8B6, 0x7A8F8 },
	{ 0xF0A7A8B7, 0x5D1A4 },
	{ 0xF0A7A8B8, 0x4CDDD },
	{ 0xF0A7A8B9, 0x5D1A6 },
	{ 0xF0A7A8BA, 0x4CDE2 },
	{ 0xF0A7A8BB, 0x7A9A4 },
	{ 0xF0A7A8BC, 0x7A8F7 },
	{ 0xF0A7A8BD, 0x7A8EF },
	{ 0xF0A7A8BE, 0x5D0F8 },
	{ 0xF0A7A8BF, 0x5D0FC },
	{ 0xF0A7A980, 0x7A8FD },
	{ 0xF0A7A982, 0x7A8ED },
	{ 0xF0A7A983, 0x5D1A5 },
	{ 0xF0A7A984, 0x5D0FD },
	{ 0xF0A7A985, 0x5D0F7 },
	{ 0xF0A7A986, 0x5D0F9 },
	{ 0xF0A7A987, 0x5D0F6 },
	{ 0xF0A7A989, 0xFD2B2 },
	{ 0xF0A7A98A, 0xFD2B3 },
	{ 0xF0A7A98B, 0xFD2B4 },
	{ 0xF0A7A98C, 0xFD2B5 },
	{ 0xF0A7A98D, 0xFD2B7 },
	{ 0xF0A7A98E, 0xFD2B9 },
	{ 0xF0A7A98F, 0xFD2BA },
	{ 0xF0A7A990, 0x7A8F6 },
	{ 0xF0A7A991, 0x7A8F5 },
	{ 0xF0A7A996, 0x7A8EC },
	{ 0xF0A7A998, 0x7A8F2 },
	{ 0xF0A7A999, 0xFD2B8 },
	{ 0xF0A7A99A, 0x5D1A1 },
	{ 0xF0A7A99B, 0x7A8FB },
	{ 0xF0A7A99C, 0x7A8EE },
	{ 0xF0A7A99D, 0x5D1A8 },
	{ 0xF0A7A99E, 0x7A9A3 },
	{ 0xF0A7A99F, 0x7A8FE },
	{ 0xF0A7A9A0, 0x7A8FA },
	{ 0xF0A7A9A1, 0x7A8F3 },
	{ 0xF0A7A9A2, 0x7B3C6 },
	{ 0xF0A7A9A3, 0x5D8C0 },
	{ 0xF0A7A9A4, 0x4D3F1 },
	{ 0xF0A7A9A5, 0x7B3D2 },
	{ 0xF0A7A9A6, 0x4D3E8 },
	{ 0xF0A7A9A7, 0x4D3E5 },
	{ 0xF0A7A9A8, 0x4D3EC },
	{ 0xF0A7A9A9, 0x7B3C9 },
	{ 0xF0A7A9AA, 0x7B3D1 },
	{ 0xF0A7A9AB, 0x7B3C3 },
	{ 0xF0A7A9AC, 0x5D8BD },
	{ 0xF0A7A9AD, 0x7B3C2 },
	{ 0xF0A7A9AE, 0x5D8BC },
	{ 0xF0A7A9AF, 0x7B3BC },
	{ 0xF0A7A9B1, 0x4D3F0 },
	{ 0xF0A7A9B2, 0x4D3E7 },
	{ 0xF0A7A9B3, 0x7B3C5 },
	{ 0xF0A7A9B4, 0x4D3EF },
	{ 0xF0A7A9B5, 0x7B3BD },
	{ 0xF0A7A9B6, 0x4D3EE },
	{ 0xF0A7A9B7, 0x7B3C7 },
	{ 0xF0A7A9B8, 0x7B3CE },
	{ 0xF0A7A9B9, 0x4D3E6 },
	{ 0xF0A7A9BA, 0x7B3D0 },
	{ 0xF0A7A9BB, 0x7B3BE },
	{ 0xF0A7A9BC, 0x4D3E9 },
	{ 0xF0A7A9BD, 0x7B3BB },
	{ 0xF0A7A9BE, 0x7B3D3 },
	{ 0xF0A7A9BF, 0x7B3C0 },
	{ 0xF0A7AA80, 0x7B3BF },
	{ 0xF0A7AA81, 0x7B3C8 },
	{ 0xF0A7AA82, 0x7B3CA },
	{ 0xF0A7AA83, 0x5D8BF },
	{ 0xF0A7AA84, 0x7B3CC },
	{ 0xF0A7AA85, 0x4D3ED },
	{ 0xF0A7AA86, 0x7B3C4 },
	{ 0xF0A7AA87, 0x5D8BE },
	{ 0xF0A7AA88, 0xFD7EE },
	{ 0xF0A7AA89, 0xFD7EF },
	{ 0xF0A7AA8A, 0xFD7F0 },
	{ 0xF0A7AA8B, 0xFD7F1 },
	{ 0xF0A7AA8C, 0xFD7F2 },
	{ 0xF0A7AA8D, 0xFD7F3 },
	{ 0xF0A7AA8E, 0xFD7F4 },
	{ 0xF0A7AA8F, 0xFD7F5 },
	{ 0xF0A7AA90, 0xFD7F6 },
	{ 0xF0A7AA91, 0xFD7F7 },
	{ 0xF0A7AA92, 0xFD7F8 },
	{ 0xF0A7AA94, 0x7B3D4 },
	{ 0xF0A7AA96, 0x7B3C1 },
	{ 0xF0A7AA97, 0x7B3CB },
	{ 0xF0A7AA98, 0x4D8EE },
	{ 0xF0A7AA99, 0x5DED2 },
	{ 0xF0A7AA9A, 0x5DED1 },
	{ 0xF0A7AA9B, 0x7BBFD },
	{ 0xF0A7AA9C, 0x4D8EF },
	{ 0xF0A7AA9D, 0x5DED4 },
	{ 0xF0A7AA9E, 0x4D8F1 },
	{ 0xF0A7AA9F, 0x7BBF9 },
	{ 0xF0A7AAA0, 0x4D8ED },
	{ 0xF0A7AAA1, 0x5DECD },
	{ 0xF0A7AAA2, 0x5DED3 },
	{ 0xF0A7AAA3, 0x5DECE },
	{ 0xF0A7AAA4, 0x7BBF6 },
	{ 0xF0A7AAA5, 0x7BCA5 },
	{ 0xF0A7AAA6, 0x4D8F2 },
	{ 0xF0A7AAA7, 0x7C3AA },
	{ 0xF0A7AAA8, 0x5DECF },
	{ 0xF0A7AAA9, 0x7BCA1 },
	{ 0xF0A7AAAA, 0x7BBF7 },
	{ 0xF0A7AAAB, 0x5DED6 },
	{ 0xF0A7AAAC, 0x7BCA7 },
	{ 0xF0A7AAAD, 0x7BBFC },
	{ 0xF0A7AAAE, 0x7BBF8 },
	{ 0xF0A7AAAF, 0x5DED0 },
	{ 0xF0A7AAB0, 0x4D8F4 },
	{ 0xF0A7AAB1, 0x7BBFB },
	{ 0xF0A7AAB2, 0x7BBFE },
	{ 0xF0A7AAB3, 0x7BCA2 },
	{ 0xF0A7AAB4, 0x7BCA3 },
	{ 0xF0A7AAB5, 0x4D8F3 },
	{ 0xF0A7AAB6, 0x5DECB },
	{ 0xF0A7AAB7, 0x7BCA6 },
	{ 0xF0A7AAB9, 0x5DECC },
	{ 0xF0A7AABA, 0x7BCA4 },
	{ 0xF0A7AABF, 0x7BBF5 },
	{ 0xF0A7AB80, 0xFDCE3 },
	{ 0xF0A7AB81, 0xFDCE4 },
	{ 0xF0A7AB82, 0xFDCE5 },
	{ 0xF0A7AB83, 0xFDCE6 },
	{ 0xF0A7AB84, 0xFDCE7 },
	{ 0xF0A7AB85, 0xFDCE8 },
	{ 0xF0A7AB86, 0xFDCE9 },
	{ 0xF0A7AB87, 0xFDCEA },
	{ 0xF0A7AB88, 0xFDCEB },
	{ 0xF0A7AB8B, 0x7BCA8 },
	{ 0xF0A7AB8F, 0x7BCA9 },
	{ 0xF0A7AB90, 0x7BBFA },
	{ 0xF0A7AB92, 0x4DDDE },
	{ 0xF0A7AB93, 0x4DDD6 },
	{ 0xF0A7AB94, 0x7C3B7 },
	{ 0xF0A7AB95, 0x4DDD8 },
	{ 0xF0A7AB96, 0x7C3B5 },
	{ 0xF0A7AB97, 0x5E4E8 },
	{ 0xF0A7AB98, 0x7C3BA },
	{ 0xF0A7AB99, 0x7C3AB },
	{ 0xF0A7AB9A, 0x4DDE0 },
	{ 0xF0A7AB9B, 0x5E4E6 },
	{ 0xF0A7AB9C, 0x5D8C1 },
	{ 0xF0A7AB9D, 0x4DDD9 },
	{ 0xF0A7AB9E, 0x5E4E7 },
	{ 0xF0A7AB9F, 0x7C3B8 },
	{ 0xF0A7ABA0, 0x7C3B2 },
	{ 0xF0A7ABA1, 0x5E4E4 },
	{ 0xF0A7ABA2, 0x4DDD3 },
	{ 0xF0A7ABA3, 0x7C3BB },
	{ 0xF0A7ABA4, 0x4DDD5 },
	{ 0xF0A7ABA5, 0x5E4E5 },
	{ 0xF0A7ABA6, 0x4DDDD },
	{ 0xF0A7ABA7, 0x7C3B9 },
	{ 0xF0A7ABA8, 0x7C3AF },
	{ 0xF0A7ABA9, 0x7C3B3 },
	{ 0xF0A7ABAA, 0x7CAAA },
	{ 0xF0A7ABAB, 0x7C3B0 },
	{ 0xF0A7ABAC, 0x4DDDC },
	{ 0xF0A7ABAD, 0x7C3B4 },
	{ 0xF0A7ABAE, 0x7C3B1 },
	{ 0xF0A7ABAF, 0x7C3BC },
	{ 0xF0A7ABB0, 0x7C3AC },
	{ 0xF0A7ABB2, 0x7C3AD },
	{ 0xF0A7ABB5, 0xFE0F2 },
	{ 0xF0A7ABB6, 0xFE0F5 },
	{ 0xF0A7ABB8, 0x7C3B6 },
	{ 0xF0A7ABBA, 0x4DDDF },
	{ 0xF0A7ABBD, 0x7C3AE },
	{ 0xF0A7ABBE, 0x5E9CD },
	{ 0xF0A7ABBF, 0x5E9CF },
	{ 0xF0A7AC80, 0x7CAAF },
	{ 0xF0A7AC82, 0x4E1BE },
	{ 0xF0A7AC83, 0x7CAAC },
	{ 0xF0A7AC84, 0x7CAAE },
	{ 0xF0A7AC85, 0x4E1C3 },
	{ 0xF0A7AC86, 0x4E1B9 },
	{ 0xF0A7AC87, 0x5E9D0 },
	{ 0xF0A7AC88, 0x4E1C1 },
	{ 0xF0A7AC89, 0x7CAB4 },
	{ 0xF0A7AC8A, 0x4E1C2 },
	{ 0xF0A7AC8B, 0x5E9CE },
	{ 0xF0A7AC8C, 0x4E1BF },
	{ 0xF0A7AC8D, 0x7CAA6 },
	{ 0xF0A7AC8E, 0x7CAA9 },
	{ 0xF0A7AC8F, 0x7C3BD },
	{ 0xF0A7AC90, 0x7CAA8 },
	{ 0xF0A7AC91, 0x7CAB5 },
	{ 0xF0A7AC92, 0x7D0B3 },
	{ 0xF0A7AC93, 0x7CAB3 },
	{ 0xF0A7AC95, 0x4E1BC },
	{ 0xF0A7AC96, 0x5EDE0 },
	{ 0xF0A7AC97, 0x7CAA7 },
	{ 0xF0A7AC99, 0xFE3F8 },
	{ 0xF0A7AC9A, 0xFE3F9 },
	{ 0xF0A7AC9B, 0xFE3FA },
	{ 0xF0A7AC9C, 0x4E1C4 },
	{ 0xF0A7AC9D, 0x7CAAB },
	{ 0xF0A7AC9F, 0x7D0B5 },
	{ 0xF0A7ACA0, 0x7CAB0 },
	{ 0xF0A7ACA1, 0x7CAB1 },
	{ 0xF0A7ACA2, 0x7CAAD },
	{ 0xF0A7ACA3, 0x7CAB2 },
	{ 0xF0A7ACA4, 0x4E1B8 },
	{ 0xF0A7ACA5, 0xFE0F4 },
	{ 0xF0A7ACA7, 0x4E4CA },
	{ 0xF0A7ACA8, 0x4E4CB },
	{ 0xF0A7ACA9, 0x5EDE2 },
	{ 0xF0A7ACAA, 0x5EDE1 },
	{ 0xF0A7ACAB, 0x7D0AD },
	{ 0xF0A7ACAC, 0x5EDE3 },
	{ 0xF0A7ACAD, 0x7D0AF },
	{ 0xF0A7ACAE, 0x4E4C9 },
	{ 0xF0A7ACAF, 0x7D0AB },
	{ 0xF0A7ACB0, 0x5E9D3 },
	{ 0xF0A7ACB1, 0x7D0B2 },
	{ 0xF0A7ACB2, 0x7D0AE },
	{ 0xF0A7ACB3, 0x7D0B4 },
	{ 0xF0A7ACB4, 0x7D0B6 },
	{ 0xF0A7ACB5, 0x7D0AC },
	{ 0xF0A7ACB6, 0x7D0B0 },
	{ 0xF0A7ACBB, 0xFE6B6 },
	{ 0xF0A7ACBC, 0xFE6B7 },
	{ 0xF0A7ACBD, 0xFE6B8 },
	{ 0xF0A7ACBE, 0xFE6B9 },
	{ 0xF0A7ACBF, 0x7D0B8 },
	{ 0xF0A7AD80, 0x7D0B7 },
	{ 0xF0A7AD81, 0x7D0B9 },
	{ 0xF0A7AD82, 0x7D5AA },
	{ 0xF0A7AD83, 0x4E7C2 },
	{ 0xF0A7AD84, 0x7D5B4 },
	{ 0xF0A7AD85, 0x7D5AD },
	{ 0xF0A7AD86, 0x7D5B3 },
	{ 0xF0A7AD88, 0x4E7B8 },
	{ 0xF0A7AD89, 0x7D5AE },
	{ 0xF0A7AD8A, 0x5F1BD },
	{ 0xF0A7AD8B, 0x7D5AC },
	{ 0xF0A7AD8C, 0x7D5AF },
	{ 0xF0A7AD8D, 0x4E7BC },
	{ 0xF0A7AD8E, 0x5F1BA },
	{ 0xF0A7AD8F, 0x5F1B9 },
	{ 0xF0A7AD90, 0x4E7C3 },
	{ 0xF0A7AD91, 0x7D9BB },
	{ 0xF0A7AD92, 0x7D9B5 },
	{ 0xF0A7AD93, 0x4E7BA },
	{ 0xF0A7AD94, 0x5F1BC },
	{ 0xF0A7AD95, 0x5F1BB },
	{ 0xF0A7AD96, 0x7D5B1 },
	{ 0xF0A7AD98, 0x7D5AB },
	{ 0xF0A7AD99, 0x7D5B0 },
	{ 0xF0A7AD9A, 0x5F1B8 },
	{ 0xF0A7AD9B, 0x7D5B5 },
	{ 0xF0A7AD9C, 0x5F4BB },
	{ 0xF0A7AD9D, 0x5F4BD },
	{ 0xF0A7AD9E, 0x5F4C0 },
	{ 0xF0A7AD9F, 0x5F6CB },
	{ 0xF0A7ADA0, 0x4E9C7 },
	{ 0xF0A7ADA1, 0x7D9B9 },
	{ 0xF0A7ADA2, 0x4E9CA },
	{ 0xF0A7ADA3, 0x5F4BF },
	{ 0xF0A7ADA4, 0x4E9C9 },
	{ 0xF0A7ADA5, 0x5F4BE },
	{ 0xF0A7ADA7, 0x7D9B7 },
	{ 0xF0A7ADA8, 0x7D9C0 },
	{ 0xF0A7ADA9, 0x7D5B6 },
	{ 0xF0A7ADAA, 0x5F4BC },
	{ 0xF0A7ADAB, 0x7D9B6 },
	{ 0xF0A7ADAC, 0x7D9BA },
	{ 0xF0A7ADAD, 0x7D9BF },
	{ 0xF0A7ADAE, 0x4E9C6 },
	{ 0xF0A7ADAF, 0x7D9BE },
	{ 0xF0A7ADB0, 0xFE9F2 },
	{ 0xF0A7ADB1, 0xFE9F3 },
	{ 0xF0A7ADB2, 0xFE9F4 },
	{ 0xF0A7ADB4, 0x7D9BC },
	{ 0xF0A7ADB7, 0x7D9BD },
	{ 0xF0A7ADB8, 0x4EAFD },
	{ 0xF0A7ADB9, 0x4EAFE },
	{ 0xF0A7ADBA, 0x7DCE6 },
	{ 0xF0A7ADBB, 0x5F6CE },
	{ 0xF0A7ADBC, 0x5F6CD },
	{ 0xF0A7ADBD, 0x5F8B1 },
	{ 0xF0A7ADBE, 0x7DCE8 },
	{ 0xF0A7ADBF, 0x7DCE9 },
	{ 0xF0A7AE80, 0x7DCEA },
	{ 0xF0A7AE81, 0xFEAF4 },
	{ 0xF0A7AE82, 0xFEAF5 },
	{ 0xF0A7AE83, 0x7DCE7 },
	{ 0xF0A7AE84, 0x7D9C2 },
	{ 0xF0A7AE85, 0x7DFD7 },
	{ 0xF0A7AE86, 0x7DFD8 },
	{ 0xF0A7AE87, 0x7DFD5 },
	{ 0xF0A7AE88, 0x4ECA7 },
	{ 0xF0A7AE89, 0x7DFD6 },
	{ 0xF0A7AE8A, 0x7DFDA },
	{ 0xF0A7AE8B, 0xFEBE5 },
	{ 0xF0A7AE8C, 0xFEBE6 },
	{ 0xF0A7AE8E, 0x7DFD4 },
	{ 0xF0A7AE8F, 0x7DFD9 },
	{ 0xF0A7AE90, 0x7DFDB },
	{ 0xF0A7AE91, 0x4EDA3 },
	{ 0xF0A7AE92, 0x7E1CB },
	{ 0xF0A7AE93, 0x5F9CE },
	{ 0xF0A7AE94, 0x7E1CC },
	{ 0xF0A7AE95, 0xFECBA },
	{ 0xF0A7AE96, 0xFECBB },
	{ 0xF0A7AE98, 0x7E1CA },
	{ 0xF0A7AE99, 0x5FAF5 },
	{ 0xF0A7AE9A, 0x7E2E5 },
	{ 0xF0A7AE9B, 0x7E2E4 },
	{ 0xF0A7AE9D, 0x5FAB9 },
	{ 0xF0A7AE9E, 0x4EDFE },
	{ 0xF0A7AE9F, 0x7E3F4 },
	{ 0xF0A7AEA2, 0x7E4E2 },
	{ 0xF0A7AEA3, 0x4EEBC },
	{ 0xF0A7AEA5, 0x7E4C4 },
	{ 0xF0A7AEA8, 0x7E5C4 },
	{ 0xF0A7AEA9, 0x7E6D0 },
	{ 0xF0A7AEAB, 0x5A4F7 },
	{ 0xF0A7AEAC, 0x4B0A4 },
	{ 0xF0A7AEAD, 0x5B0C4 },
	{ 0xF0A7AEAE, 0x5B0C5 },
	{ 0xF0A7AEAF, 0x4B5C8 },
	{ 0xF0A7AEB0, 0x4B5C9 },
	{ 0xF0A7AEB1, 0x4B5C7 },
	{ 0xF0A7AEB2, 0x6C4FB },
	{ 0xF0A7AEB3, 0x4BBBA },
	{ 0xF0A7AEB5, 0x5C2FE },
	{ 0xF0A7AEB6, 0x5C3A1 },
	{ 0xF0A7AEB7, 0x6D8CC },
	{ 0xF0A7AEB8, 0x4C7CD },
	{ 0xF0A7AEBA, 0x5D1AC },
	{ 0xF0A7AEBB, 0x4CDE3 },
	{ 0xF0A7AEBC, 0x5D1AD },
	{ 0xF0A7AEBD, 0x5D1AB },
	{ 0xF0A7AF80, 0x5D8C2 },
	{ 0xF0A7AF81, 0x7B3D6 },
	{ 0xF0A7AF82, 0x7B3D5 },
	{ 0xF0A7AF86, 0x7BCAA },
	{ 0xF0A7AF89, 0x5DED7 },
	{ 0xF0A7AF8A, 0x7C3BE },
	{ 0xF0A7AF8B, 0x7CAB6 },
	{ 0xF0A7AF8C, 0x7CAB9 },
	{ 0xF0A7AF8D, 0x5E9D4 },
	{ 0xF0A7AF8E, 0x7CAB7 },
	{ 0xF0A7AF8F, 0x5E9D5 },
	{ 0xF0A7AF90, 0x7CAB8 },
	{ 0xF0A7AF93, 0x7D0BA },
	{ 0xF0A7AF94, 0x7CABA },
	{ 0xF0A7AF95, 0x5F1BE },
	{ 0xF0A7AF98, 0x5FAF6 },
	{ 0xF0A7AF99, 0x7E5F7 },
	{ 0xF0A7AF9A, 0x6B4D5 },
	{ 0xF0A7AF9B, 0x6BCB5 },
	{ 0xF0A7AF9C, 0x6BCB4 },
	{ 0xF0A7AF9F, 0xFB8D7 },
	{ 0xF0A7AFA0, 0x4BBBB },
	{ 0xF0A7AFA1, 0x5BCBE },
	{ 0xF0A7AFA2, 0x6CEFB },
	{ 0xF0A7AFA3, 0xFBFBD },
	{ 0xF0A7AFA5, 0x5C3A2 },
	{ 0xF0A7AFA6, 0x4C0F5 },
	{ 0xF0A7AFA7, 0x6DBDF },
	{ 0xF0A7AFA9, 0x4C7D0 },
	{ 0xF0A7AFAA, 0x6E2D4 },
	{ 0xF0A7AFAB, 0x4C7D1 },
	{ 0xF0A7AFAD, 0x7A9A8 },
	{ 0xF0A7AFAE, 0x7A9A7 },
	{ 0xF0A7AFAF, 0x7A9A5 },
	{ 0xF0A7AFB0, 0x5D1AF },
	{ 0xF0A7AFB1, 0x5D1AE },
	{ 0xF0A7AFB3, 0x7A9A6 },
	{ 0xF0A7AFB4, 0xFD2BB },
	{ 0xF0A7AFB7, 0x5D8C3 },
	{ 0xF0A7AFB8, 0x4D3F4 },
	{ 0xF0A7AFB9, 0x7B3D7 },
	{ 0xF0A7AFBA, 0x5D8C4 },
	{ 0xF0A7AFBB, 0x7ACD6 },
	{ 0xF0A7AFBC, 0x5DEDA },
	{ 0xF0A7AFBD, 0x7BCAD },
	{ 0xF0A7AFBE, 0x5DED8 },
	{ 0xF0A7AFBF, 0x7BCAC },
	{ 0xF0A7B080, 0x5DED9 },
	{ 0xF0A7B081, 0x7BCAB },
	{ 0xF0A7B083, 0x5E4E9 },
	{ 0xF0A7B084, 0x4DDE3 },
	{ 0xF0A7B085, 0x7C3C0 },
	{ 0xF0A7B086, 0x4DDE2 },
	{ 0xF0A7B087, 0x5DEDB },
	{ 0xF0A7B089, 0x7CABC },
	{ 0xF0A7B08A, 0x5E9D7 },
	{ 0xF0A7B08B, 0x7CABD },
	{ 0xF0A7B08C, 0x7C3C1 },
	{ 0xF0A7B08D, 0x7C3C2 },
	{ 0xF0A7B090, 0x5E9D6 },
	{ 0xF0A7B091, 0x5EDE6 },
	{ 0xF0A7B092, 0x5EDE5 },
	{ 0xF0A7B093, 0x5EDE7 },
	{ 0xF0A7B094, 0xFE6BA },
	{ 0xF0A7B095, 0x5EDE4 },
	{ 0xF0A7B096, 0xFE3FB },
	{ 0xF0A7B098, 0x5F1BF },
	{ 0xF0A7B099, 0x5F4C1 },
	{ 0xF0A7B09D, 0xFEAF6 },
	{ 0xF0A7B09E, 0xFEAF7 },
	{ 0xF0A7B0A0, 0x5F8B2 },
	{ 0xF0A7B0A1, 0x5F9CF },
	{ 0xF0A7B0A3, 0x5FAF7 },
	{ 0xF0A7B0A5, 0x7E5C5 },
	{ 0xF0A7B0A7, 0x6A5D4 },
	{ 0xF0A7B0A8, 0x5A3A9 },
	{ 0xF0A7B0A9, 0x5ABCA },
	{ 0xF0A7B0AA, 0x5B0C8 },
	{ 0xF0A7B0AB, 0x5B0C7 },
	{ 0xF0A7B0AC, 0x6BCB7 },
	{ 0xF0A7B0AD, 0x6BCB6 },
	{ 0xF0A7B0AE, 0x6C4FE },
	{ 0xF0A7B0AF, 0x6C4FC },
	{ 0xF0A7B0B0, 0x5B5E1 },
	{ 0xF0A7B0B2, 0x6C5A1 },
	{ 0xF0A7B0B4, 0x6C4FD },
	{ 0xF0A7B0B5, 0x4BBBC },
	{ 0xF0A7B0B6, 0x6CEFC },
	{ 0xF0A7B0B7, 0x4BBBD },
	{ 0xF0A7B0B8, 0x5BCC0 },
	{ 0xF0A7B0B9, 0x5BCBF },
	{ 0xF0A7B0BA, 0x6CEFE },
	{ 0xF0A7B0BB, 0x5BCC1 },
	{ 0xF0A7B0BC, 0x6CFA3 },
	{ 0xF0A7B0BD, 0x6CEFD },
	{ 0xF0A7B0BE, 0xFB2D5 },
	{ 0xF0A7B0BF, 0x4C0F7 },
	{ 0xF0A7B180, 0x5C3A5 },
	{ 0xF0A7B181, 0x4C0F6 },
	{ 0xF0A7B182, 0x6D8CE },
	{ 0xF0A7B183, 0x6D8CF },
	{ 0xF0A7B184, 0x5C3A7 },
	{ 0xF0A7B185, 0x5C3A3 },
	{ 0xF0A7B186, 0x5C3A6 },
	{ 0xF0A7B187, 0x6D8CD },
	{ 0xF0A7B188, 0x6CFA2 },
	{ 0xF0A7B189, 0x5C3A4 },
	{ 0xF0A7B18A, 0x5C3A8 },
	{ 0xF0A7B18D, 0x6E2D5 },
	{ 0xF0A7B18E, 0x6E2D6 },
	{ 0xF0A7B18F, 0x4C7D3 },
	{ 0xF0A7B190, 0x4C7D2 },
	{ 0xF0A7B191, 0x6E2D9 },
	{ 0xF0A7B192, 0x5C9FD },
	{ 0xF0A7B193, 0x5C9FC },
	{ 0xF0A7B194, 0x6E2DB },
	{ 0xF0A7B195, 0x6E2DA },
	{ 0xF0A7B196, 0x6E2D7 },
	{ 0xF0A7B197, 0x6E2D8 },
	{ 0xF0A7B198, 0x5D1B2 },
	{ 0xF0A7B199, 0x4CDE6 },
	{ 0xF0A7B19A, 0x7A9A9 },
	{ 0xF0A7B19B, 0x7A9AB },
	{ 0xF0A7B19C, 0x5D1B1 },
	{ 0xF0A7B19D, 0x5D1B3 },
	{ 0xF0A7B19E, 0x7A9AD },
	{ 0xF0A7B19F, 0x7A9AC },
	{ 0xF0A7B1A0, 0x5C9FE },
	{ 0xF0A7B1A1, 0x5D1B0 },
	{ 0xF0A7B1A2, 0x7A9AA },
	{ 0xF0A7B1A3, 0x5CAA1 },
	{ 0xF0A7B1A4, 0x7A9AE },
	{ 0xF0A7B1A5, 0xFD2BC },
	{ 0xF0A7B1A8, 0x5D8C7 },
	{ 0xF0A7B1A9, 0x5D8C8 },
	{ 0xF0A7B1AA, 0x5D8C6 },
	{ 0xF0A7B1AB, 0x7B3D9 },
	{ 0xF0A7B1AC, 0x4D3F6 },
	{ 0xF0A7B1AD, 0x7B3DA },
	{ 0xF0A7B1AE, 0x7B3DC },
	{ 0xF0A7B1AF, 0x7B3DB },
	{ 0xF0A7B1B0, 0x5D8C5 },
	{ 0xF0A7B1B1, 0x7B3D8 },
	{ 0xF0A7B1B2, 0x5DEDD },
	{ 0xF0A7B1B3, 0x5DEDE },
	{ 0xF0A7B1B4, 0x5DEDF },
	{ 0xF0A7B1B5, 0x5DEDC },
	{ 0xF0A7B1B6, 0x7BCB0 },
	{ 0xF0A7B1B7, 0x7BCAE },
	{ 0xF0A7B1B8, 0x7BCAF },
	{ 0xF0A7B1BB, 0x4DDE5 },
	{ 0xF0A7B1BC, 0x5E4EA },
	{ 0xF0A7B1BE, 0x5E4EB },
	{ 0xF0A7B1BF, 0x7C3C3 },
	{ 0xF0A7B280, 0x7C3C4 },
	{ 0xF0A7B281, 0x7C3C5 },
	{ 0xF0A7B282, 0x4E1C7 },
	{ 0xF0A7B283, 0x5E9D8 },
	{ 0xF0A7B284, 0x5D8C9 },
	{ 0xF0A7B285, 0x7CABE },
	{ 0xF0A7B286, 0x4E1C9 },
	{ 0xF0A7B287, 0x5EDEB },
	{ 0xF0A7B288, 0x5EDE8 },
	{ 0xF0A7B289, 0x7D0BB },
	{ 0xF0A7B28A, 0x5EDEA },
	{ 0xF0A7B28B, 0x5EDE9 },
	{ 0xF0A7B28C, 0x4E7C6 },
	{ 0xF0A7B28D, 0x5F1C0 },
	{ 0xF0A7B28E, 0x7D5B7 },
	{ 0xF0A7B28F, 0x7D5B8 },
	{ 0xF0A7B290, 0x7D9C3 },
	{ 0xF0A7B291, 0x7DCEC },
	{ 0xF0A7B292, 0x7D9C4 },
	{ 0xF0A7B293, 0x7D9C5 },
	{ 0xF0A7B294, 0x7DCED },
	{ 0xF0A7B295, 0x7DCEE },
	{ 0xF0A7B297, 0x5F4C2 },
	{ 0xF0A7B298, 0x7DFDC },
	{ 0xF0A7B29A, 0x7E1CD },
	{ 0xF0A7B29B, 0x7DFDD },
	{ 0xF0A7B29C, 0x5F9D0 },
	{ 0xF0A7B29D, 0x5FABA },
	{ 0xF0A7B29E, 0x7E5C6 },
	{ 0xF0A7B29F, 0x7E6C3 },
	{ 0xF0A7B2A0, 0xFA8EC },
	{ 0xF0A7B2A1, 0x5ABCB },
	{ 0xF0A7B2A2, 0x6BCB8 },
	{ 0xF0A7B2A3, 0xFB2D6 },
	{ 0xF0A7B2A4, 0x5B5E4 },
	{ 0xF0A7B2A5, 0x5B5E3 },
	{ 0xF0A7B2A6, 0x4B5CF },
	{ 0xF0A7B2A7, 0x5B5E2 },
	{ 0xF0A7B2A8, 0x4B5CE },
	{ 0xF0A7B2A9, 0x6C5A5 },
	{ 0xF0A7B2AA, 0x6C5A3 },
	{ 0xF0A7B2AC, 0x6CFA5 },
	{ 0xF0A7B2AD, 0x5BCC2 },
	{ 0xF0A7B2AE, 0x5BCC6 },
	{ 0xF0A7B2AF, 0x5BCC4 },
	{ 0xF0A7B2B0, 0x5BCC8 },
	{ 0xF0A7B2B1, 0x5BCC5 },
	{ 0xF0A7B2B2, 0x6CFA8 },
	{ 0xF0A7B2B3, 0x6CFA6 },
	{ 0xF0A7B2B4, 0x5BCC7 },
	{ 0xF0A7B2B5, 0x5BCC3 },
	{ 0xF0A7B2B6, 0x6CFA7 },
	{ 0xF0A7B2B7, 0x6CFA4 },
	{ 0xF0A7B2B9, 0xFBFBE },
	{ 0xF0A7B2BE, 0x4C0FC },
	{ 0xF0A7B2BF, 0x4C0FD },
	{ 0xF0A7B380, 0x4C0FA },
	{ 0xF0A7B381, 0x6D8D2 },
	{ 0xF0A7B382, 0x5C3AB },
	{ 0xF0A7B383, 0x6D8D1 },
	{ 0xF0A7B384, 0x5C3AA },
	{ 0xF0A7B385, 0x4C0F9 },
	{ 0xF0A7B386, 0x4C0FB },
	{ 0xF0A7B387, 0x6D8D3 },
	{ 0xF0A7B388, 0xFC5C7 },
	{ 0xF0A7B389, 0x5C3A9 },
	{ 0xF0A7B38A, 0x6E2E1 },
	{ 0xF0A7B38B, 0x6E2DC },
	{ 0xF0A7B38C, 0x5CAA5 },
	{ 0xF0A7B38D, 0x5CAA3 },
	{ 0xF0A7B38E, 0x5CAA2 },
	{ 0xF0A7B38F, 0x6E2DF },
	{ 0xF0A7B390, 0x5CAA4 },
	{ 0xF0A7B391, 0x6E2DE },
	{ 0xF0A7B392, 0x6E2E0 },
	{ 0xF0A7B393, 0xFCCC8 },
	{ 0xF0A7B394, 0x6E2DD },
	{ 0xF0A7B396, 0x6E2E2 },
	{ 0xF0A7B397, 0xFCCC9 },
	{ 0xF0A7B399, 0x5D1B5 },
	{ 0xF0A7B39A, 0x5D1B4 },
	{ 0xF0A7B39B, 0x4CDE9 },
	{ 0xF0A7B39C, 0x5D1B7 },
	{ 0xF0A7B39D, 0x5D1B6 },
	{ 0xF0A7B39E, 0x5D1B8 },
	{ 0xF0A7B39F, 0x4CDEA },
	{ 0xF0A7B3A0, 0x7A9AF },
	{ 0xF0A7B3A1, 0x7A9B0 },
	{ 0xF0A7B3A2, 0x4CDEB },
	{ 0xF0A7B3A5, 0x7A9B1 },
	{ 0xF0A7B3A6, 0x7B3E4 },
	{ 0xF0A7B3A7, 0x5D8CB },
	{ 0xF0A7B3A8, 0x7B3DE },
	{ 0xF0A7B3A9, 0x7B3E0 },
	{ 0xF0A7B3AA, 0x7B3E1 },
	{ 0xF0A7B3AB, 0x4D3F8 },
	{ 0xF0A7B3AC, 0x5D8CA },
	{ 0xF0A7B3AD, 0x7B3E2 },
	{ 0xF0A7B3AE, 0x5D8CC },
	{ 0xF0A7B3AF, 0x7B3DF },
	{ 0xF0A7B3B1, 0xFD7FA },
	{ 0xF0A7B3B2, 0x7B3DD },
	{ 0xF0A7B3B3, 0x7B3E3 },
	{ 0xF0A7B3B5, 0x4D8F9 },
	{ 0xF0A7B3B6, 0x5DEE3 },
	{ 0xF0A7B3B7, 0x7BCB1 },
	{ 0xF0A7B3B8, 0x5DEE2 },
	{ 0xF0A7B3B9, 0x4D8F8 },
	{ 0xF0A7B3BA, 0x5DEE0 },
	{ 0xF0A7B3BB, 0x5DEE4 },
	{ 0xF0A7B3BC, 0x5DEE1 },
	{ 0xF0A7B3BE, 0xFDCEC },
	{ 0xF0A7B481, 0x7C3C6 },
	{ 0xF0A7B482, 0x4DDE7 },
	{ 0xF0A7B483, 0x7C3C7 },
	{ 0xF0A7B484, 0x4DDE6 },
	{ 0xF0A7B485, 0x5E4EC },
	{ 0xF0A7B486, 0x7CABF },
	{ 0xF0A7B487, 0x5E4ED },
	{ 0xF0A7B48C, 0x5E9DB },
	{ 0xF0A7B48D, 0x7CAC0 },
	{ 0xF0A7B48E, 0x5E9DA },
	{ 0xF0A7B48F, 0x7CAC3 },
	{ 0xF0A7B490, 0x7D0BD },
	{ 0xF0A7B494, 0x7CAC2 },
	{ 0xF0A7B495, 0x5E9D9 },
	{ 0xF0A7B496, 0x5EDED },
	{ 0xF0A7B497, 0x5EDEC },
	{ 0xF0A7B498, 0x7D0BC },
	{ 0xF0A7B499, 0x5F1C2 },
	{ 0xF0A7B49A, 0x5EDEE },
	{ 0xF0A7B49D, 0x5F1C1 },
	{ 0xF0A7B49E, 0x7D5B9 },
	{ 0xF0A7B49F, 0x7D9C6 },
	{ 0xF0A7B4A0, 0x7DCF0 },
	{ 0xF0A7B4A1, 0x7DCEF },
	{ 0xF0A7B4A3, 0x5FAF8 },
	{ 0xF0A7B4A4, 0x5ABCC },
	{ 0xF0A7B4A5, 0x4ABCA },
	{ 0xF0A7B4A6, 0x6B4D6 },
	{ 0xF0A7B4A8, 0xFADCA },
	{ 0xF0A7B4AA, 0x4B0A6 },
	{ 0xF0A7B4AB, 0x6BCB9 },
	{ 0xF0A7B4AC, 0x5B0C9 },
	{ 0xF0A7B4AD, 0x5B0CA },
	{ 0xF0A7B4B0, 0xFB2D7 },
	{ 0xF0A7B4B1, 0xFB2D8 },
	{ 0xF0A7B4B2, 0x6BCBA },
	{ 0xF0A7B4B3, 0x6C5AA },
	{ 0xF0A7B4B5, 0x6C5AC },
	{ 0xF0A7B4B6, 0x6C5A7 },
	{ 0xF0A7B4B7, 0x6C5A8 },
	{ 0xF0A7B4B8, 0x6C5A6 },
	{ 0xF0A7B4B9, 0x6C5AB },
	{ 0xF0A7B4BA, 0x5B5E5 },
	{ 0xF0A7B4BB, 0xFB8D9 },
	{ 0xF0A7B4BC, 0xFB8DA },
	{ 0xF0A7B4BD, 0xFB8DB },
	{ 0xF0A7B4BE, 0xFB8DC },
	{ 0xF0A7B4BF, 0xFB8DD },
	{ 0xF0A7B580, 0xFB8DE },
	{ 0xF0A7B581, 0xFB8DF },
	{ 0xF0A7B582, 0xFB8E0 },
	{ 0xF0A7B584, 0x6C5AD },
	{ 0xF0A7B585, 0x4B5D3 },
	{ 0xF0A7B587, 0x6C5A9 },
	{ 0xF0A7B588, 0x4B5D2 },
	{ 0xF0A7B589, 0x6CFAB },
	{ 0xF0A7B58A, 0x4BBC0 },
	{ 0xF0A7B58B, 0x5BCC9 },
	{ 0xF0A7B58C, 0x5BCCB },
	{ 0xF0A7B58D, 0x6CFAE },
	{ 0xF0A7B58E, 0x6CFAC },
	{ 0xF0A7B58F, 0x6CFAD },
	{ 0xF0A7B590, 0x6D8D7 },
	{ 0xF0A7B591, 0x5BCCA },
	{ 0xF0A7B595, 0xFBFBF },
	{ 0xF0A7B596, 0xFBFC1 },
	{ 0xF0A7B597, 0xFBFC2 },
	{ 0xF0A7B598, 0xFBFC3 },
	{ 0xF0A7B599, 0xFBFC4 },
	{ 0xF0A7B59A, 0xFBFC5 },
	{ 0xF0A7B59C, 0x6CFAF },
	{ 0xF0A7B59D, 0x6CFAA },
	{ 0xF0A7B5A0, 0x5BCCD },
	{ 0xF0A7B5A3, 0x4C1A2 },
	{ 0xF0A7B5A4, 0x6D8D4 },
	{ 0xF0A7B5A5, 0x6D8D9 },
	{ 0xF0A7B5A6, 0x6D8D6 },
	{ 0xF0A7B5A7, 0x5C3B0 },
	{ 0xF0A7B5A8, 0x5C3AC },
	{ 0xF0A7B5A9, 0x6D8DE },
	{ 0xF0A7B5AA, 0x6D8D5 },
	{ 0xF0A7B5AB, 0x5C3AF },
	{ 0xF0A7B5AC, 0x5C3B1 },
	{ 0xF0A7B5AD, 0x5C3B2 },
	{ 0xF0A7B5AE, 0x6D8D8 },
	{ 0xF0A7B5AF, 0x6D8E0 },
	{ 0xF0A7B5B0, 0x6D8E2 },
	{ 0xF0A7B5B1, 0x5C3B3 },
	{ 0xF0A7B5B2, 0x6D8DF },
	{ 0xF0A7B5B4, 0xFC5C8 },
	{ 0xF0A7B5B5, 0xFC5C9 },
	{ 0xF0A7B5B6, 0xFC5CA },
	{ 0xF0A7B5B7, 0xFC5CB },
	{ 0xF0A7B5B8, 0xFC5CC },
	{ 0xF0A7B5B9, 0xFC5CD },
	{ 0xF0A7B5BA, 0xFC5CE },
	{ 0xF0A7B5BD, 0x6D8E1 },
	{ 0xF0A7B5BE, 0xFBFC0 },
	{ 0xF0A7B5BF, 0x6D8DB },
	{ 0xF0A7B682, 0x5C3AE },
	{ 0xF0A7B683, 0xFC6B4 },
	{ 0xF0A7B685, 0x6E2E5 },
	{ 0xF0A7B686, 0x4C7D5 },
	{ 0xF0A7B687, 0x5CAA6 },
	{ 0xF0A7B688, 0x6E2E4 },
	{ 0xF0A7B689, 0x6E2E6 },
	{ 0xF0A7B68A, 0x6E2EC },
	{ 0xF0A7B68B, 0x6E2E3 },
	{ 0xF0A7B68C, 0x6E2E9 },
	{ 0xF0A7B68D, 0x5CAA7 },
	{ 0xF0A7B68E, 0x4C7D7 },
	{ 0xF0A7B690, 0xFCCCD },
	{ 0xF0A7B691, 0xFCCCE },
	{ 0xF0A7B692, 0xFCCCF },
	{ 0xF0A7B693, 0xFCCD1 },
	{ 0xF0A7B697, 0xFCCD0 },
	{ 0xF0A7B698, 0xFCCCC },
	{ 0xF0A7B699, 0x6E2EB },
	{ 0xF0A7B69A, 0x6D8DD },
	{ 0xF0A7B69B, 0x7A9B3 },
	{ 0xF0A7B69C, 0x7A9B5 },
	{ 0xF0A7B69D, 0x5CAA8 },
	{ 0xF0A7B69E, 0x4CDEF },
	{ 0xF0A7B69F, 0x7A9B4 },
	{ 0xF0A7B6A0, 0x5D1BA },
	{ 0xF0A7B6A1, 0x4CDF0 },
	{ 0xF0A7B6A2, 0x5D1BB },
	{ 0xF0A7B6A3, 0x7A9B9 },
	{ 0xF0A7B6A4, 0x7A9B8 },
	{ 0xF0A7B6A5, 0x7A9B2 },
	{ 0xF0A7B6A6, 0xFD2BD },
	{ 0xF0A7B6A7, 0xFD2BE },
	{ 0xF0A7B6A8, 0xFD2BF },
	{ 0xF0A7B6AA, 0x7A9B7 },
	{ 0xF0A7B6B0, 0xFCCCB },
	{ 0xF0A7B6B1, 0x7B3EA },
	{ 0xF0A7B6B2, 0x5D8CE },
	{ 0xF0A7B6B3, 0x7B3E7 },
	{ 0xF0A7B6B4, 0x7B3E6 },
	{ 0xF0A7B6B5, 0x5D8CF },
	{ 0xF0A7B6B6, 0x7B3EB },
	{ 0xF0A7B6B7, 0x7B3EE },
	{ 0xF0A7B6B8, 0x4D3FC },
	{ 0xF0A7B6B9, 0x7B3E8 },
	{ 0xF0A7B6BA, 0x5D8CD },
	{ 0xF0A7B6BB, 0x6E2E8 },
	{ 0xF0A7B6BC, 0xFD4B2 },
	{ 0xF0A7B6BE, 0xFD7FB },
	{ 0xF0A7B6BF, 0xFD7FC },
	{ 0xF0A7B780, 0xFD7FD },
	{ 0xF0A7B781, 0xFD7FE },
	{ 0xF0A7B782, 0xFD8A1 },
	{ 0xF0A7B783, 0xFD8A2 },
	{ 0xF0A7B784, 0x7B3ED },
	{ 0xF0A7B787, 0x7B3EC },
	{ 0xF0A7B789, 0x7B3E5 },
	{ 0xF0A7B78A, 0x7B3E9 },
	{ 0xF0A7B78B, 0x5D8D0 },
	{ 0xF0A7B78C, 0x7BCB2 },
	{ 0xF0A7B78D, 0x5DEE5 },
	{ 0xF0A7B78E, 0x5DBAD },
	{ 0xF0A7B78F, 0x5DEE7 },
	{ 0xF0A7B790, 0x5D8D2 },
	{ 0xF0A7B791, 0x5DEE6 },
	{ 0xF0A7B792, 0x4D8FB },
	{ 0xF0A7B793, 0x7BCB8 },
	{ 0xF0A7B794, 0x7BCB4 },
	{ 0xF0A7B795, 0x7BCB6 },
	{ 0xF0A7B796, 0x7BCB7 },
	{ 0xF0A7B797, 0x7BCB5 },
	{ 0xF0A7B799, 0xFDCEE },
	{ 0xF0A7B79A, 0xFDCF0 },
	{ 0xF0A7B79C, 0xFDCEF },
	{ 0xF0A7B79E, 0x7C3CB },
	{ 0xF0A7B79F, 0x5E4F3 },
	{ 0xF0A7B7A0, 0x7C3CE },
	{ 0xF0A7B7A1, 0x5E4EF },
	{ 0xF0A7B7A2, 0x7C3C9 },
	{ 0xF0A7B7A3, 0x7C3CA },
	{ 0xF0A7B7A4, 0x7C3D1 },
	{ 0xF0A7B7A5, 0x5E4F1 },
	{ 0xF0A7B7A6, 0x5E4EE },
	{ 0xF0A7B7A7, 0x5E4F2 },
	{ 0xF0A7B7A8, 0x7C3CD },
	{ 0xF0A7B7A9, 0x7C3CC },
	{ 0xF0A7B7AB, 0xFE0F6 },
	{ 0xF0A7B7AC, 0xFE0F7 },
	{ 0xF0A7B7AD, 0xFE0F8 },
	{ 0xF0A7B7AE, 0xFE0F9 },
	{ 0xF0A7B7AF, 0xFE0FB },
	{ 0xF0A7B7B0, 0xFE0FC },
	{ 0xF0A7B7B2, 0x7C3C8 },
	{ 0xF0A7B7B5, 0x7C3D0 },
	{ 0xF0A7B7BB, 0x5E4F0 },
	{ 0xF0A7B7BC, 0x7CAC7 },
	{ 0xF0A7B7BD, 0x7CACB },
	{ 0xF0A7B7BE, 0x5E9DD },
	{ 0xF0A7B7BF, 0x5E4F4 },
	{ 0xF0A7B880, 0x7CACA },
	{ 0xF0A7B881, 0x7C3CF },
	{ 0xF0A7B882, 0x5E9DC },
	{ 0xF0A7B883, 0x4E1CB },
	{ 0xF0A7B884, 0x7CAC8 },
	{ 0xF0A7B885, 0x5E9DE },
	{ 0xF0A7B886, 0x7CACD },
	{ 0xF0A7B887, 0x7CACC },
	{ 0xF0A7B888, 0x5E9E0 },
	{ 0xF0A7B889, 0x7CAC4 },
	{ 0xF0A7B88A, 0x7CAC9 },
	{ 0xF0A7B88B, 0x7CAC6 },
	{ 0xF0A7B88C, 0xFE3FC },
	{ 0xF0A7B88D, 0xFE3FD },
	{ 0xF0A7B88E, 0xFE3FE },
	{ 0xF0A7B88F, 0xFE4A1 },
	{ 0xF0A7B891, 0x7CACE },
	{ 0xF0A7B894, 0x7CAC5 },
	{ 0xF0A7B895, 0x5E9DF },
	{ 0xF0A7B896, 0x4E4D1 },
	{ 0xF0A7B897, 0x5EDF0 },
	{ 0xF0A7B898, 0x4E4D0 },
	{ 0xF0A7B899, 0x5EDEF },
	{ 0xF0A7B89A, 0x7D0BE },
	{ 0xF0A7B89E, 0x7D0C0 },
	{ 0xF0A7B8A0, 0xFE6BB },
	{ 0xF0A7B8A1, 0xFE6BC },
	{ 0xF0A7B8A2, 0xFE6BD },
	{ 0xF0A7B8A3, 0xFE6BE },
	{ 0xF0A7B8A4, 0xFE6BF },
	{ 0xF0A7B8A5, 0x7D0BF },
	{ 0xF0A7B8A6, 0x5F1C3 },
	{ 0xF0A7B8A7, 0x4E7C7 },
	{ 0xF0A7B8A8, 0x5F1C4 },
	{ 0xF0A7B8AB, 0x5F1C5 },
	{ 0xF0A7B8AD, 0xFE8CE },
	{ 0xF0A7B8AE, 0xFE8CF },
	{ 0xF0A7B8AF, 0x7D5BB },
	{ 0xF0A7B8B1, 0x7D9C7 },
	{ 0xF0A7B8B2, 0x5F4C5 },
	{ 0xF0A7B8B3, 0x5F4C4 },
	{ 0xF0A7B8B4, 0xFE9F6 },
	{ 0xF0A7B8B5, 0xFE9F7 },
	{ 0xF0A7B8B6, 0xFE9F8 },
	{ 0xF0A7B8B7, 0x7D9CA },
	{ 0xF0A7B8B8, 0x7D9C8 },
	{ 0xF0A7B8B9, 0x7D9C9 },
	{ 0xF0A7B8BC, 0xFE8CD },
	{ 0xF0A7B8BD, 0x7DCF1 },
	{ 0xF0A7B8BE, 0x4EBA2 },
	{ 0xF0A7B8BF, 0x5F4C3 },
	{ 0xF0A7B980, 0x7DCF2 },
	{ 0xF0A7B983, 0xFEAF8 },
	{ 0xF0A7B986, 0x7DCF3 },
	{ 0xF0A7B987, 0x7DFDE },
	{ 0xF0A7B988, 0x7DFE0 },
	{ 0xF0A7B989, 0x7DFDF },
	{ 0xF0A7B98E, 0x7E2E6 },
	{ 0xF0A7B998, 0x6AEB1 },
	{ 0xF0A7B999, 0x6B4D7 },
	{ 0xF0A7B99A, 0x6B4D8 },
	{ 0xF0A7B99B, 0x5B5E6 },
	{ 0xF0A7B99C, 0xFB8E1 },
	{ 0xF0A7B99D, 0x6CFB0 },
	{ 0xF0A7B99E, 0x4BBC4 },
	{ 0xF0A7B9A0, 0x6D8E3 },
	{ 0xF0A7B9A1, 0xFC5CF },
	{ 0xF0A7B9A3, 0x5CAAA },
	{ 0xF0A7B9A4, 0xFCCD2 },
	{ 0xF0A7B9A7, 0x7A9BA },
	{ 0xF0A7B9AC, 0x5D8D4 },
	{ 0xF0A7B9AD, 0x5D8D3 },
	{ 0xF0A7B9AE, 0xFD8A3 },
	{ 0xF0A7B9AF, 0x7B3EF },
	{ 0xF0A7B9B2, 0x5DEE9 },
	{ 0xF0A7B9B3, 0x5DEEA },
	{ 0xF0A7B9B4, 0x5DEE8 },
	{ 0xF0A7B9B5, 0xFDCF1 },
	{ 0xF0A7B9B6, 0x5E4F5 },
	{ 0xF0A7B9B7, 0x7C3D3 },
	{ 0xF0A7B9B8, 0x7CAD0 },
	{ 0xF0A7B9B9, 0x7CACF },
	{ 0xF0A7B9BD, 0x5F1C6 },
	{ 0xF0A7BA84, 0x7DCF4 },
	{ 0xF0A7BA86, 0x6AEB2 },
	{ 0xF0A7BA87, 0x6AEB3 },
	{ 0xF0A7BA88, 0x6B4D9 },
	{ 0xF0A7BA89, 0xFADCB },
	{ 0xF0A7BA8A, 0xFADCD },
	{ 0xF0A7BA8B, 0xFADCE },
	{ 0xF0A7BA8C, 0xFADCF },
	{ 0xF0A7BA8D, 0xFADD0 },
	{ 0xF0A7BA8E, 0x4ABCB },
	{ 0xF0A7BA8F, 0x5B0CD },
	{ 0xF0A7BA90, 0x6BCBE },
	{ 0xF0A7BA92, 0x6BCBD },
	{ 0xF0A7BA93, 0x5B0CE },
	{ 0xF0A7BA94, 0x6BCBC },
	{ 0xF0A7BA96, 0x4B0A9 },
	{ 0xF0A7BA97, 0xFB2D9 },
	{ 0xF0A7BA98, 0xFB2DA },
	{ 0xF0A7BA99, 0xFB2DB },
	{ 0xF0A7BA9A, 0xFB2DC },
	{ 0xF0A7BA9B, 0xFB2DD },
	{ 0xF0A7BA9D, 0x5B5ED },
	{ 0xF0A7BA9E, 0x6C5B0 },
	{ 0xF0A7BA9F, 0x5B5E7 },
	{ 0xF0A7BAA0, 0x4B5D7 },
	{ 0xF0A7BAA1, 0x5B5EA },
	{ 0xF0A7BAA2, 0x5B5EF },
	{ 0xF0A7BAA3, 0x5B5EE },
	{ 0xF0A7BAA4, 0x4B5D8 },
	{ 0xF0A7BAA5, 0x6C5AE },
	{ 0xF0A7BAA6, 0x6C5AF },
	{ 0xF0A7BAA7, 0x5B5EB },
	{ 0xF0A7BAA8, 0x5B5E8 },
	{ 0xF0A7BAA9, 0xFB8E3 },
	{ 0xF0A7BAAA, 0xFB8E4 },
	{ 0xF0A7BAAB, 0xFB8E5 },
	{ 0xF0A7BAAC, 0xFB8E6 },
	{ 0xF0A7BAAD, 0xFB8E8 },
	{ 0xF0A7BAAE, 0xFB8E9 },
	{ 0xF0A7BAAF, 0xFB8E2 },
	{ 0xF0A7BAB2, 0x5B5EC },
	{ 0xF0A7BAB3, 0x5B5E9 },
	{ 0xF0A7BAB5, 0xFB8E7 },
	{ 0xF0A7BAB6, 0x5BCD1 },
	{ 0xF0A7BAB7, 0x5BCD0 },
	{ 0xF0A7BAB8, 0x5BCD4 },
	{ 0xF0A7BAB9, 0x5BCCF },
	{ 0xF0A7BABA, 0x6CFB4 },
	{ 0xF0A7BABB, 0x6CFB1 },
	{ 0xF0A7BABC, 0x5C3B9 },
	{ 0xF0A7BABD, 0x5BCD3 },
	{ 0xF0A7BABE, 0x5BCCE },
	{ 0xF0A7BABF, 0x6CFB3 },
	{ 0xF0A7BB80, 0x4BBC6 },
	{ 0xF0A7BB81, 0x5BCD5 },
	{ 0xF0A7BB82, 0x6D8E4 },
	{ 0xF0A7BB83, 0x6CFB5 },
	{ 0xF0A7BB84, 0xFBFC7 },
	{ 0xF0A7BB85, 0xFBFC8 },
	{ 0xF0A7BB86, 0xFBFC9 },
	{ 0xF0A7BB87, 0xFBFCA },
	{ 0xF0A7BB88, 0xFBFCB },
	{ 0xF0A7BB89, 0xFBFCC },
	{ 0xF0A7BB8A, 0xFBFCF },
	{ 0xF0A7BB8B, 0xFBFD0 },
	{ 0xF0A7BB8C, 0xFBFD1 },
	{ 0xF0A7BB8E, 0x6CFB2 },
	{ 0xF0A7BB8F, 0xFBFCE },
	{ 0xF0A7BB91, 0x6D8E6 },
	{ 0xF0A7BB92, 0x5C3B6 },
	{ 0xF0A7BB93, 0x4C1A3 },
	{ 0xF0A7BB94, 0x6D8E8 },
	{ 0xF0A7BB95, 0x4C1A5 },
	{ 0xF0A7BB96, 0x5C3BB },
	{ 0xF0A7BB97, 0x5C3B5 },
	{ 0xF0A7BB98, 0x5C3BD },
	{ 0xF0A7BB99, 0x5C3B7 },
	{ 0xF0A7BB9A, 0x4C1A4 },
	{ 0xF0A7BB9B, 0x6D8EA },
	{ 0xF0A7BB9C, 0x6D8E9 },
	{ 0xF0A7BB9D, 0x5C3BA },
	{ 0xF0A7BB9F, 0xFC5D0 },
	{ 0xF0A7BBA0, 0xFC5D1 },
	{ 0xF0A7BBA1, 0xFC5D2 },
	{ 0xF0A7BBA2, 0xFC5D3 },
	{ 0xF0A7BBA3, 0xFC5D4 },
	{ 0xF0A7BBA4, 0xFC5D5 },
	{ 0xF0A7BBA5, 0xFC5D6 },
	{ 0xF0A7BBA6, 0xFC5D7 },
	{ 0xF0A7BBA7, 0x6D8E5 },
	{ 0xF0A7BBAB, 0x6D8E7 },
	{ 0xF0A7BBAC, 0x6E2ED },
	{ 0xF0A7BBAE, 0xFBFCD },
	{ 0xF0A7BBAF, 0x6E2EE },
	{ 0xF0A7BBB0, 0x4C7DC },
	{ 0xF0A7BBB1, 0x5CAAC },
	{ 0xF0A7BBB2, 0x5CAB0 },
	{ 0xF0A7BBB3, 0x6E2F2 },
	{ 0xF0A7BBB4, 0x5CAAB },
	{ 0xF0A7BBB5, 0x5CAAE },
	{ 0xF0A7BBB6, 0x5CAB1 },
	{ 0xF0A7BBB8, 0x6E2F1 },
	{ 0xF0A7BBB9, 0x6E2EF },
	{ 0xF0A7BBBA, 0x5CAB3 },
	{ 0xF0A7BBBB, 0x4C7DD },
	{ 0xF0A7BBBC, 0x5CAAF },
	{ 0xF0A7BBBD, 0x6E2F6 },
	{ 0xF0A7BBBF, 0x5CAAD },
	{ 0xF0A7BC80, 0x6E2F3 },
	{ 0xF0A7BC81, 0xFCCD3 },
	{ 0xF0A7BC82, 0xFCCD4 },
	{ 0xF0A7BC83, 0xFCCD5 },
	{ 0xF0A7BC84, 0xFCCD6 },
	{ 0xF0A7BC85, 0xFCCD7 },
	{ 0xF0A7BC86, 0xFCCD8 },
	{ 0xF0A7BC87, 0xFCCD9 },
	{ 0xF0A7BC89, 0x6E2F0 },
	{ 0xF0A7BC8E, 0x5D1C2 },
	{ 0xF0A7BC8F, 0x5D1BC },
	{ 0xF0A7BC90, 0x4CDF2 },
	{ 0xF0A7BC91, 0x5D1BF },
	{ 0xF0A7BC92, 0x5D1BE },
	{ 0xF0A7BC93, 0x5D1BD },
	{ 0xF0A7BC94, 0x5D1C0 },
	{ 0xF0A7BC95, 0x7A9BF },
	{ 0xF0A7BC96, 0x5D1C6 },
	{ 0xF0A7BC97, 0x5D1C3 },
	{ 0xF0A7BC98, 0x7A9C1 },
	{ 0xF0A7BC99, 0x5D1C1 },
	{ 0xF0A7BC9A, 0x7A9BC },
	{ 0xF0A7BC9B, 0x7A9C0 },
	{ 0xF0A7BC9C, 0x7A9BE },
	{ 0xF0A7BC9D, 0x6E2F4 },
	{ 0xF0A7BC9E, 0x7A9C2 },
	{ 0xF0A7BC9F, 0x7B3F2 },
	{ 0xF0A7BCA0, 0x5D1C5 },
	{ 0xF0A7BCA1, 0x5D1C4 },
	{ 0xF0A7BCA2, 0xFD2C0 },
	{ 0xF0A7BCA3, 0xFD2C1 },
	{ 0xF0A7BCA5, 0x7A9C3 },
	{ 0xF0A7BCA6, 0x7A9BB },
	{ 0xF0A7BCA7, 0xFD8AD },
	{ 0xF0A7BCA8, 0x4D4A3 },
	{ 0xF0A7BCA9, 0x4D4A4 },
	{ 0xF0A7BCAA, 0x4D4A8 },
	{ 0xF0A7BCAB, 0x7B3F4 },
	{ 0xF0A7BCAC, 0x5D8D9 },
	{ 0xF0A7BCAD, 0x4D4A1 },
	{ 0xF0A7BCAE, 0x4D4A2 },
	{ 0xF0A7BCAF, 0x4D4A7 },
	{ 0xF0A7BCB0, 0x7B3F5 },
	{ 0xF0A7BCB1, 0x4D4A5 },
	{ 0xF0A7BCB2, 0x7B3F1 },
	{ 0xF0A7BCB3, 0x7B3F0 },
	{ 0xF0A7BCB4, 0x5D8D8 },
	{ 0xF0A7BCB5, 0x5D8DA },
	{ 0xF0A7BCB6, 0x7B3F6 },
	{ 0xF0A7BCB7, 0xFD8A4 },
	{ 0xF0A7BCB8, 0xFD8A6 },
	{ 0xF0A7BCB9, 0xFD8A7 },
	{ 0xF0A7BCBA, 0xFD8A8 },
	{ 0xF0A7BCBB, 0xFD8A9 },
	{ 0xF0A7BCBC, 0xFD8AA },
	{ 0xF0A7BCBD, 0xFD8AB },
	{ 0xF0A7BCBE, 0xFD8AC },
	{ 0xF0A7BCBF, 0xFD8AE },
	{ 0xF0A7BD81, 0x7B3F8 },
	{ 0xF0A7BD82, 0x7B3F7 },
	{ 0xF0A7BD84, 0x5D8DB },
	{ 0xF0A7BD85, 0x5D8D6 },
	{ 0xF0A7BD86, 0x5D8D7 },
	{ 0xF0A7BD89, 0x5DEEF },
	{ 0xF0A7BD8A, 0x5DEF1 },
	{ 0xF0A7BD8B, 0x4D9A2 },
	{ 0xF0A7BD8C, 0x5DEF0 },
	{ 0xF0A7BD8D, 0x4D9A4 },
	{ 0xF0A7BD8E, 0x4D9A1 },
	{ 0xF0A7BD8F, 0x5DEF2 },
	{ 0xF0A7BD90, 0x4D8FE },
	{ 0xF0A7BD91, 0x5DEEC },
	{ 0xF0A7BD92, 0x4D9A3 },
	{ 0xF0A7BD93, 0x5DEEE },
	{ 0xF0A7BD94, 0x5DEEB },
	{ 0xF0A7BD95, 0x7BCBA },
	{ 0xF0A7BD96, 0x5DEF3 },
	{ 0xF0A7BD97, 0xFD8A5 },
	{ 0xF0A7BD98, 0xFDCF2 },
	{ 0xF0A7BD99, 0xFDCF3 },
	{ 0xF0A7BD9A, 0xFDCF4 },
	{ 0xF0A7BD9B, 0xFDCF5 },
	{ 0xF0A7BD9C, 0xFDCF6 },
	{ 0xF0A7BD9D, 0x7BCB9 },
	{ 0xF0A7BD9E, 0x5E4F9 },
	{ 0xF0A7BD9F, 0x5E4FC },
	{ 0xF0A7BDA0, 0x4DDEB },
	{ 0xF0A7BDA1, 0x7C3D7 },
	{ 0xF0A7BDA2, 0x7C3D6 },
	{ 0xF0A7BDA3, 0x5E4F6 },
	{ 0xF0A7BDA4, 0x5E4FA },
	{ 0xF0A7BDA5, 0x5E4F8 },
	{ 0xF0A7BDA6, 0x5E4F7 },
	{ 0xF0A7BDA7, 0x5E4FD },
	{ 0xF0A7BDA8, 0x5E4FE },
	{ 0xF0A7BDA9, 0x7C3DB },
	{ 0xF0A7BDAA, 0x7C3DA },
	{ 0xF0A7BDAB, 0x5E4FB },
	{ 0xF0A7BDAC, 0xFE0FD },
	{ 0xF0A7BDAD, 0x7C3D8 },
	{ 0xF0A7BDAF, 0x7C3D5 },
	{ 0xF0A7BDB3, 0x7C3D9 },
	{ 0xF0A7BDB4, 0x7C3D4 },
	{ 0xF0A7BDB6, 0x5D8DD },
	{ 0xF0A7BDB7, 0x5E9E2 },
	{ 0xF0A7BDB8, 0x5E9E6 },
	{ 0xF0A7BDB9, 0x5E9E8 },
	{ 0xF0A7BDBA, 0x4E1CE },
	{ 0xF0A7BDBB, 0x4E1CC },
	{ 0xF0A7BDBC, 0x5E9E3 },
	{ 0xF0A7BDBD, 0x5E9E7 },
	{ 0xF0A7BDBE, 0x5E9E5 },
	{ 0xF0A7BDBF, 0x5E9E1 },
	{ 0xF0A7BE80, 0x7CAD2 },
	{ 0xF0A7BE81, 0x5E9E9 },
	{ 0xF0A7BE82, 0x5E9E4 },
	{ 0xF0A7BE83, 0xFE4A3 },
	{ 0xF0A7BE84, 0xFE4A4 },
	{ 0xF0A7BE85, 0xFE4A5 },
	{ 0xF0A7BE88, 0x7CAD1 },
	{ 0xF0A7BE8B, 0x7CAD3 },
	{ 0xF0A7BE8D, 0x4E4D2 },
	{ 0xF0A7BE8E, 0x4E4D4 },
	{ 0xF0A7BE8F, 0x4E4D8 },
	{ 0xF0A7BE90, 0x4E4D7 },
	{ 0xF0A7BE91, 0x5EDF1 },
	{ 0xF0A7BE92, 0x7D0C1 },
	{ 0xF0A7BE93, 0x7D0C3 },
	{ 0xF0A7BE94, 0x5EDF2 },
	{ 0xF0A7BE95, 0x7D0C2 },
	{ 0xF0A7BE96, 0xFE6C0 },
	{ 0xF0A7BE97, 0xFE6C1 },
	{ 0xF0A7BE98, 0xFE6C2 },
	{ 0xF0A7BE99, 0x4E7C9 },
	{ 0xF0A7BE9A, 0x5F1C8 },
	{ 0xF0A7BE9B, 0x5F1C9 },
	{ 0xF0A7BE9C, 0x7D5BF },
	{ 0xF0A7BE9D, 0x7D5BD },
	{ 0xF0A7BE9E, 0x7D5BC },
	{ 0xF0A7BE9F, 0x7D5BE },
	{ 0xF0A7BEA0, 0x5F1C7 },
	{ 0xF0A7BEA1, 0x5F4C6 },
	{ 0xF0A7BEA2, 0x5F4C9 },
	{ 0xF0A7BEA3, 0x4E9CD },
	{ 0xF0A7BEA4, 0x5F4C8 },
	{ 0xF0A7BEA5, 0x5F4C7 },
	{ 0xF0A7BEA6, 0xFE9F9 },
	{ 0xF0A7BEA8, 0x5F6CF },
	{ 0xF0A7BEA9, 0x5F6D0 },
	{ 0xF0A7BEAA, 0xFEAF9 },
	{ 0xF0A7BEAB, 0x7D9CB },
	{ 0xF0A7BEAC, 0x7DCF5 },
	{ 0xF0A7BEAD, 0x7DCF6 },
	{ 0xF0A7BEAE, 0x5F8B3 },
	{ 0xF0A7BEAF, 0x5F8B4 },
	{ 0xF0A7BEB0, 0x5F8B5 },
	{ 0xF0A7BEB1, 0x4EDA6 },
	{ 0xF0A7BEB4, 0x7E1CE },
	{ 0xF0A7BEB5, 0x5FAF9 },
	{ 0xF0A7BEB6, 0x5FBC9 },
	{ 0xF0A7BEB8, 0x6AEB5 },
	{ 0xF0A7BEB9, 0x6AEB4 },
	{ 0xF0A7BEBA, 0x6B4DB },
	{ 0xF0A7BEBB, 0x5ABCD },
	{ 0xF0A7BEBC, 0xFADD1 },
	{ 0xF0A7BF80, 0x6B4DA },
	{ 0xF0A7BF81, 0x6BCC1 },
	{ 0xF0A7BF82, 0x4B0AB },
	{ 0xF0A7BF83, 0x6BCC2 },
	{ 0xF0A7BF84, 0x6BCC0 },
	{ 0xF0A7BF85, 0x5B0D0 },
	{ 0xF0A7BF86, 0x5B0CF },
	{ 0xF0A7BF89, 0x6BCBF },
	{ 0xF0A7BF8D, 0x6BCC3 },
	{ 0xF0A7BF92, 0x4B5DF },
	{ 0xF0A7BF93, 0x6C5B3 },
	{ 0xF0A7BF94, 0x4B5DA },
	{ 0xF0A7BF95, 0x5B5F3 },
	{ 0xF0A7BF96, 0x6C5B7 },
	{ 0xF0A7BF97, 0x5B5F7 },
	{ 0xF0A7BF98, 0x6C5BA },
	{ 0xF0A7BF99, 0x5B5F1 },
	{ 0xF0A7BF9A, 0x5B5F5 },
	{ 0xF0A7BF9B, 0x6C5BC },
	{ 0xF0A7BF9C, 0x6C5BD },
	{ 0xF0A7BF9D, 0x5B5F4 },
	{ 0xF0A7BF9E, 0x6C5BB },
	{ 0xF0A7BF9F, 0x6C5B2 },
	{ 0xF0A7BFA0, 0x6C5B6 },
	{ 0xF0A7BFA2, 0xFB8EA },
	{ 0xF0A7BFA3, 0x6C5B1 },
	{ 0xF0A7BFA4, 0x6C5B5 },
	{ 0xF0A7BFA6, 0x6C5B9 },
	{ 0xF0A7BFAE, 0x5B5F6 },
	{ 0xF0A7BFAF, 0x5B5F0 },
	{ 0xF0A7BFB1, 0x6C5B4 },
	{ 0xF0A7BFB2, 0x5BCE0 },
	{ 0xF0A7BFB3, 0x5BCD7 },
	{ 0xF0A7BFB4, 0x5BCD8 },
	{ 0xF0A7BFB5, 0x5BCDB },
	{ 0xF0A7BFB6, 0x6CFBB },
	{ 0xF0A7BFB7, 0x5BCD6 },
	{ 0xF0A7BFB8, 0x6CFB8 },
	{ 0xF0A7BFB9, 0x4BBCE },
	{ 0xF0A7BFBA, 0x5BCDD },
	{ 0xF0A7BFBB, 0x5BCD9 },
	{ 0xF0A7BFBC, 0x5BCE1 },
	{ 0xF0A7BFBD, 0x5BCDA },
	{ 0xF0A7BFBE, 0x6CFB9 },
	{ 0xF0A7BFBF, 0x6D8F9 },
	{ 0xF0A88080, 0x5BCE2 },
	{ 0xF0A88083, 0xFBFD4 },
	{ 0xF0A88086, 0x6CFB7 },
	{ 0xF0A88089, 0xFBFD2 },
	{ 0xF0A88093, 0x6CFBA },
	{ 0xF0A88094, 0x5BCDE },
	{ 0xF0A88095, 0x5C3C1 },
	{ 0xF0A88096, 0x5C3BF },
	{ 0xF0A88097, 0x6D8F1 },
	{ 0xF0A88098, 0x5C3C0 },
	{ 0xF0A88099, 0x5C3C2 },
	{ 0xF0A8809A, 0x6D8F4 },
	{ 0xF0A8809B, 0x6D8F0 },
	{ 0xF0A8809C, 0x5C3C7 },
	{ 0xF0A8809D, 0x5C3C5 },
	{ 0xF0A8809E, 0x6D8EE },
	{ 0xF0A8809F, 0x6D8ED },
	{ 0xF0A880A0, 0x5C3BE },
	{ 0xF0A880A1, 0x6D8EF },
	{ 0xF0A880A2, 0x6D8F2 },
	{ 0xF0A880A3, 0x6D8F6 },
	{ 0xF0A880A4, 0x5C3CA },
	{ 0xF0A880A5, 0x6D8EC },
	{ 0xF0A880A6, 0x6D8F7 },
	{ 0xF0A880A7, 0x5C3C3 },
	{ 0xF0A880A8, 0x5C3CC },
	{ 0xF0A880A9, 0x5C3C8 },
	{ 0xF0A880AA, 0x6D8F3 },
	{ 0xF0A880AB, 0x5C3C9 },
	{ 0xF0A880AC, 0x5C3C6 },
	{ 0xF0A880AD, 0x6D8F5 },
	{ 0xF0A880AE, 0x5CAB5 },
	{ 0xF0A880B1, 0xFC5D9 },
	{ 0xF0A880B6, 0x6D8F8 },
	{ 0xF0A880B7, 0x6D8EB },
	{ 0xF0A88180, 0x6E3A2 },
	{ 0xF0A88181, 0x5CAC3 },
	{ 0xF0A88182, 0x4C7E0 },
	{ 0xF0A88183, 0x5CAB7 },
	{ 0xF0A88184, 0x5CABF },
	{ 0xF0A88185, 0x5CAB6 },
	{ 0xF0A88186, 0x5D1CE },
	{ 0xF0A88187, 0x5CABB },
	{ 0xF0A88188, 0x6E2F7 },
	{ 0xF0A88189, 0x6E2FB },
	{ 0xF0A8818A, 0x5CAC2 },
	{ 0xF0A8818B, 0x5CABC },
	{ 0xF0A8818C, 0x5CAB9 },
	{ 0xF0A8818D, 0x5CAC0 },
	{ 0xF0A8818E, 0x5CAC1 },
	{ 0xF0A8818F, 0x5CABD },
	{ 0xF0A88190, 0x5C3C4 },
	{ 0xF0A88191, 0x5CAB8 },
	{ 0xF0A88192, 0x5CAC4 },
	{ 0xF0A88193, 0x6E2FE },
	{ 0xF0A88194, 0x5CAC6 },
	{ 0xF0A88195, 0x6E2F9 },
	{ 0xF0A88199, 0x5CAC7 },
	{ 0xF0A8819A, 0xFCCDA },
	{ 0xF0A8819B, 0xFCCDB },
	{ 0xF0A8819C, 0x6E2F8 },
	{ 0xF0A8819E, 0x6E2FA },
	{ 0xF0A881A0, 0x6E2FD },
	{ 0xF0A881A2, 0x6E3A1 },
	{ 0xF0A881A3, 0x6E2FC },
	{ 0xF0A881B3, 0x5CABA },
	{ 0xF0A881B5, 0x7A9C6 },
	{ 0xF0A881B6, 0x4CDFA },
	{ 0xF0A881B7, 0x5D1CC },
	{ 0xF0A881B8, 0x5D1C7 },
	{ 0xF0A881B9, 0x5D1CA },
	{ 0xF0A881BA, 0x5D1CF },
	{ 0xF0A881BB, 0x7A9C5 },
	{ 0xF0A881BC, 0x7A9C9 },
	{ 0xF0A881BD, 0x4CDFC },
	{ 0xF0A881BE, 0x7A9CD },
	{ 0xF0A881BF, 0x4CDFB },
	{ 0xF0A88280, 0x5D1CB },
	{ 0xF0A88281, 0x5D1CD },
	{ 0xF0A88282, 0x4CEA4 },
	{ 0xF0A88283, 0x5D1D1 },
	{ 0xF0A88284, 0x5D1D2 },
	{ 0xF0A88285, 0x4C7E3 },
	{ 0xF0A88286, 0x7A9CF },
	{ 0xF0A88287, 0x5D1C9 },
	{ 0xF0A88288, 0x7A9CB },
	{ 0xF0A8828B, 0xFD2C2 },
	{ 0xF0A8828C, 0xFD2C3 },
	{ 0xF0A8828D, 0xFD2C4 },
	{ 0xF0A8828E, 0xFD2C5 },
	{ 0xF0A8828F, 0x7A9C8 },
	{ 0xF0A88291, 0x7A9CC },
	{ 0xF0A88293, 0x7A9C7 },
	{ 0xF0A8829B, 0x7A9CA },
	{ 0xF0A8829C, 0x5D1D0 },
	{ 0xF0A8829D, 0x5D1D4 },
	{ 0xF0A8829E, 0x5D1D5 },
	{ 0xF0A8829F, 0x5CAC5 },
	{ 0xF0A882A0, 0x7B4A1 },
	{ 0xF0A882A1, 0x5D8E0 },
	{ 0xF0A882A2, 0x5CAC8 },
	{ 0xF0A882A3, 0x5D8E9 },
	{ 0xF0A882A4, 0x4D4AA },
	{ 0xF0A882A5, 0x7B3FA },
	{ 0xF0A882A6, 0x5D8E3 },
	{ 0xF0A882A7, 0x7B3FE },
	{ 0xF0A882A8, 0x7B4A3 },
	{ 0xF0A882A9, 0x7B3FC },
	{ 0xF0A882AA, 0x5D8DF },
	{ 0xF0A882AB, 0x7B3FB },
	{ 0xF0A882AC, 0x7B4A5 },
	{ 0xF0A882AD, 0x5D1D3 },
	{ 0xF0A882AE, 0x7B4A6 },
	{ 0xF0A882AF, 0x5D8E7 },
	{ 0xF0A882B0, 0x5D8E8 },
	{ 0xF0A882B1, 0x5D8DE },
	{ 0xF0A882B2, 0x5D8E1 },
	{ 0xF0A882B3, 0x7B3FD },
	{ 0xF0A882B4, 0x5D8E5 },
	{ 0xF0A882B5, 0x5D8E4 },
	{ 0xF0A882B6, 0x7B4A4 },
	{ 0xF0A882B7, 0x4D4AB },
	{ 0xF0A882B8, 0x5D8E6 },
	{ 0xF0A882BF, 0x4D4AC },
	{ 0xF0A88380, 0xFD8B1 },
	{ 0xF0A88381, 0xFD8B2 },
	{ 0xF0A88392, 0x7B4A2 },
	{ 0xF0A88393, 0x5DEFA },
	{ 0xF0A88394, 0x5DEFD },
	{ 0xF0A88395, 0x5DEF5 },
	{ 0xF0A88396, 0x7BCC0 },
	{ 0xF0A88397, 0x5DEF6 },
	{ 0xF0A88398, 0x5DEFC },
	{ 0xF0A88399, 0x5DEF8 },
	{ 0xF0A8839A, 0x4D9A9 },
	{ 0xF0A8839B, 0x7BCBE },
	{ 0xF0A8839C, 0x7C3E7 },
	{ 0xF0A8839D, 0x7BCC3 },
	{ 0xF0A8839E, 0x5DEFE },
	{ 0xF0A8839F, 0x4D9AE },
	{ 0xF0A883A0, 0x7BCBB },
	{ 0xF0A883A1, 0x7BCC2 },
	{ 0xF0A883A2, 0x7BCC4 },
	{ 0xF0A883A3, 0x5DEF9 },
	{ 0xF0A883A4, 0x4D9A7 },
	{ 0xF0A883A5, 0x7BCC1 },
	{ 0xF0A883A6, 0x7B4A7 },
	{ 0xF0A883A7, 0x7BCBF },
	{ 0xF0A883A8, 0x4D9AF },
	{ 0xF0A883AC, 0xFDCF7 },
	{ 0xF0A883AE, 0x7BCBD },
	{ 0xF0A883B3, 0xFDCF9 },
	{ 0xF0A883BF, 0x5DEF7 },
	{ 0xF0A88480, 0x5DEF4 },
	{ 0xF0A88483, 0x7C3E2 },
	{ 0xF0A88485, 0x4DDF0 },
	{ 0xF0A88486, 0x7C3E6 },
	{ 0xF0A88487, 0x4DDEF },
	{ 0xF0A88488, 0x5E5A1 },
	{ 0xF0A88489, 0x5E5A2 },
	{ 0xF0A8848A, 0x5E5AD },
	{ 0xF0A8848B, 0x5E5A6 },
	{ 0xF0A8848C, 0x4DDF1 },
	{ 0xF0A8848D, 0x5E5AC },
	{ 0xF0A8848E, 0x5E5A8 },
	{ 0xF0A8848F, 0x7C3DF },
	{ 0xF0A88490, 0x5E9F0 },
	{ 0xF0A88491, 0x7C3E5 },
	{ 0xF0A88492, 0x7C3DC },
	{ 0xF0A88493, 0x5E5AE },
	{ 0xF0A88494, 0x7C3DE },
	{ 0xF0A88495, 0x5E5A4 },
	{ 0xF0A88496, 0x7C3E1 },
	{ 0xF0A88497, 0x5E5A3 },
	{ 0xF0A88498, 0x5E5A9 },
	{ 0xF0A88499, 0x4DFB3 },
	{ 0xF0A8849A, 0x4DDF6 },
	{ 0xF0A8849B, 0x5E5A5 },
	{ 0xF0A884A1, 0xFE0FE },
	{ 0xF0A884A2, 0xFE1A1 },
	{ 0xF0A884A3, 0xFE1A2 },
	{ 0xF0A884A4, 0xFE1A3 },
	{ 0xF0A884A5, 0xFE1A4 },
	{ 0xF0A884A6, 0xFE1A5 },
	{ 0xF0A884A7, 0x7C3EB },
	{ 0xF0A884A8, 0x5E5A7 },
	{ 0xF0A884A9, 0x7C3E0 },
	{ 0xF0A884AA, 0x7C3E9 },
	{ 0xF0A884AB, 0x7C3E8 },
	{ 0xF0A884AC, 0x7C3EA },
	{ 0xF0A884AD, 0x7C3DD },
	{ 0xF0A88585, 0x5E5AB },
	{ 0xF0A88586, 0x7C3E3 },
	{ 0xF0A88588, 0x7BCBC },
	{ 0xF0A8858A, 0x5E5AF },
	{ 0xF0A8858B, 0x5E9EA },
	{ 0xF0A8858C, 0x7CAE5 },
	{ 0xF0A8858E, 0x5E9EF },
	{ 0xF0A8858F, 0x5E9F1 },
	{ 0xF0A88590, 0x7CAE8 },
	{ 0xF0A88591, 0x5E9F4 },
	{ 0xF0A88592, 0x7CADB },
	{ 0xF0A88593, 0x5E5AA },
	{ 0xF0A88594, 0x5E9EE },
	{ 0xF0A88595, 0x7CAD8 },
	{ 0xF0A88596, 0x5E9ED },
	{ 0xF0A88597, 0x5E9F2 },
	{ 0xF0A88598, 0x4E1D5 },
	{ 0xF0A88599, 0x7CAD4 },
	{ 0xF0A8859A, 0x4DDF3 },
	{ 0xF0A8859B, 0x7CAD9 },
	{ 0xF0A8859C, 0x7C3E4 },
	{ 0xF0A8859D, 0x7CADE },
	{ 0xF0A8859E, 0x5E9F3 },
	{ 0xF0A8859F, 0x7CADA },
	{ 0xF0A885A0, 0x7CAE6 },
	{ 0xF0A885A1, 0x7CAD5 },
	{ 0xF0A885A2, 0x7CADC },
	{ 0xF0A885A3, 0x5E9EB },
	{ 0xF0A885A4, 0x5E9EC },
	{ 0xF0A885A5, 0x7CAE1 },
	{ 0xF0A885A6, 0x7CAE2 },
	{ 0xF0A885A7, 0x7CAE3 },
	{ 0xF0A885A8, 0x7CADF },
	{ 0xF0A885A9, 0x5E9F6 },
	{ 0xF0A885AA, 0x5E9F5 },
	{ 0xF0A885B1, 0x7CAE0 },
	{ 0xF0A885B2, 0x7CADD },
	{ 0xF0A885B4, 0x7CAE7 },
	{ 0xF0A885B5, 0x7CAD6 },
	{ 0xF0A885B6, 0x7CAE4 },
	{ 0xF0A88680, 0x4E1D3 },
	{ 0xF0A88681, 0x4E4D9 },
	{ 0xF0A88682, 0x5EDFD },
	{ 0xF0A88683, 0x5EDF7 },
	{ 0xF0A88684, 0x7D0C4 },
	{ 0xF0A88685, 0x5EDFB },
	{ 0xF0A88686, 0x5EDF6 },
	{ 0xF0A88687, 0x5EDF9 },
	{ 0xF0A88688, 0x7D0C8 },
	{ 0xF0A88689, 0x7D0C6 },
	{ 0xF0A8868A, 0x4E4DC },
	{ 0xF0A8868B, 0x5EDF3 },
	{ 0xF0A8868C, 0x4E4DD },
	{ 0xF0A8868D, 0x7D0C7 },
	{ 0xF0A8868E, 0x5EDF8 },
	{ 0xF0A8868F, 0x5EDF5 },
	{ 0xF0A88690, 0x5EDF4 },
	{ 0xF0A88691, 0x7D0C9 },
	{ 0xF0A88694, 0xFE6C3 },
	{ 0xF0A88695, 0xFE6C4 },
	{ 0xF0A88696, 0xFE6C5 },
	{ 0xF0A88697, 0xFE6C6 },
	{ 0xF0A88698, 0xFE6C7 },
	{ 0xF0A8869A, 0x7D0C5 },
	{ 0xF0A8869B, 0x7D0CA },
	{ 0xF0A8869C, 0x7D0CB },
	{ 0xF0A886A6, 0x5EDFC },
	{ 0xF0A886A7, 0x5EDFE },
	{ 0xF0A886A8, 0x5EDFA },
	{ 0xF0A886AA, 0x4E7CE },
	{ 0xF0A886AB, 0x7D5C2 },
	{ 0xF0A886AC, 0x4E7CF },
	{ 0xF0A886AD, 0x5F1CB },
	{ 0xF0A886AE, 0x7D5C1 },
	{ 0xF0A886AF, 0x7D5C4 },
	{ 0xF0A886B0, 0x4E7CD },
	{ 0xF0A886B1, 0x4E7CB },
	{ 0xF0A886B2, 0x5F1CC },
	{ 0xF0A886B3, 0x7D5C3 },
	{ 0xF0A886B4, 0x7D5C0 },
	{ 0xF0A886B5, 0x5F1CA },
	{ 0xF0A886BB, 0xFE8D1 },
	{ 0xF0A886BC, 0xFE8D2 },
	{ 0xF0A88781, 0x5F4CA },
	{ 0xF0A88782, 0x7D5C5 },
	{ 0xF0A88783, 0x7D9CC },
	{ 0xF0A88784, 0x5F4CD },
	{ 0xF0A88785, 0x5F4CF },
	{ 0xF0A88786, 0x5F4CE },
	{ 0xF0A88787, 0x5F4CC },
	{ 0xF0A88788, 0x7D9CD },
	{ 0xF0A8878A, 0x5F4D1 },
	{ 0xF0A8878B, 0x7D9CE },
	{ 0xF0A8878C, 0xFE9FA },
	{ 0xF0A8878F, 0x7D9CF },
	{ 0xF0A88794, 0x5F4D0 },
	{ 0xF0A88796, 0x5F6D4 },
	{ 0xF0A88797, 0x5F6D2 },
	{ 0xF0A88798, 0x5F6D5 },
	{ 0xF0A88799, 0x7DCF9 },
	{ 0xF0A8879A, 0x7DCF8 },
	{ 0xF0A8879D, 0x5F6D3 },
	{ 0xF0A8879E, 0x5F6D1 },
	{ 0xF0A887A4, 0x4ECAB },
	{ 0xF0A887A5, 0x7DFE1 },
	{ 0xF0A887A6, 0x5F8B7 },
	{ 0xF0A887A7, 0x5F8B6 },
	{ 0xF0A887A8, 0x4ECAA },
	{ 0xF0A887A9, 0x5F8B8 },
	{ 0xF0A887AA, 0x7DFE2 },
	{ 0xF0A887AB, 0x7E1CF },
	{ 0xF0A887AD, 0x7DFE3 },
	{ 0xF0A887AE, 0x7E1D2 },
	{ 0xF0A887AF, 0x4EDA8 },
	{ 0xF0A887B0, 0x7E1D4 },
	{ 0xF0A887B1, 0x7E2E7 },
	{ 0xF0A887B2, 0x7E1D3 },
	{ 0xF0A887B3, 0x7E1D1 },
	{ 0xF0A887B4, 0x7E1D0 },
	{ 0xF0A887BA, 0xFEBE7 },
	{ 0xF0A887BB, 0x5FABC },
	{ 0xF0A887BC, 0x5FABB },
	{ 0xF0A887BD, 0x5FABD },
	{ 0xF0A88883, 0x7E3F6 },
	{ 0xF0A88884, 0x5FBCA },
	{ 0xF0A88885, 0x7E4E3 },
	{ 0xF0A88888, 0x5FBEA },
	{ 0xF0A8888A, 0xFEDA8 },
	{ 0xF0A8888B, 0x7E5E5 },
	{ 0xF0A8888D, 0xFEDB3 },
	{ 0xF0A8888F, 0x6A3B9 },
	{ 0xF0A88890, 0x6A3BA },
	{ 0xF0A88891, 0x6A5D5 },
	{ 0xF0A88893, 0x5B0D2 },
	{ 0xF0A88894, 0x6BCC4 },
	{ 0xF0A88895, 0x5B0D1 },
	{ 0xF0A88898, 0x5B5FA },
	{ 0xF0A88899, 0x5B5F9 },
	{ 0xF0A8889A, 0x5B5F8 },
	{ 0xF0A8889B, 0x6C5BE },
	{ 0xF0A8889C, 0x6C5C1 },
	{ 0xF0A8889D, 0x6C5C0 },
	{ 0xF0A8889E, 0x6C5C2 },
	{ 0xF0A8889F, 0x6C5BF },
	{ 0xF0A888A0, 0x6C5C3 },
	{ 0xF0A888A1, 0x6C5C4 },
	{ 0xF0A888A2, 0x4B5E0 },
	{ 0xF0A888A4, 0xFB8EB },
	{ 0xF0A888A9, 0x5BCE5 },
	{ 0xF0A888AA, 0x6CFBF },
	{ 0xF0A888AB, 0x5BCE4 },
	{ 0xF0A888AC, 0x6CFC1 },
	{ 0xF0A888AD, 0x6CFBE },
	{ 0xF0A888AE, 0x5BCE6 },
	{ 0xF0A888AF, 0xFBFD5 },
	{ 0xF0A888B0, 0xFBFD6 },
	{ 0xF0A888B1, 0xFBFD7 },
	{ 0xF0A888B2, 0xFBFD8 },
	{ 0xF0A888B4, 0x6CFBD },
	{ 0xF0A888B5, 0x6CFC0 },
	{ 0xF0A888B8, 0x6D8FD },
	{ 0xF0A888B9, 0x5C3CD },
	{ 0xF0A888BA, 0x6D8FA },
	{ 0xF0A888BB, 0x6D8FE },
	{ 0xF0A888BC, 0x6D9A1 },
	{ 0xF0A888BD, 0xFC5DA },
	{ 0xF0A888BE, 0xFC5DB },
	{ 0xF0A888BF, 0xFC5DC },
	{ 0xF0A88980, 0x6D8FB },
	{ 0xF0A88982, 0x6D8FC },
	{ 0xF0A88983, 0x6D9A2 },
	{ 0xF0A88988, 0x5CACA },
	{ 0xF0A88989, 0x6E3A3 },
	{ 0xF0A8898A, 0x6E3A4 },
	{ 0xF0A8898B, 0x5CAC9 },
	{ 0xF0A8898C, 0x6E3A5 },
	{ 0xF0A8898D, 0x6E3A6 },
	{ 0xF0A8898E, 0xFCCDC },
	{ 0xF0A8898F, 0xFCCDD },
	{ 0xF0A88990, 0xFCCDE },
	{ 0xF0A88994, 0x7A9D1 },
	{ 0xF0A88995, 0x5D1D6 },
	{ 0xF0A88997, 0x4CEA5 },
	{ 0xF0A88998, 0xFD2C6 },
	{ 0xF0A88999, 0xFD2C8 },
	{ 0xF0A8899B, 0x7A9D0 },
	{ 0xF0A889A2, 0x5D8EA },
	{ 0xF0A889A3, 0x4D4B1 },
	{ 0xF0A889A4, 0x5D8EB },
	{ 0xF0A889A5, 0x7B4A8 },
	{ 0xF0A889A6, 0x7BCC6 },
	{ 0xF0A889A7, 0xFD8B4 },
	{ 0xF0A889A8, 0xFD8B6 },
	{ 0xF0A889AE, 0x7BCC8 },
	{ 0xF0A889AF, 0x7BCC7 },
	{ 0xF0A889B0, 0x7BCC5 },
	{ 0xF0A889B1, 0x5DFA1 },
	{ 0xF0A889B2, 0xFDCFA },
	{ 0xF0A889B3, 0xFDCFB },
	{ 0xF0A889B9, 0x5E5B0 },
	{ 0xF0A889BA, 0x7C3EC },
	{ 0xF0A889BB, 0xFE1A6 },
	{ 0xF0A889BC, 0xFE1A7 },
	{ 0xF0A889BF, 0x7CAEC },
	{ 0xF0A88A80, 0x7CAED },
	{ 0xF0A88A81, 0x7CAEA },
	{ 0xF0A88A83, 0xFE4A6 },
	{ 0xF0A88A84, 0xFE4A7 },
	{ 0xF0A88A86, 0x7CAEB },
	{ 0xF0A88A8A, 0x7CAE9 },
	{ 0xF0A88A8D, 0x4E4DE },
	{ 0xF0A88A8E, 0x7D0CD },
	{ 0xF0A88A8F, 0xFE6C8 },
	{ 0xF0A88A90, 0xFE6C9 },
	{ 0xF0A88A92, 0x7D0CE },
	{ 0xF0A88A93, 0x7D5C6 },
	{ 0xF0A88A94, 0x5F1CD },
	{ 0xF0A88A95, 0x7D5C7 },
	{ 0xF0A88A96, 0x7D5C8 },
	{ 0xF0A88A97, 0x7D5C9 },
	{ 0xF0A88A98, 0x7D9D0 },
	{ 0xF0A88A99, 0xFE9FC },
	{ 0xF0A88A9B, 0x5F6D6 },
	{ 0xF0A88A9D, 0x5F9D1 },
	{ 0xF0A88AA0, 0x6B4DC },
	{ 0xF0A88AA1, 0x5ABCE },
	{ 0xF0A88AA2, 0x6B4DE },
	{ 0xF0A88AA3, 0xFADD2 },
	{ 0xF0A88AA4, 0xFADD4 },
	{ 0xF0A88AA7, 0x6BCC5 },
	{ 0xF0A88AA9, 0x5B0D4 },
	{ 0xF0A88AAA, 0x6BCC7 },
	{ 0xF0A88AAB, 0xFB2DF },
	{ 0xF0A88AAC, 0xFB2E0 },
	{ 0xF0A88AAF, 0x6BCC6 },
	{ 0xF0A88AB1, 0x5B0D3 },
	{ 0xF0A88AB2, 0xFB2DE },
	{ 0xF0A88AB3, 0x5B5FB },
	{ 0xF0A88AB4, 0x6C5CE },
	{ 0xF0A88AB5, 0x6C5CD },
	{ 0xF0A88AB6, 0x6C5C6 },
	{ 0xF0A88AB7, 0x4B5E4 },
	{ 0xF0A88AB8, 0x5B6A2 },
	{ 0xF0A88AB9, 0x5B6A1 },
	{ 0xF0A88ABA, 0x6C5CA },
	{ 0xF0A88ABB, 0x5B5FD },
	{ 0xF0A88ABC, 0x6C5C7 },
	{ 0xF0A88ABD, 0x6C5CC },
	{ 0xF0A88ABE, 0x6C5CB },
	{ 0xF0A88ABF, 0x5B5FC },
	{ 0xF0A88B80, 0x5B5FE },
	{ 0xF0A88B84, 0xFB8ED },
	{ 0xF0A88B86, 0x6C5C8 },
	{ 0xF0A88B87, 0x6C5C9 },
	{ 0xF0A88B8C, 0x4B5E5 },
	{ 0xF0A88B8E, 0x6CFC6 },
	{ 0xF0A88B8F, 0x6CFC7 },
	{ 0xF0A88B90, 0x5BCF0 },
	{ 0xF0A88B91, 0x5BCEE },
	{ 0xF0A88B92, 0x6CFC5 },
	{ 0xF0A88B93, 0x6CFC4 },
	{ 0xF0A88B94, 0x6CFC2 },
	{ 0xF0A88B95, 0x5B6A3 },
	{ 0xF0A88B96, 0x5BCED },
	{ 0xF0A88B97, 0x5BCE8 },
	{ 0xF0A88B98, 0x5BCEB },
	{ 0xF0A88B99, 0x5BCEA },
	{ 0xF0A88B9A, 0x6CFC3 },
	{ 0xF0A88B9B, 0x5BCE9 },
	{ 0xF0A88B9C, 0x5BCF1 },
	{ 0xF0A88BA6, 0x5BCEC },
	{ 0xF0A88BA7, 0x5BCEF },
	{ 0xF0A88BA8, 0x6D9A3 },
	{ 0xF0A88BA9, 0x6D9A8 },
	{ 0xF0A88BAA, 0x5C3D3 },
	{ 0xF0A88BAB, 0x6D9A6 },
	{ 0xF0A88BAC, 0x6D9A9 },
	{ 0xF0A88BAD, 0x5C3D1 },
	{ 0xF0A88BAE, 0x4C1AB },
	{ 0xF0A88BAF, 0x5C3D2 },
	{ 0xF0A88BB0, 0x5C3CF },
	{ 0xF0A88BB1, 0x6D9A7 },
	{ 0xF0A88BB2, 0x5C3CE },
	{ 0xF0A88BB4, 0xFC5DD },
	{ 0xF0A88BB5, 0xFC5DE },
	{ 0xF0A88BB6, 0xFC5DF },
	{ 0xF0A88BB9, 0x6D9A5 },
	{ 0xF0A88BBC, 0x4C1AD },
	{ 0xF0A88C81, 0x5C3D4 },
	{ 0xF0A88C82, 0x6E3AD },
	{ 0xF0A88C83, 0x6E3AF },
	{ 0xF0A88C84, 0x5CAD0 },
	{ 0xF0A88C85, 0x4C7E8 },
	{ 0xF0A88C86, 0x6E3A8 },
	{ 0xF0A88C87, 0x6E3AB },
	{ 0xF0A88C88, 0x5CACD },
	{ 0xF0A88C89, 0x6E3AC },
	{ 0xF0A88C8A, 0x6E3A7 },
	{ 0xF0A88C8B, 0x6E3B0 },
	{ 0xF0A88C8D, 0x5CACB },
	{ 0xF0A88C8E, 0x5CACE },
	{ 0xF0A88C8F, 0x6E3B1 },
	{ 0xF0A88C96, 0x6E3AE },
	{ 0xF0A88C99, 0xFCCDF },
	{ 0xF0A88C9A, 0xFCCE0 },
	{ 0xF0A88C9B, 0xFCCE1 },
	{ 0xF0A88C9C, 0xFCCE3 },
	{ 0xF0A88C9D, 0x5CACF },
	{ 0xF0A88C9F, 0x5CACC },
	{ 0xF0A88CA0, 0x7A9D9 },
	{ 0xF0A88CA1, 0x6E3AA },
	{ 0xF0A88CA2, 0x5D1E0 },
	{ 0xF0A88CA3, 0x7A9D7 },
	{ 0xF0A88CA4, 0x7A9DE },
	{ 0xF0A88CA5, 0x7A9E2 },
	{ 0xF0A88CA6, 0x7A9D6 },
	{ 0xF0A88CA7, 0x5D1D9 },
	{ 0xF0A88CA8, 0x7A9DA },
	{ 0xF0A88CA9, 0x7A9D5 },
	{ 0xF0A88CAA, 0x7A9DC },
	{ 0xF0A88CAB, 0x5D1D8 },
	{ 0xF0A88CAC, 0x5D1DB },
	{ 0xF0A88CAD, 0x5D1DE },
	{ 0xF0A88CAE, 0x4CEAC },
	{ 0xF0A88CAF, 0x6E3A9 },
	{ 0xF0A88CB0, 0x7A9D8 },
	{ 0xF0A88CB1, 0x7A9DD },
	{ 0xF0A88CB2, 0x7A9DB },
	{ 0xF0A88CB3, 0x5D1DD },
	{ 0xF0A88CB4, 0x5D1DF },
	{ 0xF0A88CB5, 0x7A9D2 },
	{ 0xF0A88CB6, 0x5D1D7 },
	{ 0xF0A88CB7, 0x7A9D4 },
	{ 0xF0A88CB8, 0x7A9E3 },
	{ 0xF0A88CBB, 0xFD2C9 },
	{ 0xF0A88CBC, 0xFD2CA },
	{ 0xF0A88CBD, 0xFD2CB },
	{ 0xF0A88CBE, 0xFD2CC },
	{ 0xF0A88D80, 0x7A9D3 },
	{ 0xF0A88D81, 0x7A9DF },
	{ 0xF0A88D82, 0x7A9E0 },
	{ 0xF0A88D83, 0x7A9E1 },
	{ 0xF0A88D85, 0x5D1DC },
	{ 0xF0A88D86, 0x5D1DA },
	{ 0xF0A88D87, 0x7B4A9 },
	{ 0xF0A88D88, 0x5D8F3 },
	{ 0xF0A88D89, 0x7B4AF },
	{ 0xF0A88D8A, 0x5D8F4 },
	{ 0xF0A88D8B, 0x7B4AD },
	{ 0xF0A88D8C, 0x5D8F0 },
	{ 0xF0A88D8D, 0x7B4AB },
	{ 0xF0A88D8E, 0x7B4B4 },
	{ 0xF0A88D8F, 0x5D8EE },
	{ 0xF0A88D90, 0x5D8F1 },
	{ 0xF0A88D91, 0x5D8ED },
	{ 0xF0A88D92, 0x7B4B5 },
	{ 0xF0A88D93, 0x7B4B0 },
	{ 0xF0A88D94, 0x7B4B6 },
	{ 0xF0A88D96, 0x5D8EC },
	{ 0xF0A88D97, 0x7B4B3 },
	{ 0xF0A88D98, 0xFD8B7 },
	{ 0xF0A88D99, 0xFD8B9 },
	{ 0xF0A88D9A, 0xFD8BA },
	{ 0xF0A88D9F, 0x7B4AC },
	{ 0xF0A88DA0, 0x7B4AE },
	{ 0xF0A88DA3, 0x7B4AA },
	{ 0xF0A88DA5, 0xFD8B8 },
	{ 0xF0A88DA7, 0x4D4B5 },
	{ 0xF0A88DA8, 0x5D8EF },
	{ 0xF0A88DA9, 0x7BCCA },
	{ 0xF0A88DAA, 0x7BCD2 },
	{ 0xF0A88DAB, 0x5DFA5 },
	{ 0xF0A88DAC, 0x7BCCD },
	{ 0xF0A88DAD, 0x7BCCC },
	{ 0xF0A88DAE, 0x7BCCB },
	{ 0xF0A88DAF, 0x7BCD3 },
	{ 0xF0A88DB0, 0x4D9B3 },
	{ 0xF0A88DB1, 0x7BCD0 },
	{ 0xF0A88DB2, 0x4D9B4 },
	{ 0xF0A88DB3, 0x7BCD1 },
	{ 0xF0A88DB4, 0x5DFA2 },
	{ 0xF0A88DB6, 0x5DFAB },
	{ 0xF0A88DB7, 0x4D9B6 },
	{ 0xF0A88DB8, 0x5DFA8 },
	{ 0xF0A88DB9, 0x5DFA7 },
	{ 0xF0A88DBB, 0x7BCD4 },
	{ 0xF0A88DBF, 0x5DFA4 },
	{ 0xF0A88E80, 0x5DFAA },
	{ 0xF0A88E81, 0x7BCC9 },
	{ 0xF0A88E82, 0xFDCFC },
	{ 0xF0A88E83, 0xFDCFD },
	{ 0xF0A88E84, 0x7BCCE },
	{ 0xF0A88E85, 0x7BCCF },
	{ 0xF0A88E87, 0x5DFA6 },
	{ 0xF0A88E88, 0x5DFA3 },
	{ 0xF0A88E89, 0x5DFA9 },
	{ 0xF0A88E8A, 0x4DDF9 },
	{ 0xF0A88E8B, 0x7C3F0 },
	{ 0xF0A88E8C, 0x4DEA1 },
	{ 0xF0A88E8D, 0x5E5B2 },
	{ 0xF0A88E90, 0x5E5B4 },
	{ 0xF0A88E91, 0xFE1A8 },
	{ 0xF0A88E92, 0xFE1A9 },
	{ 0xF0A88E93, 0xFE1AA },
	{ 0xF0A88E95, 0x7C3EF },
	{ 0xF0A88E96, 0x7C3F2 },
	{ 0xF0A88E98, 0x7C3F1 },
	{ 0xF0A88E99, 0x7C3EE },
	{ 0xF0A88E9C, 0x7C3ED },
	{ 0xF0A88EA1, 0x5E5B1 },
	{ 0xF0A88EA2, 0x5E5B3 },
	{ 0xF0A88EA4, 0x5E9F8 },
	{ 0xF0A88EA5, 0x7CAEE },
	{ 0xF0A88EA6, 0x7CAF1 },
	{ 0xF0A88EA7, 0x7CAEF },
	{ 0xF0A88EA8, 0x7CAF0 },
	{ 0xF0A88EA9, 0x5E9FA },
	{ 0xF0A88EAA, 0x4E1DA },
	{ 0xF0A88EAB, 0x4E1DB },
	{ 0xF0A88EAC, 0x5E9F9 },
	{ 0xF0A88EAD, 0x5E9F7 },
	{ 0xF0A88EAE, 0x5E9FB },
	{ 0xF0A88EAF, 0x7CAF2 },
	{ 0xF0A88EB0, 0xFE4A8 },
	{ 0xF0A88EB1, 0x7CAF4 },
	{ 0xF0A88EB2, 0x4E4E2 },
	{ 0xF0A88EB3, 0x5EEA5 },
	{ 0xF0A88EB4, 0x5EEA3 },
	{ 0xF0A88EB5, 0x7D0D3 },
	{ 0xF0A88EB6, 0x5EEA4 },
	{ 0xF0A88EB7, 0x5EEA2 },
	{ 0xF0A88EB8, 0x7D0D1 },
	{ 0xF0A88EB9, 0x5EEA1 },
	{ 0xF0A88EBC, 0xFE6CA },
	{ 0xF0A88EBE, 0x7D0D2 },
	{ 0xF0A88F81, 0x7D0D0 },
	{ 0xF0A88F85, 0x7D0CF },
	{ 0xF0A88F86, 0x5EEA6 },
	{ 0xF0A88F87, 0x7D0D4 },
	{ 0xF0A88F88, 0x4E7D3 },
	{ 0xF0A88F89, 0x5F1CE },
	{ 0xF0A88F8A, 0x4E7D4 },
	{ 0xF0A88F8B, 0x7D5CC },
	{ 0xF0A88F8E, 0x7D5CB },
	{ 0xF0A88F8F, 0x7D5CA },
	{ 0xF0A88F91, 0x7D9D6 },
	{ 0xF0A88F92, 0x4E9D0 },
	{ 0xF0A88F93, 0x7D9D2 },
	{ 0xF0A88F94, 0x7D9D1 },
	{ 0xF0A88F95, 0x4E9D1 },
	{ 0xF0A88F96, 0x7D9D7 },
	{ 0xF0A88F98, 0x7D9D3 },
	{ 0xF0A88F99, 0x7D9D4 },
	{ 0xF0A88F9D, 0x7D9D5 },
	{ 0xF0A88F9E, 0x7DCFE },
	{ 0xF0A88F9F, 0x7DDA1 },
	{ 0xF0A88FA0, 0x5F6D7 },
	{ 0xF0A88FA1, 0x7DCFB },
	{ 0xF0A88FA2, 0x7DCFA },
	{ 0xF0A88FA3, 0x7DCFC },
	{ 0xF0A88FA4, 0x7DCFD },
	{ 0xF0A88FA6, 0x5F6D9 },
	{ 0xF0A88FA8, 0x5F6D8 },
	{ 0xF0A88FA9, 0x5F8BC },
	{ 0xF0A88FAA, 0x5F8BB },
	{ 0xF0A88FAB, 0x5F8BA },
	{ 0xF0A88FAC, 0x7DFE7 },
	{ 0xF0A88FAF, 0x7DFE5 },
	{ 0xF0A88FB0, 0x7DFE4 },
	{ 0xF0A88FB1, 0x5F8B9 },
	{ 0xF0A88FB2, 0x7DFE6 },
	{ 0xF0A88FB3, 0x5F9D3 },
	{ 0xF0A88FB4, 0x5F9D2 },
	{ 0xF0A88FB5, 0x5FABE },
	{ 0xF0A88FB6, 0x5FABF },
	{ 0xF0A88FB8, 0x7E2E8 },
	{ 0xF0A88FB9, 0x5FAFA },
	{ 0xF0A88FBA, 0x7E4E4 },
	{ 0xF0A88FBD, 0x7E2E9 },
	{ 0xF0A88FBE, 0x7E3F7 },
	{ 0xF0A89081, 0x5FBEB },
	{ 0xF0A89082, 0x7E5E6 },
	{ 0xF0A8908B, 0x6A9AB },
	{ 0xF0A8908C, 0x6AEB6 },
	{ 0xF0A8908D, 0x6BCC8 },
	{ 0xF0A8908F, 0x6C5CF },
	{ 0xF0A89090, 0x5B6A5 },
	{ 0xF0A89091, 0x5B6A4 },
	{ 0xF0A89094, 0x4C1AE },
	{ 0xF0A89095, 0x6D9AA },
	{ 0xF0A89097, 0xFC5E1 },
	{ 0xF0A89098, 0x5CAD1 },
	{ 0xF0A89099, 0xFCCE5 },
	{ 0xF0A8909A, 0xFCCE6 },
	{ 0xF0A8909B, 0x5CAD2 },
	{ 0xF0A8909C, 0x7A9E4 },
	{ 0xF0A8909D, 0x7A9E5 },
	{ 0xF0A8909E, 0x7A9E6 },
	{ 0xF0A8909F, 0x5D1E2 },
	{ 0xF0A890A0, 0x7B4B7 },
	{ 0xF0A890A1, 0x5D8F5 },
	{ 0xF0A890A2, 0x7B4B8 },
	{ 0xF0A890A4, 0xFD8BB },
	{ 0xF0A890A8, 0x5DFAD },
	{ 0xF0A890A9, 0x5DFAC },
	{ 0xF0A890AA, 0xFDCFE },
	{ 0xF0A890AB, 0xFDDA1 },
	{ 0xF0A890AC, 0xFDDA2 },
	{ 0xF0A890AD, 0xFDDA3 },
	{ 0xF0A890AF, 0x5DFAE },
	{ 0xF0A890B0, 0x5E5B7 },
	{ 0xF0A890B1, 0x5E5B6 },
	{ 0xF0A890B2, 0x7C3F3 },
	{ 0xF0A890B5, 0x7CAF5 },
	{ 0xF0A890B6, 0x4E1DC },
	{ 0xF0A890B9, 0x7CAF6 },
	{ 0xF0A890BB, 0xFE6CB },
	{ 0xF0A890BC, 0x7D0D5 },
	{ 0xF0A890BD, 0xFE8D4 },
	{ 0xF0A890BE, 0x7D9D8 },
	{ 0xF0A89180, 0x7DFE8 },
	{ 0xF0A89181, 0x7E5C7 },
	{ 0xF0A89182, 0x7E5E7 },
	{ 0xF0A89183, 0x6A9AC },
	{ 0xF0A89184, 0x6AEB7 },
	{ 0xF0A89185, 0x6D9AD },
	{ 0xF0A89186, 0x6D9AC },
	{ 0xF0A89187, 0x6D9AB },
	{ 0xF0A89188, 0xFD2CD },
	{ 0xF0A89189, 0x7B3A1 },
	{ 0xF0A8918A, 0x4E1DD },
	{ 0xF0A8918B, 0x7D5CD },
	{ 0xF0A8918D, 0x6A5D9 },
	{ 0xF0A8918F, 0x6A5D8 },
	{ 0xF0A89190, 0x6A5D7 },
	{ 0xF0A89191, 0x4A4FE },
	{ 0xF0A89192, 0x6A9AD },
	{ 0xF0A89193, 0x4A5A4 },
	{ 0xF0A89194, 0x6BCC9 },
	{ 0xF0A89198, 0x6A9AE },
	{ 0xF0A89199, 0xFA5B3 },
	{ 0xF0A8919A, 0xFA5B4 },
	{ 0xF0A8919B, 0x6BCCA },
	{ 0xF0A8919E, 0x6A9AF },
	{ 0xF0A891A0, 0x5A4F8 },
	{ 0xF0A891A1, 0x6BCCB },
	{ 0xF0A891A2, 0x6C5D0 },
	{ 0xF0A891A3, 0x5A7EA },
	{ 0xF0A891A4, 0x5A7EB },
	{ 0xF0A891A5, 0x5A7F0 },
	{ 0xF0A891A6, 0x6AEB8 },
	{ 0xF0A891A7, 0x6AEBD },
	{ 0xF0A891A8, 0x5A7EF },
	{ 0xF0A891A9, 0x4A8A5 },
	{ 0xF0A891AA, 0x5A7F1 },
	{ 0xF0A891AB, 0x5A7ED },
	{ 0xF0A891AC, 0x4A8A8 },
	{ 0xF0A891AD, 0x6AEBB },
	{ 0xF0A891AF, 0xFA8ED },
	{ 0xF0A891B0, 0xFA8EF },
	{ 0xF0A891B1, 0xFA8F0 },
	{ 0xF0A891B2, 0xFA8F3 },
	{ 0xF0A891B3, 0xFA8F4 },
	{ 0xF0A891B4, 0xFA8F5 },
	{ 0xF0A891B5, 0x6AEBA },
	{ 0xF0A891B7, 0x6AEBF },
	{ 0xF0A891BC, 0x5A7EE },
	{ 0xF0A891BD, 0x5A7E8 },
	{ 0xF0A891BE, 0x6AEBC },
	{ 0xF0A891BF, 0x5A7EC },
	{ 0xF0A89280, 0x6AEB9 },
	{ 0xF0A89281, 0x6AEBE },
	{ 0xF0A89283, 0x5ABCF },
	{ 0xF0A89284, 0x5ABD6 },
	{ 0xF0A89285, 0x5ABD2 },
	{ 0xF0A89286, 0x6B4DF },
	{ 0xF0A89287, 0x5ABD1 },
	{ 0xF0A89288, 0x6B4E2 },
	{ 0xF0A89289, 0x5ABD5 },
	{ 0xF0A8928A, 0x5ABD3 },
	{ 0xF0A8928B, 0x4ABCF },
	{ 0xF0A8928C, 0x4ABD1 },
	{ 0xF0A8928D, 0x5ABD0 },
	{ 0xF0A8928E, 0x6B4E4 },
	{ 0xF0A8928F, 0x6B4E3 },
	{ 0xF0A89293, 0xFADD5 },
	{ 0xF0A89294, 0xFADD6 },
	{ 0xF0A89295, 0xFADD7 },
	{ 0xF0A89296, 0xFADD8 },
	{ 0xF0A89297, 0xFADD9 },
	{ 0xF0A8929A, 0x4ABD2 },
	{ 0xF0A8929B, 0x6B4E5 },
	{ 0xF0A8929D, 0x6B4E1 },
	{ 0xF0A892A0, 0x6CAC7 },
	{ 0xF0A892A2, 0x5ABD7 },
	{ 0xF0A892A3, 0x5ABD4 },
	{ 0xF0A892A4, 0x6BCD4 },
	{ 0xF0A892A5, 0x6BCD8 },
	{ 0xF0A892A6, 0x5B0DB },
	{ 0xF0A892A7, 0x6BCD3 },
	{ 0xF0A892A8, 0x5B0D6 },
	{ 0xF0A892A9, 0x5B0DA },
	{ 0xF0A892AA, 0x4B0B1 },
	{ 0xF0A892AB, 0x5B0D7 },
	{ 0xF0A892AC, 0x5B0D9 },
	{ 0xF0A892AD, 0x6BCD2 },
	{ 0xF0A892AE, 0x6BCCC },
	{ 0xF0A892AF, 0x6BCD6 },
	{ 0xF0A892B0, 0x4B0B2 },
	{ 0xF0A892B2, 0x6BCD7 },
	{ 0xF0A892B3, 0x6BCCD },
	{ 0xF0A892BC, 0x5C3D5 },
	{ 0xF0A892BD, 0x6BCD5 },
	{ 0xF0A892BE, 0x5B0D8 },
	{ 0xF0A892BF, 0x6BCD0 },
	{ 0xF0A89380, 0x6BCCE },
	{ 0xF0A89381, 0x5B0DC },
	{ 0xF0A89382, 0x5B6A7 },
	{ 0xF0A89383, 0x5B6A6 },
	{ 0xF0A89384, 0x6BCCF },
	{ 0xF0A89385, 0x6C5DB },
	{ 0xF0A89387, 0x5B6AC },
	{ 0xF0A89388, 0x4B5EA },
	{ 0xF0A89389, 0x6C5DC },
	{ 0xF0A8938A, 0x5B6AB },
	{ 0xF0A8938B, 0x6BCD1 },
	{ 0xF0A8938D, 0x5B6A9 },
	{ 0xF0A8938E, 0x6C5D7 },
	{ 0xF0A89392, 0x6C5DA },
	{ 0xF0A89393, 0xFB8F0 },
	{ 0xF0A89394, 0xFB8F1 },
	{ 0xF0A89395, 0xFB8F2 },
	{ 0xF0A89396, 0x6C5D6 },
	{ 0xF0A89397, 0x6C5D4 },
	{ 0xF0A89398, 0x6C5D5 },
	{ 0xF0A89399, 0x6C5D2 },
	{ 0xF0A8939B, 0x6C5DD },
	{ 0xF0A8939D, 0x6C5D8 },
	{ 0xF0A893A4, 0x6C5D3 },
	{ 0xF0A893A5, 0x5B6AA },
	{ 0xF0A893A6, 0x4B5E7 },
	{ 0xF0A893A7, 0x6C5D9 },
	{ 0xF0A893A8, 0x5B6AD },
	{ 0xF0A893A9, 0x5B6A8 },
	{ 0xF0A893AA, 0xFB8EF },
	{ 0xF0A893AB, 0x6C5D1 },
	{ 0xF0A893AC, 0x5BCF6 },
	{ 0xF0A893AD, 0x5BCF2 },
	{ 0xF0A893AE, 0x5BCF8 },
	{ 0xF0A893AF, 0x5BCF7 },
	{ 0xF0A893B0, 0x4BBD6 },
	{ 0xF0A893B1, 0x6CFD3 },
	{ 0xF0A893B2, 0x4BBDA },
	{ 0xF0A893B3, 0x4BBD8 },
	{ 0xF0A893B4, 0x5BCF9 },
	{ 0xF0A893B5, 0x6CFD2 },
	{ 0xF0A893B6, 0x7A9E7 },
	{ 0xF0A893B7, 0x6CFCD },
	{ 0xF0A893B8, 0x6CFCC },
	{ 0xF0A893B9, 0x6CFD0 },
	{ 0xF0A893BA, 0x6CFCF },
	{ 0xF0A893BB, 0x4BBDB },
	{ 0xF0A893BD, 0x6CFC9 },
	{ 0xF0A893BE, 0x6CFCB },
	{ 0xF0A893BF, 0xFBFE2 },
	{ 0xF0A89480, 0x6CFD1 },
	{ 0xF0A89483, 0x6CFD4 },
	{ 0xF0A89485, 0x6CFD5 },
	{ 0xF0A8948B, 0x6CFCA },
	{ 0xF0A8948E, 0xFBFD9 },
	{ 0xF0A8948F, 0xFBFDA },
	{ 0xF0A89490, 0xFBFDB },
	{ 0xF0A89491, 0xFBFDC },
	{ 0xF0A89492, 0xFBFDD },
	{ 0xF0A89493, 0xFBFDF },
	{ 0xF0A89494, 0xFBFE0 },
	{ 0xF0A89495, 0xFBFE1 },
	{ 0xF0A89496, 0x5BCF5 },
	{ 0xF0A89497, 0x6CFCE },
	{ 0xF0A89499, 0x5BCF4 },
	{ 0xF0A8949A, 0x5BCF3 },
	{ 0xF0A8949B, 0x4BBD9 },
	{ 0xF0A8949C, 0x6CFD6 },
	{ 0xF0A8949D, 0x6D9C0 },
	{ 0xF0A8949E, 0x6D9B4 },
	{ 0xF0A8949F, 0x6D9BD },
	{ 0xF0A894A1, 0x6D9B0 },
	{ 0xF0A894A2, 0x4C1B1 },
	{ 0xF0A894A3, 0x4C1B0 },
	{ 0xF0A894A4, 0x6D9AE },
	{ 0xF0A894A6, 0x5C3D9 },
	{ 0xF0A894A7, 0x6D9B1 },
	{ 0xF0A894A8, 0x6D9C1 },
	{ 0xF0A894A9, 0x6D9BB },
	{ 0xF0A894AA, 0x6D9BF },
	{ 0xF0A894AB, 0x6D9B7 },
	{ 0xF0A894AC, 0x6D9B5 },
	{ 0xF0A894AD, 0x6D9C3 },
	{ 0xF0A894AE, 0x6D9C2 },
	{ 0xF0A894AF, 0x5BCFA },
	{ 0xF0A894B0, 0x4C1B2 },
	{ 0xF0A894B1, 0x6D9B3 },
	{ 0xF0A894B2, 0x6D9BE },
	{ 0xF0A89581, 0xFC5E2 },
	{ 0xF0A89582, 0xFC5E3 },
	{ 0xF0A89583, 0xFC5E4 },
	{ 0xF0A89584, 0xFC5E5 },
	{ 0xF0A89585, 0xFC5E6 },
	{ 0xF0A89586, 0xFC5E7 },
	{ 0xF0A89587, 0xFC5E8 },
	{ 0xF0A89588, 0xFC5E9 },
	{ 0xF0A89589, 0xFC5EA },
	{ 0xF0A8958A, 0xFC5EB },
	{ 0xF0A8958B, 0xFC5EC },
	{ 0xF0A8958D, 0x6D9B2 },
	{ 0xF0A8958F, 0x6D9B6 },
	{ 0xF0A89590, 0x6D9BC },
	{ 0xF0A89591, 0x6D9B9 },
	{ 0xF0A89593, 0x6D9B8 },
	{ 0xF0A89594, 0x6D9BA },
	{ 0xF0A89596, 0x6D9AF },
	{ 0xF0A8959A, 0x5C3D8 },
	{ 0xF0A8959B, 0x5C3D7 },
	{ 0xF0A8959C, 0x5C3D6 },
	{ 0xF0A8959D, 0x6E3B5 },
	{ 0xF0A8959E, 0x6E3B4 },
	{ 0xF0A8959F, 0x6E3B7 },
	{ 0xF0A895A0, 0x6E3B2 },
	{ 0xF0A895A1, 0x6E3BA },
	{ 0xF0A895A2, 0x5CAD4 },
	{ 0xF0A895A3, 0x6E3B6 },
	{ 0xF0A895A4, 0x6E3B8 },
	{ 0xF0A895A5, 0x6E3BC },
	{ 0xF0A895A6, 0x5CAD3 },
	{ 0xF0A895A7, 0x5CAD6 },
	{ 0xF0A895A8, 0x6E3B3 },
	{ 0xF0A895A9, 0x6E3BB },
	{ 0xF0A895AA, 0x7BCD5 },
	{ 0xF0A895AE, 0xFCCE9 },
	{ 0xF0A895AF, 0xFCCEA },
	{ 0xF0A895B0, 0xFCCEC },
	{ 0xF0A895B1, 0xFCCED },
	{ 0xF0A895B2, 0xFCCEE },
	{ 0xF0A895B3, 0xFCCEF },
	{ 0xF0A895B4, 0xFCCF0 },
	{ 0xF0A895B5, 0xFCCF1 },
	{ 0xF0A895B6, 0xFCCF2 },
	{ 0xF0A895B8, 0x6E3B9 },
	{ 0xF0A895BC, 0x7BCD6 },
	{ 0xF0A895BD, 0x7BCD7 },
	{ 0xF0A89681, 0x7BCD8 },
	{ 0xF0A89683, 0x5CAD5 },
	{ 0xF0A89686, 0x7A9EE },
	{ 0xF0A89687, 0x7A9EC },
	{ 0xF0A89688, 0x7A9F2 },
	{ 0xF0A89689, 0x7A9E9 },
	{ 0xF0A8968A, 0x7A9EB },
	{ 0xF0A8968B, 0x4CEAF },
	{ 0xF0A8968C, 0x5D1E4 },
	{ 0xF0A8968D, 0x4CEB0 },
	{ 0xF0A8968E, 0x5D1E8 },
	{ 0xF0A8968F, 0x5D1E5 },
	{ 0xF0A89690, 0x4CEB4 },
	{ 0xF0A89693, 0x7A9F0 },
	{ 0xF0A89694, 0xFD2CE },
	{ 0xF0A89695, 0xFD2CF },
	{ 0xF0A89696, 0xFD2D0 },
	{ 0xF0A89697, 0xFD2D1 },
	{ 0xF0A89698, 0xFD2D2 },
	{ 0xF0A89699, 0x5D1ED },
	{ 0xF0A8969D, 0x7A9EA },
	{ 0xF0A8969E, 0x7A9EF },
	{ 0xF0A8969F, 0x7A9F4 },
	{ 0xF0A896A0, 0x7A9F5 },
	{ 0xF0A896A1, 0x7A9F1 },
	{ 0xF0A896A3, 0x7A9F3 },
	{ 0xF0A896A4, 0x7C3F4 },
	{ 0xF0A896A5, 0x7A9E8 },
	{ 0xF0A896AA, 0x7C3F5 },
	{ 0xF0A896AB, 0x7A9ED },
	{ 0xF0A896AC, 0x5D1E9 },
	{ 0xF0A896AD, 0x5D1E7 },
	{ 0xF0A896AE, 0x5D1EC },
	{ 0xF0A896AF, 0x5D1E6 },
	{ 0xF0A896B0, 0x5D1EA },
	{ 0xF0A896B1, 0x5D1EB },
	{ 0xF0A896B3, 0x5D1E3 },
	{ 0xF0A896B4, 0x7B4C6 },
	{ 0xF0A896B5, 0x5D8FC },
	{ 0xF0A896B6, 0x5D8FB },
	{ 0xF0A896B7, 0x5D8F9 },
	{ 0xF0A896B8, 0x7B4C1 },
	{ 0xF0A896B9, 0x5D8F7 },
	{ 0xF0A896BA, 0x7B4C5 },
	{ 0xF0A896BB, 0x7B4BE },
	{ 0xF0A896BC, 0x7B4C7 },
	{ 0xF0A896BE, 0x4D4B6 },
	{ 0xF0A896BF, 0x7B4C2 },
	{ 0xF0A89780, 0x7B4C4 },
	{ 0xF0A89781, 0x7B4B9 },
	{ 0xF0A89782, 0x7B4CA },
	{ 0xF0A89783, 0x7CAF7 },
	{ 0xF0A89784, 0x7B4BC },
	{ 0xF0A8978B, 0x7B4C0 },
	{ 0xF0A8978C, 0x7B4CC },
	{ 0xF0A8978D, 0xFD8BC },
	{ 0xF0A8978E, 0xFD8BD },
	{ 0xF0A8978F, 0xFD8BE },
	{ 0xF0A89790, 0x7B4BD },
	{ 0xF0A89792, 0xFD8BF },
	{ 0xF0A89793, 0x7ACDA },
	{ 0xF0A89794, 0x7B4C8 },
	{ 0xF0A89795, 0x7B4BB },
	{ 0xF0A89797, 0x7B4BA },
	{ 0xF0A89798, 0x7B4C3 },
	{ 0xF0A89799, 0x7B4CB },
	{ 0xF0A8979E, 0x5D8F8 },
	{ 0xF0A8979F, 0x5D8FD },
	{ 0xF0A897A1, 0x5D8FA },
	{ 0xF0A897A2, 0x7B4BF },
	{ 0xF0A897A3, 0x5D8F6 },
	{ 0xF0A897A5, 0x5DFAF },
	{ 0xF0A897A6, 0x4D9BA },
	{ 0xF0A897A7, 0x7BCE0 },
	{ 0xF0A897A8, 0x5DFB3 },
	{ 0xF0A897A9, 0x7BCDD },
	{ 0xF0A897AA, 0x5DFB4 },
	{ 0xF0A897AB, 0x7BCDB },
	{ 0xF0A897AC, 0x7D0D7 },
	{ 0xF0A897AD, 0x7B4C9 },
	{ 0xF0A897AE, 0x7BCE2 },
	{ 0xF0A897AF, 0x7BCDE },
	{ 0xF0A897B0, 0x5DFB2 },
	{ 0xF0A897B1, 0x5DFB5 },
	{ 0xF0A897B6, 0xFDDA4 },
	{ 0xF0A897B7, 0xFDDA6 },
	{ 0xF0A897B8, 0xFDDA7 },
	{ 0xF0A897B9, 0xFDDA8 },
	{ 0xF0A897BA, 0x7BCD9 },
	{ 0xF0A897BB, 0x7BCDC },
	{ 0xF0A897BC, 0x7BCDF },
	{ 0xF0A897BD, 0x7BCE3 },
	{ 0xF0A89880, 0xFDDA5 },
	{ 0xF0A89881, 0x5DFB6 },
	{ 0xF0A89882, 0x5DFB7 },
	{ 0xF0A89883, 0x5DFB1 },
	{ 0xF0A89884, 0x5DFB0 },
	{ 0xF0A89885, 0x7BCDA },
	{ 0xF0A89887, 0x5E5BD },
	{ 0xF0A89888, 0x7C3FC },
	{ 0xF0A89889, 0x4DEA2 },
	{ 0xF0A8988A, 0x7C3FA },
	{ 0xF0A8988C, 0x5E5BA },
	{ 0xF0A8988D, 0x7C3F8 },
	{ 0xF0A8988E, 0xFE1AB },
	{ 0xF0A8988F, 0xFE1AC },
	{ 0xF0A89890, 0xFE1AD },
	{ 0xF0A89891, 0x7C4A1 },
	{ 0xF0A89893, 0x7C3FE },
	{ 0xF0A89899, 0x5E5B9 },
	{ 0xF0A8989A, 0x7C3FD },
	{ 0xF0A8989B, 0x7C3F6 },
	{ 0xF0A8989C, 0x7C3F9 },
	{ 0xF0A8989D, 0x5E5BC },
	{ 0xF0A8989E, 0x5E5BB },
	{ 0xF0A8989F, 0x5E5B8 },
	{ 0xF0A898A0, 0x7C3FB },
	{ 0xF0A898A1, 0x7CBA1 },
	{ 0xF0A898A2, 0x7CBA2 },
	{ 0xF0A898A3, 0x7CAFE },
	{ 0xF0A898A6, 0xFE4AA },
	{ 0xF0A898A7, 0xFE4AB },
	{ 0xF0A898A8, 0xFE4AD },
	{ 0xF0A898A9, 0xFE4AE },
	{ 0xF0A898AA, 0x7CAF9 },
	{ 0xF0A898AB, 0x7CAFA },
	{ 0xF0A898AC, 0x7CAFD },
	{ 0xF0A898AD, 0x7CAFB },
	{ 0xF0A898AE, 0x7CAFC },
	{ 0xF0A898B0, 0x7CAF8 },
	{ 0xF0A898B2, 0x5EAA1 },
	{ 0xF0A898B5, 0x5E9FE },
	{ 0xF0A898B6, 0xFE4AC },
	{ 0xF0A898B7, 0x7D0DA },
	{ 0xF0A898B8, 0x5EEA9 },
	{ 0xF0A898B9, 0x7D0D9 },
	{ 0xF0A898BC, 0x5EEA7 },
	{ 0xF0A898BD, 0xFE6CC },
	{ 0xF0A898BF, 0x7D0D8 },
	{ 0xF0A89980, 0x5EEA8 },
	{ 0xF0A89981, 0x7DDA2 },
	{ 0xF0A89982, 0x4E7D5 },
	{ 0xF0A89983, 0x7D5CF },
	{ 0xF0A89984, 0x5F1D1 },
	{ 0xF0A89985, 0x7D5D0 },
	{ 0xF0A89986, 0x7D5CE },
	{ 0xF0A89987, 0xFE8D5 },
	{ 0xF0A89988, 0xFE8D6 },
	{ 0xF0A89989, 0xFE8D7 },
	{ 0xF0A8998A, 0xFE8D8 },
	{ 0xF0A8998E, 0x5F1CF },
	{ 0xF0A8998F, 0x5F1D0 },
	{ 0xF0A89990, 0x5E9FD },
	{ 0xF0A89991, 0x7D5D1 },
	{ 0xF0A89992, 0x5F1D2 },
	{ 0xF0A89993, 0x5F4D2 },
	{ 0xF0A89994, 0x4EBA5 },
	{ 0xF0A89995, 0x7D9DB },
	{ 0xF0A89997, 0x7D9DA },
	{ 0xF0A89998, 0x7D9D9 },
	{ 0xF0A89999, 0x7DDA3 },
	{ 0xF0A8999A, 0x7DDA5 },
	{ 0xF0A8999C, 0x7DDA4 },
	{ 0xF0A8999E, 0x7E2EA },
	{ 0xF0A8999F, 0x7DFEA },
	{ 0xF0A899A0, 0x7DFE9 },
	{ 0xF0A899A3, 0x5F8BD },
	{ 0xF0A899A4, 0x7E1D5 },
	{ 0xF0A899A6, 0x7E2EB },
	{ 0xF0A899A7, 0x7E5E8 },
	{ 0xF0A899A8, 0x6A9B0 },
	{ 0xF0A899A9, 0x5A1FC },
	{ 0xF0A899AB, 0x5A3AC },
	{ 0xF0A899AD, 0x5A3AB },
	{ 0xF0A899AE, 0x5A3AD },
	{ 0xF0A899AF, 0x5A3AA },
	{ 0xF0A899B0, 0x4A3B1 },
	{ 0xF0A899B1, 0x6A5DA },
	{ 0xF0A899B2, 0x6A5DC },
	{ 0xF0A899B5, 0x4A3B3 },
	{ 0xF0A899B6, 0x4A5A7 },
	{ 0xF0A899B7, 0x5A4F9 },
	{ 0xF0A899B8, 0x4A5A6 },
	{ 0xF0A899B9, 0x4A5A8 },
	{ 0xF0A899BA, 0x4A5A5 },
	{ 0xF0A899BB, 0x6A9B3 },
	{ 0xF0A899BC, 0x4A5AA },
	{ 0xF0A899BD, 0x5A4FA },
	{ 0xF0A899BE, 0x4B5F1 },
	{ 0xF0A89A82, 0x6A9B2 },
	{ 0xF0A89A83, 0xFA5B5 },
	{ 0xF0A89A84, 0xFA5B6 },
	{ 0xF0A89A85, 0xFA5B7 },
	{ 0xF0A89A86, 0xFB8F3 },
	{ 0xF0A89A87, 0xFB8F5 },
	{ 0xF0A89A89, 0x6C5E1 },
	{ 0xF0A89A8A, 0x6C5DF },
	{ 0xF0A89A8B, 0x6C5E0 },
	{ 0xF0A89A8D, 0x6A9B1 },
	{ 0xF0A89A8F, 0x4A5A9 },
	{ 0xF0A89A91, 0x4A8AE },
	{ 0xF0A89A92, 0x6C5DE },
	{ 0xF0A89A93, 0x4A8AA },
	{ 0xF0A89A94, 0x4A8AD },
	{ 0xF0A89A95, 0x4A8AC },
	{ 0xF0A89A96, 0x6B4E9 },
	{ 0xF0A89A97, 0x4A8AF },
	{ 0xF0A89A98, 0x5A7F2 },
	{ 0xF0A89A99, 0x5A7F3 },
	{ 0xF0A89A9A, 0x6CFD8 },
	{ 0xF0A89A9B, 0x6AEC3 },
	{ 0xF0A89A9C, 0xFA8F6 },
	{ 0xF0A89A9D, 0xFA8F8 },
	{ 0xF0A89A9E, 0xFA8F9 },
	{ 0xF0A89A9F, 0xFA8FC },
	{ 0xF0A89AA0, 0x6CFDA },
	{ 0xF0A89AA2, 0x6AEC1 },
	{ 0xF0A89AA5, 0x6AEC2 },
	{ 0xF0A89AA8, 0x6AEC0 },
	{ 0xF0A89AAA, 0xFA8F7 },
	{ 0xF0A89AAB, 0xFA8FB },
	{ 0xF0A89AAC, 0x6CFD7 },
	{ 0xF0A89AAD, 0x6CFD9 },
	{ 0xF0A89AAE, 0x5A7F4 },
	{ 0xF0A89AAF, 0x5ABDA },
	{ 0xF0A89AB0, 0x5ABD9 },
	{ 0xF0A89AB1, 0x5ABD8 },
	{ 0xF0A89AB2, 0x4ABD7 },
	{ 0xF0A89AB3, 0x4ABD5 },
	{ 0xF0A89AB4, 0x5ABDF },
	{ 0xF0A89AB5, 0x4C1B3 },
	{ 0xF0A89AB6, 0x5ABDB },
	{ 0xF0A89AB9, 0xFADDA },
	{ 0xF0A89ABA, 0xFC5EE },
	{ 0xF0A89ABB, 0x6D9C5 },
	{ 0xF0A89ABC, 0x6D9C4 },
	{ 0xF0A89ABD, 0x6D9C6 },
	{ 0xF0A89ABF, 0x6B4EC },
	{ 0xF0A89B81, 0x6B4E6 },
	{ 0xF0A89B83, 0x6B4E7 },
	{ 0xF0A89B84, 0x6B4E8 },
	{ 0xF0A89B86, 0x6B4EB },
	{ 0xF0A89B87, 0x6B4EA },
	{ 0xF0A89B88, 0x5ABDE },
	{ 0xF0A89B89, 0x5ABDC },
	{ 0xF0A89B8A, 0x5ABDD },
	{ 0xF0A89B8B, 0x5B0E1 },
	{ 0xF0A89B8C, 0x5B0DD },
	{ 0xF0A89B8D, 0x4B0B6 },
	{ 0xF0A89B8E, 0x6BCDB },
	{ 0xF0A89B8F, 0x5B0E5 },
	{ 0xF0A89B90, 0x5B0E6 },
	{ 0xF0A89B91, 0x5B0DE },
	{ 0xF0A89B92, 0x5B0E3 },
	{ 0xF0A89B93, 0x5B0DF },
	{ 0xF0A89B94, 0x4B0B5 },
	{ 0xF0A89B95, 0x6BCDD },
	{ 0xF0A89B96, 0x4B0B7 },
	{ 0xF0A89B99, 0x6BCDF },
	{ 0xF0A89B9A, 0x6E3BD },
	{ 0xF0A89B9B, 0x6E3BF },
	{ 0xF0A89B9C, 0x6E3C0 },
	{ 0xF0A89B9E, 0x6BCDC },
	{ 0xF0A89B9F, 0x6BCDE },
	{ 0xF0A89BA0, 0x6BCDA },
	{ 0xF0A89BA1, 0x5B0E2 },
	{ 0xF0A89BA3, 0x5B0E4 },
	{ 0xF0A89BA4, 0x5B0E0 },
	{ 0xF0A89BA5, 0x5B0E7 },
	{ 0xF0A89BA6, 0x6E3BE },
	{ 0xF0A89BA7, 0x6BCD9 },
	{ 0xF0A89BA8, 0xFB2E2 },
	{ 0xF0A89BA9, 0xFB2E3 },
	{ 0xF0A89BAA, 0xFB2E4 },
	{ 0xF0A89BAB, 0x5D1EE },
	{ 0xF0A89BAC, 0x4CEB6 },
	{ 0xF0A89BAD, 0x4B5EF },
	{ 0xF0A89BAE, 0x5B6B1 },
	{ 0xF0A89BAF, 0x5B6B0 },
	{ 0xF0A89BB0, 0x5B6B5 },
	{ 0xF0A89BB1, 0x5B6AE },
	{ 0xF0A89BB3, 0x5B6B2 },
	{ 0xF0A89BB4, 0x4B5ED },
	{ 0xF0A89BB5, 0x6C5E6 },
	{ 0xF0A89BB6, 0x5B6B4 },
	{ 0xF0A89BB7, 0x7A9FA },
	{ 0xF0A89BB8, 0x7A9F9 },
	{ 0xF0A89BBB, 0x6C5E8 },
	{ 0xF0A89BBC, 0xFB2E1 },
	{ 0xF0A89BBD, 0xFB8F6 },
	{ 0xF0A89BBE, 0xFD2D4 },
	{ 0xF0A89BBF, 0x7A9F6 },
	{ 0xF0A89C80, 0x7A9F7 },
	{ 0xF0A89C81, 0x7A9FB },
	{ 0xF0A89C82, 0x7A9F8 },
	{ 0xF0A89C83, 0x6C5E3 },
	{ 0xF0A89C85, 0x6C5E5 },
	{ 0xF0A89C86, 0x6C5E4 },
	{ 0xF0A89C88, 0x6C5E2 },
	{ 0xF0A89C8A, 0xFB3BC },
	{ 0xF0A89C8B, 0x6C5E7 },
	{ 0xF0A89C8C, 0x5B6AF },
	{ 0xF0A89C8D, 0x5B6B3 },
	{ 0xF0A89C8E, 0x5B0E8 },
	{ 0xF0A89C8F, 0x4BBDF },
	{ 0xF0A89C90, 0x5BDA3 },
	{ 0xF0A89C91, 0x5BCFE },
	{ 0xF0A89C92, 0x5BDA2 },
	{ 0xF0A89C93, 0x4BBDD },
	{ 0xF0A89C94, 0x5BDA4 },
	{ 0xF0A89C95, 0x6CFE4 },
	{ 0xF0A89C96, 0x5BDA1 },
	{ 0xF0A89C97, 0x5C3E7 },
	{ 0xF0A89C98, 0x5BCFD },
	{ 0xF0A89C99, 0x5BCFC },
	{ 0xF0A89C9A, 0x6CFE2 },
	{ 0xF0A89C9B, 0x6CFDB },
	{ 0xF0A89C9C, 0x4BBDC },
	{ 0xF0A89C9F, 0xFBFE3 },
	{ 0xF0A89CA0, 0xFBFE4 },
	{ 0xF0A89CA1, 0xFBFE5 },
	{ 0xF0A89CA2, 0xFD8C1 },
	{ 0xF0A89CA3, 0x7B4CE },
	{ 0xF0A89CA4, 0x6CFDD },
	{ 0xF0A89CA5, 0x6CFDC },
	{ 0xF0A89CA6, 0x6CFDE },
	{ 0xF0A89CA7, 0x6CFDF },
	{ 0xF0A89CA8, 0x6CFE0 },
	{ 0xF0A89CAA, 0x6CFE1 },
	{ 0xF0A89CAD, 0xFBFE6 },
	{ 0xF0A89CAE, 0x6CFE3 },
	{ 0xF0A89CAF, 0x7B4CD },
	{ 0xF0A89CB0, 0x5BCFB },
	{ 0xF0A89CB2, 0x7BCE4 },
	{ 0xF0A89CB3, 0x5C3DB },
	{ 0xF0A89CB4, 0x5C3E0 },
	{ 0xF0A89CB5, 0x5C3E3 },
	{ 0xF0A89CB6, 0x5C3DE },
	{ 0xF0A89CB7, 0x5C3DD },
	{ 0xF0A89CB8, 0x4C1B5 },
	{ 0xF0A89CB9, 0x6E3C1 },
	{ 0xF0A89CBA, 0x5C3DC },
	{ 0xF0A89CBB, 0x5C3E2 },
	{ 0xF0A89CBC, 0x5C3DF },
	{ 0xF0A89CBD, 0x5C3E4 },
	{ 0xF0A89CBE, 0x5C3E6 },
	{ 0xF0A89CBF, 0x4C1B7 },
	{ 0xF0A89D80, 0x5C3E5 },
	{ 0xF0A89D81, 0x6D9C9 },
	{ 0xF0A89D83, 0x5C3DA },
	{ 0xF0A89D84, 0xFC5EF },
	{ 0xF0A89D87, 0x6D9C8 },
	{ 0xF0A89D89, 0x6D9CB },
	{ 0xF0A89D8A, 0x5C3E1 },
	{ 0xF0A89D8B, 0x4C7EF },
	{ 0xF0A89D8C, 0x5CADD },
	{ 0xF0A89D8D, 0x5CADC },
	{ 0xF0A89D8E, 0x5CAD9 },
	{ 0xF0A89D8F, 0x5CAD8 },
	{ 0xF0A89D90, 0x5CAE3 },
	{ 0xF0A89D91, 0x5CADF },
	{ 0xF0A89D93, 0x5CADB },
	{ 0xF0A89D94, 0x6E3C6 },
	{ 0xF0A89D95, 0x6E3C3 },
	{ 0xF0A89D97, 0x6E3C2 },
	{ 0xF0A89D98, 0x5CAE1 },
	{ 0xF0A89D9B, 0x5CAE2 },
	{ 0xF0A89D9D, 0x7C4A2 },
	{ 0xF0A89D9E, 0x7C4A4 },
	{ 0xF0A89D9F, 0x7C4A3 },
	{ 0xF0A89DA0, 0x7C4A5 },
	{ 0xF0A89DA1, 0x6E3C5 },
	{ 0xF0A89DA2, 0x5CAD7 },
	{ 0xF0A89DA3, 0x4C7F2 },
	{ 0xF0A89DA5, 0x6E3C4 },
	{ 0xF0A89DA6, 0x5E5BE },
	{ 0xF0A89DA7, 0x5CADA },
	{ 0xF0A89DA8, 0x5CADE },
	{ 0xF0A89DAA, 0x5CAE4 },
	{ 0xF0A89DAB, 0x4CEB8 },
	{ 0xF0A89DAC, 0x7CBA3 },
	{ 0xF0A89DAD, 0x5D1F2 },
	{ 0xF0A89DAE, 0x7AAA1 },
	{ 0xF0A89DAF, 0x4CEB7 },
	{ 0xF0A89DB0, 0x5D1F3 },
	{ 0xF0A89DB1, 0x4CEB9 },
	{ 0xF0A89DB3, 0x5D9A8 },
	{ 0xF0A89DB4, 0x5D1EF },
	{ 0xF0A89DB5, 0x5D1F0 },
	{ 0xF0A89DB6, 0x7A9FE },
	{ 0xF0A89DB7, 0x7AAA2 },
	{ 0xF0A89DB8, 0x4CEBA },
	{ 0xF0A89DBD, 0xFD2D3 },
	{ 0xF0A89DBE, 0xFD2D5 },
	{ 0xF0A89DBF, 0xFD2D6 },
	{ 0xF0A89E80, 0x7CBA6 },
	{ 0xF0A89E81, 0x7CBA4 },
	{ 0xF0A89E82, 0x7AAA3 },
	{ 0xF0A89E83, 0x7AAA5 },
	{ 0xF0A89E84, 0x7AAA6 },
	{ 0xF0A89E85, 0x7AAA4 },
	{ 0xF0A89E87, 0x7A9FC },
	{ 0xF0A89E89, 0x7A9FD },
	{ 0xF0A89E8C, 0x5D1F4 },
	{ 0xF0A89E8D, 0x7B4D0 },
	{ 0xF0A89E8E, 0x5D1F1 },
	{ 0xF0A89E8F, 0x7CBA5 },
	{ 0xF0A89E91, 0x5EEAA },
	{ 0xF0A89E92, 0x5D9A5 },
	{ 0xF0A89E93, 0x5D9A6 },
	{ 0xF0A89E94, 0x7D0DC },
	{ 0xF0A89E95, 0x4D4B8 },
	{ 0xF0A89E96, 0x7B4CF },
	{ 0xF0A89E97, 0x5D9A1 },
	{ 0xF0A89E98, 0x5D9A4 },
	{ 0xF0A89E99, 0x7B4D2 },
	{ 0xF0A89E9A, 0x5D9A2 },
	{ 0xF0A89E9B, 0x5D9A3 },
	{ 0xF0A89E9C, 0x4D4B9 },
	{ 0xF0A89E9E, 0x7B4D1 },
	{ 0xF0A89E9F, 0xFD8C0 },
	{ 0xF0A89EA0, 0x7D0DD },
	{ 0xF0A89EA1, 0x7D0DB },
	{ 0xF0A89EA6, 0x5EEAB },
	{ 0xF0A89EA7, 0x7BCE5 },
	{ 0xF0A89EA8, 0x7BCE9 },
	{ 0xF0A89EA9, 0x5DFB8 },
	{ 0xF0A89EAA, 0x4D9BB },
	{ 0xF0A89EAB, 0x5DFB9 },
	{ 0xF0A89EAE, 0x7D5D2 },
	{ 0xF0A89EAF, 0x7D5D3 },
	{ 0xF0A89EB0, 0x7D5D4 },
	{ 0xF0A89EB1, 0x7BCE7 },
	{ 0xF0A89EB3, 0x7BCEA },
	{ 0xF0A89EB5, 0x7BCE6 },
	{ 0xF0A89EB6, 0x5DFBB },
	{ 0xF0A89EB7, 0x5DFBA },
	{ 0xF0A89EB8, 0x7D5D5 },
	{ 0xF0A89EB9, 0x7BCE8 },
	{ 0xF0A89EBA, 0x5E5C0 },
	{ 0xF0A89EBB, 0x7C4A6 },
	{ 0xF0A89EBC, 0x7C4A7 },
	{ 0xF0A89EBD, 0x5E5C1 },
	{ 0xF0A89EBE, 0x5EAA5 },
	{ 0xF0A89EBF, 0x5E5C4 },
	{ 0xF0A89F80, 0x7C4A9 },
	{ 0xF0A89F81, 0x7C4A8 },
	{ 0xF0A89F82, 0x5E5C2 },
	{ 0xF0A89F83, 0x5E5C3 },
	{ 0xF0A89F84, 0x7D9DC },
	{ 0xF0A89F85, 0x5E5BF },
	{ 0xF0A89F88, 0x7C4AA },
	{ 0xF0A89F8D, 0x7CBA8 },
	{ 0xF0A89F8E, 0x7C4AB },
	{ 0xF0A89F8F, 0x5EAA4 },
	{ 0xF0A89F90, 0x7CBA7 },
	{ 0xF0A89F91, 0x5EAA3 },
	{ 0xF0A89F94, 0x7CBAA },
	{ 0xF0A89F95, 0x7CBA9 },
	{ 0xF0A89F96, 0x4E1E0 },
	{ 0xF0A89F97, 0x5D9A7 },
	{ 0xF0A89F98, 0x5EAA2 },
	{ 0xF0A89F99, 0x4E4E4 },
	{ 0xF0A89F9A, 0x5EEAC },
	{ 0xF0A89F9B, 0x7D0DF },
	{ 0xF0A89F9C, 0x7D0E1 },
	{ 0xF0A89F9E, 0x7D0DE },
	{ 0xF0A89F9F, 0x7D0E0 },
	{ 0xF0A89FA0, 0x4E7D6 },
	{ 0xF0A89FA1, 0xFE8D9 },
	{ 0xF0A89FA2, 0x7D5D6 },
	{ 0xF0A89FA3, 0x7D5D7 },
	{ 0xF0A89FA4, 0x7D9DD },
	{ 0xF0A89FA6, 0x7D5D8 },
	{ 0xF0A89FA7, 0xFE8DA },
	{ 0xF0A89FA8, 0x7DDA6 },
	{ 0xF0A89FAB, 0x7DFEB },
	{ 0xF0A89FAC, 0x7DFEC },
	{ 0xF0A89FAE, 0x5FBCB },
	{ 0xF0A89FAF, 0x7E3F8 },
	{ 0xF0A89FB0, 0x4B0B9 },
	{ 0xF0A89FB1, 0xFB2E5 },
	{ 0xF0A89FB2, 0x6BCE0 },
	{ 0xF0A89FB4, 0x5B6B8 },
	{ 0xF0A89FB5, 0x5B6B7 },
	{ 0xF0A89FB6, 0x6C5F2 },
	{ 0xF0A89FB7, 0x6C5EE },
	{ 0xF0A89FB8, 0x5B6B9 },
	{ 0xF0A89FB9, 0x4B5F6 },
	{ 0xF0A89FBA, 0x6C5EC },
	{ 0xF0A89FBB, 0x6C5F3 },
	{ 0xF0A89FBC, 0x6C5E9 },
	{ 0xF0A89FBD, 0x4B5F7 },
	{ 0xF0A89FBE, 0x5B6BA },
	{ 0xF0A89FBF, 0x6C5F0 },
	{ 0xF0A8A080, 0x6C5EF },
	{ 0xF0A8A081, 0x6C5EA },
	{ 0xF0A8A082, 0x6C5EB },
	{ 0xF0A8A085, 0xFB8F7 },
	{ 0xF0A8A086, 0x6C5F1 },
	{ 0xF0A8A087, 0x4B5F9 },
	{ 0xF0A8A088, 0x6C5ED },
	{ 0xF0A8A08A, 0x6C5F4 },
	{ 0xF0A8A08B, 0x6CFEB },
	{ 0xF0A8A08C, 0x5BDA5 },
	{ 0xF0A8A08D, 0x5BDA6 },
	{ 0xF0A8A08E, 0x4BBE5 },
	{ 0xF0A8A08F, 0x6CFE9 },
	{ 0xF0A8A090, 0x5C3EA },
	{ 0xF0A8A091, 0x4BBE2 },
	{ 0xF0A8A092, 0x4BBE3 },
	{ 0xF0A8A093, 0x6CFEA },
	{ 0xF0A8A094, 0x6CFE6 },
	{ 0xF0A8A095, 0x6CFE5 },
	{ 0xF0A8A096, 0x4BBE1 },
	{ 0xF0A8A097, 0x6CFE7 },
	{ 0xF0A8A098, 0x6CFE8 },
	{ 0xF0A8A09B, 0xFBFE8 },
	{ 0xF0A8A09C, 0xFBFE9 },
	{ 0xF0A8A09D, 0xFBFEA },
	{ 0xF0A8A09E, 0xFBFEB },
	{ 0xF0A8A0A2, 0x6CFEC },
	{ 0xF0A8A0A4, 0x5C3E9 },
	{ 0xF0A8A0A5, 0x5C3EC },
	{ 0xF0A8A0A6, 0x5C3E8 },
	{ 0xF0A8A0A7, 0x6D9CE },
	{ 0xF0A8A0AE, 0x6D9CD },
	{ 0xF0A8A0B6, 0x5C3EB },
	{ 0xF0A8A0B7, 0x6E3CA },
	{ 0xF0A8A0B8, 0x5CAE6 },
	{ 0xF0A8A0B9, 0x5CAE5 },
	{ 0xF0A8A0BA, 0xFCCF3 },
	{ 0xF0A8A0BB, 0xFCCF4 },
	{ 0xF0A8A0BC, 0xFCCF5 },
	{ 0xF0A8A0BD, 0xFCCF7 },
	{ 0xF0A8A0BE, 0x6E3C9 },
	{ 0xF0A8A181, 0x6E3C8 },
	{ 0xF0A8A182, 0xFCCF8 },
	{ 0xF0A8A185, 0x6E3C7 },
	{ 0xF0A8A18B, 0x7AAA8 },
	{ 0xF0A8A18C, 0x5D1F8 },
	{ 0xF0A8A18D, 0x7AAAC },
	{ 0xF0A8A18E, 0x5D1F9 },
	{ 0xF0A8A18F, 0x5D1F5 },
	{ 0xF0A8A190, 0x7AAB0 },
	{ 0xF0A8A191, 0x5D1F6 },
	{ 0xF0A8A193, 0x7AAAF },
	{ 0xF0A8A194, 0x7AAAE },
	{ 0xF0A8A195, 0x7AAAD },
	{ 0xF0A8A196, 0x7AAA9 },
	{ 0xF0A8A197, 0x7AAA7 },
	{ 0xF0A8A198, 0x5D1F7 },
	{ 0xF0A8A19A, 0xFCCF6 },
	{ 0xF0A8A19B, 0xFD2D8 },
	{ 0xF0A8A19C, 0xFD2D9 },
	{ 0xF0A8A19D, 0x7AAAA },
	{ 0xF0A8A1A0, 0x7AAAB },
	{ 0xF0A8A1A2, 0x7AAB2 },
	{ 0xF0A8A1A3, 0x7AAB1 },
	{ 0xF0A8A1A9, 0x7B4D6 },
	{ 0xF0A8A1AA, 0x7B4D5 },
	{ 0xF0A8A1AB, 0x5D9A9 },
	{ 0xF0A8A1AC, 0x7B4D8 },
	{ 0xF0A8A1AD, 0x5D9AC },
	{ 0xF0A8A1AE, 0x7B4DA },
	{ 0xF0A8A1AF, 0x4D4C1 },
	{ 0xF0A8A1B0, 0x7B4DF },
	{ 0xF0A8A1B1, 0x4D4BE },
	{ 0xF0A8A1B2, 0x4D4BF },
	{ 0xF0A8A1B3, 0x7B4DE },
	{ 0xF0A8A1B4, 0x5D9AA },
	{ 0xF0A8A1B5, 0x7B4D7 },
	{ 0xF0A8A1B6, 0x7B4DD },
	{ 0xF0A8A1B7, 0x7B4DC },
	{ 0xF0A8A1B8, 0x5D9AB },
	{ 0xF0A8A1BD, 0xFD8C2 },
	{ 0xF0A8A1BE, 0xFD8C3 },
	{ 0xF0A8A280, 0x7B4D9 },
	{ 0xF0A8A281, 0x7B4DB },
	{ 0xF0A8A283, 0x7B4D3 },
	{ 0xF0A8A284, 0x7B4E0 },
	{ 0xF0A8A285, 0x5DFC1 },
	{ 0xF0A8A286, 0x5DFBF },
	{ 0xF0A8A287, 0x5DFC0 },
	{ 0xF0A8A288, 0x5DFC3 },
	{ 0xF0A8A289, 0x4D9C0 },
	{ 0xF0A8A28A, 0x7BCEC },
	{ 0xF0A8A28B, 0x5DFC2 },
	{ 0xF0A8A28C, 0x4D9BE },
	{ 0xF0A8A28D, 0x7BCEE },
	{ 0xF0A8A28E, 0x5DFBE },
	{ 0xF0A8A28F, 0x7BCF4 },
	{ 0xF0A8A290, 0x5DFC4 },
	{ 0xF0A8A291, 0x7BCED },
	{ 0xF0A8A292, 0x7BCF3 },
	{ 0xF0A8A294, 0xFDDAA },
	{ 0xF0A8A295, 0xFDDAB },
	{ 0xF0A8A296, 0xFDDAC },
	{ 0xF0A8A299, 0x7BCEF },
	{ 0xF0A8A29A, 0x7BCF1 },
	{ 0xF0A8A29B, 0x7BCF2 },
	{ 0xF0A8A2A0, 0x5DFBD },
	{ 0xF0A8A2A1, 0x5E5C6 },
	{ 0xF0A8A2A2, 0x5E5C7 },
	{ 0xF0A8A2A3, 0x5E5C9 },
	{ 0xF0A8A2A4, 0x7C4B3 },
	{ 0xF0A8A2A5, 0x7C4AF },
	{ 0xF0A8A2A6, 0x4DEA3 },
	{ 0xF0A8A2A7, 0x7C4AC },
	{ 0xF0A8A2A8, 0x5E5C8 },
	{ 0xF0A8A2A9, 0x4DEA6 },
	{ 0xF0A8A2AA, 0x5E5CA },
	{ 0xF0A8A2AB, 0x7BCF5 },
	{ 0xF0A8A2AC, 0x4DEA5 },
	{ 0xF0A8A2AD, 0x7C4B2 },
	{ 0xF0A8A2AF, 0x5E5CB },
	{ 0xF0A8A2B0, 0x7C4B5 },
	{ 0xF0A8A2B1, 0x7C4B6 },
	{ 0xF0A8A2B2, 0x7C4AD },
	{ 0xF0A8A2B3, 0xFE1AE },
	{ 0xF0A8A2B5, 0x7C4B1 },
	{ 0xF0A8A2B6, 0x7C4AE },
	{ 0xF0A8A2B9, 0x5E5CC },
	{ 0xF0A8A2BA, 0x7C4B0 },
	{ 0xF0A8A2BD, 0x7CBAF },
	{ 0xF0A8A2BE, 0x7CBAC },
	{ 0xF0A8A2BF, 0x5EAAE },
	{ 0xF0A8A380, 0x5EAAB },
	{ 0xF0A8A381, 0x5EAA7 },
	{ 0xF0A8A382, 0x5EAAA },
	{ 0xF0A8A383, 0x5EAA9 },
	{ 0xF0A8A384, 0x5EAAF },
	{ 0xF0A8A385, 0x5EAAC },
	{ 0xF0A8A386, 0x5EAA8 },
	{ 0xF0A8A387, 0x5EAAD },
	{ 0xF0A8A38B, 0x7CBAD },
	{ 0xF0A8A38E, 0x7CBAE },
	{ 0xF0A8A390, 0x7CBB0 },
	{ 0xF0A8A391, 0x7CBAB },
	{ 0xF0A8A393, 0x7C4B4 },
	{ 0xF0A8A394, 0x5EAB0 },
	{ 0xF0A8A395, 0x5EAA6 },
	{ 0xF0A8A396, 0x7D0E2 },
	{ 0xF0A8A397, 0x5EEB1 },
	{ 0xF0A8A398, 0x5EEAE },
	{ 0xF0A8A399, 0x5EEAF },
	{ 0xF0A8A39A, 0x5EEAD },
	{ 0xF0A8A39B, 0x5EEB0 },
	{ 0xF0A8A39C, 0x7D0E3 },
	{ 0xF0A8A39D, 0x7D0E4 },
	{ 0xF0A8A39F, 0xFE6CE },
	{ 0xF0A8A3A0, 0x7D0E5 },
	{ 0xF0A8A3A1, 0x7D0E7 },
	{ 0xF0A8A3A3, 0x7D0E6 },
	{ 0xF0A8A3A6, 0x4E7D9 },
	{ 0xF0A8A3A7, 0x4E7D7 },
	{ 0xF0A8A3A8, 0x4E7D8 },
	{ 0xF0A8A3A9, 0x5F1D3 },
	{ 0xF0A8A3AA, 0x7D5DA },
	{ 0xF0A8A3AB, 0xFE8DB },
	{ 0xF0A8A3AD, 0x7D5D9 },
	{ 0xF0A8A3AE, 0x7D9DE },
	{ 0xF0A8A3AF, 0x7D9DF },
	{ 0xF0A8A3B0, 0x7D9E2 },
	{ 0xF0A8A3B1, 0x5F4D3 },
	{ 0xF0A8A3B2, 0x7D9E1 },
	{ 0xF0A8A3B3, 0x7D9E0 },
	{ 0xF0A8A3B4, 0xFE9FD },
	{ 0xF0A8A3B6, 0x7DDA7 },
	{ 0xF0A8A3B7, 0x7DDA9 },
	{ 0xF0A8A3B8, 0x5F6DA },
	{ 0xF0A8A3B9, 0x7DDAB },
	{ 0xF0A8A3BA, 0x7DDAA },
	{ 0xF0A8A3BB, 0x5F6DB },
	{ 0xF0A8A3BC, 0x7DDA8 },
	{ 0xF0A8A3BD, 0xFEAFA },
	{ 0xF0A8A3BE, 0x5F8BF },
	{ 0xF0A8A3BF, 0x4ECAF },
	{ 0xF0A8A480, 0x7DFED },
	{ 0xF0A8A481, 0x7DFEE },
	{ 0xF0A8A482, 0x5F8BE },
	{ 0xF0A8A485, 0x7E2EC },
	{ 0xF0A8A487, 0x5FAFB },
	{ 0xF0A8A488, 0x7E3FA },
	{ 0xF0A8A489, 0x7E3F9 },
	{ 0xF0A8A48A, 0x7E4E6 },
	{ 0xF0A8A48C, 0x7E4E5 },
	{ 0xF0A8A48D, 0x7E5F8 },
	{ 0xF0A8A48E, 0x7E5F9 },
	{ 0xF0A8A48F, 0x6B4EE },
	{ 0xF0A8A490, 0x5BDA7 },
	{ 0xF0A8A491, 0x5B6BB },
	{ 0xF0A8A492, 0x6E3CB },
	{ 0xF0A8A493, 0x6E3CC },
	{ 0xF0A8A495, 0x5D1FA },
	{ 0xF0A8A496, 0x7AAB4 },
	{ 0xF0A8A497, 0x7AAB3 },
	{ 0xF0A8A498, 0x5D9AD },
	{ 0xF0A8A499, 0x7B4E1 },
	{ 0xF0A8A49A, 0x5DFC5 },
	{ 0xF0A8A49B, 0xFDDAD },
	{ 0xF0A8A49D, 0x7C4B7 },
	{ 0xF0A8A49E, 0xFE6CF },
	{ 0xF0A8A4A0, 0xFE8DC },
	{ 0xF0A8A4A1, 0x5F4D4 },
	{ 0xF0A8A4A2, 0x5B6BC },
	{ 0xF0A8A4A3, 0x6BCE1 },
	{ 0xF0A8A4A5, 0x6C5F5 },
	{ 0xF0A8A4A6, 0x6CFEE },
	{ 0xF0A8A4A8, 0x5BDA9 },
	{ 0xF0A8A4A9, 0x5BDA8 },
	{ 0xF0A8A4AA, 0xFC5F0 },
	{ 0xF0A8A4AC, 0x6E3CD },
	{ 0xF0A8A4AD, 0x7AAB5 },
	{ 0xF0A8A4B4, 0x5DFC6 },
	{ 0xF0A8A4B6, 0xFE1AF },
	{ 0xF0A8A4B7, 0x5E5CD },
	{ 0xF0A8A4B8, 0xFE8DD },
	{ 0xF0A8A4B9, 0x5F1D4 },
	{ 0xF0A8A4BA, 0x7D5DB },
	{ 0xF0A8A4BE, 0x6BCE4 },
	{ 0xF0A8A4BF, 0xFB2E6 },
	{ 0xF0A8A580, 0x6BCE2 },
	{ 0xF0A8A582, 0x5B6BD },
	{ 0xF0A8A583, 0x6C5F6 },
	{ 0xF0A8A584, 0x6C5F7 },
	{ 0xF0A8A589, 0xFB8F8 },
	{ 0xF0A8A58A, 0x6CFF3 },
	{ 0xF0A8A58B, 0x6CFF4 },
	{ 0xF0A8A58C, 0x6CFF5 },
	{ 0xF0A8A58D, 0x6CFF1 },
	{ 0xF0A8A58E, 0x6CFF2 },
	{ 0xF0A8A58F, 0x6CFF8 },
	{ 0xF0A8A590, 0x6CFF6 },
	{ 0xF0A8A591, 0x6CFF0 },
	{ 0xF0A8A592, 0x6CFF9 },
	{ 0xF0A8A593, 0xFBFEC },
	{ 0xF0A8A594, 0xFBFED },
	{ 0xF0A8A595, 0xFBFEE },
	{ 0xF0A8A596, 0xFBFEF },
	{ 0xF0A8A597, 0xFBFF2 },
	{ 0xF0A8A598, 0xFBFF4 },
	{ 0xF0A8A599, 0xFBFF1 },
	{ 0xF0A8A5A2, 0x6CFF7 },
	{ 0xF0A8A5A4, 0xFBFF0 },
	{ 0xF0A8A5A5, 0x4C1C7 },
	{ 0xF0A8A5A6, 0x5C3EE },
	{ 0xF0A8A5A7, 0x4C1C5 },
	{ 0xF0A8A5A8, 0x4C1C4 },
	{ 0xF0A8A5A9, 0x6D9D3 },
	{ 0xF0A8A5AA, 0x6D9CF },
	{ 0xF0A8A5AD, 0xFC5F1 },
	{ 0xF0A8A5AE, 0xFC5F5 },
	{ 0xF0A8A5AF, 0xFC5F6 },
	{ 0xF0A8A5B0, 0xFC5F7 },
	{ 0xF0A8A5B1, 0xFC5F8 },
	{ 0xF0A8A5B2, 0x6D9D5 },
	{ 0xF0A8A5B3, 0x6D9D1 },
	{ 0xF0A8A5B5, 0x6D9D2 },
	{ 0xF0A8A5B6, 0xFC5F9 },
	{ 0xF0A8A5B9, 0x6D9D4 },
	{ 0xF0A8A5BB, 0x6D9D0 },
	{ 0xF0A8A5BE, 0xFC5F4 },
	{ 0xF0A8A682, 0x5CAE7 },
	{ 0xF0A8A684, 0x5CAE8 },
	{ 0xF0A8A685, 0x6E3D2 },
	{ 0xF0A8A686, 0x5CAE9 },
	{ 0xF0A8A68A, 0xFCCE8 },
	{ 0xF0A8A68B, 0xFCCF9 },
	{ 0xF0A8A68C, 0xFCCFB },
	{ 0xF0A8A68D, 0xFCCFC },
	{ 0xF0A8A68E, 0xFCCFD },
	{ 0xF0A8A68F, 0xFCDA1 },
	{ 0xF0A8A690, 0xFCDA3 },
	{ 0xF0A8A691, 0xFCDA4 },
	{ 0xF0A8A692, 0xFCDA5 },
	{ 0xF0A8A693, 0xFCDA8 },
	{ 0xF0A8A694, 0xFCDA9 },
	{ 0xF0A8A696, 0x6E3CE },
	{ 0xF0A8A699, 0x4C7FA },
	{ 0xF0A8A69C, 0x6E3D0 },
	{ 0xF0A8A69D, 0x6E3D1 },
	{ 0xF0A8A69E, 0xFCDAA },
	{ 0xF0A8A69F, 0x6E3D4 },
	{ 0xF0A8A6A0, 0xFCCFA },
	{ 0xF0A8A6A3, 0x6E3D5 },
	{ 0xF0A8A6A8, 0xFCDAB },
	{ 0xF0A8A6AA, 0xFCDA6 },
	{ 0xF0A8A6AB, 0xFCCFE },
	{ 0xF0A8A6AC, 0x7AABA },
	{ 0xF0A8A6AD, 0x4CEC2 },
	{ 0xF0A8A6AE, 0x5D1FE },
	{ 0xF0A8A6AF, 0x7AAC1 },
	{ 0xF0A8A6B0, 0x7AABB },
	{ 0xF0A8A6B1, 0x7AAC0 },
	{ 0xF0A8A6B2, 0x7AAB9 },
	{ 0xF0A8A6B3, 0x5D1FD },
	{ 0xF0A8A6B4, 0x7AAC3 },
	{ 0xF0A8A6B7, 0x7AAC4 },
	{ 0xF0A8A6B8, 0x7AABD },
	{ 0xF0A8A6BE, 0x5D1FB },
	{ 0xF0A8A6BF, 0x7AAB7 },
	{ 0xF0A8A781, 0xFD2DB },
	{ 0xF0A8A782, 0xFD2DD },
	{ 0xF0A8A783, 0xFD2DF },
	{ 0xF0A8A784, 0xFD2E0 },
	{ 0xF0A8A785, 0xFD2E3 },
	{ 0xF0A8A786, 0xFD2E4 },
	{ 0xF0A8A787, 0xFD2E5 },
	{ 0xF0A8A788, 0xFD2E7 },
	{ 0xF0A8A789, 0xFD2E8 },
	{ 0xF0A8A78A, 0xFD2E9 },
	{ 0xF0A8A78B, 0xFD2EA },
	{ 0xF0A8A78C, 0xFD2EC },
	{ 0xF0A8A78D, 0xFD2ED },
	{ 0xF0A8A78E, 0x7AAC2 },
	{ 0xF0A8A78F, 0x7AABC },
	{ 0xF0A8A793, 0x7AABF },
	{ 0xF0A8A795, 0x7AAC5 },
	{ 0xF0A8A796, 0xFD2DE },
	{ 0xF0A8A799, 0x7AAB6 },
	{ 0xF0A8A79B, 0x5D1FC },
	{ 0xF0A8A79C, 0xFD2E2 },
	{ 0xF0A8A7A1, 0xFD2E6 },
	{ 0xF0A8A7A4, 0xFD2DA },
	{ 0xF0A8A7A5, 0x5D9B4 },
	{ 0xF0A8A7A6, 0x5D9B7 },
	{ 0xF0A8A7A7, 0x5D9B2 },
	{ 0xF0A8A7A8, 0x4D4C7 },
	{ 0xF0A8A7A9, 0x5D9AE },
	{ 0xF0A8A7AA, 0x5D9B0 },
	{ 0xF0A8A7AB, 0x7B4E5 },
	{ 0xF0A8A7AC, 0x7B4E4 },
	{ 0xF0A8A7AD, 0x7B4EB },
	{ 0xF0A8A7AE, 0x7B4E9 },
	{ 0xF0A8A7AF, 0x7B4E7 },
	{ 0xF0A8A7B0, 0x5D9B6 },
	{ 0xF0A8A7B1, 0x4D4C4 },
	{ 0xF0A8A7B2, 0x7B4E2 },
	{ 0xF0A8A7B3, 0x7B4EA },
	{ 0xF0A8A7B4, 0x7B4E8 },
	{ 0xF0A8A7B5, 0x5D9AF },
	{ 0xF0A8A7B6, 0x7B4E6 },
	{ 0xF0A8A7BD, 0xFD2DC },
	{ 0xF0A8A7BE, 0x5D9B3 },
	{ 0xF0A8A7BF, 0xFD8C4 },
	{ 0xF0A8A880, 0xFD8C6 },
	{ 0xF0A8A881, 0xFD8C7 },
	{ 0xF0A8A882, 0xFD8C9 },
	{ 0xF0A8A883, 0xFD8CA },
	{ 0xF0A8A884, 0xFD8CB },
	{ 0xF0A8A885, 0xFD8CD },
	{ 0xF0A8A886, 0xFD8CE },
	{ 0xF0A8A887, 0xFD8CF },
	{ 0xF0A8A888, 0xFD8D1 },
	{ 0xF0A8A889, 0xFD8D3 },
	{ 0xF0A8A88A, 0xFD8D4 },
	{ 0xF0A8A88B, 0xFD8D6 },
	{ 0xF0A8A88C, 0xFD8D7 },
	{ 0xF0A8A88D, 0xFD8DA },
	{ 0xF0A8A88E, 0xFD8DC },
	{ 0xF0A8A890, 0xFD8DD },
	{ 0xF0A8A891, 0xFD8DE },
	{ 0xF0A8A892, 0xFD8E0 },
	{ 0xF0A8A893, 0xFD8E1 },
	{ 0xF0A8A894, 0xFD8E3 },
	{ 0xF0A8A895, 0xFD8E4 },
	{ 0xF0A8A896, 0xFD8D0 },
	{ 0xF0A8A897, 0xFD8D2 },
	{ 0xF0A8A89D, 0xFD8DF },
	{ 0xF0A8A8A5, 0xFD8C5 },
	{ 0xF0A8A8A9, 0xFD8D8 },
	{ 0xF0A8A8AC, 0x5D9B8 },
	{ 0xF0A8A8AE, 0x5D9B1 },
	{ 0xF0A8A8AF, 0x5DFC8 },
	{ 0xF0A8A8B0, 0x5DFC9 },
	{ 0xF0A8A8B1, 0x7BCF9 },
	{ 0xF0A8A8B2, 0x4D9C3 },
	{ 0xF0A8A8B3, 0x5DFCC },
	{ 0xF0A8A8B4, 0x5DFCB },
	{ 0xF0A8A8B5, 0x7BCFC },
	{ 0xF0A8A8B6, 0x5D9B5 },
	{ 0xF0A8A8B7, 0x5DFC7 },
	{ 0xF0A8A8B8, 0x7BCFA },
	{ 0xF0A8A8B9, 0x5DFCA },
	{ 0xF0A8A8BA, 0x5DFCF },
	{ 0xF0A8A8BB, 0x7BCFE },
	{ 0xF0A8A8BC, 0x7BDA4 },
	{ 0xF0A8A8BD, 0x7BDA1 },
	{ 0xF0A8A8BE, 0x7BDA5 },
	{ 0xF0A8A98C, 0xFDDAF },
	{ 0xF0A8A98D, 0xFDDB0 },
	{ 0xF0A8A98E, 0xFDDB4 },
	{ 0xF0A8A98F, 0xFDDB5 },
	{ 0xF0A8A990, 0xFDDB6 },
	{ 0xF0A8A991, 0xFDDB7 },
	{ 0xF0A8A992, 0xFDDBA },
	{ 0xF0A8A993, 0xFDDBB },
	{ 0xF0A8A994, 0xFDDBC },
	{ 0xF0A8A995, 0xFDDBD },
	{ 0xF0A8A996, 0xFDDBF },
	{ 0xF0A8A997, 0xFDDC0 },
	{ 0xF0A8A998, 0xFDDC2 },
	{ 0xF0A8A99B, 0xFDDC3 },
	{ 0xF0A8A99C, 0xFDDC4 },
	{ 0xF0A8A99D, 0xFDDC5 },
	{ 0xF0A8A99E, 0xFDDC6 },
	{ 0xF0A8A99F, 0xFDDC7 },
	{ 0xF0A8A9A0, 0xFDDC8 },
	{ 0xF0A8A9A1, 0xFDDC9 },
	{ 0xF0A8A9A2, 0xFDDCB },
	{ 0xF0A8A9A3, 0xFDDCE },
	{ 0xF0A8A9A4, 0xFDDCF },
	{ 0xF0A8A9A9, 0x7BCFD },
	{ 0xF0A8A9AC, 0x7BDA2 },
	{ 0xF0A8A9B5, 0x7BCF8 },
	{ 0xF0A8A9B9, 0x7BDA3 },
	{ 0xF0A8A9BA, 0x4D9C8 },
	{ 0xF0A8A9BC, 0xFDDCA },
	{ 0xF0A8AA81, 0xFDDB8 },
	{ 0xF0A8AA82, 0xFDDB3 },
	{ 0xF0A8AA83, 0xFDDB1 },
	{ 0xF0A8AA84, 0x5DFCE },
	{ 0xF0A8AA85, 0x5DFCD },
	{ 0xF0A8AA86, 0xFDDAE },
	{ 0xF0A8AA87, 0x5E5D1 },
	{ 0xF0A8AA88, 0x4DEAD },
	{ 0xF0A8AA89, 0x4DEAE },
	{ 0xF0A8AA8A, 0x5E5D2 },
	{ 0xF0A8AA8B, 0x4DEA8 },
	{ 0xF0A8AA8C, 0x4DEAA },
	{ 0xF0A8AA8D, 0x7C4B8 },
	{ 0xF0A8AA8E, 0x5E5D0 },
	{ 0xF0A8AA8F, 0x5E5CE },
	{ 0xF0A8AA90, 0x5EAB1 },
	{ 0xF0A8AA91, 0x7C4BA },
	{ 0xF0A8AA92, 0x5E5D3 },
	{ 0xF0A8AA93, 0x4DEB0 },
	{ 0xF0A8AA94, 0x7C4C0 },
	{ 0xF0A8AA96, 0x7C4BF },
	{ 0xF0A8AA97, 0x5E5D4 },
	{ 0xF0A8AA9F, 0x5E5D5 },
	{ 0xF0A8AAA0, 0x7C4C1 },
	{ 0xF0A8AAA1, 0xFE1B1 },
	{ 0xF0A8AAA2, 0xFE1B2 },
	{ 0xF0A8AAA3, 0xFE1B4 },
	{ 0xF0A8AAA4, 0xFE1B6 },
	{ 0xF0A8AAA5, 0xFE1B7 },
	{ 0xF0A8AAA6, 0xFE1B8 },
	{ 0xF0A8AAA7, 0xFE1BA },
	{ 0xF0A8AAA8, 0xFE1BC },
	{ 0xF0A8AAA9, 0xFE1BD },
	{ 0xF0A8AAAA, 0xFE1BE },
	{ 0xF0A8AAAB, 0xFE1C0 },
	{ 0xF0A8AAAC, 0xFE1C1 },
	{ 0xF0A8AAAD, 0xFE1C2 },
	{ 0xF0A8AAAE, 0xFE1C4 },
	{ 0xF0A8AAAF, 0xFE1C5 },
	{ 0xF0A8AAB0, 0xFE1C6 },
	{ 0xF0A8AAB6, 0x7C4BB },
	{ 0xF0A8AAB7, 0x7C4BC },
	{ 0xF0A8AABC, 0x7C4BE },
	{ 0xF0A8AABD, 0x7C4BD },
	{ 0xF0A8AB86, 0xFE1B0 },
	{ 0xF0A8AB8B, 0xFE1B9 },
	{ 0xF0A8AB8C, 0xFE1B5 },
	{ 0xF0A8AB8E, 0xFDFDD },
	{ 0xF0A8AB8F, 0x4E1EB },
	{ 0xF0A8AB90, 0x7CBB3 },
	{ 0xF0A8AB91, 0x7CBB7 },
	{ 0xF0A8AB92, 0x5EAB2 },
	{ 0xF0A8AB93, 0x7CBB4 },
	{ 0xF0A8AB94, 0x5EAB4 },
	{ 0xF0A8AB95, 0x7CBB2 },
	{ 0xF0A8AB96, 0x7CBBA },
	{ 0xF0A8AB98, 0x7CBB6 },
	{ 0xF0A8AB99, 0x7CBB9 },
	{ 0xF0A8ABA6, 0x7CBBB },
	{ 0xF0A8ABA7, 0xFE4B1 },
	{ 0xF0A8ABA8, 0xFE4B2 },
	{ 0xF0A8ABA9, 0xFE4B3 },
	{ 0xF0A8ABAA, 0xFE4B5 },
	{ 0xF0A8ABAB, 0xFE4B6 },
	{ 0xF0A8ABAC, 0xFE4B8 },
	{ 0xF0A8ABAD, 0xFE4B9 },
	{ 0xF0A8ABAE, 0xFE4BA },
	{ 0xF0A8ABAF, 0xFE4BB },
	{ 0xF0A8ABB0, 0xFE4BC },
	{ 0xF0A8ABB1, 0xFE4BD },
	{ 0xF0A8ABB2, 0xFE4BF },
	{ 0xF0A8ABB3, 0xFE4C0 },
	{ 0xF0A8ABB4, 0xFE4C1 },
	{ 0xF0A8ABB5, 0xFE4C2 },
	{ 0xF0A8ABB6, 0xFE4C3 },
	{ 0xF0A8ABB7, 0xFE4C4 },
	{ 0xF0A8ABB8, 0xFE4C5 },
	{ 0xF0A8ABB9, 0x7CBBC },
	{ 0xF0A8ABBB, 0x7CBB5 },
	{ 0xF0A8ABBD, 0x7CBB8 },
	{ 0xF0A8AC83, 0x4E1EA },
	{ 0xF0A8AC84, 0x7CBB1 },
	{ 0xF0A8AC85, 0x5E5D6 },
	{ 0xF0A8AC8C, 0xFE4BE },
	{ 0xF0A8AC8D, 0x4E4E8 },
	{ 0xF0A8AC8E, 0x7D0ED },
	{ 0xF0A8AC8F, 0x7D0EE },
	{ 0xF0A8AC90, 0x5EEB8 },
	{ 0xF0A8AC91, 0x7D0F2 },
	{ 0xF0A8AC92, 0x5EEB3 },
	{ 0xF0A8AC93, 0x4E4EA },
	{ 0xF0A8AC94, 0x5EEB6 },
	{ 0xF0A8AC96, 0x5EEB2 },
	{ 0xF0A8AC97, 0x7D0F0 },
	{ 0xF0A8AC98, 0x7D0E8 },
	{ 0xF0A8AC99, 0x7D0E9 },
	{ 0xF0A8AC9A, 0x5EEB7 },
	{ 0xF0A8AC9B, 0x4E4EE },
	{ 0xF0A8AC9D, 0x7D0F1 },
	{ 0xF0A8AC9F, 0x5EEB4 },
	{ 0xF0A8ACA3, 0xFE6D0 },
	{ 0xF0A8ACA4, 0xFE6D1 },
	{ 0xF0A8ACA5, 0xFE6D3 },
	{ 0xF0A8ACA6, 0xFE6D4 },
	{ 0xF0A8ACA7, 0xFE6D5 },
	{ 0xF0A8ACA8, 0xFE6D6 },
	{ 0xF0A8ACA9, 0xFE6D8 },
	{ 0xF0A8ACAA, 0xFE6D9 },
	{ 0xF0A8ACAE, 0xFE6DA },
	{ 0xF0A8ACAF, 0xFE6DB },
	{ 0xF0A8ACB0, 0xFE6DD },
	{ 0xF0A8ACB1, 0xFE6DF },
	{ 0xF0A8ACB2, 0xFE6E0 },
	{ 0xF0A8ACB3, 0xFE6E1 },
	{ 0xF0A8ACB4, 0xFE6E2 },
	{ 0xF0A8ACB5, 0xFE6E3 },
	{ 0xF0A8ACB6, 0xFE6E4 },
	{ 0xF0A8ACB7, 0xFE6E6 },
	{ 0xF0A8ACB8, 0xFE6E8 },
	{ 0xF0A8ACB9, 0xFE6EA },
	{ 0xF0A8ACBA, 0xFE6EB },
	{ 0xF0A8ACBB, 0xFE6EC },
	{ 0xF0A8ACBC, 0xFE6ED },
	{ 0xF0A8ACBD, 0xFE6EE },
	{ 0xF0A8ACBE, 0xFE6EF },
	{ 0xF0A8AD84, 0x7D0EC },
	{ 0xF0A8AD87, 0x7D0EF },
	{ 0xF0A8AD89, 0xFE6D2 },
	{ 0xF0A8AD8E, 0xFE6DC },
	{ 0xF0A8AD90, 0xFE6E7 },
	{ 0xF0A8AD93, 0x7D0EA },
	{ 0xF0A8AD95, 0x7D5E2 },
	{ 0xF0A8AD96, 0x4E7DE },
	{ 0xF0A8AD97, 0x7D5E7 },
	{ 0xF0A8AD98, 0x7D5E1 },
	{ 0xF0A8AD99, 0x7D5DC },
	{ 0xF0A8AD9A, 0x4E7E0 },
	{ 0xF0A8AD9B, 0x4E7DD },
	{ 0xF0A8AD9C, 0x7D5E0 },
	{ 0xF0A8AD9D, 0x7D5E3 },
	{ 0xF0A8AD9E, 0x7D5E9 },
	{ 0xF0A8AD9F, 0x7D5DE },
	{ 0xF0A8ADA2, 0xFE8DE },
	{ 0xF0A8ADA7, 0xFE8DF },
	{ 0xF0A8ADA8, 0xFE8E0 },
	{ 0xF0A8ADA9, 0xFE8E1 },
	{ 0xF0A8ADAA, 0xFE8E2 },
	{ 0xF0A8ADAB, 0xFE8E3 },
	{ 0xF0A8ADAD, 0xFE8E4 },
	{ 0xF0A8ADAE, 0xFE8E5 },
	{ 0xF0A8ADAF, 0xFE8E6 },
	{ 0xF0A8ADB0, 0xFE8E7 },
	{ 0xF0A8ADB1, 0xFE8E8 },
	{ 0xF0A8ADB2, 0xFE8E9 },
	{ 0xF0A8ADB3, 0xFE8EB },
	{ 0xF0A8ADB4, 0xFE8EC },
	{ 0xF0A8ADB5, 0xFE8ED },
	{ 0xF0A8ADB6, 0xFE8EE },
	{ 0xF0A8ADB7, 0xFE8EF },
	{ 0xF0A8ADBC, 0x7D5DF },
	{ 0xF0A8ADBE, 0x7D5E4 },
	{ 0xF0A8AE80, 0x7D5E5 },
	{ 0xF0A8AE83, 0x7D5E6 },
	{ 0xF0A8AE84, 0x7D5DD },
	{ 0xF0A8AE8F, 0xFE8EA },
	{ 0xF0A8AE92, 0x5F4D7 },
	{ 0xF0A8AE93, 0x7D9EB },
	{ 0xF0A8AE94, 0x7D9EA },
	{ 0xF0A8AE95, 0x7DDB0 },
	{ 0xF0A8AE97, 0x7D9E6 },
	{ 0xF0A8AE9A, 0x7D9E4 },
	{ 0xF0A8AE9B, 0xFE9FE },
	{ 0xF0A8AE9E, 0xFEAA1 },
	{ 0xF0A8AE9F, 0xFEAA2 },
	{ 0xF0A8AEA0, 0xFEAA3 },
	{ 0xF0A8AEA1, 0xFEAA4 },
	{ 0xF0A8AEA2, 0xFEAA5 },
	{ 0xF0A8AEA3, 0xFEAA6 },
	{ 0xF0A8AEA4, 0xFEAA7 },
	{ 0xF0A8AEA5, 0xFEAA8 },
	{ 0xF0A8AEA6, 0xFEAA9 },
	{ 0xF0A8AEA7, 0xFEAAA },
	{ 0xF0A8AEA8, 0xFEAAB },
	{ 0xF0A8AEAB, 0x7D9E3 },
	{ 0xF0A8AEAF, 0x7D9E5 },
	{ 0xF0A8AEB7, 0x5F4D6 },
	{ 0xF0A8AEB8, 0x5F6DE },
	{ 0xF0A8AEB9, 0x4EBA8 },
	{ 0xF0A8AEBB, 0x5F6DC },
	{ 0xF0A8AEBC, 0xFEBAF },
	{ 0xF0A8AEBD, 0x7DDAF },
	{ 0xF0A8AEBE, 0x7DDAD },
	{ 0xF0A8AEBF, 0x7D9E9 },
	{ 0xF0A8AF84, 0x7DDAC },
	{ 0xF0A8AF86, 0xFEAFC },
	{ 0xF0A8AF87, 0xFEAFD },
	{ 0xF0A8AF88, 0xFEBA3 },
	{ 0xF0A8AF89, 0xFEBA4 },
	{ 0xF0A8AF8A, 0xFEBA5 },
	{ 0xF0A8AF8B, 0xFEBA6 },
	{ 0xF0A8AF8C, 0xFEBA9 },
	{ 0xF0A8AF8D, 0xFEBAA },
	{ 0xF0A8AF8E, 0xFEBAB },
	{ 0xF0A8AF8F, 0xFEBAC },
	{ 0xF0A8AF90, 0xFEBAD },
	{ 0xF0A8AF91, 0xFEBAE },
	{ 0xF0A8AF92, 0x7DDAE },
	{ 0xF0A8AF94, 0x7DDB1 },
	{ 0xF0A8AF97, 0xFEBA1 },
	{ 0xF0A8AF99, 0xFEAFE },
	{ 0xF0A8AF9A, 0xFEBA7 },
	{ 0xF0A8AF9E, 0x5F8C0 },
	{ 0xF0A8AF9F, 0x7DFF0 },
	{ 0xF0A8AFA0, 0x7DFF1 },
	{ 0xF0A8AFA1, 0x7DFF2 },
	{ 0xF0A8AFA2, 0x7DFEF },
	{ 0xF0A8AFA3, 0x7DFF3 },
	{ 0xF0A8AFA6, 0xFEBE8 },
	{ 0xF0A8AFAD, 0xFEBE9 },
	{ 0xF0A8AFAE, 0xFEBEA },
	{ 0xF0A8AFAF, 0xFEBEB },
	{ 0xF0A8AFB0, 0xFEBEC },
	{ 0xF0A8AFBA, 0x4EDE3 },
	{ 0xF0A8AFBB, 0x7E1D7 },
	{ 0xF0A8AFBC, 0x7E1D8 },
	{ 0xF0A8AFBE, 0xFEBED },
	{ 0xF0A8B080, 0xFECBC },
	{ 0xF0A8B081, 0xFECBD },
	{ 0xF0A8B085, 0x7E1D6 },
	{ 0xF0A8B089, 0x7E2F2 },
	{ 0xF0A8B08A, 0x7E2ED },
	{ 0xF0A8B08B, 0x7E2EE },
	{ 0xF0A8B08C, 0x7E2F4 },
	{ 0xF0A8B08D, 0x7E2F0 },
	{ 0xF0A8B08E, 0x7E2EF },
	{ 0xF0A8B08F, 0x5FAC0 },
	{ 0xF0A8B090, 0x7E2F3 },
	{ 0xF0A8B091, 0x7E2F1 },
	{ 0xF0A8B092, 0x7E2F5 },
	{ 0xF0A8B094, 0xFECD2 },
	{ 0xF0A8B095, 0xFECD3 },
	{ 0xF0A8B096, 0xFECD4 },
	{ 0xF0A8B097, 0xFECD5 },
	{ 0xF0A8B098, 0xFECD6 },
	{ 0xF0A8B099, 0xFECD7 },
	{ 0xF0A8B09A, 0xFECD8 },
	{ 0xF0A8B09C, 0xFECC0 },
	{ 0xF0A8B09D, 0x5FAC1 },
	{ 0xF0A8B09E, 0x5FAFC },
	{ 0xF0A8B09F, 0x7E3FD },
	{ 0xF0A8B0A0, 0x7E3FB },
	{ 0xF0A8B0A2, 0xFECEF },
	{ 0xF0A8B0A4, 0x7E3FC },
	{ 0xF0A8B0A8, 0xFEDA3 },
	{ 0xF0A8B0A9, 0x7E4E8 },
	{ 0xF0A8B0AC, 0xFEDA1 },
	{ 0xF0A8B0AE, 0x7E4E7 },
	{ 0xF0A8B0AF, 0x7E4E9 },
	{ 0xF0A8B0B0, 0xFEDA2 },
	{ 0xF0A8B0B1, 0xFECBE },
	{ 0xF0A8B0B2, 0x7E5C8 },
	{ 0xF0A8B0B3, 0x7E5C9 },
	{ 0xF0A8B0B6, 0xFEDA9 },
	{ 0xF0A8B0B8, 0x5FCA1 },
	{ 0xF0A8B0BB, 0xFEDB5 },
	{ 0xF0A8B0BC, 0xFEDB8 },
	{ 0xF0A8B0BD, 0xFEDB9 },
	{ 0xF0A8B197, 0x6AEC4 },
	{ 0xF0A8B198, 0x6A9B4 },
	{ 0xF0A8B199, 0x5ABE0 },
	{ 0xF0A8B19A, 0x5B6BF },
	{ 0xF0A8B19B, 0x6C5FB },
	{ 0xF0A8B19C, 0x5B6BE },
	{ 0xF0A8B19D, 0x5B6C0 },
	{ 0xF0A8B19E, 0x6C5FA },
	{ 0xF0A8B19F, 0xFB8F9 },
	{ 0xF0A8B1A2, 0x6C5F9 },
	{ 0xF0A8B1A4, 0x6C5F8 },
	{ 0xF0A8B1A5, 0x5BDAA },
	{ 0xF0A8B1A6, 0x5BDAB },
	{ 0xF0A8B1A7, 0x4BBE8 },
	{ 0xF0A8B1A8, 0x6CFFA },
	{ 0xF0A8B1A9, 0x6CFFB },
	{ 0xF0A8B1AB, 0xFBFF5 },
	{ 0xF0A8B1B3, 0x6D9D9 },
	{ 0xF0A8B1B4, 0x6D9D8 },
	{ 0xF0A8B1B5, 0x4C1CA },
	{ 0xF0A8B1B6, 0x6D9D6 },
	{ 0xF0A8B1B7, 0x6D9D7 },
	{ 0xF0A8B1B9, 0xFC5FA },
	{ 0xF0A8B1BA, 0x5C3F0 },
	{ 0xF0A8B1BF, 0x5C3EF },
	{ 0xF0A8B280, 0x5CAEA },
	{ 0xF0A8B281, 0x4C7FC },
	{ 0xF0A8B282, 0x6E3D6 },
	{ 0xF0A8B283, 0x6E3D7 },
	{ 0xF0A8B286, 0x5CAEB },
	{ 0xF0A8B287, 0x5D2A1 },
	{ 0xF0A8B288, 0x5D2A3 },
	{ 0xF0A8B289, 0x5D9B9 },
	{ 0xF0A8B28A, 0x5D2A2 },
	{ 0xF0A8B28B, 0x5D2A4 },
	{ 0xF0A8B28C, 0x5D2A5 },
	{ 0xF0A8B28D, 0xFD8E5 },
	{ 0xF0A8B293, 0x5D9BB },
	{ 0xF0A8B294, 0x7B4EE },
	{ 0xF0A8B295, 0x5D9BA },
	{ 0xF0A8B297, 0x7BDA6 },
	{ 0xF0A8B298, 0x7B4ED },
	{ 0xF0A8B29A, 0x7B4F0 },
	{ 0xF0A8B29B, 0x7B4EC },
	{ 0xF0A8B29D, 0x7BDA9 },
	{ 0xF0A8B29E, 0x4D9CA },
	{ 0xF0A8B29F, 0x5DFD0 },
	{ 0xF0A8B2A0, 0x4D9CB },
	{ 0xF0A8B2A1, 0x7BDAA },
	{ 0xF0A8B2A2, 0x7BDA8 },
	{ 0xF0A8B2A5, 0x7BDA7 },
	{ 0xF0A8B2A6, 0x7C4C3 },
	{ 0xF0A8B2A7, 0x5E5D8 },
	{ 0xF0A8B2A8, 0x7C4C2 },
	{ 0xF0A8B2A9, 0x5E5D7 },
	{ 0xF0A8B2AD, 0x5EAB8 },
	{ 0xF0A8B2AE, 0x5EAB6 },
	{ 0xF0A8B2AF, 0x5EAB5 },
	{ 0xF0A8B2B2, 0x5EAB7 },
	{ 0xF0A8B2B3, 0x5EEB9 },
	{ 0xF0A8B2B4, 0x7D0F3 },
	{ 0xF0A8B2B6, 0x7D0F4 },
	{ 0xF0A8B2B8, 0x4E7E4 },
	{ 0xF0A8B2BA, 0x7D5EA },
	{ 0xF0A8B2BB, 0x7D9ED },
	{ 0xF0A8B2BC, 0x7D9EE },
	{ 0xF0A8B2BE, 0x7D9EC },
	{ 0xF0A8B380, 0x5F6E1 },
	{ 0xF0A8B381, 0x5F6E0 },
	{ 0xF0A8B382, 0x5F8C1 },
	{ 0xF0A8B383, 0x7DFF4 },
	{ 0xF0A8B384, 0x7E2F6 },
	{ 0xF0A8B385, 0x7E4EA },
	{ 0xF0A8B389, 0x5ABE1 },
	{ 0xF0A8B38A, 0x5B0EA },
	{ 0xF0A8B38B, 0x5B0EB },
	{ 0xF0A8B38C, 0x5B0E9 },
	{ 0xF0A8B38E, 0xFB2E7 },
	{ 0xF0A8B38F, 0x6BCE6 },
	{ 0xF0A8B390, 0x5B6C2 },
	{ 0xF0A8B391, 0x5B6C1 },
	{ 0xF0A8B393, 0xFB8FA },
	{ 0xF0A8B395, 0xFB8FB },
	{ 0xF0A8B396, 0x6C5FC },
	{ 0xF0A8B397, 0x5BDB3 },
	{ 0xF0A8B398, 0x5BDB1 },
	{ 0xF0A8B399, 0x5BDAF },
	{ 0xF0A8B39A, 0x4BBEA },
	{ 0xF0A8B39B, 0x5BDB0 },
	{ 0xF0A8B39C, 0x4BBEC },
	{ 0xF0A8B39D, 0x3BFED },
	{ 0xF0A8B39E, 0x5BDAC },
	{ 0xF0A8B39F, 0x5BDAD },
	{ 0xF0A8B3A0, 0x5BDAE },
	{ 0xF0A8B3A1, 0x6CFFE },
	{ 0xF0A8B3A2, 0x6D0A1 },
	{ 0xF0A8B3A3, 0x5BDB2 },
	{ 0xF0A8B3A5, 0x6CFFC },
	{ 0xF0A8B3A7, 0xFBFF8 },
	{ 0xF0A8B3A8, 0xFBFF9 },
	{ 0xF0A8B3A9, 0xFBFFA },
	{ 0xF0A8B3AA, 0xFBFFB },
	{ 0xF0A8B3AB, 0xFBFFC },
	{ 0xF0A8B3AC, 0xFBFFD },
	{ 0xF0A8B3AD, 0xFC0A1 },
	{ 0xF0A8B3B0, 0x6CFFD },
	{ 0xF0A8B3B2, 0x4BBE9 },
	{ 0xF0A8B3B3, 0x4C1CC },
	{ 0xF0A8B3B4, 0x6D9DE },
	{ 0xF0A8B3B5, 0x4C1D2 },
	{ 0xF0A8B3B6, 0x4C1CD },
	{ 0xF0A8B3B7, 0x4C1CB },
	{ 0xF0A8B3B8, 0xFC5FE },
	{ 0xF0A8B3B9, 0x6D9DD },
	{ 0xF0A8B3BA, 0x5C3F4 },
	{ 0xF0A8B3BB, 0x5C3F1 },
	{ 0xF0A8B3BC, 0x5C3F3 },
	{ 0xF0A8B3BD, 0x5C3F2 },
	{ 0xF0A8B3BE, 0x6D9DB },
	{ 0xF0A8B3BF, 0x4C1D1 },
	{ 0xF0A8B480, 0x4C1CF },
	{ 0xF0A8B481, 0x6D9DC },
	{ 0xF0A8B482, 0x6D9DA },
	{ 0xF0A8B484, 0xFC5FD },
	{ 0xF0A8B485, 0xFC6A1 },
	{ 0xF0A8B48D, 0x5CAF3 },
	{ 0xF0A8B48E, 0x5CAEF },
	{ 0xF0A8B48F, 0x5CAF1 },
	{ 0xF0A8B490, 0x4C7FE },
	{ 0xF0A8B491, 0x5CAED },
	{ 0xF0A8B492, 0x4C8A1 },
	{ 0xF0A8B493, 0x5CAF4 },
	{ 0xF0A8B494, 0x6E3DA },
	{ 0xF0A8B495, 0x5CAF0 },
	{ 0xF0A8B496, 0x5CAF5 },
	{ 0xF0A8B497, 0x4C7FD },
	{ 0xF0A8B498, 0x5CAF2 },
	{ 0xF0A8B499, 0x5CAF6 },
	{ 0xF0A8B49D, 0x6E3D9 },
	{ 0xF0A8B49F, 0x6E3DB },
	{ 0xF0A8B4A0, 0x6E3DC },
	{ 0xF0A8B4A5, 0x5CAEC },
	{ 0xF0A8B4A8, 0x7AAC8 },
	{ 0xF0A8B4A9, 0x5D2AD },
	{ 0xF0A8B4AA, 0x5D2A8 },
	{ 0xF0A8B4AB, 0x7AACD },
	{ 0xF0A8B4AC, 0x5D2AA },
	{ 0xF0A8B4AD, 0x5D2A7 },
	{ 0xF0A8B4AE, 0x7AACE },
	{ 0xF0A8B4AF, 0x4CEC9 },
	{ 0xF0A8B4B0, 0x5D2AC },
	{ 0xF0A8B4B1, 0x5D2A9 },
	{ 0xF0A8B4B3, 0x7AACC },
	{ 0xF0A8B4B5, 0xFD2EE },
	{ 0xF0A8B4B6, 0xFD2EF },
	{ 0xF0A8B4B7, 0xFD2F1 },
	{ 0xF0A8B4B8, 0x7AAC7 },
	{ 0xF0A8B4BF, 0x7AAC9 },
	{ 0xF0A8B580, 0x7AACA },
	{ 0xF0A8B581, 0x7AACB },
	{ 0xF0A8B584, 0x5D2A6 },
	{ 0xF0A8B585, 0x5D2AB },
	{ 0xF0A8B586, 0x5D2AE },
	{ 0xF0A8B587, 0xFD2F0 },
	{ 0xF0A8B588, 0x4D4D0 },
	{ 0xF0A8B589, 0x4D4CD },
	{ 0xF0A8B58A, 0x5D9BD },
	{ 0xF0A8B58B, 0x5D9C0 },
	{ 0xF0A8B58C, 0x7B4F2 },
	{ 0xF0A8B58D, 0x5D9BC },
	{ 0xF0A8B58F, 0x5D9BE },
	{ 0xF0A8B590, 0x5D9BF },
	{ 0xF0A8B591, 0x7B4F5 },
	{ 0xF0A8B592, 0x7B4F7 },
	{ 0xF0A8B593, 0x7B4F9 },
	{ 0xF0A8B594, 0xFD8E6 },
	{ 0xF0A8B595, 0xFD8E7 },
	{ 0xF0A8B596, 0xFD8E8 },
	{ 0xF0A8B597, 0x7B4F4 },
	{ 0xF0A8B59C, 0x7B4F8 },
	{ 0xF0A8B5A2, 0x7B4F6 },
	{ 0xF0A8B5A4, 0x4D4CE },
	{ 0xF0A8B5A5, 0x4D9D3 },
	{ 0xF0A8B5A6, 0x4D9D1 },
	{ 0xF0A8B5A7, 0x5DFD4 },
	{ 0xF0A8B5A8, 0x7BDAB },
	{ 0xF0A8B5A9, 0x5DFD1 },
	{ 0xF0A8B5AA, 0x5DFD3 },
	{ 0xF0A8B5AB, 0x5DFD5 },
	{ 0xF0A8B5AC, 0x5DFD2 },
	{ 0xF0A8B5AD, 0x7BDAD },
	{ 0xF0A8B5AE, 0x4D9D0 },
	{ 0xF0A8B5AF, 0x7BDAC },
	{ 0xF0A8B5B0, 0x4D9CC },
	{ 0xF0A8B5B2, 0x7BDAE },
	{ 0xF0A8B5B3, 0xFDDD0 },
	{ 0xF0A8B5B5, 0x7BDAF },
	{ 0xF0A8B5B7, 0x7BDB0 },
	{ 0xF0A8B5B9, 0x7BDB1 },
	{ 0xF0A8B680, 0x5E5DF },
	{ 0xF0A8B681, 0x5E5DE },
	{ 0xF0A8B682, 0x5E5DA },
	{ 0xF0A8B683, 0x4DEB3 },
	{ 0xF0A8B684, 0x7C4C4 },
	{ 0xF0A8B685, 0x5E5DB },
	{ 0xF0A8B686, 0x5E5E1 },
	{ 0xF0A8B687, 0x5E5E0 },
	{ 0xF0A8B688, 0x7C4C6 },
	{ 0xF0A8B689, 0x5E5DD },
	{ 0xF0A8B68A, 0x5E5D9 },
	{ 0xF0A8B68B, 0x5E5DC },
	{ 0xF0A8B68C, 0xFE1C7 },
	{ 0xF0A8B68D, 0xFE1C8 },
	{ 0xF0A8B68E, 0xFE1C9 },
	{ 0xF0A8B68F, 0xFE1CC },
	{ 0xF0A8B692, 0xFE1CB },
	{ 0xF0A8B696, 0x7C4C5 },
	{ 0xF0A8B69A, 0x7C4C7 },
	{ 0xF0A8B69C, 0x5EAB9 },
	{ 0xF0A8B69D, 0x7CBBE },
	{ 0xF0A8B69E, 0x7CBBF },
	{ 0xF0A8B69F, 0x4E1ED },
	{ 0xF0A8B6A0, 0x5EABA },
	{ 0xF0A8B6A1, 0x7CBBD },
	{ 0xF0A8B6A2, 0x4E1EE },
	{ 0xF0A8B6A3, 0xFE4C6 },
	{ 0xF0A8B6A4, 0xFE4C7 },
	{ 0xF0A8B6A5, 0xFE4C8 },
	{ 0xF0A8B6A6, 0xFE4C9 },
	{ 0xF0A8B6A7, 0xFE4CA },
	{ 0xF0A8B6AC, 0x4E4F0 },
	{ 0xF0A8B6AD, 0x5EEBF },
	{ 0xF0A8B6AE, 0x5EEBA },
	{ 0xF0A8B6AF, 0x5EEBD },
	{ 0xF0A8B6B0, 0x5EEBC },
	{ 0xF0A8B6B1, 0x5EEBE },
	{ 0xF0A8B6B2, 0x5EEC0 },
	{ 0xF0A8B6B3, 0x4E4F2 },
	{ 0xF0A8B6B4, 0x7D0F8 },
	{ 0xF0A8B6B6, 0x5EABB },
	{ 0xF0A8B6B7, 0x7D0F5 },
	{ 0xF0A8B6B8, 0xFE6F0 },
	{ 0xF0A8B6B9, 0xFE6F1 },
	{ 0xF0A8B6BE, 0x7D0F6 },
	{ 0xF0A8B781, 0x5EEBB },
	{ 0xF0A8B782, 0x7D0F7 },
	{ 0xF0A8B783, 0x5F1DA },
	{ 0xF0A8B784, 0x5EEC1 },
	{ 0xF0A8B785, 0x4E7E5 },
	{ 0xF0A8B786, 0x5F1D9 },
	{ 0xF0A8B787, 0x5F1D7 },
	{ 0xF0A8B789, 0xFE8F0 },
	{ 0xF0A8B78A, 0xFE8F1 },
	{ 0xF0A8B78B, 0xFE8F3 },
	{ 0xF0A8B78C, 0xFE8F4 },
	{ 0xF0A8B78D, 0xFE8F5 },
	{ 0xF0A8B792, 0x5F1DC },
	{ 0xF0A8B793, 0x5F1D8 },
	{ 0xF0A8B794, 0x5F4D8 },
	{ 0xF0A8B795, 0x7D5EB },
	{ 0xF0A8B797, 0xFEAAF },
	{ 0xF0A8B799, 0x7D9EF },
	{ 0xF0A8B79B, 0xFEAAC },
	{ 0xF0A8B79C, 0xFEAAD },
	{ 0xF0A8B79D, 0xFEAAE },
	{ 0xF0A8B79E, 0xFEAB0 },
	{ 0xF0A8B79F, 0xFEAB1 },
	{ 0xF0A8B7A1, 0xFEBB0 },
	{ 0xF0A8B7A2, 0xFEBB1 },
	{ 0xF0A8B7A3, 0xFEBB2 },
	{ 0xF0A8B7A4, 0x7DDB2 },
	{ 0xF0A8B7A6, 0x5F8C2 },
	{ 0xF0A8B7A7, 0xFEBEE },
	{ 0xF0A8B7A8, 0xFEBEF },
	{ 0xF0A8B7AA, 0x7DFF6 },
	{ 0xF0A8B7AB, 0x7DFF5 },
	{ 0xF0A8B7B0, 0x5F9D4 },
	{ 0xF0A8B7B1, 0x4EDA9 },
	{ 0xF0A8B7B2, 0x4EDAA },
	{ 0xF0A8B7B3, 0x7E1D9 },
	{ 0xF0A8B7B7, 0x7E2F7 },
	{ 0xF0A8B7B8, 0x7E2F8 },
	{ 0xF0A8B7BB, 0x5FAFD },
	{ 0xF0A8B7BC, 0xFEDAA },
	{ 0xF0A8B88F, 0x6AEC5 },
	{ 0xF0A8B890, 0x5A2A2 },
	{ 0xF0A8B891, 0x5A1FE },
	{ 0xF0A8B892, 0x4A2A3 },
	{ 0xF0A8B893, 0x5A2A3 },
	{ 0xF0A8B894, 0x4A2A2 },
	{ 0xF0A8B895, 0x5A2A1 },
	{ 0xF0A8B896, 0x5A3AE },
	{ 0xF0A8B897, 0x4A3B4 },
	{ 0xF0A8B898, 0x6A5DD },
	{ 0xF0A8B89A, 0x5A4FD },
	{ 0xF0A8B89B, 0x4A5AC },
	{ 0xF0A8B89C, 0x4A5AD },
	{ 0xF0A8B89D, 0x5A4FE },
	{ 0xF0A8B89E, 0x5A4FC },
	{ 0xF0A8B8A0, 0xFA5BA },
	{ 0xF0A8B8A1, 0xFA5BB },
	{ 0xF0A8B8A2, 0xFA5BC },
	{ 0xF0A8B8A3, 0xFA5BD },
	{ 0xF0A8B8A4, 0xFA5BE },
	{ 0xF0A8B8A9, 0xFA5BF },
	{ 0xF0A8B8AB, 0x5A7F5 },
	{ 0xF0A8B8AC, 0x6AEC7 },
	{ 0xF0A8B8AD, 0x5A7F6 },
	{ 0xF0A8B8AE, 0x5A7F8 },
	{ 0xF0A8B8AF, 0x5A7F9 },
	{ 0xF0A8B8B0, 0x4A8B0 },
	{ 0xF0A8B8B1, 0x5A7F7 },
	{ 0xF0A8B8B2, 0x6AEC6 },
	{ 0xF0A8B8B3, 0x6AEC8 },
	{ 0xF0A8B8B5, 0xFA8FD },
	{ 0xF0A8B8B8, 0xFA8FE },
	{ 0xF0A8B981, 0x5ABE2 },
	{ 0xF0A8B982, 0x6B4F0 },
	{ 0xF0A8B983, 0x6B4F3 },
	{ 0xF0A8B984, 0x4ABDC },
	{ 0xF0A8B985, 0x5ABE5 },
	{ 0xF0A8B986, 0x6B4F1 },
	{ 0xF0A8B987, 0x6E3DD },
	{ 0xF0A8B988, 0x6B4F5 },
	{ 0xF0A8B989, 0x6B4F6 },
	{ 0xF0A8B98A, 0x6B4F7 },
	{ 0xF0A8B98B, 0x6B4F2 },
	{ 0xF0A8B98C, 0x5ABE3 },
	{ 0xF0A8B98E, 0x6B4F8 },
	{ 0xF0A8B98F, 0xFADDB },
	{ 0xF0A8B990, 0xFADDC },
	{ 0xF0A8B991, 0xFADDD },
	{ 0xF0A8B993, 0x6B4F4 },
	{ 0xF0A8B995, 0x6B4EF },
	{ 0xF0A8B998, 0x6BCE9 },
	{ 0xF0A8B999, 0x5B0EF },
	{ 0xF0A8B99A, 0x5ABE6 },
	{ 0xF0A8B99B, 0x6BCE8 },
	{ 0xF0A8B99C, 0x5B0EC },
	{ 0xF0A8B99D, 0x5B0EE },
	{ 0xF0A8B99E, 0x6BCEE },
	{ 0xF0A8B99F, 0x6BCEB },
	{ 0xF0A8B9A0, 0x6BCEF },
	{ 0xF0A8B9A1, 0x5B0ED },
	{ 0xF0A8B9A2, 0x6BCEA },
	{ 0xF0A8B9A3, 0x6BCED },
	{ 0xF0A8B9A7, 0x6BCEC },
	{ 0xF0A8B9AD, 0xFB2E8 },
	{ 0xF0A8B9AE, 0xFB2E9 },
	{ 0xF0A8B9AF, 0xFB2EA },
	{ 0xF0A8B9B0, 0xFB2EB },
	{ 0xF0A8B9B1, 0xFB2EC },
	{ 0xF0A8B9B2, 0xFB2ED },
	{ 0xF0A8B9B3, 0xFB2EE },
	{ 0xF0A8B9B5, 0x5B6C3 },
	{ 0xF0A8B9B6, 0x6C6A8 },
	{ 0xF0A8B9B7, 0x6C6A1 },
	{ 0xF0A8B9B8, 0x4B5FE },
	{ 0xF0A8B9B9, 0x4B6A2 },
	{ 0xF0A8B9BA, 0x4B6A1 },
	{ 0xF0A8B9BB, 0x5B6C4 },
	{ 0xF0A8B9BC, 0x6C6A3 },
	{ 0xF0A8B9BD, 0x6C6A4 },
	{ 0xF0A8B9BE, 0x6C6AB },
	{ 0xF0A8B9BF, 0x6C6AA },
	{ 0xF0A8BA80, 0x6E3DE },
	{ 0xF0A8BA81, 0x6C6A6 },
	{ 0xF0A8BA82, 0x6C6A2 },
	{ 0xF0A8BA83, 0x6C6A9 },
	{ 0xF0A8BA84, 0x6C6A7 },
	{ 0xF0A8BA85, 0x7B4FB },
	{ 0xF0A8BA86, 0x6C6A5 },
	{ 0xF0A8BA8A, 0xFB8FC },
	{ 0xF0A8BA8B, 0xFB8FD },
	{ 0xF0A8BA8C, 0xFB8FE },
	{ 0xF0A8BA8D, 0xFB9A1 },
	{ 0xF0A8BA8E, 0xFB9A2 },
	{ 0xF0A8BA8F, 0xFB9A3 },
	{ 0xF0A8BA90, 0xFB9A4 },
	{ 0xF0A8BA91, 0xFB9A5 },
	{ 0xF0A8BA92, 0xFB9A6 },
	{ 0xF0A8BA93, 0xFB9A7 },
	{ 0xF0A8BA9F, 0x5BDB8 },
	{ 0xF0A8BAA0, 0x5BDBD },
	{ 0xF0A8BAA1, 0x5BDB9 },
	{ 0xF0A8BAA2, 0x5BDBA },
	{ 0xF0A8BAA3, 0x5BDBC },
	{ 0xF0A8BAA4, 0x6D0A5 },
	{ 0xF0A8BAA5, 0x6D0A3 },
	{ 0xF0A8BAA6, 0x5BDB4 },
	{ 0xF0A8BAA7, 0x5BDB5 },
	{ 0xF0A8BAA8, 0x5BDB7 },
	{ 0xF0A8BAA9, 0x6D0A4 },
	{ 0xF0A8BAAA, 0x6D0A9 },
	{ 0xF0A8BAAB, 0x7BDB4 },
	{ 0xF0A8BAAC, 0x6D0A7 },
	{ 0xF0A8BAAD, 0x5BDBB },
	{ 0xF0A8BAAE, 0x6D0A8 },
	{ 0xF0A8BAAF, 0x6D0A6 },
	{ 0xF0A8BAB1, 0xFC0A2 },
	{ 0xF0A8BAB4, 0xFC0A3 },
	{ 0xF0A8BAB5, 0x7BDB2 },
	{ 0xF0A8BABF, 0x5BDB6 },
	{ 0xF0A8BB80, 0x6D9EA },
	{ 0xF0A8BB81, 0x5C3FB },
	{ 0xF0A8BB82, 0x5C3F8 },
	{ 0xF0A8BB83, 0x6D9E2 },
	{ 0xF0A8BB84, 0x6D9E9 },
	{ 0xF0A8BB85, 0x6D9E7 },
	{ 0xF0A8BB86, 0x5C3FC },
	{ 0xF0A8BB87, 0x5C3F9 },
	{ 0xF0A8BB88, 0x5C3F7 },
	{ 0xF0A8BB89, 0x6E3DF },
	{ 0xF0A8BB8A, 0x6D9E3 },
	{ 0xF0A8BB8B, 0x6D9E5 },
	{ 0xF0A8BB8C, 0x5C3FD },
	{ 0xF0A8BB8D, 0x5C3FA },
	{ 0xF0A8BB8E, 0x6D9E6 },
	{ 0xF0A8BB8F, 0x7C4C9 },
	{ 0xF0A8BB90, 0x6D9E4 },
	{ 0xF0A8BB91, 0x7C4C8 },
	{ 0xF0A8BB92, 0x5C3F6 },
	{ 0xF0A8BB93, 0x6D9DF },
	{ 0xF0A8BB94, 0x6D9EB },
	{ 0xF0A8BB95, 0x6D9E0 },
	{ 0xF0A8BB96, 0x5C3F5 },
	{ 0xF0A8BB98, 0x6D9E1 },
	{ 0xF0A8BB9A, 0xFC6A2 },
	{ 0xF0A8BB9B, 0xFC6A3 },
	{ 0xF0A8BB9C, 0xFC6A4 },
	{ 0xF0A8BB9D, 0xFC6A5 },
	{ 0xF0A8BB9E, 0xFC6A6 },
	{ 0xF0A8BB9F, 0xFC6A7 },
	{ 0xF0A8BBA0, 0xFC6A8 },
	{ 0xF0A8BBA1, 0xFC6A9 },
	{ 0xF0A8BBA6, 0x6D9E8 },
	{ 0xF0A8BBA8, 0x6D9EC },
	{ 0xF0A8BBAA, 0x7BDB3 },
	{ 0xF0A8BBAF, 0x6E3E4 },
	{ 0xF0A8BBB0, 0x6E3E2 },
	{ 0xF0A8BBB1, 0x6E3E6 },
	{ 0xF0A8BBB2, 0x4C8A7 },
	{ 0xF0A8BBB3, 0x4C8A6 },
	{ 0xF0A8BBB4, 0x5D2AF },
	{ 0xF0A8BBB5, 0x4C8A8 },
	{ 0xF0A8BBB6, 0x4C8A9 },
	{ 0xF0A8BBB7, 0x5CAF8 },
	{ 0xF0A8BBB8, 0x6E3E3 },
	{ 0xF0A8BBB9, 0x6E3E0 },
	{ 0xF0A8BBBA, 0x4C8A5 },
	{ 0xF0A8BBBB, 0x5CAF9 },
	{ 0xF0A8BBBC, 0x5CAFA },
	{ 0xF0A8BBBD, 0x6E3E5 },
	{ 0xF0A8BBBE, 0x6E3E7 },
	{ 0xF0A8BBBF, 0x7CBC1 },
	{ 0xF0A8BC80, 0xFCDAE },
	{ 0xF0A8BC81, 0xFCDAF },
	{ 0xF0A8BC82, 0xFCDB0 },
	{ 0xF0A8BC83, 0xFCDB1 },
	{ 0xF0A8BC84, 0xFCDB2 },
	{ 0xF0A8BC85, 0xFCDB3 },
	{ 0xF0A8BC86, 0x6E3E1 },
	{ 0xF0A8BC88, 0x5CAF7 },
	{ 0xF0A8BC8A, 0x5D2B6 },
	{ 0xF0A8BC8B, 0x5D2B4 },
	{ 0xF0A8BC8C, 0x5D2B5 },
	{ 0xF0A8BC8D, 0x7AAD5 },
	{ 0xF0A8BC8E, 0x5D2B8 },
	{ 0xF0A8BC8F, 0x5D2B2 },
	{ 0xF0A8BC90, 0x5D2B1 },
	{ 0xF0A8BC91, 0x7AACF },
	{ 0xF0A8BC92, 0x5D2B3 },
	{ 0xF0A8BC93, 0x5D2B7 },
	{ 0xF0A8BC94, 0x5D2B0 },
	{ 0xF0A8BC95, 0x7D0FA },
	{ 0xF0A8BC96, 0x7AAD3 },
	{ 0xF0A8BC97, 0x7AAD1 },
	{ 0xF0A8BC98, 0x7AAD0 },
	{ 0xF0A8BC99, 0x7AAD2 },
	{ 0xF0A8BC9B, 0xFD2F2 },
	{ 0xF0A8BC9C, 0xFD2F3 },
	{ 0xF0A8BC9D, 0xFD2F4 },
	{ 0xF0A8BC9E, 0xFD2F5 },
	{ 0xF0A8BC9F, 0xFD2F6 },
	{ 0xF0A8BCA0, 0xFD2F7 },
	{ 0xF0A8BCA6, 0x7AAD6 },
	{ 0xF0A8BCAA, 0x5D9C1 },
	{ 0xF0A8BCAB, 0x5D9C2 },
	{ 0xF0A8BCAC, 0x4D4D4 },
	{ 0xF0A8BCAD, 0x7B4FC },
	{ 0xF0A8BCAE, 0x5D9C4 },
	{ 0xF0A8BCAF, 0x5D9C3 },
	{ 0xF0A8BCB0, 0x7B4FE },
	{ 0xF0A8BCB1, 0x7D0F9 },
	{ 0xF0A8BCB3, 0xFD8E9 },
	{ 0xF0A8BCB4, 0xFD8EA },
	{ 0xF0A8BCB5, 0xFD8EB },
	{ 0xF0A8BCB6, 0xFD8EC },
	{ 0xF0A8BCBD, 0x5EABC },
	{ 0xF0A8BCBE, 0x7B4FD },
	{ 0xF0A8BCBF, 0x5DFD6 },
	{ 0xF0A8BD80, 0x5DFD7 },
	{ 0xF0A8BD81, 0x7BDB6 },
	{ 0xF0A8BD82, 0x7BDB7 },
	{ 0xF0A8BD83, 0x7BDB5 },
	{ 0xF0A8BD84, 0x5F4D9 },
	{ 0xF0A8BD85, 0xFDDD1 },
	{ 0xF0A8BD86, 0xFDDD2 },
	{ 0xF0A8BD87, 0xFDDD3 },
	{ 0xF0A8BD8C, 0xFDDD4 },
	{ 0xF0A8BD8D, 0x5E5E2 },
	{ 0xF0A8BD8E, 0x7C4CC },
	{ 0xF0A8BD8F, 0x4DEB4 },
	{ 0xF0A8BD90, 0x7C4CA },
	{ 0xF0A8BD91, 0x7C4CB },
	{ 0xF0A8BD92, 0xFE1CD },
	{ 0xF0A8BD93, 0xFE1CE },
	{ 0xF0A8BD94, 0xFE1CF },
	{ 0xF0A8BD95, 0xFE1D0 },
	{ 0xF0A8BD96, 0x5EABD },
	{ 0xF0A8BD97, 0x7CBC3 },
	{ 0xF0A8BD98, 0x7D5EC },
	{ 0xF0A8BD99, 0x7CBC5 },
	{ 0xF0A8BD9C, 0xFE4CC },
	{ 0xF0A8BD9D, 0x5F8C3 },
	{ 0xF0A8BD9F, 0x7CBC2 },
	{ 0xF0A8BDA0, 0x7CBC4 },
	{ 0xF0A8BDA1, 0x7DFF7 },
	{ 0xF0A8BDA2, 0xFE6F2 },
	{ 0xF0A8BDA3, 0xFE6F3 },
	{ 0xF0A8BDA5, 0x7D1F2 },
	{ 0xF0A8BDA6, 0x5F1DD },
	{ 0xF0A8BDA7, 0x7D5EE },
	{ 0xF0A8BDA8, 0x7D5ED },
	{ 0xF0A8BDAA, 0x7E2F9 },
	{ 0xF0A8BDAB, 0x7E2FA },
	{ 0xF0A8BDAC, 0x7D9F0 },
	{ 0xF0A8BDAE, 0x7DDC9 },
	{ 0xF0A8BDB1, 0x7DFF8 },
	{ 0xF0A8BDB2, 0x5FAFE },
	{ 0xF0A8BDB3, 0x5FBA1 },
	{ 0xF0A8BDB4, 0x7E6B7 },
	{ 0xF0A8BDB5, 0x7E6A8 },
	{ 0xF0A8BDB6, 0x6D9ED },
	{ 0xF0A8BDB8, 0x4CECB },
	{ 0xF0A8BDB9, 0x7AAD7 },
	{ 0xF0A8BDBA, 0xFD2F9 },
	{ 0xF0A8BDBB, 0xFD2F8 },
	{ 0xF0A8BDBC, 0x5D9C5 },
	{ 0xF0A8BDBD, 0x7B5A1 },
	{ 0xF0A8BDBF, 0x4D9D6 },
	{ 0xF0A8BE80, 0x7C4CD },
	{ 0xF0A8BE81, 0x7C4CE },
	{ 0xF0A8BE82, 0x5EABE },
	{ 0xF0A8BE83, 0x7D0FB },
	{ 0xF0A8BE85, 0x6BCF0 },
	{ 0xF0A8BE86, 0x6BCF1 },
	{ 0xF0A8BE87, 0x6BCF2 },
	{ 0xF0A8BE88, 0x6C6AC },
	{ 0xF0A8BE89, 0x5B6C5 },
	{ 0xF0A8BE8A, 0x4B6A3 },
	{ 0xF0A8BE8B, 0x6C6AE },
	{ 0xF0A8BE8D, 0x6C6AD },
	{ 0xF0A8BE8F, 0x6C6B0 },
	{ 0xF0A8BE91, 0x6C6AF },
	{ 0xF0A8BE92, 0x4BBF0 },
	{ 0xF0A8BE93, 0x6D0AC },
	{ 0xF0A8BE94, 0x4BBEE },
	{ 0xF0A8BE95, 0x6D0AA },
	{ 0xF0A8BE96, 0x6D9F3 },
	{ 0xF0A8BE97, 0x6D0B0 },
	{ 0xF0A8BE98, 0x6D0AE },
	{ 0xF0A8BE99, 0x6D0AB },
	{ 0xF0A8BE9A, 0x4BBF1 },
	{ 0xF0A8BE9B, 0x4BBEF },
	{ 0xF0A8BE9C, 0x6D0AF },
	{ 0xF0A8BE9D, 0x6D0AD },
	{ 0xF0A8BEA0, 0x6D9FB },
	{ 0xF0A8BEA1, 0x5C3FE },
	{ 0xF0A8BEA2, 0x6D9EE },
	{ 0xF0A8BEA3, 0x6D9F1 },
	{ 0xF0A8BEA4, 0x6D9F7 },
	{ 0xF0A8BEA5, 0x6D9F5 },
	{ 0xF0A8BEA6, 0x6D9FA },
	{ 0xF0A8BEA7, 0x6D9F2 },
	{ 0xF0A8BEA8, 0x6D9F0 },
	{ 0xF0A8BEA9, 0x6D9F4 },
	{ 0xF0A8BEAA, 0x6D9F9 },
	{ 0xF0A8BEAB, 0x6D9F8 },
	{ 0xF0A8BEAE, 0x6D9EF },
	{ 0xF0A8BEAF, 0x6D9F6 },
	{ 0xF0A8BEB2, 0x6E3F4 },
	{ 0xF0A8BEB3, 0x6E3F2 },
	{ 0xF0A8BEB4, 0x5CAFB },
	{ 0xF0A8BEB5, 0x6E3EB },
	{ 0xF0A8BEB6, 0x6E3EC },
	{ 0xF0A8BEB7, 0x6E3F6 },
	{ 0xF0A8BEB8, 0x6E3E8 },
	{ 0xF0A8BEB9, 0x6E3F7 },
	{ 0xF0A8BEBA, 0x6E3F0 },
	{ 0xF0A8BEBB, 0x4C8AA },
	{ 0xF0A8BEBC, 0x6E3F5 },
	{ 0xF0A8BEBD, 0x6E3EF },
	{ 0xF0A8BEBE, 0x5CAFC },
	{ 0xF0A8BEBF, 0x6E3F1 },
	{ 0xF0A8BF80, 0x6E3E9 },
	{ 0xF0A8BF81, 0x5CAFD },
	{ 0xF0A8BF82, 0x4C8AB },
	{ 0xF0A8BF83, 0x6E3EA },
	{ 0xF0A8BF84, 0xFCDB4 },
	{ 0xF0A8BF85, 0xFCDB5 },
	{ 0xF0A8BF86, 0x6E3F3 },
	{ 0xF0A8BF88, 0x6E3F8 },
	{ 0xF0A8BF89, 0x6E3ED },
	{ 0xF0A8BF8B, 0x7AADD },
	{ 0xF0A8BF8C, 0x7AADB },
	{ 0xF0A8BF8D, 0x7AAE4 },
	{ 0xF0A8BF8E, 0x7AADF },
	{ 0xF0A8BF8F, 0x7AADC },
	{ 0xF0A8BF90, 0x5D2BA },
	{ 0xF0A8BF91, 0x7AADE },
	{ 0xF0A8BF92, 0x7AAE6 },
	{ 0xF0A8BF93, 0x7AAE2 },
	{ 0xF0A8BF94, 0x7AAE0 },
	{ 0xF0A8BF95, 0x7AAE1 },
	{ 0xF0A8BF96, 0x7AAE3 },
	{ 0xF0A8BF97, 0x7AADA },
	{ 0xF0A8BF98, 0x7AAD8 },
	{ 0xF0A8BF99, 0x5D2B9 },
	{ 0xF0A8BF9A, 0x7AAE5 },
	{ 0xF0A8BF9E, 0x7AAE7 },
	{ 0xF0A8BFA0, 0x4D9D7 },
	{ 0xF0A8BFA1, 0x4D4D5 },
	{ 0xF0A8BFA2, 0x5D9C7 },
	{ 0xF0A8BFA3, 0x7B5A9 },
	{ 0xF0A8BFA4, 0x7B5A4 },
	{ 0xF0A8BFA5, 0x7B5AF },
	{ 0xF0A8BFA6, 0x7B5A2 },
	{ 0xF0A8BFA7, 0x7B5AD },
	{ 0xF0A8BFA8, 0x7B5A8 },
	{ 0xF0A8BFA9, 0x7B5A5 },
	{ 0xF0A8BFAA, 0x7B5AC },
	{ 0xF0A8BFAB, 0x7B5AA },
	{ 0xF0A8BFAC, 0x7B5A6 },
	{ 0xF0A8BFAD, 0x5D9C6 },
	{ 0xF0A8BFAE, 0x7B5B0 },
	{ 0xF0A8BFAF, 0x4D4D6 },
	{ 0xF0A8BFB0, 0x7B5AB },
	{ 0xF0A8BFB1, 0x7B5B3 },
	{ 0xF0A8BFB2, 0x7B5A7 },
	{ 0xF0A8BFB3, 0x7AAD9 },
	{ 0xF0A8BFB4, 0x7B5B4 },
	{ 0xF0A8BFB5, 0x7B5B1 },
	{ 0xF0A8BFB6, 0x7B5A3 },
	{ 0xF0A8BFB9, 0x7B5B2 },
	{ 0xF0A8BFBA, 0xFD8ED },
	{ 0xF0A8BFBD, 0x7B5AE },
	{ 0xF0A8BFBE, 0xFD2FA },
	{ 0xF0A8BFBF, 0x4D9D9 },
	{ 0xF0A98080, 0x7BDBD },
	{ 0xF0A98081, 0x7BDBB },
	{ 0xF0A98082, 0x7BDC5 },
	{ 0xF0A98083, 0x7BDBC },
	{ 0xF0A98084, 0x7BDBE },
	{ 0xF0A98085, 0x7BDC9 },
	{ 0xF0A98086, 0x7BDBA },
	{ 0xF0A98087, 0x7BDC2 },
	{ 0xF0A98088, 0x7BDB9 },
	{ 0xF0A98089, 0x7BDB8 },
	{ 0xF0A9808A, 0x7BDBF },
	{ 0xF0A9808B, 0x5DFD8 },
	{ 0xF0A9808C, 0x7BDC7 },
	{ 0xF0A9808D, 0x7BDC1 },
	{ 0xF0A9808E, 0x7BDC0 },
	{ 0xF0A9808F, 0x7BDC3 },
	{ 0xF0A98090, 0x7BDC8 },
	{ 0xF0A98091, 0x7B5B6 },
	{ 0xF0A98092, 0xFDDD5 },
	{ 0xF0A98093, 0xFDDD7 },
	{ 0xF0A98094, 0x7BDC4 },
	{ 0xF0A98095, 0x7BDC6 },
	{ 0xF0A98097, 0x7C4D0 },
	{ 0xF0A98098, 0x7C4D6 },
	{ 0xF0A98099, 0x7C4D2 },
	{ 0xF0A9809A, 0x7C4D3 },
	{ 0xF0A9809B, 0x7C4CF },
	{ 0xF0A9809C, 0x5E5E3 },
	{ 0xF0A9809D, 0x7C4D7 },
	{ 0xF0A9809E, 0x7C4D5 },
	{ 0xF0A9809F, 0x5E5E4 },
	{ 0xF0A980A0, 0x7C4D1 },
	{ 0xF0A980A1, 0x7C4D4 },
	{ 0xF0A980A4, 0x7CBCA },
	{ 0xF0A980A5, 0x7CBC7 },
	{ 0xF0A980A6, 0x7CBCB },
	{ 0xF0A980A7, 0x7CBC8 },
	{ 0xF0A980A8, 0x5EABF },
	{ 0xF0A980A9, 0x7CBCE },
	{ 0xF0A980AA, 0x4E1EF },
	{ 0xF0A980AB, 0x5EAC0 },
	{ 0xF0A980AC, 0x7CBC6 },
	{ 0xF0A980AD, 0x7CBCC },
	{ 0xF0A980AE, 0x7CBCD },
	{ 0xF0A980AF, 0x4E1F0 },
	{ 0xF0A980B0, 0x7CBC9 },
	{ 0xF0A980B1, 0x7CBCF },
	{ 0xF0A980B4, 0x7D1A3 },
	{ 0xF0A980B5, 0x7D1A7 },
	{ 0xF0A980B6, 0x7D0FD },
	{ 0xF0A980B7, 0x7D1AA },
	{ 0xF0A980B8, 0x7D1A4 },
	{ 0xF0A980B9, 0x7D1AB },
	{ 0xF0A980BA, 0x7D1A8 },
	{ 0xF0A980BB, 0x7D0FC },
	{ 0xF0A980BC, 0x5EEC2 },
	{ 0xF0A980BD, 0x7D1A5 },
	{ 0xF0A980BE, 0x7D1A6 },
	{ 0xF0A980BF, 0x5EEC3 },
	{ 0xF0A98180, 0x7D1A2 },
	{ 0xF0A98181, 0xFE6F4 },
	{ 0xF0A98182, 0x7D0FE },
	{ 0xF0A98185, 0x7D1AC },
	{ 0xF0A98186, 0x7D1A9 },
	{ 0xF0A98187, 0x7D5F4 },
	{ 0xF0A98188, 0x4E7E8 },
	{ 0xF0A98189, 0x7D5F2 },
	{ 0xF0A9818A, 0x7D5EF },
	{ 0xF0A9818B, 0x7D5F6 },
	{ 0xF0A9818C, 0x7D5F0 },
	{ 0xF0A9818D, 0x7D5F5 },
	{ 0xF0A9818E, 0x7D5F3 },
	{ 0xF0A9818F, 0x7D5F7 },
	{ 0xF0A98190, 0x7D1A1 },
	{ 0xF0A98191, 0xFE8F6 },
	{ 0xF0A98192, 0x7D5F1 },
	{ 0xF0A98193, 0x7D9F1 },
	{ 0xF0A98194, 0x7D9F2 },
	{ 0xF0A98195, 0x4E9D7 },
	{ 0xF0A98196, 0x7D9F5 },
	{ 0xF0A98197, 0x7D9F6 },
	{ 0xF0A98198, 0x7D9F4 },
	{ 0xF0A98199, 0xFEAB2 },
	{ 0xF0A9819B, 0x7D9F3 },
	{ 0xF0A9819C, 0x7DDB8 },
	{ 0xF0A9819D, 0x7DDB9 },
	{ 0xF0A9819E, 0x7DDBA },
	{ 0xF0A9819F, 0x4EBAB },
	{ 0xF0A981A0, 0x7DDB7 },
	{ 0xF0A981A1, 0x7DDB3 },
	{ 0xF0A981A2, 0x7DDB4 },
	{ 0xF0A981A3, 0x7DDB5 },
	{ 0xF0A981A4, 0x7DDB6 },
	{ 0xF0A981A7, 0x7DFFC },
	{ 0xF0A981A8, 0x7DFFA },
	{ 0xF0A981A9, 0x7DFFB },
	{ 0xF0A981AB, 0x7DFF9 },
	{ 0xF0A981AC, 0x7E1DA },
	{ 0xF0A981AD, 0xFECC1 },
	{ 0xF0A981B0, 0x7E3FE },
	{ 0xF0A981B2, 0x7E4EB },
	{ 0xF0A981B5, 0x7E6C0 },
	{ 0xF0A981B6, 0xFADDE },
	{ 0xF0A981B7, 0x5B0F0 },
	{ 0xF0A981B8, 0xFB2F0 },
	{ 0xF0A981B9, 0x6C6B2 },
	{ 0xF0A981BA, 0x6C6B3 },
	{ 0xF0A981BB, 0x4B6A5 },
	{ 0xF0A981BC, 0x6C6B1 },
	{ 0xF0A981BD, 0xFB9A8 },
	{ 0xF0A981BE, 0xFB9A9 },
	{ 0xF0A98282, 0x5BDC0 },
	{ 0xF0A98283, 0x5BDBE },
	{ 0xF0A98284, 0x5BDC1 },
	{ 0xF0A98285, 0x5BDBF },
	{ 0xF0A98286, 0x4BBF3 },
	{ 0xF0A98287, 0x6D0B3 },
	{ 0xF0A98288, 0x4BBF2 },
	{ 0xF0A98289, 0x6D0B2 },
	{ 0xF0A9828A, 0xFC0A5 },
	{ 0xF0A9828C, 0xFC0A7 },
	{ 0xF0A9828D, 0xFC0A6 },
	{ 0xF0A98292, 0x4C1D8 },
	{ 0xF0A98293, 0x5C4A5 },
	{ 0xF0A98294, 0x5C4A2 },
	{ 0xF0A98295, 0x5C4A1 },
	{ 0xF0A98296, 0x5C4A4 },
	{ 0xF0A98297, 0x5C4A3 },
	{ 0xF0A98298, 0x6D9FC },
	{ 0xF0A9829A, 0xFC6AB },
	{ 0xF0A9829B, 0xFC6AC },
	{ 0xF0A9829C, 0xFC6AD },
	{ 0xF0A982A1, 0x5C4A6 },
	{ 0xF0A982A2, 0x5CBA2 },
	{ 0xF0A982A3, 0x4C8B0 },
	{ 0xF0A982A4, 0x5CBA3 },
	{ 0xF0A982A5, 0x5CBA1 },
	{ 0xF0A982A6, 0x5CAFE },
	{ 0xF0A982A7, 0x4C8AC },
	{ 0xF0A982A8, 0x4C8AF },
	{ 0xF0A982A9, 0x6E3FD },
	{ 0xF0A982AA, 0x4C8B2 },
	{ 0xF0A982AC, 0x6E3FC },
	{ 0xF0A982AD, 0x6E3FE },
	{ 0xF0A982AE, 0xFCDB7 },
	{ 0xF0A982B2, 0xFCDB8 },
	{ 0xF0A982B3, 0x6E3FA },
	{ 0xF0A982B5, 0x6E3F9 },
	{ 0xF0A982B7, 0x7AAEA },
	{ 0xF0A982B8, 0x7AAE9 },
	{ 0xF0A982B9, 0x5D2C5 },
	{ 0xF0A982BA, 0x5D2C0 },
	{ 0xF0A982BB, 0x5D2C1 },
	{ 0xF0A982BC, 0x5D2BF },
	{ 0xF0A982BD, 0x5D2BE },
	{ 0xF0A982BE, 0x5D2C3 },
	{ 0xF0A982BF, 0x5D2BD },
	{ 0xF0A98380, 0x4D4D7 },
	{ 0xF0A98381, 0x5D2BC },
	{ 0xF0A98382, 0x7AAEB },
	{ 0xF0A98383, 0x7AAEC },
	{ 0xF0A98385, 0xFC6AA },
	{ 0xF0A98386, 0xFD2FB },
	{ 0xF0A98387, 0xFD2FC },
	{ 0xF0A98388, 0xFD2FD },
	{ 0xF0A98389, 0xFD2FE },
	{ 0xF0A9838A, 0xFD3A1 },
	{ 0xF0A9838C, 0x7AAE8 },
	{ 0xF0A98390, 0x5D2C4 },
	{ 0xF0A98391, 0x5D2C2 },
	{ 0xF0A98392, 0x5DFD9 },
	{ 0xF0A98393, 0x7B5BB },
	{ 0xF0A98394, 0x4D4DB },
	{ 0xF0A98395, 0x5D9CE },
	{ 0xF0A98396, 0x5D9CB },
	{ 0xF0A98397, 0x4D4DA },
	{ 0xF0A98398, 0x7B5B8 },
	{ 0xF0A98399, 0x5D9CD },
	{ 0xF0A9839A, 0x5D9CA },
	{ 0xF0A9839B, 0x7B5BA },
	{ 0xF0A9839C, 0x5D9C9 },
	{ 0xF0A9839D, 0x7B5B9 },
	{ 0xF0A9839E, 0x7B5B7 },
	{ 0xF0A983A0, 0x5D9C8 },
	{ 0xF0A983A1, 0x7B5BC },
	{ 0xF0A983A3, 0xFD8EE },
	{ 0xF0A983A6, 0xFD8EF },
	{ 0xF0A983A7, 0xFD8F1 },
	{ 0xF0A983A8, 0xFD8F2 },
	{ 0xF0A983A9, 0xFD8F3 },
	{ 0xF0A983AA, 0xFD8F4 },
	{ 0xF0A983AB, 0xFD8F5 },
	{ 0xF0A983AD, 0xFD8F0 },
	{ 0xF0A983AF, 0xFD5E4 },
	{ 0xF0A983B4, 0x5D9CC },
	{ 0xF0A983B5, 0x4D9DC },
	{ 0xF0A983B6, 0x4D9DA },
	{ 0xF0A983B7, 0x4D9DB },
	{ 0xF0A983B8, 0x5DFDA },
	{ 0xF0A983B9, 0x4D9E1 },
	{ 0xF0A983BA, 0x5DFDC },
	{ 0xF0A983BC, 0x4D9DE },
	{ 0xF0A983BD, 0x7BDCA },
	{ 0xF0A983BE, 0x5E5E8 },
	{ 0xF0A983BF, 0x7BDCB },
	{ 0xF0A98480, 0x7BDCD },
	{ 0xF0A98481, 0x5DFDB },
	{ 0xF0A98483, 0xFDDD9 },
	{ 0xF0A98484, 0x7BDCC },
	{ 0xF0A98489, 0x7BDCE },
	{ 0xF0A9848D, 0xFDDDA },
	{ 0xF0A98496, 0x5DFDD },
	{ 0xF0A98497, 0x5E5EC },
	{ 0xF0A98498, 0x5E5EF },
	{ 0xF0A98499, 0x7C4DF },
	{ 0xF0A9849A, 0x7C4E3 },
	{ 0xF0A9849B, 0x5E5E9 },
	{ 0xF0A9849C, 0x7C4DE },
	{ 0xF0A9849D, 0x5E5E6 },
	{ 0xF0A9849E, 0x7C4E5 },
	{ 0xF0A9849F, 0x7C4E2 },
	{ 0xF0A984A0, 0x4DEB7 },
	{ 0xF0A984A1, 0x5E5E5 },
	{ 0xF0A984A2, 0x5E5E7 },
	{ 0xF0A984A3, 0x7C4E1 },
	{ 0xF0A984A4, 0x7C4DA },
	{ 0xF0A984A5, 0x7C4DD },
	{ 0xF0A984A6, 0x5E5EE },
	{ 0xF0A984A7, 0x7C4DB },
	{ 0xF0A984A9, 0xFE1D1 },
	{ 0xF0A984AB, 0x7C4E4 },
	{ 0xF0A984AD, 0x7C4D9 },
	{ 0xF0A984AE, 0x7C4DC },
	{ 0xF0A984B7, 0x5E5EB },
	{ 0xF0A984B8, 0x5E5ED },
	{ 0xF0A984B9, 0xFDDD8 },
	{ 0xF0A984BA, 0x5E5EA },
	{ 0xF0A984BB, 0x5EAC7 },
	{ 0xF0A984BC, 0x5EAC1 },
	{ 0xF0A984BD, 0x5EAC5 },
	{ 0xF0A984BE, 0x5EAC2 },
	{ 0xF0A984BF, 0x5EAC3 },
	{ 0xF0A98580, 0x4E1F2 },
	{ 0xF0A98581, 0x5EAC6 },
	{ 0xF0A98582, 0x5EAC4 },
	{ 0xF0A98583, 0x5EAC9 },
	{ 0xF0A98584, 0x4E1F1 },
	{ 0xF0A98585, 0x7CBD0 },
	{ 0xF0A98586, 0x7CBD5 },
	{ 0xF0A98587, 0x7CBD1 },
	{ 0xF0A98589, 0x5EAC8 },
	{ 0xF0A9858A, 0x7CBD3 },
	{ 0xF0A9858B, 0xFE4CE },
	{ 0xF0A9858E, 0x7CBD7 },
	{ 0xF0A9858F, 0x7CBD6 },
	{ 0xF0A98590, 0x7CBD4 },
	{ 0xF0A98592, 0x7CBD2 },
	{ 0xF0A98593, 0x7CBD8 },
	{ 0xF0A9859D, 0x7D1AE },
	{ 0xF0A9859E, 0x4E4F4 },
	{ 0xF0A9859F, 0x7D1B6 },
	{ 0xF0A985A0, 0x4E4F6 },
	{ 0xF0A985A1, 0x5EEC4 },
	{ 0xF0A985A2, 0x4E7ED },
	{ 0xF0A985A3, 0x4E4F8 },
	{ 0xF0A985A4, 0x7D1B4 },
	{ 0xF0A985A5, 0x7D1B3 },
	{ 0xF0A985A6, 0x5EEC5 },
	{ 0xF0A985A7, 0x4E4FA },
	{ 0xF0A985A8, 0x4E4F7 },
	{ 0xF0A985A9, 0x4E4F9 },
	{ 0xF0A985AA, 0x7D1AF },
	{ 0xF0A985AB, 0x7D1B1 },
	{ 0xF0A985AC, 0x7D1B2 },
	{ 0xF0A985AD, 0xFE6F5 },
	{ 0xF0A985B1, 0x7D1B5 },
	{ 0xF0A985B2, 0x7D1B7 },
	{ 0xF0A985B6, 0x7D1B0 },
	{ 0xF0A985B7, 0x7D1AD },
	{ 0xF0A985BC, 0x4E7EA },
	{ 0xF0A985BD, 0x4E7E9 },
	{ 0xF0A985BE, 0x7D5F8 },
	{ 0xF0A985BF, 0x5F1DE },
	{ 0xF0A98680, 0x5F1DF },
	{ 0xF0A98681, 0x4E7EB },
	{ 0xF0A98682, 0x4E7EC },
	{ 0xF0A98683, 0x7D5FA },
	{ 0xF0A98684, 0x5F1E0 },
	{ 0xF0A98685, 0x5F1E1 },
	{ 0xF0A98686, 0x7D5FD },
	{ 0xF0A98687, 0x7D5F9 },
	{ 0xF0A98688, 0x7D5FE },
	{ 0xF0A98689, 0x7D5FB },
	{ 0xF0A98691, 0x5F4DC },
	{ 0xF0A98692, 0x5F4DF },
	{ 0xF0A98693, 0x4E9D9 },
	{ 0xF0A98694, 0x7D9F8 },
	{ 0xF0A98695, 0x5F4DD },
	{ 0xF0A98696, 0x7D9F9 },
	{ 0xF0A98697, 0x7D9FA },
	{ 0xF0A98698, 0x5F4DA },
	{ 0xF0A9869A, 0x5F4DE },
	{ 0xF0A9869B, 0x5F4DB },
	{ 0xF0A9869F, 0x7D9F7 },
	{ 0xF0A986A4, 0x5F6E2 },
	{ 0xF0A986A5, 0x7DDBB },
	{ 0xF0A986A6, 0x7DDBC },
	{ 0xF0A986A9, 0xFEBB3 },
	{ 0xF0A986AB, 0x5F6E3 },
	{ 0xF0A986AD, 0x5F8C4 },
	{ 0xF0A986AE, 0x4ECB2 },
	{ 0xF0A986AF, 0x4ECB1 },
	{ 0xF0A986B0, 0x7DFFD },
	{ 0xF0A986B1, 0x7DFFE },
	{ 0xF0A986B2, 0x7E0A1 },
	{ 0xF0A986B3, 0xFEBF0 },
	{ 0xF0A986B5, 0x4EDAC },
	{ 0xF0A986B6, 0x5F9D6 },
	{ 0xF0A986B7, 0x4EDAB },
	{ 0xF0A986B8, 0x5F9D5 },
	{ 0xF0A986BA, 0x7E1DB },
	{ 0xF0A986BD, 0x5F9D7 },
	{ 0xF0A986BF, 0x5FAC4 },
	{ 0xF0A98780, 0x7E2FB },
	{ 0xF0A98781, 0x5FAC3 },
	{ 0xF0A98782, 0x7E2FC },
	{ 0xF0A98783, 0xFECD9 },
	{ 0xF0A98784, 0x7E3A3 },
	{ 0xF0A98787, 0x5FAC2 },
	{ 0xF0A98788, 0x7E4EC },
	{ 0xF0A98789, 0x4EEBE },
	{ 0xF0A9878A, 0x7E5CB },
	{ 0xF0A9878B, 0x7E5CA },
	{ 0xF0A9878C, 0x7E5CC },
	{ 0xF0A9878E, 0x5FBEC },
	{ 0xF0A98791, 0x7E6AD },
	{ 0xF0A98792, 0x7E6CE },
	{ 0xF0A98793, 0x7E6D1 },
	{ 0xF0A98794, 0x4EEDC },
	{ 0xF0A98795, 0x4B6A6 },
	{ 0xF0A98797, 0x6D0B4 },
	{ 0xF0A98798, 0xFC6AE },
	{ 0xF0A98799, 0xFC6AF },
	{ 0xF0A9879A, 0xFC6B0 },
	{ 0xF0A9879B, 0x6D9FD },
	{ 0xF0A9879C, 0x4C8B6 },
	{ 0xF0A9879D, 0x7ACC4 },
	{ 0xF0A9879E, 0x7B5BD },
	{ 0xF0A9879F, 0x5DAF4 },
	{ 0xF0A987A0, 0x7C4E6 },
	{ 0xF0A987A1, 0xFE4CF },
	{ 0xF0A987A3, 0x5F1E2 },
	{ 0xF0A987A4, 0xFEBF1 },
	{ 0xF0A987A6, 0x6BCF4 },
	{ 0xF0A987A7, 0x6AEC9 },
	{ 0xF0A987A8, 0x6BCF3 },
	{ 0xF0A987A9, 0x4B6A7 },
	{ 0xF0A987AA, 0x6C6B4 },
	{ 0xF0A987AB, 0x4B6A9 },
	{ 0xF0A987AC, 0xFB9AD },
	{ 0xF0A987AD, 0x6D0B5 },
	{ 0xF0A987AE, 0x5BDC2 },
	{ 0xF0A987AF, 0x4BBF5 },
	{ 0xF0A987B0, 0x6D0B7 },
	{ 0xF0A987B1, 0x6D0B6 },
	{ 0xF0A987B2, 0xFC0A8 },
	{ 0xF0A987B3, 0xFC0A9 },
	{ 0xF0A987B5, 0x6DAA1 },
	{ 0xF0A987B6, 0x6D9FE },
	{ 0xF0A987B7, 0xFCDBB },
	{ 0xF0A987B8, 0x4CECD },
	{ 0xF0A987B9, 0x7AAEE },
	{ 0xF0A987BA, 0x7AAED },
	{ 0xF0A987BC, 0x7B5BE },
	{ 0xF0A987BE, 0x7D1B8 },
	{ 0xF0A987BF, 0x7D1B9 },
	{ 0xF0A98883, 0x6D0B9 },
	{ 0xF0A98884, 0x6D0BA },
	{ 0xF0A98885, 0x6D0B8 },
	{ 0xF0A98886, 0x4C1D9 },
	{ 0xF0A98887, 0x4C1DB },
	{ 0xF0A98888, 0x5C4A8 },
	{ 0xF0A98889, 0x5C4A7 },
	{ 0xF0A9888A, 0x6DAA3 },
	{ 0xF0A9888C, 0x6DAA2 },
	{ 0xF0A9888D, 0x6E4A2 },
	{ 0xF0A9888E, 0x5CBA5 },
	{ 0xF0A9888F, 0x4C8B9 },
	{ 0xF0A98891, 0x6E4A1 },
	{ 0xF0A98892, 0x5CBA4 },
	{ 0xF0A98893, 0xFCDBC },
	{ 0xF0A98896, 0x6E4A3 },
	{ 0xF0A98899, 0x4CECE },
	{ 0xF0A9889A, 0x5D2C6 },
	{ 0xF0A9889B, 0x5D2C8 },
	{ 0xF0A9889C, 0x5D2C7 },
	{ 0xF0A9889D, 0x7AAF0 },
	{ 0xF0A9889F, 0x7AAEF },
	{ 0xF0A988A0, 0xFD8F7 },
	{ 0xF0A988A1, 0x5D9D0 },
	{ 0xF0A988A2, 0x5D9CF },
	{ 0xF0A988A3, 0x5D9D4 },
	{ 0xF0A988A4, 0x5D9D1 },
	{ 0xF0A988A5, 0x5D9D2 },
	{ 0xF0A988A6, 0x5D9D3 },
	{ 0xF0A988A7, 0xFD8F6 },
	{ 0xF0A988A8, 0x7B5BF },
	{ 0xF0A988AB, 0x7BDCF },
	{ 0xF0A988AC, 0x5DFDF },
	{ 0xF0A988AD, 0x5DFE0 },
	{ 0xF0A988AE, 0x5DFE2 },
	{ 0xF0A988AF, 0x5DFE1 },
	{ 0xF0A988B0, 0xFDDDB },
	{ 0xF0A988B1, 0x7BDD1 },
	{ 0xF0A988B2, 0x5E5F2 },
	{ 0xF0A988B3, 0x7C4E7 },
	{ 0xF0A988B4, 0x5E5F0 },
	{ 0xF0A988B5, 0x5E5F1 },
	{ 0xF0A988B6, 0x4DEB9 },
	{ 0xF0A988B8, 0x5EACB },
	{ 0xF0A988B9, 0x5EACA },
	{ 0xF0A988BB, 0x5EEC7 },
	{ 0xF0A988BC, 0x5EEC6 },
	{ 0xF0A988BD, 0x7CDD0 },
	{ 0xF0A988BE, 0x7D1BA },
	{ 0xF0A98980, 0x5ECC6 },
	{ 0xF0A98981, 0x5F1E4 },
	{ 0xF0A98982, 0x7D6A2 },
	{ 0xF0A98983, 0x5F1E6 },
	{ 0xF0A98984, 0x5F1E5 },
	{ 0xF0A98985, 0xFE8F9 },
	{ 0xF0A98987, 0x7D6A1 },
	{ 0xF0A98988, 0x7D6A4 },
	{ 0xF0A98989, 0x7D6A3 },
	{ 0xF0A9898A, 0x7D9FB },
	{ 0xF0A9898B, 0x7D9FC },
	{ 0xF0A9898C, 0x7DDBD },
	{ 0xF0A9898D, 0x5F6E4 },
	{ 0xF0A9898E, 0xFEBB4 },
	{ 0xF0A98991, 0x7E0A2 },
	{ 0xF0A98994, 0x5FAC5 },
	{ 0xF0A98996, 0x7E4A1 },
	{ 0xF0A98999, 0x7E4EE },
	{ 0xF0A9899A, 0x7E4ED },
	{ 0xF0A9899B, 0xFB9AE },
	{ 0xF0A9899D, 0x5BDC3 },
	{ 0xF0A9899E, 0x4BBF8 },
	{ 0xF0A9899F, 0x6D0BB },
	{ 0xF0A989A1, 0x5C4AC },
	{ 0xF0A989A2, 0x5C4AB },
	{ 0xF0A989A3, 0x6DAA6 },
	{ 0xF0A989A4, 0x6DAA9 },
	{ 0xF0A989A5, 0x5C4AA },
	{ 0xF0A989A6, 0x6DAA7 },
	{ 0xF0A989A7, 0x5C4A9 },
	{ 0xF0A989A8, 0x6DAA5 },
	{ 0xF0A989A9, 0x6DAAB },
	{ 0xF0A989AA, 0x6DAAA },
	{ 0xF0A989AB, 0x4C1DC },
	{ 0xF0A989AC, 0x4C1DE },
	{ 0xF0A989AE, 0xFC6B1 },
	{ 0xF0A989B8, 0x5CBA7 },
	{ 0xF0A989B9, 0x4C8BC },
	{ 0xF0A989BA, 0x5CBA6 },
	{ 0xF0A989BB, 0x6E4A7 },
	{ 0xF0A989BC, 0x6E4A5 },
	{ 0xF0A989BD, 0x5CBA8 },
	{ 0xF0A989BE, 0x5CBA9 },
	{ 0xF0A989BF, 0x4C8BE },
	{ 0xF0A98A80, 0x5CBAC },
	{ 0xF0A98A81, 0x5CBAA },
	{ 0xF0A98A82, 0x5CBAD },
	{ 0xF0A98A83, 0x5CBAB },
	{ 0xF0A98A84, 0x6E4A9 },
	{ 0xF0A98A85, 0x4C8BF },
	{ 0xF0A98A88, 0x6E4A8 },
	{ 0xF0A98A89, 0x6E4A4 },
	{ 0xF0A98A8B, 0x6E4A6 },
	{ 0xF0A98A90, 0x7AAF3 },
	{ 0xF0A98A91, 0x5D2C9 },
	{ 0xF0A98A92, 0x7AAF7 },
	{ 0xF0A98A93, 0x7AAF6 },
	{ 0xF0A98A94, 0x4CED1 },
	{ 0xF0A98A95, 0x7AAF9 },
	{ 0xF0A98A96, 0x5D2CA },
	{ 0xF0A98A97, 0x4CED2 },
	{ 0xF0A98A98, 0x7AAF5 },
	{ 0xF0A98A99, 0x4CED3 },
	{ 0xF0A98A9A, 0x5D2CD },
	{ 0xF0A98A9B, 0x4CED0 },
	{ 0xF0A98A9C, 0x5D2CC },
	{ 0xF0A98A9D, 0x5D2CE },
	{ 0xF0A98A9E, 0x7AAF4 },
	{ 0xF0A98A9F, 0x5D2CB },
	{ 0xF0A98AA5, 0x7AAF8 },
	{ 0xF0A98AA6, 0x7AAF2 },
	{ 0xF0A98AA9, 0x7B5C4 },
	{ 0xF0A98AAA, 0x5D9D5 },
	{ 0xF0A98AAB, 0x5D9D8 },
	{ 0xF0A98AAC, 0x4D4E6 },
	{ 0xF0A98AAD, 0x4D4DE },
	{ 0xF0A98AAE, 0x4D4E5 },
	{ 0xF0A98AAF, 0x5D9D6 },
	{ 0xF0A98AB0, 0x5D9D7 },
	{ 0xF0A98AB2, 0x7B5C3 },
	{ 0xF0A98AB3, 0x7B5C7 },
	{ 0xF0A98AB7, 0x7B5C0 },
	{ 0xF0A98AB8, 0x7B5C1 },
	{ 0xF0A98AB9, 0x7B5C5 },
	{ 0xF0A98ABC, 0x7B5C6 },
	{ 0xF0A98ABF, 0x7BDD8 },
	{ 0xF0A98B80, 0x7BDDA },
	{ 0xF0A98B81, 0x5DFE3 },
	{ 0xF0A98B82, 0x5DFE9 },
	{ 0xF0A98B83, 0x4D9E6 },
	{ 0xF0A98B84, 0x5DFE5 },
	{ 0xF0A98B85, 0x7BDD3 },
	{ 0xF0A98B86, 0x4D9E7 },
	{ 0xF0A98B87, 0x7B5C2 },
	{ 0xF0A98B88, 0x5DFED },
	{ 0xF0A98B89, 0x7BDD7 },
	{ 0xF0A98B8A, 0x4D9E5 },
	{ 0xF0A98B8B, 0x7BDD9 },
	{ 0xF0A98B8C, 0x5DFE7 },
	{ 0xF0A98B8D, 0x5DFEA },
	{ 0xF0A98B8E, 0x7BDD5 },
	{ 0xF0A98B8F, 0x5DFEB },
	{ 0xF0A98B90, 0x7BDDB },
	{ 0xF0A98B91, 0x7B5C8 },
	{ 0xF0A98B92, 0x5DFE8 },
	{ 0xF0A98B93, 0x7BDD4 },
	{ 0xF0A98B94, 0x7BDDC },
	{ 0xF0A98B95, 0xFDDDC },
	{ 0xF0A98B9B, 0x7BDD2 },
	{ 0xF0A98B9D, 0x5DFEC },
	{ 0xF0A98B9E, 0x5DFE6 },
	{ 0xF0A98B9F, 0x4DEC4 },
	{ 0xF0A98BA0, 0x5E5FC },
	{ 0xF0A98BA1, 0x5E5F4 },
	{ 0xF0A98BA2, 0x4DEBA },
	{ 0xF0A98BA3, 0x5E5F6 },
	{ 0xF0A98BA4, 0x5E6A2 },
	{ 0xF0A98BA5, 0x7C4EA },
	{ 0xF0A98BA6, 0x7C4E8 },
	{ 0xF0A98BA7, 0x4DEBF },
	{ 0xF0A98BA8, 0x5E5F7 },
	{ 0xF0A98BA9, 0x4DEC0 },
	{ 0xF0A98BAA, 0x7C4ED },
	{ 0xF0A98BAB, 0x7C4F0 },
	{ 0xF0A98BAC, 0x5E6A1 },
	{ 0xF0A98BAD, 0x7C4EF },
	{ 0xF0A98BAE, 0x4DEBD },
	{ 0xF0A98BAF, 0x5E6A3 },
	{ 0xF0A98BB0, 0x7C4F1 },
	{ 0xF0A98BB1, 0x7C4F2 },
	{ 0xF0A98BB2, 0x7C4EE },
	{ 0xF0A98BB3, 0xFE1D3 },
	{ 0xF0A98BB4, 0xFE1D4 },
	{ 0xF0A98BB5, 0x5DFE4 },
	{ 0xF0A98BB6, 0x7C4EC },
	{ 0xF0A98BB8, 0x7C4EB },
	{ 0xF0A98BB9, 0x5E5F8 },
	{ 0xF0A98BBA, 0x5E6A4 },
	{ 0xF0A98BBC, 0x7C4E9 },
	{ 0xF0A98BBD, 0x5E5F5 },
	{ 0xF0A98BBE, 0x5E5FA },
	{ 0xF0A98BBF, 0x5E5F9 },
	{ 0xF0A98C80, 0x5E5FD },
	{ 0xF0A98C83, 0x4E1FA },
	{ 0xF0A98C84, 0x5EAD1 },
	{ 0xF0A98C85, 0x5EAD4 },
	{ 0xF0A98C86, 0x5EACF },
	{ 0xF0A98C87, 0x4E1F9 },
	{ 0xF0A98C88, 0x5EACD },
	{ 0xF0A98C89, 0x7CBDA },
	{ 0xF0A98C8A, 0x5EAD5 },
	{ 0xF0A98C8B, 0x7CBE3 },
	{ 0xF0A98C8C, 0x5EACE },
	{ 0xF0A98C8D, 0x4E1F8 },
	{ 0xF0A98C8E, 0x7CBE1 },
	{ 0xF0A98C8F, 0x4E1F6 },
	{ 0xF0A98C90, 0x7CBDE },
	{ 0xF0A98C91, 0x4E1F5 },
	{ 0xF0A98C92, 0x7CBE2 },
	{ 0xF0A98C93, 0x5EAD0 },
	{ 0xF0A98C94, 0x7CBE0 },
	{ 0xF0A98C95, 0xFE4D0 },
	{ 0xF0A98C96, 0xFE4D2 },
	{ 0xF0A98C97, 0xFE4D3 },
	{ 0xF0A98C9A, 0x7CBDB },
	{ 0xF0A98C9B, 0x7CBDC },
	{ 0xF0A98C9D, 0x5EAD3 },
	{ 0xF0A98CA0, 0x5EAD2 },
	{ 0xF0A98CA1, 0x7CBD9 },
	{ 0xF0A98CA2, 0x5EACC },
	{ 0xF0A98CA6, 0x4E5A4 },
	{ 0xF0A98CA7, 0x5EECE },
	{ 0xF0A98CA8, 0x4E4FD },
	{ 0xF0A98CA9, 0x5EECF },
	{ 0xF0A98CAA, 0x5EECA },
	{ 0xF0A98CAB, 0x7D1BB },
	{ 0xF0A98CAC, 0x5EEC8 },
	{ 0xF0A98CAD, 0x7D1BD },
	{ 0xF0A98CAE, 0x4E5A1 },
	{ 0xF0A98CAF, 0x5EECC },
	{ 0xF0A98CB0, 0x4E5A2 },
	{ 0xF0A98CB1, 0x4E5A5 },
	{ 0xF0A98CB2, 0x5EECD },
	{ 0xF0A98CB3, 0x7D1C1 },
	{ 0xF0A98CB6, 0x7D1BC },
	{ 0xF0A98CB7, 0xFE6F8 },
	{ 0xF0A98CB9, 0x7D1BE },
	{ 0xF0A98CBA, 0x7D1C3 },
	{ 0xF0A98CBB, 0x7D1C0 },
	{ 0xF0A98CBE, 0x5EECB },
	{ 0xF0A98CBF, 0x7D1BF },
	{ 0xF0A98D80, 0x5EED0 },
	{ 0xF0A98D81, 0x4E5A6 },
	{ 0xF0A98D82, 0x7D1C2 },
	{ 0xF0A98D83, 0x5F1ED },
	{ 0xF0A98D84, 0x7D6A8 },
	{ 0xF0A98D85, 0x4E7EF },
	{ 0xF0A98D86, 0x7D6AA },
	{ 0xF0A98D87, 0x7D6AB },
	{ 0xF0A98D89, 0x5F1EA },
	{ 0xF0A98D8A, 0x5F1EB },
	{ 0xF0A98D8B, 0x5F1EC },
	{ 0xF0A98D8E, 0x5F1E7 },
	{ 0xF0A98D8F, 0x5F1E8 },
	{ 0xF0A98D91, 0x7D6A9 },
	{ 0xF0A98D92, 0xFE6F7 },
	{ 0xF0A98D93, 0x5F4E0 },
	{ 0xF0A98D94, 0x7DAA6 },
	{ 0xF0A98D95, 0x7D9FD },
	{ 0xF0A98D96, 0x4E9DD },
	{ 0xF0A98D97, 0x5F4E1 },
	{ 0xF0A98D98, 0x7DAA5 },
	{ 0xF0A98D99, 0x7DAA3 },
	{ 0xF0A98D9A, 0x7D9FE },
	{ 0xF0A98D9B, 0x7DAA4 },
	{ 0xF0A98D9C, 0x5F4E3 },
	{ 0xF0A98D9D, 0x5F4E4 },
	{ 0xF0A98D9E, 0x7DAA1 },
	{ 0xF0A98D9F, 0x7DAA2 },
	{ 0xF0A98DA4, 0x5F4E5 },
	{ 0xF0A98DA5, 0x5F6E5 },
	{ 0xF0A98DA6, 0x5F6E8 },
	{ 0xF0A98DA7, 0x5F6E6 },
	{ 0xF0A98DA8, 0x7DDBE },
	{ 0xF0A98DA9, 0x5F6E9 },
	{ 0xF0A98DAA, 0x5F6E7 },
	{ 0xF0A98DAB, 0x7DDC1 },
	{ 0xF0A98DAE, 0x7DDBF },
	{ 0xF0A98DAF, 0x7DDC2 },
	{ 0xF0A98DB1, 0x7DDC0 },
	{ 0xF0A98DB2, 0x5F8C6 },
	{ 0xF0A98DB3, 0x5F9D8 },
	{ 0xF0A98DB4, 0x7E0A3 },
	{ 0xF0A98DB5, 0x5F8C5 },
	{ 0xF0A98DB7, 0x5F8C7 },
	{ 0xF0A98DB8, 0x7E1DE },
	{ 0xF0A98DB9, 0x7E1DC },
	{ 0xF0A98DBE, 0x7E1DD },
	{ 0xF0A98DBF, 0x5FAC6 },
	{ 0xF0A98E80, 0x7E2FE },
	{ 0xF0A98E81, 0x7E3A2 },
	{ 0xF0A98E82, 0x5F9D9 },
	{ 0xF0A98E84, 0x7E3A1 },
	{ 0xF0A98E85, 0x7E2FD },
	{ 0xF0A98E87, 0x5FBA2 },
	{ 0xF0A98E88, 0x7E4F0 },
	{ 0xF0A98E89, 0x7E4EF },
	{ 0xF0A98E8A, 0x5FBCC },
	{ 0xF0A98E8B, 0x7E5E9 },
	{ 0xF0A98E8C, 0x5FCB5 },
	{ 0xF0A98E8D, 0x7E6AE },
	{ 0xF0A98E8E, 0x7E6B9 },
	{ 0xF0A98E8F, 0x7E6B8 },
	{ 0xF0A98E91, 0x5FCCC },
	{ 0xF0A98E92, 0x5BDC4 },
	{ 0xF0A98E93, 0x4C1E0 },
	{ 0xF0A98E94, 0x4C1E2 },
	{ 0xF0A98E95, 0x6DAAC },
	{ 0xF0A98E97, 0x5C4AD },
	{ 0xF0A98E98, 0x6E4AB },
	{ 0xF0A98E99, 0x5CBAF },
	{ 0xF0A98E9A, 0x5CBB1 },
	{ 0xF0A98E9B, 0x5CBAE },
	{ 0xF0A98E9C, 0x5CBB0 },
	{ 0xF0A98E9D, 0x6E4AA },
	{ 0xF0A98E9E, 0xFCDBD },
	{ 0xF0A98EA1, 0x5CBB2 },
	{ 0xF0A98EA4, 0x4CED5 },
	{ 0xF0A98EA5, 0x5D2D0 },
	{ 0xF0A98EA6, 0x4CED4 },
	{ 0xF0A98EA7, 0x4CED6 },
	{ 0xF0A98EA8, 0x7AAFB },
	{ 0xF0A98EA9, 0x7AAFA },
	{ 0xF0A98EAA, 0x7AAFC },
	{ 0xF0A98EAB, 0x7AAFD },
	{ 0xF0A98EAC, 0x7AAFE },
	{ 0xF0A98EAD, 0x5D2CF },
	{ 0xF0A98EAE, 0x5D2D1 },
	{ 0xF0A98EAF, 0x5D9D9 },
	{ 0xF0A98EB0, 0x7B5C9 },
	{ 0xF0A98EB1, 0x7B5CA },
	{ 0xF0A98EB2, 0x5D9DC },
	{ 0xF0A98EB3, 0x5D9DD },
	{ 0xF0A98EB5, 0x5D9DB },
	{ 0xF0A98EB6, 0x7B5CB },
	{ 0xF0A98EB7, 0x5D9DA },
	{ 0xF0A98EB8, 0x4D9E9 },
	{ 0xF0A98EB9, 0x7BDDE },
	{ 0xF0A98EBA, 0x5DFEE },
	{ 0xF0A98EBB, 0x7BDDF },
	{ 0xF0A98EBC, 0x4D9EC },
	{ 0xF0A98EBD, 0x4D9EA },
	{ 0xF0A98EBE, 0x5DFEF },
	{ 0xF0A98EBF, 0x5DFF0 },
	{ 0xF0A98F80, 0xFDDDD },
	{ 0xF0A98F81, 0x7BDDD },
	{ 0xF0A98F83, 0x7BDE0 },
	{ 0xF0A98F85, 0x7C4F6 },
	{ 0xF0A98F86, 0x7C4F3 },
	{ 0xF0A98F87, 0x4DEC6 },
	{ 0xF0A98F88, 0x7C4F4 },
	{ 0xF0A98F89, 0x7BDE1 },
	{ 0xF0A98F8A, 0x5E6A5 },
	{ 0xF0A98F8B, 0x7C4F8 },
	{ 0xF0A98F8E, 0x7C4F5 },
	{ 0xF0A98F8F, 0x7CBE4 },
	{ 0xF0A98F90, 0x7CBE6 },
	{ 0xF0A98F91, 0x7CBE9 },
	{ 0xF0A98F92, 0x7CBE5 },
	{ 0xF0A98F93, 0x7CBE8 },
	{ 0xF0A98F94, 0x7CBE7 },
	{ 0xF0A98F95, 0x7D1C4 },
	{ 0xF0A98F96, 0x5EAD6 },
	{ 0xF0A98F97, 0x5EAD7 },
	{ 0xF0A98F98, 0x7D1C5 },
	{ 0xF0A98F99, 0x7D1C6 },
	{ 0xF0A98F9A, 0x4E5A8 },
	{ 0xF0A98F9B, 0xFE6F9 },
	{ 0xF0A98F9E, 0x5EED2 },
	{ 0xF0A98F9F, 0x5EED1 },
	{ 0xF0A98FA0, 0x5F1EE },
	{ 0xF0A98FA1, 0x5F1F0 },
	{ 0xF0A98FA2, 0x5F1F2 },
	{ 0xF0A98FA3, 0x4E7F4 },
	{ 0xF0A98FA4, 0x7D6AC },
	{ 0xF0A98FA5, 0x5F1EF },
	{ 0xF0A98FA6, 0x5F1F1 },
	{ 0xF0A98FA8, 0x7DAA7 },
	{ 0xF0A98FA9, 0x4E9DF },
	{ 0xF0A98FAA, 0x5F4E6 },
	{ 0xF0A98FAB, 0x7DAA8 },
	{ 0xF0A98FAC, 0x7DAA9 },
	{ 0xF0A98FAD, 0x5F4E7 },
	{ 0xF0A98FAE, 0x7DDC3 },
	{ 0xF0A98FAF, 0x7DDC6 },
	{ 0xF0A98FB0, 0x7DDC5 },
	{ 0xF0A98FB1, 0x7DDC4 },
	{ 0xF0A98FB2, 0x4ECB5 },
	{ 0xF0A98FB4, 0x7E1DF },
	{ 0xF0A98FB5, 0x5FAC7 },
	{ 0xF0A98FB6, 0x7E4A4 },
	{ 0xF0A98FB7, 0x7E4A2 },
	{ 0xF0A98FB8, 0x7E4A3 },
	{ 0xF0A98FB9, 0x5FBCD },
	{ 0xF0A98FBA, 0x5FBED },
	{ 0xF0A98FBB, 0x5FCA2 },
	{ 0xF0A99081, 0x5C4AE },
	{ 0xF0A99082, 0x6DAAD },
	{ 0xF0A99083, 0x5D2D2 },
	{ 0xF0A99084, 0x7B5CC },
	{ 0xF0A99085, 0x4D9ED },
	{ 0xF0A99087, 0x7BDE2 },
	{ 0xF0A99089, 0x7CBEC },
	{ 0xF0A9908A, 0x7D1C8 },
	{ 0xF0A9908B, 0x4E5AB },
	{ 0xF0A9908C, 0x5F1F3 },
	{ 0xF0A9908D, 0x7D1C7 },
	{ 0xF0A9908F, 0x7D6AD },
	{ 0xF0A99093, 0x7DAAA },
	{ 0xF0A99094, 0x7DDC8 },
	{ 0xF0A99095, 0x7DDC7 },
	{ 0xF0A99096, 0x7E1E0 },
	{ 0xF0A99097, 0xFC0AC },
	{ 0xF0A99098, 0x5C4B0 },
	{ 0xF0A99099, 0x5C4AF },
	{ 0xF0A9909A, 0x5CBB3 },
	{ 0xF0A9909B, 0x4C8C5 },
	{ 0xF0A9909C, 0x5CBB4 },
	{ 0xF0A9909E, 0x5D2DA },
	{ 0xF0A9909F, 0x7ABA1 },
	{ 0xF0A990A0, 0x5D2D4 },
	{ 0xF0A990A1, 0x5D2D7 },
	{ 0xF0A990A2, 0x7ABA2 },
	{ 0xF0A990A3, 0x5D2D5 },
	{ 0xF0A990A4, 0x5D2D6 },
	{ 0xF0A990A5, 0x5D2D9 },
	{ 0xF0A990A6, 0x5D2D3 },
	{ 0xF0A990A7, 0x4D4EB },
	{ 0xF0A990A8, 0x5D2D8 },
	{ 0xF0A990AA, 0xFD8F9 },
	{ 0xF0A990AB, 0x5D9DE },
	{ 0xF0A990AC, 0x7B5CD },
	{ 0xF0A990AD, 0x7BDE3 },
	{ 0xF0A990AE, 0x5DFF1 },
	{ 0xF0A990B0, 0x5DFF2 },
	{ 0xF0A990B1, 0x5E6A6 },
	{ 0xF0A990B2, 0x5E6A7 },
	{ 0xF0A990B4, 0x5E6A8 },
	{ 0xF0A990B5, 0x4E2A1 },
	{ 0xF0A990B6, 0x5EAD8 },
	{ 0xF0A990B7, 0x5EAD9 },
	{ 0xF0A990B9, 0x7D1C9 },
	{ 0xF0A990BA, 0x7D1CA },
	{ 0xF0A990BB, 0x5EED4 },
	{ 0xF0A990BC, 0x5EED3 },
	{ 0xF0A990BE, 0x5EED5 },
	{ 0xF0A990BF, 0x7D6AE },
	{ 0xF0A99180, 0x5F1F4 },
	{ 0xF0A99181, 0x5E6A9 },
	{ 0xF0A99182, 0x5F4E8 },
	{ 0xF0A99183, 0x5F4E9 },
	{ 0xF0A99185, 0x4E9E1 },
	{ 0xF0A99186, 0xFEAB3 },
	{ 0xF0A99187, 0x7DDCA },
	{ 0xF0A99188, 0x4ECB6 },
	{ 0xF0A99189, 0x5FBA3 },
	{ 0xF0A9918A, 0x5FCBF },
	{ 0xF0A9918B, 0x6B4FB },
	{ 0xF0A9918C, 0x6C6B5 },
	{ 0xF0A9918D, 0x5B6C6 },
	{ 0xF0A99190, 0x5BDCA },
	{ 0xF0A99191, 0x5BDC8 },
	{ 0xF0A99192, 0x5BDC9 },
	{ 0xF0A99193, 0x5BDC6 },
	{ 0xF0A99194, 0x4BBFD },
	{ 0xF0A99195, 0x5BDC5 },
	{ 0xF0A99196, 0x4BBFC },
	{ 0xF0A99197, 0x6D0BC },
	{ 0xF0A99198, 0x4BBFA },
	{ 0xF0A99199, 0x4C1EC },
	{ 0xF0A9919A, 0x5C4BA },
	{ 0xF0A9919B, 0x4C1EB },
	{ 0xF0A9919C, 0x5C4B1 },
	{ 0xF0A9919D, 0x5C4B9 },
	{ 0xF0A9919E, 0x6DAAF },
	{ 0xF0A9919F, 0x4C1E9 },
	{ 0xF0A991A0, 0x5CBBB },
	{ 0xF0A991A1, 0x5C4B7 },
	{ 0xF0A991A2, 0x4C1E6 },
	{ 0xF0A991A3, 0x4C1E7 },
	{ 0xF0A991A4, 0x4C1EA },
	{ 0xF0A991A5, 0x6DAB2 },
	{ 0xF0A991A6, 0x5C4B6 },
	{ 0xF0A991A7, 0x5C4B2 },
	{ 0xF0A991A8, 0x6DAB0 },
	{ 0xF0A991A9, 0x6DAB1 },
	{ 0xF0A991AA, 0x6DAAE },
	{ 0xF0A991AB, 0xFC6B3 },
	{ 0xF0A991AC, 0x5C4B3 },
	{ 0xF0A991AE, 0x5C4B8 },
	{ 0xF0A991B0, 0x5CBBD },
	{ 0xF0A991B1, 0x6E4B1 },
	{ 0xF0A991B2, 0x6E4B2 },
	{ 0xF0A991B3, 0x5CBB7 },
	{ 0xF0A991B4, 0x5CBC4 },
	{ 0xF0A991B5, 0x5CBB8 },
	{ 0xF0A991B6, 0x4C8C9 },
	{ 0xF0A991B7, 0x4C8C8 },
	{ 0xF0A991B8, 0x5CBBA },
	{ 0xF0A991B9, 0x5CBB6 },
	{ 0xF0A991BA, 0x4C8CF },
	{ 0xF0A991BB, 0x5CBC2 },
	{ 0xF0A991BC, 0x5CBB9 },
	{ 0xF0A991BD, 0x7ABAB },
	{ 0xF0A991BE, 0x5CBC3 },
	{ 0xF0A99280, 0x6E4B5 },
	{ 0xF0A99281, 0x6E4B3 },
	{ 0xF0A99282, 0x6E4AE },
	{ 0xF0A99283, 0x5CBBC },
	{ 0xF0A99284, 0x5CBC1 },
	{ 0xF0A99285, 0xFCDBE },
	{ 0xF0A99286, 0x6E4AD },
	{ 0xF0A99287, 0x5CBC0 },
	{ 0xF0A99288, 0x6E4AC },
	{ 0xF0A99289, 0x6E4B6 },
	{ 0xF0A9928A, 0x5CBB5 },
	{ 0xF0A9928B, 0x6E4AF },
	{ 0xF0A9928C, 0x6E4B4 },
	{ 0xF0A9928F, 0x5D2DD },
	{ 0xF0A99290, 0x4CEDB },
	{ 0xF0A99291, 0x7ABA5 },
	{ 0xF0A99292, 0x7ABB0 },
	{ 0xF0A99293, 0x5D2DC },
	{ 0xF0A99294, 0x5D2DB },
	{ 0xF0A99295, 0x4CED8 },
	{ 0xF0A99296, 0x7ABA4 },
	{ 0xF0A99297, 0x7ABAA },
	{ 0xF0A99298, 0x4C8CA },
	{ 0xF0A99299, 0x7ABAE },
	{ 0xF0A9929A, 0x5D2DE },
	{ 0xF0A9929B, 0x4CEDE },
	{ 0xF0A9929C, 0x7ABAD },
	{ 0xF0A9929D, 0x7ABA9 },
	{ 0xF0A9929E, 0x7B5CF },
	{ 0xF0A9929F, 0x7ABAC },
	{ 0xF0A992A0, 0xFD3A3 },
	{ 0xF0A992A1, 0xFD3A4 },
	{ 0xF0A992A2, 0x7ABA7 },
	{ 0xF0A992A4, 0x7ABA8 },
	{ 0xF0A992A6, 0x7ABAF },
	{ 0xF0A992A7, 0x7ABB1 },
	{ 0xF0A992AA, 0x7ABA3 },
	{ 0xF0A992AB, 0x7ABA6 },
	{ 0xF0A992AD, 0x5D2DF },
	{ 0xF0A992AE, 0x4D4EC },
	{ 0xF0A992AF, 0x5D9E1 },
	{ 0xF0A992B0, 0x4D4EE },
	{ 0xF0A992B1, 0x5D9E9 },
	{ 0xF0A992B2, 0x7B5D8 },
	{ 0xF0A992B3, 0x5D9E8 },
	{ 0xF0A992B4, 0x5D9E6 },
	{ 0xF0A992B5, 0x7B5D9 },
	{ 0xF0A992B6, 0x7B5D7 },
	{ 0xF0A992B7, 0x5D9E5 },
	{ 0xF0A992B8, 0x5D9E3 },
	{ 0xF0A992B9, 0x7B5DB },
	{ 0xF0A992BA, 0x7B5D0 },
	{ 0xF0A992BB, 0x5D9EA },
	{ 0xF0A992BC, 0x5D9E2 },
	{ 0xF0A992BD, 0x5D9EB },
	{ 0xF0A992BE, 0x5D9E4 },
	{ 0xF0A992BF, 0x5D9E7 },
	{ 0xF0A99380, 0x4D4F1 },
	{ 0xF0A99381, 0x7B5CE },
	{ 0xF0A99382, 0x5D9E0 },
	{ 0xF0A99383, 0x7B5DA },
	{ 0xF0A99384, 0x4D4F2 },
	{ 0xF0A99385, 0x7B5D6 },
	{ 0xF0A99386, 0x7B5DC },
	{ 0xF0A99388, 0xFCDC0 },
	{ 0xF0A99389, 0xFD8FA },
	{ 0xF0A9938A, 0xFD8FC },
	{ 0xF0A9938B, 0xFD8FD },
	{ 0xF0A9938C, 0xFD9A1 },
	{ 0xF0A9938D, 0xFD9A2 },
	{ 0xF0A9938E, 0xFD9A3 },
	{ 0xF0A99391, 0x7B5D2 },
	{ 0xF0A99393, 0x7B5D3 },
	{ 0xF0A99394, 0x7B5D4 },
	{ 0xF0A99395, 0x7B5D5 },
	{ 0xF0A99396, 0x5D9EC },
	{ 0xF0A99398, 0x5D9DF },
	{ 0xF0A99399, 0xFD8FE },
	{ 0xF0A9939D, 0x5D9ED },
	{ 0xF0A9939E, 0x4D9F5 },
	{ 0xF0A9939F, 0x4D9F1 },
	{ 0xF0A993A0, 0x4D9EE },
	{ 0xF0A993A1, 0x7BDE5 },
	{ 0xF0A993A2, 0x5DFF7 },
	{ 0xF0A993A3, 0x4D9F9 },
	{ 0xF0A993A4, 0x5DFF8 },
	{ 0xF0A993A5, 0x4D9F4 },
	{ 0xF0A993A6, 0x5DFF6 },
	{ 0xF0A993A7, 0x5DFF3 },
	{ 0xF0A993A8, 0x5DFF5 },
	{ 0xF0A993A9, 0x4D9EF },
	{ 0xF0A993AA, 0x5DFFB },
	{ 0xF0A993AB, 0x7BDEA },
	{ 0xF0A993AC, 0x4D9F2 },
	{ 0xF0A993AD, 0x7BDEC },
	{ 0xF0A993AE, 0x5DFF4 },
	{ 0xF0A993AF, 0x7BDE7 },
	{ 0xF0A993B0, 0x4D9F8 },
	{ 0xF0A993B1, 0x7BDEB },
	{ 0xF0A993B2, 0xFDDDE },
	{ 0xF0A993B3, 0xFDDDF },
	{ 0xF0A993B4, 0xFDDE0 },
	{ 0xF0A993B5, 0xFDDE1 },
	{ 0xF0A993B6, 0xFDDE2 },
	{ 0xF0A993B7, 0xFDDE3 },
	{ 0xF0A993B8, 0x7BDE4 },
	{ 0xF0A993BA, 0x7BDE6 },
	{ 0xF0A993BB, 0x5DFF9 },
	{ 0xF0A993BC, 0x5DFFA },
	{ 0xF0A993BD, 0x7BDE8 },
	{ 0xF0A993BE, 0x7BDED },
	{ 0xF0A99480, 0x5E6AA },
	{ 0xF0A99481, 0x4DECA },
	{ 0xF0A99482, 0x5E6B0 },
	{ 0xF0A99483, 0x5E6AE },
	{ 0xF0A99484, 0x4E2A4 },
	{ 0xF0A99485, 0x5E6AD },
	{ 0xF0A99486, 0x5E6AB },
	{ 0xF0A99487, 0x7C4FB },
	{ 0xF0A99488, 0x5E6AC },
	{ 0xF0A99489, 0x4DEC8 },
	{ 0xF0A9948A, 0x5E6B1 },
	{ 0xF0A9948B, 0x5E6AF },
	{ 0xF0A9948C, 0x7C4FC },
	{ 0xF0A9948D, 0xFE1D5 },
	{ 0xF0A9948E, 0xFE1D6 },
	{ 0xF0A9948F, 0xFE1D7 },
	{ 0xF0A99490, 0xFE1D8 },
	{ 0xF0A99493, 0x7C4F9 },
	{ 0xF0A99494, 0x7C4FA },
	{ 0xF0A99499, 0x7CBF6 },
	{ 0xF0A9949A, 0x5EADD },
	{ 0xF0A9949B, 0x7CBF0 },
	{ 0xF0A9949C, 0x7CBED },
	{ 0xF0A9949D, 0x5EADE },
	{ 0xF0A9949E, 0x4E2AE },
	{ 0xF0A9949F, 0x7CBF2 },
	{ 0xF0A994A0, 0x5EADC },
	{ 0xF0A994A1, 0x5EED6 },
	{ 0xF0A994A2, 0x5EADB },
	{ 0xF0A994A3, 0x5EADA },
	{ 0xF0A994A4, 0x7CBF4 },
	{ 0xF0A994A5, 0x7CBEF },
	{ 0xF0A994A6, 0x4E2AA },
	{ 0xF0A994A7, 0x7CBEE },
	{ 0xF0A994A8, 0x7CBF5 },
	{ 0xF0A994A9, 0x7CBF1 },
	{ 0xF0A994AC, 0xFE4D4 },
	{ 0xF0A994AD, 0xFE4D5 },
	{ 0xF0A994AF, 0x7CBF7 },
	{ 0xF0A994B0, 0x7CBF3 },
	{ 0xF0A994B3, 0x4E5AE },
	{ 0xF0A994B4, 0x4E5AD },
	{ 0xF0A994B5, 0x5EEDB },
	{ 0xF0A994B6, 0x5EED9 },
	{ 0xF0A994B7, 0x7D1CE },
	{ 0xF0A994B8, 0x5EEDA },
	{ 0xF0A994B9, 0x4E5B2 },
	{ 0xF0A994BA, 0x7D1CD },
	{ 0xF0A994BB, 0x4E5B3 },
	{ 0xF0A994BC, 0x5EED8 },
	{ 0xF0A994BD, 0x7D1CB },
	{ 0xF0A994BE, 0x7D1CF },
	{ 0xF0A994BF, 0xFE6FA },
	{ 0xF0A99580, 0x4E5B4 },
	{ 0xF0A99582, 0x7D1D0 },
	{ 0xF0A99585, 0x7D1CC },
	{ 0xF0A99586, 0x5EED7 },
	{ 0xF0A99588, 0x7D0CC },
	{ 0xF0A99589, 0x5F1F5 },
	{ 0xF0A9958A, 0x5F1F6 },
	{ 0xF0A9958B, 0x7D6AF },
	{ 0xF0A9958C, 0x5F1F8 },
	{ 0xF0A9958D, 0x7D6B8 },
	{ 0xF0A9958E, 0x7DAB1 },
	{ 0xF0A9958F, 0x4E7FA },
	{ 0xF0A99590, 0x4E7F8 },
	{ 0xF0A99591, 0x7D6B3 },
	{ 0xF0A99592, 0x7D6B1 },
	{ 0xF0A99593, 0x7D6B6 },
	{ 0xF0A99594, 0x5F1F7 },
	{ 0xF0A99595, 0x5F1F9 },
	{ 0xF0A99596, 0x5F1FA },
	{ 0xF0A99597, 0x7D6B0 },
	{ 0xF0A99598, 0x7D6B4 },
	{ 0xF0A99599, 0xFE8FA },
	{ 0xF0A9959A, 0xFE8FB },
	{ 0xF0A9959B, 0xFE8FC },
	{ 0xF0A9959D, 0x7D6B7 },
	{ 0xF0A9959E, 0x7D6B5 },
	{ 0xF0A9959F, 0x7DAB0 },
	{ 0xF0A995A0, 0x5F4EC },
	{ 0xF0A995A1, 0x5F4EB },
	{ 0xF0A995A2, 0x7DAAD },
	{ 0xF0A995A3, 0x7DAAF },
	{ 0xF0A995A4, 0x5F4EA },
	{ 0xF0A995A5, 0xFEAB4 },
	{ 0xF0A995A6, 0x7DAAB },
	{ 0xF0A995A9, 0x7DAAE },
	{ 0xF0A995AB, 0x7DAAC },
	{ 0xF0A995AC, 0x7DDD2 },
	{ 0xF0A995AD, 0x7DDD1 },
	{ 0xF0A995AE, 0x7DDCF },
	{ 0xF0A995AF, 0x5F6EC },
	{ 0xF0A995B1, 0x5F6ED },
	{ 0xF0A995B2, 0x4EBAE },
	{ 0xF0A995B3, 0x5F6EA },
	{ 0xF0A995B4, 0x7DDCD },
	{ 0xF0A995B5, 0x4EBAF },
	{ 0xF0A995B6, 0x7DDCE },
	{ 0xF0A995B7, 0xFEBB5 },
	{ 0xF0A995B8, 0x7DDD0 },
	{ 0xF0A995BA, 0x7DDCC },
	{ 0xF0A995BC, 0x7DDCB },
	{ 0xF0A995BE, 0x4ECB8 },
	{ 0xF0A995BF, 0x7E0A4 },
	{ 0xF0A99680, 0x5F6EB },
	{ 0xF0A99681, 0x4ECB7 },
	{ 0xF0A99683, 0xFEBF2 },
	{ 0xF0A99684, 0x7E0A5 },
	{ 0xF0A99686, 0x4EDAE },
	{ 0xF0A99687, 0x5F9DA },
	{ 0xF0A9968A, 0x5FAC8 },
	{ 0xF0A9968B, 0x7E3A4 },
	{ 0xF0A9968C, 0x5FAC9 },
	{ 0xF0A9968D, 0x7E3A5 },
	{ 0xF0A9968E, 0x7E3A6 },
	{ 0xF0A9968F, 0x4EEA3 },
	{ 0xF0A99690, 0x7E4A5 },
	{ 0xF0A99693, 0x7E5CD },
	{ 0xF0A99699, 0x6C6B6 },
	{ 0xF0A9969A, 0x6D0BF },
	{ 0xF0A9969B, 0x4BCA1 },
	{ 0xF0A9969C, 0x6D0BD },
	{ 0xF0A9969D, 0x5BDCB },
	{ 0xF0A9969F, 0xFC0AE },
	{ 0xF0A996A1, 0x6D0BE },
	{ 0xF0A996A2, 0x5C4BB },
	{ 0xF0A996A3, 0x5C4C0 },
	{ 0xF0A996A4, 0x4C1EF },
	{ 0xF0A996A5, 0x5C4BD },
	{ 0xF0A996A6, 0x5C4BE },
	{ 0xF0A996A7, 0x6DAB4 },
	{ 0xF0A996A8, 0x6DAB6 },
	{ 0xF0A996A9, 0x5C4BC },
	{ 0xF0A996AC, 0x4C1F0 },
	{ 0xF0A996AE, 0x6DAB5 },
	{ 0xF0A996B0, 0x6D3B3 },
	{ 0xF0A996B2, 0x5C4BF },
	{ 0xF0A996B3, 0x6DAB7 },
	{ 0xF0A996B4, 0x4C8D8 },
	{ 0xF0A996B5, 0x5CBC8 },
	{ 0xF0A996B6, 0x4C8D5 },
	{ 0xF0A996B7, 0x5CBC7 },
	{ 0xF0A996B8, 0x5CBC6 },
	{ 0xF0A996B9, 0x5CBC5 },
	{ 0xF0A996BA, 0x4C8D3 },
	{ 0xF0A996BB, 0x6E4B7 },
	{ 0xF0A996BC, 0x4C8D2 },
	{ 0xF0A996BD, 0x6E4BB },
	{ 0xF0A996BE, 0x6E4B9 },
	{ 0xF0A99781, 0x6E4B8 },
	{ 0xF0A99784, 0x4CEDF },
	{ 0xF0A99785, 0x5D2E2 },
	{ 0xF0A99786, 0x4CEE2 },
	{ 0xF0A99787, 0x7ABB4 },
	{ 0xF0A99788, 0x7ABB3 },
	{ 0xF0A99789, 0x7ABB2 },
	{ 0xF0A9978A, 0x5D2E1 },
	{ 0xF0A9978B, 0x7ABB5 },
	{ 0xF0A9978C, 0xFD3A5 },
	{ 0xF0A9978D, 0xFD3A6 },
	{ 0xF0A99793, 0x5D9EF },
	{ 0xF0A99794, 0x5D9F7 },
	{ 0xF0A99795, 0x5D9F0 },
	{ 0xF0A99796, 0x7B5DD },
	{ 0xF0A99797, 0x7B5E0 },
	{ 0xF0A99798, 0x5D9EE },
	{ 0xF0A99799, 0x5D9F3 },
	{ 0xF0A9979A, 0x5D9F6 },
	{ 0xF0A9979B, 0x7B5DF },
	{ 0xF0A9979D, 0x7B5E1 },
	{ 0xF0A9979E, 0x5D9F4 },
	{ 0xF0A9979F, 0x5D9F5 },
	{ 0xF0A997A0, 0x7B5DE },
	{ 0xF0A997A1, 0xFD9A5 },
	{ 0xF0A997A2, 0x5D9F2 },
	{ 0xF0A997A3, 0x5D9F1 },
	{ 0xF0A997A8, 0x7BDF1 },
	{ 0xF0A997A9, 0x4DAA5 },
	{ 0xF0A997AA, 0x5E0A5 },
	{ 0xF0A997AB, 0x5E0A6 },
	{ 0xF0A997AC, 0x4D9FB },
	{ 0xF0A997AD, 0x5DFFC },
	{ 0xF0A997AE, 0x7BDF0 },
	{ 0xF0A997AF, 0x4DAA4 },
	{ 0xF0A997B0, 0x5E6B2 },
	{ 0xF0A997B1, 0x5E0A2 },
	{ 0xF0A997B2, 0x4DAA3 },
	{ 0xF0A997B3, 0x5DFFE },
	{ 0xF0A997B4, 0x5E0A1 },
	{ 0xF0A997B5, 0x5E0A4 },
	{ 0xF0A997B6, 0x5DFFD },
	{ 0xF0A997B7, 0x5E0A3 },
	{ 0xF0A997B8, 0x7BDEE },
	{ 0xF0A997BA, 0xFDDE4 },
	{ 0xF0A997BB, 0xFDDE5 },
	{ 0xF0A99881, 0x7BDF2 },
	{ 0xF0A99883, 0x7BDEF },
	{ 0xF0A99885, 0x4DED3 },
	{ 0xF0A99886, 0x7C5A2 },
	{ 0xF0A99887, 0x7C5A4 },
	{ 0xF0A99888, 0x5E6B7 },
	{ 0xF0A99889, 0x7C5A6 },
	{ 0xF0A9988A, 0x5E6B4 },
	{ 0xF0A9988B, 0x5E6B8 },
	{ 0xF0A9988C, 0x4DED4 },
	{ 0xF0A9988D, 0x5E6BA },
	{ 0xF0A9988E, 0x4E2B1 },
	{ 0xF0A9988F, 0x5E6B5 },
	{ 0xF0A99890, 0x7C5A5 },
	{ 0xF0A99891, 0x5E6B6 },
	{ 0xF0A99892, 0x5E6B9 },
	{ 0xF0A99893, 0x5E6B3 },
	{ 0xF0A99894, 0xFE1D9 },
	{ 0xF0A99895, 0x7C5A8 },
	{ 0xF0A99896, 0x7C5A3 },
	{ 0xF0A99897, 0x7C5A1 },
	{ 0xF0A99899, 0x7C5A7 },
	{ 0xF0A9989A, 0x7C4FD },
	{ 0xF0A9989C, 0x5EADF },
	{ 0xF0A9989D, 0x4E2B3 },
	{ 0xF0A9989E, 0x4E2B4 },
	{ 0xF0A9989F, 0x4E2B5 },
	{ 0xF0A998A0, 0x5EAE0 },
	{ 0xF0A998A1, 0x7CBF9 },
	{ 0xF0A998A2, 0xFE4D6 },
	{ 0xF0A998A3, 0xFE4D7 },
	{ 0xF0A998A4, 0x7CBF8 },
	{ 0xF0A998A5, 0x7CBFA },
	{ 0xF0A998A6, 0x7CBFB },
	{ 0xF0A998A7, 0x7CBFC },
	{ 0xF0A998AD, 0x5EEDE },
	{ 0xF0A998AE, 0x5EEE1 },
	{ 0xF0A998AF, 0x5EEE0 },
	{ 0xF0A998B0, 0x4E5B5 },
	{ 0xF0A998B1, 0x5EEDC },
	{ 0xF0A998B2, 0x4E5B7 },
	{ 0xF0A998B3, 0x5EEDF },
	{ 0xF0A998B4, 0xFE6FB },
	{ 0xF0A998B5, 0x5EEE2 },
	{ 0xF0A998B6, 0x5EEDD },
	{ 0xF0A998B7, 0x4E5B8 },
	{ 0xF0A998B8, 0x7D6C0 },
	{ 0xF0A998B9, 0x4E7FD },
	{ 0xF0A998BA, 0x4E8A1 },
	{ 0xF0A998BB, 0x5F1FB },
	{ 0xF0A998BC, 0x7D6B9 },
	{ 0xF0A998BD, 0x5F1FC },
	{ 0xF0A998BE, 0x7D6BC },
	{ 0xF0A998BF, 0x7D6BA },
	{ 0xF0A99980, 0xFE8FD },
	{ 0xF0A99981, 0x7D6BF },
	{ 0xF0A99982, 0x7D6C1 },
	{ 0xF0A99983, 0x7D6C2 },
	{ 0xF0A99984, 0x7D6BD },
	{ 0xF0A99985, 0x7D6BE },
	{ 0xF0A99986, 0x7D6BB },
	{ 0xF0A99988, 0x7DAB2 },
	{ 0xF0A99989, 0xFEAB5 },
	{ 0xF0A9998A, 0x7DAB3 },
	{ 0xF0A9998E, 0x7DDD3 },
	{ 0xF0A99991, 0x5F8C9 },
	{ 0xF0A99992, 0x4ECBB },
	{ 0xF0A99993, 0x7E0A6 },
	{ 0xF0A99994, 0x7E0A7 },
	{ 0xF0A99996, 0x5F9DB },
	{ 0xF0A99997, 0x7E1E1 },
	{ 0xF0A99999, 0x5F9DC },
	{ 0xF0A9999A, 0x4EDAF },
	{ 0xF0A9999B, 0x4EDE6 },
	{ 0xF0A9999C, 0x5FACA },
	{ 0xF0A9999D, 0x5FBA4 },
	{ 0xF0A9999E, 0x7E4A6 },
	{ 0xF0A9999F, 0xFEDA4 },
	{ 0xF0A999A1, 0x5FCC7 },
	{ 0xF0A999A4, 0x7E6D5 },
	{ 0xF0A999B1, 0x6BCF5 },
	{ 0xF0A999B2, 0x5C0B9 },
	{ 0xF0A999B4, 0x7ABB6 },
	{ 0xF0A999B6, 0x7CBFD },
	{ 0xF0A999B7, 0x5EAE1 },
	{ 0xF0A999BA, 0x7D6C3 },
	{ 0xF0A999BC, 0x4E9E4 },
	{ 0xF0A999BD, 0x5F4ED },
	{ 0xF0A99A80, 0x6B4FC },
	{ 0xF0A99A81, 0x6B4FD },
	{ 0xF0A99A82, 0x6B5A2 },
	{ 0xF0A99A83, 0x6B4FE },
	{ 0xF0A99A84, 0x5B0F1 },
	{ 0xF0A99A85, 0x6BCF6 },
	{ 0xF0A99A86, 0x6BCF8 },
	{ 0xF0A99A87, 0x5BDCC },
	{ 0xF0A99A88, 0x5B6CA },
	{ 0xF0A99A89, 0x5B6C7 },
	{ 0xF0A99A8A, 0x6C6BA },
	{ 0xF0A99A8B, 0x6C6B8 },
	{ 0xF0A99A8C, 0x5B6C9 },
	{ 0xF0A99A8D, 0x6C6B9 },
	{ 0xF0A99A8E, 0x6C6BB },
	{ 0xF0A99A8F, 0x6D0C0 },
	{ 0xF0A99A92, 0x5B6C8 },
	{ 0xF0A99A93, 0x6D0C1 },
	{ 0xF0A99A95, 0x6D0C6 },
	{ 0xF0A99A96, 0x4BCA2 },
	{ 0xF0A99A97, 0x5BDCD },
	{ 0xF0A99A98, 0x6D0C4 },
	{ 0xF0A99A99, 0x6D0C5 },
	{ 0xF0A99A9A, 0x4BCA6 },
	{ 0xF0A99A9B, 0x5BDCE },
	{ 0xF0A99A9C, 0x6DAB8 },
	{ 0xF0A99A9D, 0x5BDCF },
	{ 0xF0A99A9E, 0x6D0C2 },
	{ 0xF0A99AA0, 0xFC0AF },
	{ 0xF0A99AA3, 0x6D0C3 },
	{ 0xF0A99AA4, 0x4BCA3 },
	{ 0xF0A99AA8, 0x6DAC2 },
	{ 0xF0A99AA9, 0x6DAB9 },
	{ 0xF0A99AAA, 0x5C4C2 },
	{ 0xF0A99AAB, 0x5C4C4 },
	{ 0xF0A99AAC, 0x5C4C1 },
	{ 0xF0A99AAD, 0x5C4C7 },
	{ 0xF0A99AAE, 0x4C1F6 },
	{ 0xF0A99AAF, 0x5C4C3 },
	{ 0xF0A99AB0, 0x6E4C3 },
	{ 0xF0A99AB1, 0x5C4C5 },
	{ 0xF0A99AB2, 0x6DABC },
	{ 0xF0A99AB3, 0x6DABB },
	{ 0xF0A99AB4, 0x6E4BD },
	{ 0xF0A99AB5, 0x4C1F3 },
	{ 0xF0A99AB6, 0x6DABA },
	{ 0xF0A99AB7, 0x6E4BE },
	{ 0xF0A99AB8, 0x6DABE },
	{ 0xF0A99AB9, 0x5C4C8 },
	{ 0xF0A99ABA, 0x6DAC1 },
	{ 0xF0A99ABB, 0x5D2E3 },
	{ 0xF0A99ABD, 0xFC6B7 },
	{ 0xF0A99ABF, 0x6DAC0 },
	{ 0xF0A99B80, 0x6DABF },
	{ 0xF0A99B81, 0x6E4BC },
	{ 0xF0A99B85, 0x4C1F8 },
	{ 0xF0A99B86, 0x5C4C6 },
	{ 0xF0A99B88, 0x6E4BF },
	{ 0xF0A99B89, 0x7ABB7 },
	{ 0xF0A99B8A, 0x6E4C4 },
	{ 0xF0A99B8B, 0x5CBCD },
	{ 0xF0A99B8C, 0x5CBC9 },
	{ 0xF0A99B8D, 0x6E4C5 },
	{ 0xF0A99B8E, 0x5CBCA },
	{ 0xF0A99B8F, 0x4C8DA },
	{ 0xF0A99B90, 0x6E4C2 },
	{ 0xF0A99B91, 0x5CBCB },
	{ 0xF0A99B92, 0x7ABB9 },
	{ 0xF0A99B93, 0x6E4C1 },
	{ 0xF0A99B96, 0xFC6B6 },
	{ 0xF0A99B97, 0xFD3A8 },
	{ 0xF0A99B9B, 0x7ABBA },
	{ 0xF0A99B9D, 0x4CEEB },
	{ 0xF0A99B9E, 0x7ABC0 },
	{ 0xF0A99B9F, 0x4CEEA },
	{ 0xF0A99BA0, 0x5D2E9 },
	{ 0xF0A99BA1, 0x5D2E4 },
	{ 0xF0A99BA2, 0x5D9F9 },
	{ 0xF0A99BA3, 0x4CEE8 },
	{ 0xF0A99BA4, 0x5D2E6 },
	{ 0xF0A99BA5, 0x5D2EB },
	{ 0xF0A99BA6, 0x5D2E8 },
	{ 0xF0A99BA7, 0x4CEEC },
	{ 0xF0A99BA8, 0x5D2EA },
	{ 0xF0A99BA9, 0x7ABBC },
	{ 0xF0A99BAA, 0x5D2E5 },
	{ 0xF0A99BAB, 0x7ABBB },
	{ 0xF0A99BAC, 0x7BDF3 },
	{ 0xF0A99BAD, 0x5D2E7 },
	{ 0xF0A99BAE, 0x7ABBE },
	{ 0xF0A99BAF, 0x7ABBD },
	{ 0xF0A99BB1, 0xFD3A7 },
	{ 0xF0A99BB3, 0x5D9F8 },
	{ 0xF0A99BB9, 0x7ABBF },
	{ 0xF0A99BBA, 0x5DAA3 },
	{ 0xF0A99BBB, 0x4DAA6 },
	{ 0xF0A99BBC, 0x5DAA4 },
	{ 0xF0A99BBD, 0x4D4FB },
	{ 0xF0A99BBE, 0x7B5E6 },
	{ 0xF0A99BBF, 0x7B5EA },
	{ 0xF0A99C80, 0x5E0A7 },
	{ 0xF0A99C81, 0x5D9FB },
	{ 0xF0A99C82, 0x7B5E9 },
	{ 0xF0A99C83, 0x5D9FE },
	{ 0xF0A99C84, 0x7B5E7 },
	{ 0xF0A99C85, 0x5D9FC },
	{ 0xF0A99C86, 0x7B5EF },
	{ 0xF0A99C87, 0x4D4F9 },
	{ 0xF0A99C88, 0x7B5EB },
	{ 0xF0A99C89, 0x7B5F0 },
	{ 0xF0A99C8A, 0x5DAA5 },
	{ 0xF0A99C8B, 0x7B5E8 },
	{ 0xF0A99C8C, 0x7B5E3 },
	{ 0xF0A99C8D, 0x5D9FA },
	{ 0xF0A99C8E, 0x7B5E5 },
	{ 0xF0A99C8F, 0x7B5E4 },
	{ 0xF0A99C90, 0x7B5EC },
	{ 0xF0A99C92, 0x5E0A9 },
	{ 0xF0A99C93, 0x7B5EE },
	{ 0xF0A99C94, 0x7BDF5 },
	{ 0xF0A99C95, 0x7B5E2 },
	{ 0xF0A99C96, 0x5DAA2 },
	{ 0xF0A99C97, 0x7B5ED },
	{ 0xF0A99C9A, 0x5D9FD },
	{ 0xF0A99C9B, 0xFD9A6 },
	{ 0xF0A99C9C, 0xFD9A7 },
	{ 0xF0A99C9D, 0xFD9A8 },
	{ 0xF0A99C9E, 0xFD9A9 },
	{ 0xF0A99C9F, 0x5DAA1 },
	{ 0xF0A99CA2, 0x7BDF4 },
	{ 0xF0A99CAC, 0x5E0A8 },
	{ 0xF0A99CAD, 0x5E0B4 },
	{ 0xF0A99CAF, 0x7BDF7 },
	{ 0xF0A99CB0, 0x5E0AD },
	{ 0xF0A99CB1, 0x5E0AF },
	{ 0xF0A99CB2, 0x5E0B3 },
	{ 0xF0A99CB3, 0x5E0AB },
	{ 0xF0A99CB4, 0x7BDF6 },
	{ 0xF0A99CB5, 0x5E0B2 },
	{ 0xF0A99CB6, 0x5E0B5 },
	{ 0xF0A99CB7, 0x4DAAB },
	{ 0xF0A99CB8, 0x5E0B6 },
	{ 0xF0A99CB9, 0x7BDF8 },
	{ 0xF0A99CBA, 0x7BDFD },
	{ 0xF0A99CBB, 0x7C5AA },
	{ 0xF0A99CBC, 0x7BDFA },
	{ 0xF0A99CBD, 0x5E0AA },
	{ 0xF0A99CBE, 0x7C5AB },
	{ 0xF0A99CBF, 0x7BEA1 },
	{ 0xF0A99D80, 0x5E0AE },
	{ 0xF0A99D81, 0x7BDF9 },
	{ 0xF0A99D82, 0x7BDFE },
	{ 0xF0A99D85, 0xFDDE6 },
	{ 0xF0A99D86, 0xFDDE7 },
	{ 0xF0A99D89, 0x7BDFB },
	{ 0xF0A99D97, 0x5E0B0 },
	{ 0xF0A99D98, 0x7BDFC },
	{ 0xF0A99D99, 0x7C5AF },
	{ 0xF0A99D9A, 0x5E6BF },
	{ 0xF0A99D9B, 0x5E6BB },
	{ 0xF0A99D9D, 0x4DED6 },
	{ 0xF0A99D9E, 0x4DEDC },
	{ 0xF0A99D9F, 0x5E0B8 },
	{ 0xF0A99DA0, 0x4DEDD },
	{ 0xF0A99DA1, 0x5E6BD },
	{ 0xF0A99DA2, 0x5E0B7 },
	{ 0xF0A99DA3, 0x5E6BC },
	{ 0xF0A99DA4, 0x7C5AE },
	{ 0xF0A99DA5, 0x7C5AD },
	{ 0xF0A99DA6, 0x7CBFE },
	{ 0xF0A99DA7, 0x4DEDE },
	{ 0xF0A99DA8, 0x5E6BE },
	{ 0xF0A99DA9, 0x7CCA2 },
	{ 0xF0A99DAB, 0x7D1D4 },
	{ 0xF0A99DAC, 0x7C5AC },
	{ 0xF0A99DAE, 0x7C5A9 },
	{ 0xF0A99DB0, 0x7C5B1 },
	{ 0xF0A99DB1, 0xFE1DA },
	{ 0xF0A99DB2, 0xFE1DB },
	{ 0xF0A99DB4, 0x7CCA5 },
	{ 0xF0A99DB5, 0x7CCA1 },
	{ 0xF0A99DB8, 0x4DED5 },
	{ 0xF0A99DB9, 0x7C5B2 },
	{ 0xF0A99DBC, 0x7C5B0 },
	{ 0xF0A99DBD, 0x5EAE4 },
	{ 0xF0A99DBE, 0x7CCA3 },
	{ 0xF0A99DBF, 0x5EAE2 },
	{ 0xF0A99E80, 0x4E2BB },
	{ 0xF0A99E81, 0x4E5BD },
	{ 0xF0A99E82, 0x7D1D3 },
	{ 0xF0A99E83, 0x5EAE9 },
	{ 0xF0A99E84, 0x5EAE6 },
	{ 0xF0A99E85, 0x5EAE8 },
	{ 0xF0A99E86, 0x5EAEA },
	{ 0xF0A99E87, 0x7D1D1 },
	{ 0xF0A99E88, 0x4E2B7 },
	{ 0xF0A99E89, 0x5EAE7 },
	{ 0xF0A99E8A, 0x5E0B9 },
	{ 0xF0A99E8B, 0x5EAE3 },
	{ 0xF0A99E8C, 0x7D1D2 },
	{ 0xF0A99E8D, 0x4E2B9 },
	{ 0xF0A99E8E, 0x7D1D8 },
	{ 0xF0A99E8F, 0x7CCA4 },
	{ 0xF0A99E90, 0x7D1D7 },
	{ 0xF0A99E91, 0x4E2BA },
	{ 0xF0A99E96, 0xFE4D8 },
	{ 0xF0A99E97, 0xFE4D9 },
	{ 0xF0A99E99, 0x5EAE5 },
	{ 0xF0A99E9A, 0x7D1D6 },
	{ 0xF0A99E9E, 0x5EAEB },
	{ 0xF0A99E9F, 0x4E5BE },
	{ 0xF0A99EA0, 0x7D1D5 },
	{ 0xF0A99EA1, 0x7D1D9 },
	{ 0xF0A99EA2, 0x7D1DF },
	{ 0xF0A99EA3, 0x7D6C4 },
	{ 0xF0A99EA4, 0x5F1FD },
	{ 0xF0A99EA5, 0x7D1E0 },
	{ 0xF0A99EA6, 0x5EEE5 },
	{ 0xF0A99EA7, 0x4E5BF },
	{ 0xF0A99EA8, 0x5F1FE },
	{ 0xF0A99EA9, 0x5EEE4 },
	{ 0xF0A99EAA, 0x7D1DE },
	{ 0xF0A99EAB, 0x7D1E2 },
	{ 0xF0A99EAC, 0x5EEE3 },
	{ 0xF0A99EAD, 0x7CCA7 },
	{ 0xF0A99EAE, 0x7D1E1 },
	{ 0xF0A99EB2, 0x7D1DB },
	{ 0xF0A99EB5, 0x7D1DC },
	{ 0xF0A99EB7, 0x7D1DD },
	{ 0xF0A99EBA, 0x7D6C5 },
	{ 0xF0A99EBC, 0x7D1E3 },
	{ 0xF0A99EBD, 0x7D1DA },
	{ 0xF0A99EBE, 0x5F2A8 },
	{ 0xF0A99EBF, 0x5F2A2 },
	{ 0xF0A99F80, 0x7D6C6 },
	{ 0xF0A99F81, 0x4E8A5 },
	{ 0xF0A99F82, 0x5F2A4 },
	{ 0xF0A99F83, 0x5F2A1 },
	{ 0xF0A99F84, 0x7D6C7 },
	{ 0xF0A99F85, 0x5F2AB },
	{ 0xF0A99F86, 0x7D6C8 },
	{ 0xF0A99F87, 0x5F2AA },
	{ 0xF0A99F88, 0x5F2A3 },
	{ 0xF0A99F89, 0x5F2A7 },
	{ 0xF0A99F8A, 0x5F2A5 },
	{ 0xF0A99F8B, 0x7D6C9 },
	{ 0xF0A99F8C, 0x5F2A6 },
	{ 0xF0A99F8D, 0x5F2A9 },
	{ 0xF0A99F8F, 0xFE8FE },
	{ 0xF0A99F93, 0x4E9E6 },
	{ 0xF0A99F94, 0x5F4EE },
	{ 0xF0A99F95, 0x5F4EF },
	{ 0xF0A99F96, 0x7DAB7 },
	{ 0xF0A99F97, 0x7DDD4 },
	{ 0xF0A99F98, 0x7DAB6 },
	{ 0xF0A99F99, 0x5F4F0 },
	{ 0xF0A99F9B, 0x7DAB5 },
	{ 0xF0A99F9D, 0xFEAB7 },
	{ 0xF0A99FA3, 0x7DAB4 },
	{ 0xF0A99FA4, 0x5F6EE },
	{ 0xF0A99FA5, 0x7DDD6 },
	{ 0xF0A99FA6, 0x5F6EF },
	{ 0xF0A99FA7, 0x5F6F0 },
	{ 0xF0A99FA8, 0x5F8CA },
	{ 0xF0A99FAA, 0x7DDD5 },
	{ 0xF0A99FAD, 0x5F8CB },
	{ 0xF0A99FAE, 0x5F8CC },
	{ 0xF0A99FAF, 0x4ECBC },
	{ 0xF0A99FB0, 0x7E0A8 },
	{ 0xF0A99FB1, 0x7E0AA },
	{ 0xF0A99FB4, 0x7E0A9 },
	{ 0xF0A99FB6, 0x5F9DD },
	{ 0xF0A99FB7, 0x7E4A7 },
	{ 0xF0A99FB8, 0x5FBA5 },
	{ 0xF0A9A090, 0x6BCF9 },
	{ 0xF0A9A091, 0x6C6BC },
	{ 0xF0A9A095, 0x6E4C6 },
	{ 0xF0A9A096, 0x7ABC1 },
	{ 0xF0A9A097, 0x6E4C8 },
	{ 0xF0A9A099, 0x6E4C7 },
	{ 0xF0A9A09A, 0x5D2EC },
	{ 0xF0A9A09B, 0x4D5A4 },
	{ 0xF0A9A09C, 0x4D5A5 },
	{ 0xF0A9A0A2, 0x7BEA2 },
	{ 0xF0A9A0A3, 0x7BEA3 },
	{ 0xF0A9A0A4, 0x7B5F1 },
	{ 0xF0A9A0A5, 0x7B5F3 },
	{ 0xF0A9A0A6, 0x7B5F2 },
	{ 0xF0A9A0AA, 0x7CCA9 },
	{ 0xF0A9A0AB, 0x7CCA8 },
	{ 0xF0A9A0AC, 0x7C5B3 },
	{ 0xF0A9A0B0, 0x7CDF3 },
	{ 0xF0A9A0B2, 0x7D1E4 },
	{ 0xF0A9A0B7, 0x7E0AB },
	{ 0xF0A9A0B9, 0x4EEA6 },
	{ 0xF0A9A0BA, 0xFB2F1 },
	{ 0xF0A9A0BB, 0x4C1FC },
	{ 0xF0A9A0BC, 0x6DAC3 },
	{ 0xF0A9A0BE, 0x5C7D4 },
	{ 0xF0A9A0BF, 0x6E4C9 },
	{ 0xF0A9A180, 0x6E4CA },
	{ 0xF0A9A181, 0xFCDC1 },
	{ 0xF0A9A182, 0xFD3A9 },
	{ 0xF0A9A184, 0x6E4CB },
	{ 0xF0A9A185, 0x7ABC2 },
	{ 0xF0A9A186, 0xFD3AA },
	{ 0xF0A9A187, 0xFD9AA },
	{ 0xF0A9A188, 0x7B5F4 },
	{ 0xF0A9A189, 0xFDDE8 },
	{ 0xF0A9A18A, 0x7BEA4 },
	{ 0xF0A9A18C, 0x7C5B6 },
	{ 0xF0A9A18D, 0x5E6C1 },
	{ 0xF0A9A18E, 0x5E6C0 },
	{ 0xF0A9A190, 0x5E6C2 },
	{ 0xF0A9A191, 0x7C5B5 },
	{ 0xF0A9A192, 0x7C5B4 },
	{ 0xF0A9A193, 0x5EAEC },
	{ 0xF0A9A194, 0x4E2BD },
	{ 0xF0A9A195, 0x4E2BE },
	{ 0xF0A9A198, 0x7CCAA },
	{ 0xF0A9A19A, 0x7D1E5 },
	{ 0xF0A9A19B, 0xFE6FC },
	{ 0xF0A9A19D, 0x5F2AC },
	{ 0xF0A9A19E, 0xFE9A1 },
	{ 0xF0A9A1A1, 0x7D6CA },
	{ 0xF0A9A1A4, 0x7DDD7 },
	{ 0xF0A9A1A5, 0x5FACB },
	{ 0xF0A9A1A7, 0x5B6CB },
	{ 0xF0A9A1A8, 0x5B6CC },
	{ 0xF0A9A1A9, 0x5BDD0 },
	{ 0xF0A9A1AA, 0x6D0C8 },
	{ 0xF0A9A1AD, 0xFC0B1 },
	{ 0xF0A9A1AE, 0x6D0C7 },
	{ 0xF0A9A1B0, 0x5C4C9 },
	{ 0xF0A9A1B1, 0x6DAC5 },
	{ 0xF0A9A1B2, 0x6DAC4 },
	{ 0xF0A9A1B3, 0x6DAC7 },
	{ 0xF0A9A1B5, 0x6DAC6 },
	{ 0xF0A9A1B7, 0x5CBD1 },
	{ 0xF0A9A1B8, 0x6E4CD },
	{ 0xF0A9A1B9, 0x6E4CE },
	{ 0xF0A9A1BA, 0x5CBD0 },
	{ 0xF0A9A1BB, 0x4C8E1 },
	{ 0xF0A9A1BC, 0x6E4CC },
	{ 0xF0A9A1BD, 0x6E4D2 },
	{ 0xF0A9A1BE, 0x5CBCF },
	{ 0xF0A9A1BF, 0x7ABC3 },
	{ 0xF0A9A281, 0xFCDC2 },
	{ 0xF0A9A282, 0xFCDC3 },
	{ 0xF0A9A283, 0xFCDC4 },
	{ 0xF0A9A284, 0xFCDC5 },
	{ 0xF0A9A286, 0x7ABC6 },
	{ 0xF0A9A288, 0x6E4CF },
	{ 0xF0A9A289, 0x6E4D1 },
	{ 0xF0A9A28C, 0x5CBD2 },
	{ 0xF0A9A28D, 0x7ABCA },
	{ 0xF0A9A28E, 0x5D2F2 },
	{ 0xF0A9A28F, 0x7ABCE },
	{ 0xF0A9A290, 0x7ABC7 },
	{ 0xF0A9A291, 0x5DAB2 },
	{ 0xF0A9A292, 0x5D2F4 },
	{ 0xF0A9A293, 0x5D2F7 },
	{ 0xF0A9A294, 0x5D2ED },
	{ 0xF0A9A295, 0x5D2F0 },
	{ 0xF0A9A296, 0x5D2EE },
	{ 0xF0A9A297, 0x5D2F5 },
	{ 0xF0A9A298, 0x7ABC4 },
	{ 0xF0A9A299, 0x5D2F6 },
	{ 0xF0A9A29A, 0x7ABC8 },
	{ 0xF0A9A29B, 0x5D2F3 },
	{ 0xF0A9A29C, 0x7ABCB },
	{ 0xF0A9A29D, 0x7ABC9 },
	{ 0xF0A9A29E, 0x5D2EF },
	{ 0xF0A9A29F, 0x7ABC5 },
	{ 0xF0A9A2A0, 0x7ABCC },
	{ 0xF0A9A2A1, 0x5D2F1 },
	{ 0xF0A9A2A3, 0xFD3AB },
	{ 0xF0A9A2A5, 0xFD3AC },
	{ 0xF0A9A2A6, 0xFD3AD },
	{ 0xF0A9A2A7, 0x7ABCD },
	{ 0xF0A9A2AD, 0x7B5FA },
	{ 0xF0A9A2AE, 0x4D5AC },
	{ 0xF0A9A2AF, 0x7B5F9 },
	{ 0xF0A9A2B0, 0x5DAAF },
	{ 0xF0A9A2B1, 0x4D5AA },
	{ 0xF0A9A2B2, 0x4D5A7 },
	{ 0xF0A9A2B3, 0x4D5AB },
	{ 0xF0A9A2B4, 0x4D5A8 },
	{ 0xF0A9A2B5, 0x7B5F5 },
	{ 0xF0A9A2B6, 0x5DAA9 },
	{ 0xF0A9A2B7, 0x4D5A9 },
	{ 0xF0A9A2B8, 0x5DAB0 },
	{ 0xF0A9A2B9, 0x5DAAD },
	{ 0xF0A9A2BA, 0x7B6A4 },
	{ 0xF0A9A2BB, 0x5DAB3 },
	{ 0xF0A9A2BC, 0x5DAA7 },
	{ 0xF0A9A2BD, 0x5DAB1 },
	{ 0xF0A9A2BE, 0x5DAB4 },
	{ 0xF0A9A2BF, 0x5DAAB },
	{ 0xF0A9A380, 0x7B5FC },
	{ 0xF0A9A381, 0x7B5FB },
	{ 0xF0A9A382, 0x7B6A6 },
	{ 0xF0A9A383, 0x7B6A1 },
	{ 0xF0A9A384, 0x7B5F8 },
	{ 0xF0A9A385, 0x7B6A3 },
	{ 0xF0A9A387, 0x5DAAA },
	{ 0xF0A9A388, 0x7B6A2 },
	{ 0xF0A9A389, 0xFD9AC },
	{ 0xF0A9A38A, 0x5DAA8 },
	{ 0xF0A9A38C, 0x7B5FD },
	{ 0xF0A9A38D, 0x7B5FE },
	{ 0xF0A9A38E, 0x7B6A7 },
	{ 0xF0A9A390, 0x7B6A5 },
	{ 0xF0A9A391, 0xFD9AB },
	{ 0xF0A9A392, 0x7B5F6 },
	{ 0xF0A9A395, 0x7B5F7 },
	{ 0xF0A9A396, 0x5E0BA },
	{ 0xF0A9A397, 0x7BEAC },
	{ 0xF0A9A398, 0x5E0BB },
	{ 0xF0A9A399, 0x7BEA6 },
	{ 0xF0A9A39A, 0x4DAAF },
	{ 0xF0A9A39B, 0x7BEA7 },
	{ 0xF0A9A39C, 0x7BEA5 },
	{ 0xF0A9A39D, 0x5E0BC },
	{ 0xF0A9A39E, 0x4DAAC },
	{ 0xF0A9A39F, 0x7BEAA },
	{ 0xF0A9A3A0, 0x7BEAB },
	{ 0xF0A9A3A1, 0x5CBD3 },
	{ 0xF0A9A3A2, 0x7BEA8 },
	{ 0xF0A9A3A3, 0x5E0BE },
	{ 0xF0A9A3A4, 0x5E0BD },
	{ 0xF0A9A3A7, 0xFDDE9 },
	{ 0xF0A9A3A8, 0xFDDEA },
	{ 0xF0A9A3AD, 0x7C5BC },
	{ 0xF0A9A3AE, 0x5E6CC },
	{ 0xF0A9A3AF, 0x5E6CB },
	{ 0xF0A9A3B0, 0x5E6C7 },
	{ 0xF0A9A3B1, 0x4DEE4 },
	{ 0xF0A9A3B2, 0x5E6C9 },
	{ 0xF0A9A3B3, 0x5E6C8 },
	{ 0xF0A9A3B4, 0x4DEE1 },
	{ 0xF0A9A3B5, 0x5E6C5 },
	{ 0xF0A9A3B6, 0x5E6CE },
	{ 0xF0A9A3B7, 0x4DEED },
	{ 0xF0A9A3B8, 0x4DEE9 },
	{ 0xF0A9A3B9, 0x4DEEA },
	{ 0xF0A9A3BA, 0x4DEE6 },
	{ 0xF0A9A3BB, 0x5E6CF },
	{ 0xF0A9A3BC, 0x5E6C3 },
	{ 0xF0A9A3BD, 0x4DEEC },
	{ 0xF0A9A3BE, 0x7C5BB },
	{ 0xF0A9A3BF, 0x7C5BA },
	{ 0xF0A9A480, 0x7C5B7 },
	{ 0xF0A9A481, 0x5E6CA },
	{ 0xF0A9A484, 0xFE1DD },
	{ 0xF0A9A486, 0xFE1DE },
	{ 0xF0A9A487, 0xFE1E0 },
	{ 0xF0A9A489, 0x4DEEB },
	{ 0xF0A9A48F, 0xFE1DC },
	{ 0xF0A9A490, 0x7C5B8 },
	{ 0xF0A9A492, 0x5E6C4 },
	{ 0xF0A9A493, 0x7C5B9 },
	{ 0xF0A9A496, 0x5E6CD },
	{ 0xF0A9A497, 0x5EAED },
	{ 0xF0A9A498, 0x5EAF3 },
	{ 0xF0A9A499, 0x5EAEF },
	{ 0xF0A9A49A, 0x4E2C3 },
	{ 0xF0A9A49B, 0x7CCB1 },
	{ 0xF0A9A49C, 0x5E6D0 },
	{ 0xF0A9A49D, 0x7CCAC },
	{ 0xF0A9A49E, 0x5E6C6 },
	{ 0xF0A9A49F, 0x5EAF1 },
	{ 0xF0A9A4A0, 0x5EAF0 },
	{ 0xF0A9A4A1, 0x5EAF4 },
	{ 0xF0A9A4A2, 0x7CCAB },
	{ 0xF0A9A4A3, 0x5EAF2 },
	{ 0xF0A9A4A4, 0x5EAF6 },
	{ 0xF0A9A4A5, 0x4E2C2 },
	{ 0xF0A9A4A6, 0x5EAF7 },
	{ 0xF0A9A4A7, 0x7CCB2 },
	{ 0xF0A9A4A8, 0x7CCB4 },
	{ 0xF0A9A4A9, 0x5EAF5 },
	{ 0xF0A9A4AA, 0x7CCB3 },
	{ 0xF0A9A4AB, 0x7CCAD },
	{ 0xF0A9A4AC, 0x7CCAE },
	{ 0xF0A9A4AD, 0x7CCAF },
	{ 0xF0A9A4AE, 0xFE4DB },
	{ 0xF0A9A4B0, 0xFE4DC },
	{ 0xF0A9A4B1, 0xFE4DD },
	{ 0xF0A9A4B3, 0x7CCB0 },
	{ 0xF0A9A4B7, 0x3D7B6 },
	{ 0xF0A9A4BB, 0x7CCB5 },
	{ 0xF0A9A4BD, 0x4E5C5 },
	{ 0xF0A9A4BE, 0x7D1EA },
	{ 0xF0A9A4BF, 0x7D1E9 },
	{ 0xF0A9A580, 0x5EEEE },
	{ 0xF0A9A581, 0x5EEE9 },
	{ 0xF0A9A582, 0x5EEEB },
	{ 0xF0A9A583, 0x5EEE8 },
	{ 0xF0A9A584, 0x4E5C2 },
	{ 0xF0A9A585, 0x5EEF0 },
	{ 0xF0A9A586, 0xFE6FD },
	{ 0xF0A9A587, 0x4E5C3 },
	{ 0xF0A9A588, 0x4E5C4 },
	{ 0xF0A9A589, 0x4E5C8 },
	{ 0xF0A9A58A, 0x5EEF1 },
	{ 0xF0A9A58B, 0x5EEF2 },
	{ 0xF0A9A58C, 0x5EEE7 },
	{ 0xF0A9A58D, 0x7D1E8 },
	{ 0xF0A9A58E, 0x4E8A6 },
	{ 0xF0A9A58F, 0x5EEEA },
	{ 0xF0A9A590, 0x5EEEF },
	{ 0xF0A9A591, 0x5EEEC },
	{ 0xF0A9A592, 0x7D1EB },
	{ 0xF0A9A593, 0x7D1EF },
	{ 0xF0A9A594, 0x7D1F0 },
	{ 0xF0A9A596, 0x7D1F1 },
	{ 0xF0A9A597, 0x7D1ED },
	{ 0xF0A9A598, 0x7D1EC },
	{ 0xF0A9A59A, 0xFE6FE },
	{ 0xF0A9A59B, 0xFE7A1 },
	{ 0xF0A9A59C, 0x7D1E7 },
	{ 0xF0A9A59E, 0x7D1EE },
	{ 0xF0A9A5A2, 0x7D2A7 },
	{ 0xF0A9A5A4, 0x7D1E6 },
	{ 0xF0A9A5AB, 0x5F2AF },
	{ 0xF0A9A5AC, 0x5F2AE },
	{ 0xF0A9A5AD, 0x5F2B1 },
	{ 0xF0A9A5AE, 0x4E8A7 },
	{ 0xF0A9A5AF, 0x5F2B2 },
	{ 0xF0A9A5B0, 0x5F2B0 },
	{ 0xF0A9A5B1, 0x4E8AC },
	{ 0xF0A9A5B2, 0x7D6CD },
	{ 0xF0A9A5B3, 0x7D6CC },
	{ 0xF0A9A5B4, 0x7D6CE },
	{ 0xF0A9A5BA, 0x7D6CB },
	{ 0xF0A9A5BB, 0xFE9A2 },
	{ 0xF0A9A680, 0x7D6CF },
	{ 0xF0A9A681, 0x7D6D0 },
	{ 0xF0A9A682, 0x5F4F8 },
	{ 0xF0A9A683, 0x7DABD },
	{ 0xF0A9A684, 0x5F2B4 },
	{ 0xF0A9A685, 0x7DAC1 },
	{ 0xF0A9A686, 0x7DAB8 },
	{ 0xF0A9A687, 0x5F4F1 },
	{ 0xF0A9A688, 0x7DABB },
	{ 0xF0A9A689, 0x5F2B3 },
	{ 0xF0A9A68A, 0x5F4F4 },
	{ 0xF0A9A68B, 0x5F4F7 },
	{ 0xF0A9A68C, 0x5F4F3 },
	{ 0xF0A9A68D, 0x7DAC0 },
	{ 0xF0A9A68E, 0x4E9EC },
	{ 0xF0A9A68F, 0x5F4F5 },
	{ 0xF0A9A690, 0x7DAB9 },
	{ 0xF0A9A691, 0x7DABA },
	{ 0xF0A9A694, 0x7DABC },
	{ 0xF0A9A695, 0xFEAB8 },
	{ 0xF0A9A696, 0xFEAB9 },
	{ 0xF0A9A697, 0xFEABA },
	{ 0xF0A9A699, 0x5F4F2 },
	{ 0xF0A9A69B, 0x5F4F9 },
	{ 0xF0A9A69C, 0x7DABF },
	{ 0xF0A9A69E, 0x7DDDF },
	{ 0xF0A9A69F, 0x7DDDD },
	{ 0xF0A9A6A0, 0x5F6F1 },
	{ 0xF0A9A6A1, 0x5F8CE },
	{ 0xF0A9A6A2, 0x7DDDC },
	{ 0xF0A9A6A3, 0x7DDD9 },
	{ 0xF0A9A6A4, 0x5F6F2 },
	{ 0xF0A9A6A5, 0x7DDDA },
	{ 0xF0A9A6A6, 0x7DDDE },
	{ 0xF0A9A6A7, 0x7DDDB },
	{ 0xF0A9A6A8, 0x7DDE0 },
	{ 0xF0A9A6AC, 0xFEBB8 },
	{ 0xF0A9A6AD, 0xFEBB9 },
	{ 0xF0A9A6B3, 0x7DDD8 },
	{ 0xF0A9A6B6, 0x5F8CF },
	{ 0xF0A9A6B7, 0x7E0B1 },
	{ 0xF0A9A6B8, 0x7E0B4 },
	{ 0xF0A9A6B9, 0x5F8CD },
	{ 0xF0A9A6BA, 0x7E0B3 },
	{ 0xF0A9A6BB, 0x7E0B6 },
	{ 0xF0A9A6BC, 0x7E0B5 },
	{ 0xF0A9A6BD, 0x7E0AF },
	{ 0xF0A9A6BE, 0x7E0B0 },
	{ 0xF0A9A6BF, 0x7E0AC },
	{ 0xF0A9A780, 0x7E0B2 },
	{ 0xF0A9A782, 0x5F9E2 },
	{ 0xF0A9A783, 0x7E1E3 },
	{ 0xF0A9A784, 0x5F9E3 },
	{ 0xF0A9A785, 0x5F9DF },
	{ 0xF0A9A786, 0x4EDB1 },
	{ 0xF0A9A787, 0x5F9E0 },
	{ 0xF0A9A788, 0x7E1E2 },
	{ 0xF0A9A789, 0x5F9DE },
	{ 0xF0A9A78A, 0x5F9E1 },
	{ 0xF0A9A78B, 0x4EDB2 },
	{ 0xF0A9A78E, 0x7E1E4 },
	{ 0xF0A9A78F, 0x5FACC },
	{ 0xF0A9A790, 0x5FACD },
	{ 0xF0A9A794, 0x4EEA7 },
	{ 0xF0A9A795, 0x7E4A9 },
	{ 0xF0A9A796, 0x7E4A8 },
	{ 0xF0A9A798, 0x4EEC0 },
	{ 0xF0A9A799, 0x7E4F2 },
	{ 0xF0A9A79A, 0x7E4F3 },
	{ 0xF0A9A79B, 0x7E4F1 },
	{ 0xF0A9A7A0, 0x7E5CE },
	{ 0xF0A9A7A1, 0x5FCA3 },
	{ 0xF0A9A7A2, 0x7E5EA },
	{ 0xF0A9A7A3, 0x7E5FA },
	{ 0xF0A9A7A4, 0x7E5FB },
	{ 0xF0A9A7A5, 0x7E6C4 },
	{ 0xF0A9A891, 0x5BDD1 },
	{ 0xF0A9A892, 0x4BCA7 },
	{ 0xF0A9A895, 0x6DAC9 },
	{ 0xF0A9A896, 0x6DACA },
	{ 0xF0A9A897, 0x6DAC8 },
	{ 0xF0A9A89B, 0x6DACB },
	{ 0xF0A9A89C, 0x4C8E3 },
	{ 0xF0A9A89D, 0x4C8E5 },
	{ 0xF0A9A89E, 0x5CBD5 },
	{ 0xF0A9A89F, 0x6E4D8 },
	{ 0xF0A9A8A0, 0x5CBD4 },
	{ 0xF0A9A8A1, 0x4C8E4 },
	{ 0xF0A9A8A2, 0x6E4D6 },
	{ 0xF0A9A8A3, 0x6E4D3 },
	{ 0xF0A9A8A4, 0x6E4D4 },
	{ 0xF0A9A8A6, 0x6E4D5 },
	{ 0xF0A9A8A7, 0x6E4D7 },
	{ 0xF0A9A8AC, 0x4CEF2 },
	{ 0xF0A9A8AD, 0x4CEF1 },
	{ 0xF0A9A8AE, 0x5D2FA },
	{ 0xF0A9A8AF, 0x5D2F9 },
	{ 0xF0A9A8B0, 0x7ABD2 },
	{ 0xF0A9A8B1, 0x7B6AC },
	{ 0xF0A9A8B2, 0x5D2F8 },
	{ 0xF0A9A8B3, 0x5D2FB },
	{ 0xF0A9A8B4, 0x4CEF7 },
	{ 0xF0A9A8B5, 0x7ABD0 },
	{ 0xF0A9A8B6, 0x7ABD4 },
	{ 0xF0A9A8B7, 0x7ABD1 },
	{ 0xF0A9A8B8, 0x4CEF8 },
	{ 0xF0A9A8BA, 0x7ABD3 },
	{ 0xF0A9A8BD, 0x5DAB6 },
	{ 0xF0A9A8BE, 0x5DAB5 },
	{ 0xF0A9A8BF, 0x4D5B3 },
	{ 0xF0A9A980, 0x7B6AB },
	{ 0xF0A9A981, 0x7ABCF },
	{ 0xF0A9A982, 0x7B6AA },
	{ 0xF0A9A983, 0x7B6A9 },
	{ 0xF0A9A986, 0x7BEAE },
	{ 0xF0A9A989, 0x4DAB4 },
	{ 0xF0A9A98A, 0x7BEB2 },
	{ 0xF0A9A98B, 0x4DAB2 },
	{ 0xF0A9A98C, 0x7BEB3 },
	{ 0xF0A9A98D, 0x5E0BF },
	{ 0xF0A9A98E, 0x7BEB1 },
	{ 0xF0A9A98F, 0x7BEAD },
	{ 0xF0A9A993, 0x7BEAF },
	{ 0xF0A9A995, 0x7BEB0 },
	{ 0xF0A9A997, 0x5E6D9 },
	{ 0xF0A9A998, 0x7C5BE },
	{ 0xF0A9A999, 0x4DEEF },
	{ 0xF0A9A99A, 0x7C5BD },
	{ 0xF0A9A99B, 0x5E6D7 },
	{ 0xF0A9A99C, 0x7C5BF },
	{ 0xF0A9A99D, 0x5E6D2 },
	{ 0xF0A9A99E, 0x5EAF8 },
	{ 0xF0A9A99F, 0x5E6D5 },
	{ 0xF0A9A9A0, 0x5E6D3 },
	{ 0xF0A9A9A1, 0x5E6D6 },
	{ 0xF0A9A9A2, 0x5E6D8 },
	{ 0xF0A9A9A3, 0x7BEB4 },
	{ 0xF0A9A9A6, 0x5E6D4 },
	{ 0xF0A9A9AD, 0x7CCBB },
	{ 0xF0A9A9AE, 0x5EAFA },
	{ 0xF0A9A9AF, 0x5EAF9 },
	{ 0xF0A9A9B0, 0x7CCBA },
	{ 0xF0A9A9B1, 0x7CCB7 },
	{ 0xF0A9A9B2, 0x5EAFC },
	{ 0xF0A9A9B3, 0x5EAFD },
	{ 0xF0A9A9B4, 0x5EAFB },
	{ 0xF0A9A9B5, 0x7CCBD },
	{ 0xF0A9A9B6, 0x7CCBE },
	{ 0xF0A9A9B8, 0x7CCB9 },
	{ 0xF0A9A9B9, 0x7CCB8 },
	{ 0xF0A9A9BD, 0x7CCBC },
	{ 0xF0A9A9BE, 0x7CCB6 },
	{ 0xF0A9AA80, 0x4E5CA },
	{ 0xF0A9AA81, 0x5EEF5 },
	{ 0xF0A9AA82, 0x5EEF4 },
	{ 0xF0A9AA83, 0x5EEF3 },
	{ 0xF0A9AA84, 0x7D1F3 },
	{ 0xF0A9AA85, 0x7D1F4 },
	{ 0xF0A9AA86, 0x7D1F5 },
	{ 0xF0A9AA89, 0x4E8AF },
	{ 0xF0A9AA8A, 0x5F2B6 },
	{ 0xF0A9AA8B, 0x7D6D7 },
	{ 0xF0A9AA8C, 0x4E8AE },
	{ 0xF0A9AA8D, 0x5F2B5 },
	{ 0xF0A9AA8E, 0x5F2B7 },
	{ 0xF0A9AA8F, 0x7D6D3 },
	{ 0xF0A9AA90, 0x7D6D4 },
	{ 0xF0A9AA91, 0x5F2B8 },
	{ 0xF0A9AA92, 0x7D6D5 },
	{ 0xF0A9AA93, 0xFE9A3 },
	{ 0xF0A9AA94, 0x7D6D6 },
	{ 0xF0A9AA95, 0x7D6D2 },
	{ 0xF0A9AA97, 0x4E9ED },
	{ 0xF0A9AA98, 0x7DAC2 },
	{ 0xF0A9AA99, 0x4E9F0 },
	{ 0xF0A9AA9A, 0x7DAC3 },
	{ 0xF0A9AA9B, 0x4E9EF },
	{ 0xF0A9AA9C, 0x7DAC4 },
	{ 0xF0A9AAA0, 0x7DDE5 },
	{ 0xF0A9AAA1, 0x7DDE6 },
	{ 0xF0A9AAA2, 0x5F6F3 },
	{ 0xF0A9AAA3, 0x4EBB6 },
	{ 0xF0A9AAA4, 0x5F6F5 },
	{ 0xF0A9AAA5, 0x4EBB7 },
	{ 0xF0A9AAA6, 0x7DDE2 },
	{ 0xF0A9AAA7, 0x5F6F4 },
	{ 0xF0A9AAA8, 0x7DDE7 },
	{ 0xF0A9AAA9, 0x7DDE1 },
	{ 0xF0A9AAAA, 0x7DDE3 },
	{ 0xF0A9AAAB, 0x7DDE4 },
	{ 0xF0A9AAAD, 0x4ECBF },
	{ 0xF0A9AAAE, 0x5F8D0 },
	{ 0xF0A9AAB2, 0x4EDB4 },
	{ 0xF0A9AAB3, 0x7E1E5 },
	{ 0xF0A9AAB6, 0xFEBBA },
	{ 0xF0A9AAB7, 0x7E3A7 },
	{ 0xF0A9AAB8, 0x5FACE },
	{ 0xF0A9AAB9, 0x7E3A8 },
	{ 0xF0A9AABB, 0x7E4AA },
	{ 0xF0A9AABC, 0x7E4F4 },
	{ 0xF0A9AABE, 0x5FBEE },
	{ 0xF0A9AABF, 0x4C2A3 },
	{ 0xF0A9AB80, 0x4C8E6 },
	{ 0xF0A9AB81, 0x5C6E4 },
	{ 0xF0A9AB82, 0x5CBD6 },
	{ 0xF0A9AB83, 0x6E4DA },
	{ 0xF0A9AB84, 0xFCDC6 },
	{ 0xF0A9AB85, 0xFCDC7 },
	{ 0xF0A9AB86, 0xFCDC8 },
	{ 0xF0A9AB89, 0x6E4D9 },
	{ 0xF0A9AB8A, 0x7ABD6 },
	{ 0xF0A9AB8B, 0xFD3AE },
	{ 0xF0A9AB8C, 0xFD3AF },
	{ 0xF0A9AB8E, 0x7B6AE },
	{ 0xF0A9AB8F, 0x7B6AD },
	{ 0xF0A9AB90, 0xFD9AD },
	{ 0xF0A9AB91, 0xFD9AE },
	{ 0xF0A9AB95, 0x4DAB6 },
	{ 0xF0A9AB97, 0x5E0C0 },
	{ 0xF0A9AB98, 0xFDDEB },
	{ 0xF0A9AB99, 0xFDDEC },
	{ 0xF0A9AB9A, 0x7C5C0 },
	{ 0xF0A9AB9C, 0xFE1E1 },
	{ 0xF0A9AB9D, 0xFE1E2 },
	{ 0xF0A9AB9E, 0x7CCBF },
	{ 0xF0A9AB9F, 0xFE4DF },
	{ 0xF0A9ABA0, 0x5EEF6 },
	{ 0xF0A9ABA1, 0xFE7A2 },
	{ 0xF0A9ABA2, 0xFE7A3 },
	{ 0xF0A9ABA3, 0xFE7A4 },
	{ 0xF0A9ABA4, 0xFE7A5 },
	{ 0xF0A9ABA5, 0x4E8B1 },
	{ 0xF0A9ABA6, 0x7D6D8 },
	{ 0xF0A9ABA7, 0x7DAC5 },
	{ 0xF0A9ABA8, 0x7DDE8 },
	{ 0xF0A9ABA9, 0x7DDE9 },
	{ 0xF0A9ABAA, 0x7DDEA },
	{ 0xF0A9ABAB, 0x7E0B7 },
	{ 0xF0A9ABAC, 0xFEBF3 },
	{ 0xF0A9ABAD, 0x7E1E6 },
	{ 0xF0A9ABAE, 0x7E1E7 },
	{ 0xF0A9ABAF, 0x7E3A9 },
	{ 0xF0A9ABB0, 0x7E4AB },
	{ 0xF0A9ABB1, 0x4EEA8 },
	{ 0xF0A9ABB3, 0x7E5FC },
	{ 0xF0A9ABB4, 0x6D0C9 },
	{ 0xF0A9ABB7, 0x6D0CA },
	{ 0xF0A9ABB9, 0x6DACD },
	{ 0xF0A9ABBA, 0x6DACC },
	{ 0xF0A9ABBC, 0xFC6BA },
	{ 0xF0A9ABBD, 0xFC0E9 },
	{ 0xF0A9ABBF, 0x4C8E8 },
	{ 0xF0A9AC80, 0x5CBD8 },
	{ 0xF0A9AC81, 0x6E4E0 },
	{ 0xF0A9AC83, 0x6E4DF },
	{ 0xF0A9AC84, 0x6E4DD },
	{ 0xF0A9AC89, 0x6E4E1 },
	{ 0xF0A9AC8A, 0x6E4DB },
	{ 0xF0A9AC8B, 0x6E4DC },
	{ 0xF0A9AC8F, 0x5CBD7 },
	{ 0xF0A9AC90, 0x5CBDA },
	{ 0xF0A9AC91, 0x5D2FE },
	{ 0xF0A9AC92, 0x7ABD7 },
	{ 0xF0A9AC93, 0x7ABDA },
	{ 0xF0A9AC94, 0x4CEFE },
	{ 0xF0A9AC95, 0x7ABD8 },
	{ 0xF0A9AC96, 0x5D3A4 },
	{ 0xF0A9AC97, 0x4CFA2 },
	{ 0xF0A9AC98, 0x7ABDB },
	{ 0xF0A9AC99, 0x5D3A3 },
	{ 0xF0A9AC9A, 0x4CEFC },
	{ 0xF0A9AC9B, 0x4CEFD },
	{ 0xF0A9AC9C, 0x5D2FC },
	{ 0xF0A9AC9D, 0x4CEFA },
	{ 0xF0A9AC9E, 0x5D2FD },
	{ 0xF0A9AC9F, 0x5D3A2 },
	{ 0xF0A9ACA0, 0x5D3A1 },
	{ 0xF0A9ACA1, 0x7ABDC },
	{ 0xF0A9ACA2, 0x7ABD9 },
	{ 0xF0A9ACA6, 0xFD3B0 },
	{ 0xF0A9ACA7, 0xFD3B1 },
	{ 0xF0A9ACA8, 0xFD3B2 },
	{ 0xF0A9ACA9, 0xFD3B3 },
	{ 0xF0A9ACB0, 0x7B6AF },
	{ 0xF0A9ACB1, 0x4D5B7 },
	{ 0xF0A9ACB2, 0x7B6B1 },
	{ 0xF0A9ACB3, 0x5DABA },
	{ 0xF0A9ACB4, 0x7B6B0 },
	{ 0xF0A9ACB5, 0x4D5B9 },
	{ 0xF0A9ACB6, 0x4D5B4 },
	{ 0xF0A9ACB7, 0x4D5BB },
	{ 0xF0A9ACB8, 0x5DAB7 },
	{ 0xF0A9ACB9, 0x5DAB9 },
	{ 0xF0A9ACBA, 0x4D5BA },
	{ 0xF0A9ACBB, 0x4D5B8 },
	{ 0xF0A9ACBC, 0x7B6B3 },
	{ 0xF0A9ACBD, 0x5DAB8 },
	{ 0xF0A9ACBF, 0xFD9AF },
	{ 0xF0A9AD80, 0xFD9B0 },
	{ 0xF0A9AD81, 0xFD9B1 },
	{ 0xF0A9AD82, 0xFD9B3 },
	{ 0xF0A9AD83, 0x7B6B2 },
	{ 0xF0A9AD87, 0x4DABA },
	{ 0xF0A9AD88, 0x4DABC },
	{ 0xF0A9AD89, 0x7BEBA },
	{ 0xF0A9AD8A, 0x5E0C1 },
	{ 0xF0A9AD8B, 0x5E0C4 },
	{ 0xF0A9AD8C, 0x5E0C2 },
	{ 0xF0A9AD8D, 0x7BEB8 },
	{ 0xF0A9AD8E, 0x5E0C5 },
	{ 0xF0A9AD8F, 0x5E0C6 },
	{ 0xF0A9AD90, 0x5E0C3 },
	{ 0xF0A9AD91, 0x7BEB5 },
	{ 0xF0A9AD92, 0x4DAB9 },
	{ 0xF0A9AD93, 0x7BEB6 },
	{ 0xF0A9AD95, 0xFDDED },
	{ 0xF0A9AD96, 0xFDDEE },
	{ 0xF0A9AD97, 0xFDDEF },
	{ 0xF0A9AD98, 0x7BEB7 },
	{ 0xF0A9AD9A, 0x7BEB9 },
	{ 0xF0A9AD9D, 0x7BEBB },
	{ 0xF0A9AD9E, 0x7C5C2 },
	{ 0xF0A9AD9F, 0x5E6DE },
	{ 0xF0A9ADA0, 0x4DEF1 },
	{ 0xF0A9ADA1, 0x5E6DC },
	{ 0xF0A9ADA2, 0x5E6E0 },
	{ 0xF0A9ADA3, 0x5E6DF },
	{ 0xF0A9ADA4, 0x7C5C4 },
	{ 0xF0A9ADA5, 0x5E6E1 },
	{ 0xF0A9ADA6, 0x7CCC0 },
	{ 0xF0A9ADA7, 0x7C5C3 },
	{ 0xF0A9ADA8, 0x4DEF2 },
	{ 0xF0A9ADA9, 0x5E6DA },
	{ 0xF0A9ADAA, 0x4DEF8 },
	{ 0xF0A9ADAB, 0x5E6DB },
	{ 0xF0A9ADAD, 0xFE1E3 },
	{ 0xF0A9ADAE, 0xFE1E5 },
	{ 0xF0A9ADB7, 0x5E6DD },
	{ 0xF0A9ADB8, 0x7C5C1 },
	{ 0xF0A9ADB9, 0xFE1E4 },
	{ 0xF0A9ADBA, 0x4E2CD },
	{ 0xF0A9ADBB, 0x7CCC3 },
	{ 0xF0A9ADBC, 0x7CCC7 },
	{ 0xF0A9ADBD, 0x5EAFE },
	{ 0xF0A9ADBE, 0x5EBA1 },
	{ 0xF0A9ADBF, 0x5EBA3 },
	{ 0xF0A9AE80, 0x4E2D0 },
	{ 0xF0A9AE81, 0x7CCC8 },
	{ 0xF0A9AE82, 0x7CCC6 },
	{ 0xF0A9AE83, 0x7CCC1 },
	{ 0xF0A9AE84, 0x5EBA4 },
	{ 0xF0A9AE85, 0x5EBA2 },
	{ 0xF0A9AE86, 0x7CCC5 },
	{ 0xF0A9AE87, 0x7CCC2 },
	{ 0xF0A9AE88, 0x4E2CB },
	{ 0xF0A9AE89, 0x7CCC4 },
	{ 0xF0A9AE8B, 0xFE4E0 },
	{ 0xF0A9AE8C, 0xFE4E1 },
	{ 0xF0A9AE8D, 0xFE4E3 },
	{ 0xF0A9AE96, 0x5EEFC },
	{ 0xF0A9AE97, 0x7D1F6 },
	{ 0xF0A9AE98, 0x5EEF7 },
	{ 0xF0A9AE99, 0x5EEFB },
	{ 0xF0A9AE9A, 0x5EEFA },
	{ 0xF0A9AE9B, 0x5EEF9 },
	{ 0xF0A9AE9C, 0x4E5D0 },
	{ 0xF0A9AE9D, 0x4E5CC },
	{ 0xF0A9AE9E, 0x5EEFE },
	{ 0xF0A9AE9F, 0x5EEF8 },
	{ 0xF0A9AEA0, 0x4E5CB },
	{ 0xF0A9AEA1, 0x7D1F7 },
	{ 0xF0A9AEA2, 0x7D1F8 },
	{ 0xF0A9AEA3, 0x7D1FB },
	{ 0xF0A9AEA6, 0x7D1FC },
	{ 0xF0A9AEA7, 0xFE7A6 },
	{ 0xF0A9AEA8, 0xFE7A7 },
	{ 0xF0A9AEA9, 0xFE7A8 },
	{ 0xF0A9AEAE, 0x5EEFD },
	{ 0xF0A9AEAF, 0x5F2BB },
	{ 0xF0A9AEB0, 0x5F2BE },
	{ 0xF0A9AEB1, 0x5F2BA },
	{ 0xF0A9AEB2, 0x7D6D9 },
	{ 0xF0A9AEB3, 0x4E8B2 },
	{ 0xF0A9AEB4, 0x4E8B4 },
	{ 0xF0A9AEB5, 0x5F2B9 },
	{ 0xF0A9AEB6, 0x4E8B3 },
	{ 0xF0A9AEB7, 0x5F2BD },
	{ 0xF0A9AEB8, 0x7D6DA },
	{ 0xF0A9AEB9, 0x5F2BC },
	{ 0xF0A9AEBA, 0x7D6DE },
	{ 0xF0A9AEBC, 0xFE9A4 },
	{ 0xF0A9AEBD, 0x7D6DB },
	{ 0xF0A9AEBE, 0x7D6DC },
	{ 0xF0A9AF83, 0x5F5A1 },
	{ 0xF0A9AF84, 0x5F4FC },
	{ 0xF0A9AF85, 0x7DAC6 },
	{ 0xF0A9AF86, 0x5F5A2 },
	{ 0xF0A9AF87, 0x5F4FE },
	{ 0xF0A9AF88, 0x5F4FB },
	{ 0xF0A9AF89, 0x5F5A5 },
	{ 0xF0A9AF8A, 0x5F5A4 },
	{ 0xF0A9AF8B, 0x5F5A3 },
	{ 0xF0A9AF8C, 0x5F4FD },
	{ 0xF0A9AF8D, 0x5F5A6 },
	{ 0xF0A9AF8E, 0x7D6DD },
	{ 0xF0A9AF8F, 0x4E9F3 },
	{ 0xF0A9AF90, 0x7DAC7 },
	{ 0xF0A9AF91, 0x7DAC8 },
	{ 0xF0A9AF94, 0xFEABB },
	{ 0xF0A9AF96, 0xFEABC },
	{ 0xF0A9AF9B, 0x5F6F7 },
	{ 0xF0A9AF9C, 0x4EBB8 },
	{ 0xF0A9AF9D, 0x4EBB9 },
	{ 0xF0A9AF9E, 0x5F6F6 },
	{ 0xF0A9AF9F, 0x7DDEC },
	{ 0xF0A9AFA0, 0x7DDED },
	{ 0xF0A9AFA4, 0x7DDEB },
	{ 0xF0A9AFA5, 0xFEBBB },
	{ 0xF0A9AFA6, 0x4ECC0 },
	{ 0xF0A9AFA7, 0x7E0B8 },
	{ 0xF0A9AFA8, 0x5F8D1 },
	{ 0xF0A9AFA9, 0x4ECC4 },
	{ 0xF0A9AFAD, 0x4ECC2 },
	{ 0xF0A9AFB0, 0x5F9E5 },
	{ 0xF0A9AFB1, 0x7E1E8 },
	{ 0xF0A9AFB2, 0x5F9E4 },
	{ 0xF0A9AFB3, 0x4EDB6 },
	{ 0xF0A9AFB4, 0xFECC2 },
	{ 0xF0A9AFB5, 0xFECC3 },
	{ 0xF0A9AFB8, 0x7E1E9 },
	{ 0xF0A9AFBA, 0x5FACF },
	{ 0xF0A9AFBB, 0x7E3AA },
	{ 0xF0A9AFBF, 0x7E3AB },
	{ 0xF0A9B081, 0x7E4AC },
	{ 0xF0A9B082, 0x4EEA9 },
	{ 0xF0A9B083, 0x5FBA6 },
	{ 0xF0A9B084, 0xFECF2 },
	{ 0xF0A9B085, 0x7E4F7 },
	{ 0xF0A9B086, 0x7E4F6 },
	{ 0xF0A9B087, 0x5FBCE },
	{ 0xF0A9B089, 0x4EED4 },
	{ 0xF0A9B08A, 0x6A3BD },
	{ 0xF0A9B08B, 0x6A3BC },
	{ 0xF0A9B08C, 0x5C4CB },
	{ 0xF0A9B08D, 0x5CBDB },
	{ 0xF0A9B08E, 0x5CBDC },
	{ 0xF0A9B08F, 0x6E4E2 },
	{ 0xF0A9B090, 0x7ABDD },
	{ 0xF0A9B091, 0x7B6B4 },
	{ 0xF0A9B092, 0x7BEBC },
	{ 0xF0A9B093, 0x7C5C5 },
	{ 0xF0A9B094, 0x4DEF9 },
	{ 0xF0A9B095, 0x7D1FE },
	{ 0xF0A9B096, 0x7D6DF },
	{ 0xF0A9B097, 0x5F2C0 },
	{ 0xF0A9B099, 0x7DAC9 },
	{ 0xF0A9B09C, 0x7E0BA },
	{ 0xF0A9B09D, 0x7E0B9 },
	{ 0xF0A9B09E, 0x5F8D3 },
	{ 0xF0A9B09F, 0x5FBCF },
	{ 0xF0A9B0A0, 0x7ABDE },
	{ 0xF0A9B0A1, 0x4CFA3 },
	{ 0xF0A9B0A2, 0x4D5BC },
	{ 0xF0A9B0A3, 0x7C5C6 },
	{ 0xF0A9B0A4, 0x7D2A1 },
	{ 0xF0A9B0A5, 0x7D6E1 },
	{ 0xF0A9B0A6, 0x7D6E0 },
	{ 0xF0A9B0A7, 0x7DACA },
	{ 0xF0A9B0A8, 0x7DDEE },
	{ 0xF0A9B0A9, 0xFECF3 },
	{ 0xF0A9B0AA, 0x5FBD0 },
	{ 0xF0A9B0AB, 0x4C2A4 },
	{ 0xF0A9B0AC, 0x6DACE },
	{ 0xF0A9B0AD, 0x6E4E4 },
	{ 0xF0A9B0AE, 0x6E4E3 },
	{ 0xF0A9B0AF, 0x7ABDF },
	{ 0xF0A9B0B1, 0x7B6B8 },
	{ 0xF0A9B0B2, 0x4D5BE },
	{ 0xF0A9B0B3, 0x5DABB },
	{ 0xF0A9B0B4, 0x7B6B6 },
	{ 0xF0A9B0B5, 0x7B6B5 },
	{ 0xF0A9B0B6, 0x4D5BD },
	{ 0xF0A9B0B7, 0x7B6B7 },
	{ 0xF0A9B0B9, 0x5E0C7 },
	{ 0xF0A9B0BC, 0x7BEBD },
	{ 0xF0A9B0BE, 0x4DEFA },
	{ 0xF0A9B0BF, 0x7C5C8 },
	{ 0xF0A9B180, 0x7C5C9 },
	{ 0xF0A9B181, 0x7C5C7 },
	{ 0xF0A9B183, 0x7CCC9 },
	{ 0xF0A9B184, 0x5EBA5 },
	{ 0xF0A9B185, 0x7CCCA },
	{ 0xF0A9B187, 0x4E5D1 },
	{ 0xF0A9B188, 0x7D2A4 },
	{ 0xF0A9B189, 0x7D2A3 },
	{ 0xF0A9B18A, 0x7D2A2 },
	{ 0xF0A9B18B, 0x7D2A5 },
	{ 0xF0A9B18C, 0x7D6E2 },
	{ 0xF0A9B18D, 0x4E8B5 },
	{ 0xF0A9B18E, 0x7D6E4 },
	{ 0xF0A9B18F, 0x5F2C2 },
	{ 0xF0A9B190, 0x7D6E3 },
	{ 0xF0A9B191, 0x7D6E5 },
	{ 0xF0A9B192, 0x7D6E6 },
	{ 0xF0A9B193, 0x5F5A7 },
	{ 0xF0A9B194, 0x7DACC },
	{ 0xF0A9B196, 0x7DDF1 },
	{ 0xF0A9B197, 0x7DDF2 },
	{ 0xF0A9B198, 0x5F6F8 },
	{ 0xF0A9B199, 0x4E9F5 },
	{ 0xF0A9B19A, 0x4EBBA },
	{ 0xF0A9B19B, 0x7DDF0 },
	{ 0xF0A9B19C, 0x5F6F9 },
	{ 0xF0A9B19D, 0x7DDEF },
	{ 0xF0A9B19F, 0x7DDF3 },
	{ 0xF0A9B1A0, 0x4ECC6 },
	{ 0xF0A9B1A1, 0x4ECC5 },
	{ 0xF0A9B1A2, 0x7DDF4 },
	{ 0xF0A9B1A3, 0x7E0BB },
	{ 0xF0A9B1A4, 0x7E1EB },
	{ 0xF0A9B1A5, 0x7E1EC },
	{ 0xF0A9B1A6, 0x5FAD0 },
	{ 0xF0A9B1A7, 0x7E3AC },
	{ 0xF0A9B1A8, 0x7E3AD },
	{ 0xF0A9B1A9, 0x7E3AE },
	{ 0xF0A9B1AB, 0x4EEAA },
	{ 0xF0A9B1AC, 0x7E4AD },
	{ 0xF0A9B1AD, 0x7E4F9 },
	{ 0xF0A9B1AF, 0x7E4F8 },
	{ 0xF0A9B1B0, 0x7E4FA },
	{ 0xF0A9B1B1, 0x7E5CF },
	{ 0xF0A9B1B2, 0x5FCA4 },
	{ 0xF0A9B1B3, 0x4EED1 },
	{ 0xF0A9B1B4, 0x5FCAD },
	{ 0xF0A9B1B5, 0x7E5FD },
	{ 0xF0A9B1B7, 0x7E6CA },
	{ 0xF0A9B1B8, 0x7E6CB },
	{ 0xF0A9B1B9, 0x6D0CB },
	{ 0xF0A9B1BA, 0x5BDD3 },
	{ 0xF0A9B1BD, 0x6DAD2 },
	{ 0xF0A9B1BE, 0x5C4CE },
	{ 0xF0A9B1BF, 0x6DAD1 },
	{ 0xF0A9B280, 0x4C2A6 },
	{ 0xF0A9B281, 0x5C4CC },
	{ 0xF0A9B282, 0x6DAD0 },
	{ 0xF0A9B283, 0x5C4CD },
	{ 0xF0A9B284, 0x4C2A5 },
	{ 0xF0A9B285, 0x6DACF },
	{ 0xF0A9B286, 0xFB9B0 },
	{ 0xF0A9B287, 0xFB9AF },
	{ 0xF0A9B288, 0x6DAD3 },
	{ 0xF0A9B28A, 0x5CBDF },
	{ 0xF0A9B28B, 0x5CBE0 },
	{ 0xF0A9B28C, 0x5CBE1 },
	{ 0xF0A9B28D, 0x5CBDE },
	{ 0xF0A9B28E, 0x5CBDD },
	{ 0xF0A9B28F, 0x5CBE2 },
	{ 0xF0A9B290, 0x6E4E8 },
	{ 0xF0A9B291, 0x6E4E5 },
	{ 0xF0A9B294, 0x6E4E9 },
	{ 0xF0A9B295, 0xFCDC9 },
	{ 0xF0A9B296, 0xFCDCA },
	{ 0xF0A9B297, 0xFCDCB },
	{ 0xF0A9B298, 0x6E4EB },
	{ 0xF0A9B299, 0x6E4E6 },
	{ 0xF0A9B29A, 0x6E4EE },
	{ 0xF0A9B29B, 0x6E4EC },
	{ 0xF0A9B29C, 0x6E4ED },
	{ 0xF0A9B29D, 0x6E4EA },
	{ 0xF0A9B29E, 0x6E4E7 },
	{ 0xF0A9B2A1, 0x4CFA7 },
	{ 0xF0A9B2A2, 0x5D3A9 },
	{ 0xF0A9B2A3, 0x7ABE1 },
	{ 0xF0A9B2A5, 0x7ABE0 },
	{ 0xF0A9B2A6, 0x5D3A8 },
	{ 0xF0A9B2A7, 0x5D3AB },
	{ 0xF0A9B2A8, 0x5DAC1 },
	{ 0xF0A9B2A9, 0x5D3AA },
	{ 0xF0A9B2AA, 0x4CFA6 },
	{ 0xF0A9B2AB, 0x7ABE3 },
	{ 0xF0A9B2AC, 0x5D3A5 },
	{ 0xF0A9B2AE, 0xFD3B4 },
	{ 0xF0A9B2AF, 0xFD3B5 },
	{ 0xF0A9B2B0, 0xFD3B6 },
	{ 0xF0A9B2B3, 0x5D3A7 },
	{ 0xF0A9B2B6, 0x7ABE2 },
	{ 0xF0A9B2B9, 0x5D3A6 },
	{ 0xF0A9B2BB, 0x5DABC },
	{ 0xF0A9B2BC, 0x7B6BA },
	{ 0xF0A9B2BD, 0x5DAC5 },
	{ 0xF0A9B2BE, 0x5DAC3 },
	{ 0xF0A9B2BF, 0x7B6B9 },
	{ 0xF0A9B380, 0x4D5C0 },
	{ 0xF0A9B381, 0x5DAC4 },
	{ 0xF0A9B382, 0x7B6BB },
	{ 0xF0A9B384, 0xFD9B4 },
	{ 0xF0A9B385, 0x5DABE },
	{ 0xF0A9B386, 0x5DABD },
	{ 0xF0A9B387, 0x5DABF },
	{ 0xF0A9B388, 0x5DAC2 },
	{ 0xF0A9B389, 0x7B6BC },
	{ 0xF0A9B38B, 0x5DAC0 },
	{ 0xF0A9B38C, 0x4DABD },
	{ 0xF0A9B38D, 0x5E0C9 },
	{ 0xF0A9B38E, 0x5E0CC },
	{ 0xF0A9B38F, 0x5E0D0 },
	{ 0xF0A9B390, 0x4DABE },
	{ 0xF0A9B391, 0x7BEBE },
	{ 0xF0A9B392, 0x5E0C8 },
	{ 0xF0A9B393, 0x5E0CA },
	{ 0xF0A9B394, 0x5E0CF },
	{ 0xF0A9B395, 0x5E0CD },
	{ 0xF0A9B396, 0x7BEC0 },
	{ 0xF0A9B398, 0x7BEC1 },
	{ 0xF0A9B399, 0x7BEC3 },
	{ 0xF0A9B39A, 0xFDDF0 },
	{ 0xF0A9B39B, 0xFDDF1 },
	{ 0xF0A9B39C, 0xFDDF2 },
	{ 0xF0A9B39D, 0x5E0CE },
	{ 0xF0A9B39F, 0x7BEBF },
	{ 0xF0A9B3A0, 0x7BEC2 },
	{ 0xF0A9B3A1, 0x5E0CB },
	{ 0xF0A9B3A2, 0x5E6E3 },
	{ 0xF0A9B3A3, 0x7C5CB },
	{ 0xF0A9B3A4, 0x4DEFB },
	{ 0xF0A9B3A5, 0x5E6E9 },
	{ 0xF0A9B3A6, 0x7C5CE },
	{ 0xF0A9B3A7, 0x5E6E7 },
	{ 0xF0A9B3A8, 0x5E6E5 },
	{ 0xF0A9B3A9, 0x7C5CF },
	{ 0xF0A9B3AA, 0x7C5CC },
	{ 0xF0A9B3AC, 0xFE1E7 },
	{ 0xF0A9B3AD, 0x7C5CA },
	{ 0xF0A9B3AE, 0x7C5D1 },
	{ 0xF0A9B3AF, 0x5E6E2 },
	{ 0xF0A9B3B0, 0x7C5CD },
	{ 0xF0A9B3B1, 0x7C5D0 },
	{ 0xF0A9B3B2, 0x5E6E6 },
	{ 0xF0A9B3B5, 0x5EBA6 },
	{ 0xF0A9B3B6, 0x5EBA9 },
	{ 0xF0A9B3B7, 0x7CCCB },
	{ 0xF0A9B3B8, 0x5EBA7 },
	{ 0xF0A9B3B9, 0x7CCCC },
	{ 0xF0A9B3BA, 0x7CCCD },
	{ 0xF0A9B3BC, 0xFE4E4 },
	{ 0xF0A9B3BD, 0xFE4E5 },
	{ 0xF0A9B3BE, 0xFE4E6 },
	{ 0xF0A9B3BF, 0xFE4E7 },
	{ 0xF0A9B480, 0x5E6E4 },
	{ 0xF0A9B483, 0x5EBA8 },
	{ 0xF0A9B486, 0x7D2AB },
	{ 0xF0A9B487, 0x4E5D2 },
	{ 0xF0A9B488, 0x7D2AA },
	{ 0xF0A9B489, 0x5EFA1 },
	{ 0xF0A9B48A, 0x7D2A9 },
	{ 0xF0A9B48B, 0x7D2A8 },
	{ 0xF0A9B48D, 0x5EFA2 },
	{ 0xF0A9B48E, 0x7D2A6 },
	{ 0xF0A9B48F, 0xFE7A9 },
	{ 0xF0A9B490, 0x5F2C4 },
	{ 0xF0A9B491, 0x5F2C6 },
	{ 0xF0A9B492, 0x5F2C8 },
	{ 0xF0A9B493, 0x4E8B7 },
	{ 0xF0A9B494, 0x7D6E7 },
	{ 0xF0A9B495, 0x7D6E8 },
	{ 0xF0A9B496, 0xFE9A5 },
	{ 0xF0A9B498, 0x5F2C5 },
	{ 0xF0A9B499, 0x5F2C3 },
	{ 0xF0A9B49B, 0x7D6E9 },
	{ 0xF0A9B49C, 0x5F2C7 },
	{ 0xF0A9B49D, 0x5F5AA },
	{ 0xF0A9B49E, 0x4E2D1 },
	{ 0xF0A9B49F, 0x7DAD0 },
	{ 0xF0A9B4A0, 0x4E9F8 },
	{ 0xF0A9B4A1, 0x5F5A8 },
	{ 0xF0A9B4A2, 0x7DACE },
	{ 0xF0A9B4A3, 0x4E9F9 },
	{ 0xF0A9B4A4, 0x5F5AB },
	{ 0xF0A9B4A6, 0xFEABD },
	{ 0xF0A9B4A8, 0x5F5AC },
	{ 0xF0A9B4A9, 0x5F5A9 },
	{ 0xF0A9B4AA, 0x4E9FA },
	{ 0xF0A9B4AB, 0xFE7AA },
	{ 0xF0A9B4AD, 0x7DACD },
	{ 0xF0A9B4AE, 0x5F6FB },
	{ 0xF0A9B4AF, 0x5F6FA },
	{ 0xF0A9B4B0, 0xFE9A6 },
	{ 0xF0A9B4B1, 0x5F8D4 },
	{ 0xF0A9B4B2, 0x5F8D5 },
	{ 0xF0A9B4B3, 0x4ECC7 },
	{ 0xF0A9B4B4, 0x7E0BF },
	{ 0xF0A9B4B6, 0x7E0BE },
	{ 0xF0A9B4B7, 0x7E0C0 },
	{ 0xF0A9B4B8, 0x7E0BD },
	{ 0xF0A9B4BA, 0x5F9E7 },
	{ 0xF0A9B4BB, 0x5F9E6 },
	{ 0xF0A9B4BD, 0xFECC4 },
	{ 0xF0A9B4BF, 0x7E3AF },
	{ 0xF0A9B580, 0x4EEAB },
	{ 0xF0A9B581, 0x7E4AE },
	{ 0xF0A9B582, 0x7E4AF },
	{ 0xF0A9B584, 0x4EEC1 },
	{ 0xF0A9B585, 0x5FBD1 },
	{ 0xF0A9B587, 0x5FBEF },
	{ 0xF0A9B588, 0x5FCA5 },
	{ 0xF0A9B58A, 0x5FCC0 },
	{ 0xF0A9B58B, 0x4B0C3 },
	{ 0xF0A9B58C, 0x4C2AA },
	{ 0xF0A9B58D, 0x4C2A7 },
	{ 0xF0A9B58E, 0x6DAD5 },
	{ 0xF0A9B58F, 0x4C2A8 },
	{ 0xF0A9B590, 0x6DAD6 },
	{ 0xF0A9B591, 0x5C4CF },
	{ 0xF0A9B593, 0xFC6BB },
	{ 0xF0A9B594, 0x6E4EF },
	{ 0xF0A9B595, 0x5CBE5 },
	{ 0xF0A9B596, 0x4C8EC },
	{ 0xF0A9B597, 0x5CBE3 },
	{ 0xF0A9B598, 0xFCDCC },
	{ 0xF0A9B599, 0xFCDCD },
	{ 0xF0A9B59B, 0x5CBE6 },
	{ 0xF0A9B5A0, 0x4CFAF },
	{ 0xF0A9B5A1, 0x4CFB3 },
	{ 0xF0A9B5A2, 0x4CFB1 },
	{ 0xF0A9B5A3, 0x4CFAD },
	{ 0xF0A9B5A4, 0x7ABE8 },
	{ 0xF0A9B5A5, 0x5D3B1 },
	{ 0xF0A9B5A6, 0x5D3B0 },
	{ 0xF0A9B5A7, 0x7ABE5 },
	{ 0xF0A9B5A8, 0x7ABE4 },
	{ 0xF0A9B5A9, 0x5D3AE },
	{ 0xF0A9B5AA, 0x4CFB8 },
	{ 0xF0A9B5AB, 0x5D3B3 },
	{ 0xF0A9B5AC, 0x5D3AC },
	{ 0xF0A9B5AD, 0x5D3AD },
	{ 0xF0A9B5AE, 0x7ABEC },
	{ 0xF0A9B5AF, 0x7ABE6 },
	{ 0xF0A9B5B0, 0x4CFB6 },
	{ 0xF0A9B5B1, 0x5D3B2 },
	{ 0xF0A9B5B3, 0xFD3B7 },
	{ 0xF0A9B5B4, 0xFD3BA },
	{ 0xF0A9B5B5, 0xFD3BD },
	{ 0xF0A9B5B6, 0x7ABEB },
	{ 0xF0A9B5B7, 0x7ABE7 },
	{ 0xF0A9B5B8, 0x7ABE9 },
	{ 0xF0A9B5B9, 0x4CFAE },
	{ 0xF0A9B5BC, 0xFD3B9 },
	{ 0xF0A9B680, 0x5D3AF },
	{ 0xF0A9B681, 0x5DAC8 },
	{ 0xF0A9B682, 0x5DAC6 },
	{ 0xF0A9B683, 0x7B6BD },
	{ 0xF0A9B684, 0x5DAC9 },
	{ 0xF0A9B685, 0x4D5C6 },
	{ 0xF0A9B686, 0x4DAC6 },
	{ 0xF0A9B687, 0x5DACE },
	{ 0xF0A9B688, 0x5DACD },
	{ 0xF0A9B689, 0x4D5C9 },
	{ 0xF0A9B68A, 0x7B6C3 },
	{ 0xF0A9B68B, 0x7B6BE },
	{ 0xF0A9B68C, 0x7B6C1 },
	{ 0xF0A9B68D, 0x7B6C0 },
	{ 0xF0A9B68E, 0x5DACC },
	{ 0xF0A9B691, 0x7B6C4 },
	{ 0xF0A9B692, 0xFD9B6 },
	{ 0xF0A9B693, 0xFD9B7 },
	{ 0xF0A9B694, 0xFD9B9 },
	{ 0xF0A9B695, 0xFD9BA },
	{ 0xF0A9B696, 0x5DACB },
	{ 0xF0A9B69A, 0x7B6C2 },
	{ 0xF0A9B69B, 0xFD9B5 },
	{ 0xF0A9B69E, 0x5DAC7 },
	{ 0xF0A9B6A0, 0x7B6BF },
	{ 0xF0A9B6A2, 0x5E0D6 },
	{ 0xF0A9B6A3, 0x4DAC8 },
	{ 0xF0A9B6A4, 0x5E0D7 },
	{ 0xF0A9B6A5, 0x5E0D4 },
	{ 0xF0A9B6A6, 0x5E0D2 },
	{ 0xF0A9B6A7, 0x4DAC7 },
	{ 0xF0A9B6A8, 0x7BECB },
	{ 0xF0A9B6A9, 0x5E0D5 },
	{ 0xF0A9B6AA, 0x7BEC6 },
	{ 0xF0A9B6AB, 0x7BECD },
	{ 0xF0A9B6AC, 0x7BEC5 },
	{ 0xF0A9B6AD, 0x4DACB },
	{ 0xF0A9B6AE, 0x7BECC },
	{ 0xF0A9B6AF, 0x5E0DA },
	{ 0xF0A9B6B0, 0x5E0D8 },
	{ 0xF0A9B6B1, 0x7BEC4 },
	{ 0xF0A9B6B6, 0x4DACA },
	{ 0xF0A9B6B7, 0xFC6BC },
	{ 0xF0A9B6B8, 0xFDDF3 },
	{ 0xF0A9B6B9, 0xFDDF4 },
	{ 0xF0A9B6BA, 0xFDDF5 },
	{ 0xF0A9B6BB, 0xFDDF7 },
	{ 0xF0A9B6BC, 0xFDDF9 },
	{ 0xF0A9B6BD, 0x7BEC8 },
	{ 0xF0A9B6BF, 0x5E0DB },
	{ 0xF0A9B782, 0x5E0D3 },
	{ 0xF0A9B783, 0x7BECA },
	{ 0xF0A9B78B, 0x5E0D1 },
	{ 0xF0A9B78C, 0x5E0D9 },
	{ 0xF0A9B78D, 0x5E6F7 },
	{ 0xF0A9B78E, 0x5E6F4 },
	{ 0xF0A9B78F, 0x5E6F0 },
	{ 0xF0A9B790, 0x5E6EB },
	{ 0xF0A9B791, 0x7C5D3 },
	{ 0xF0A9B792, 0x4DFA8 },
	{ 0xF0A9B793, 0x5E6ED },
	{ 0xF0A9B794, 0x7C5D2 },
	{ 0xF0A9B795, 0x5E6EA },
	{ 0xF0A9B796, 0x5E6F1 },
	{ 0xF0A9B797, 0x5E6F5 },
	{ 0xF0A9B798, 0x5E6F2 },
	{ 0xF0A9B799, 0x5E6EF },
	{ 0xF0A9B79A, 0x5E6EC },
	{ 0xF0A9B79C, 0x7C5D4 },
	{ 0xF0A9B79D, 0xFE1E8 },
	{ 0xF0A9B79E, 0xFE1E9 },
	{ 0xF0A9B79F, 0xFE1EA },
	{ 0xF0A9B7A0, 0xFE1EB },
	{ 0xF0A9B7A1, 0xFE1EC },
	{ 0xF0A9B7A2, 0xFE1ED },
	{ 0xF0A9B7A3, 0xFE1EE },
	{ 0xF0A9B7A4, 0xFE1EF },
	{ 0xF0A9B7A5, 0xFE1F1 },
	{ 0xF0A9B7A6, 0xFE1F3 },
	{ 0xF0A9B7AC, 0x7C5D5 },
	{ 0xF0A9B7AE, 0x7BEC7 },
	{ 0xF0A9B7B4, 0x5E6F6 },
	{ 0xF0A9B7B5, 0x5E6F3 },
	{ 0xF0A9B7B7, 0x7CCDB },
	{ 0xF0A9B7B8, 0x7CCD8 },
	{ 0xF0A9B7B9, 0x4E2DE },
	{ 0xF0A9B7BA, 0x7CCD2 },
	{ 0xF0A9B7BB, 0x5EBAD },
	{ 0xF0A9B7BC, 0x4E2D2 },
	{ 0xF0A9B7BD, 0x5EBAF },
	{ 0xF0A9B7BE, 0x7CCCF },
	{ 0xF0A9B7BF, 0x7CCD1 },
	{ 0xF0A9B880, 0x4E2DF },
	{ 0xF0A9B881, 0x5E6F8 },
	{ 0xF0A9B882, 0x4E2E3 },
	{ 0xF0A9B883, 0x5EBB2 },
	{ 0xF0A9B884, 0x4E2DB },
	{ 0xF0A9B885, 0x7CCCE },
	{ 0xF0A9B886, 0x4E2DA },
	{ 0xF0A9B887, 0x4E2E5 },
	{ 0xF0A9B888, 0x7CCDA },
	{ 0xF0A9B889, 0x7CCD3 },
	{ 0xF0A9B88A, 0x7CCD9 },
	{ 0xF0A9B88B, 0x4E2D8 },
	{ 0xF0A9B88C, 0x7CCD5 },
	{ 0xF0A9B88D, 0x5EBB6 },
	{ 0xF0A9B88E, 0x5EBAE },
	{ 0xF0A9B88F, 0x7CCD0 },
	{ 0xF0A9B890, 0x5EBB4 },
	{ 0xF0A9B892, 0xFE4EE },
	{ 0xF0A9B897, 0xFE4E8 },
	{ 0xF0A9B898, 0xFE4EA },
	{ 0xF0A9B899, 0xFE4EC },
	{ 0xF0A9B89A, 0xFE4EF },
	{ 0xF0A9B89B, 0xFE4F0 },
	{ 0xF0A9B89C, 0xFE4F1 },
	{ 0xF0A9B89F, 0x5EBB0 },
	{ 0xF0A9B8A0, 0x7CCD4 },
	{ 0xF0A9B8A2, 0x7CCD7 },
	{ 0xF0A9B8A5, 0x4E2D3 },
	{ 0xF0A9B8A7, 0x5EBB7 },
	{ 0xF0A9B8A8, 0x5EBAA },
	{ 0xF0A9B8AD, 0xFE4E9 },
	{ 0xF0A9B8B9, 0x5EBAC },
	{ 0xF0A9B8BA, 0xFE1F0 },
	{ 0xF0A9B8BC, 0x7CCD6 },
	{ 0xF0A9B8BE, 0x5EFA7 },
	{ 0xF0A9B8BF, 0x7D2AE },
	{ 0xF0A9B980, 0x5EFA6 },
	{ 0xF0A9B981, 0x5EBB8 },
	{ 0xF0A9B982, 0x5EFA9 },
	{ 0xF0A9B983, 0x7D2AC },
	{ 0xF0A9B984, 0x4E5D8 },
	{ 0xF0A9B985, 0x5EFAB },
	{ 0xF0A9B986, 0x7D2AF },
	{ 0xF0A9B987, 0x7D2AD },
	{ 0xF0A9B988, 0x5EFA8 },
	{ 0xF0A9B989, 0x4E5D6 },
	{ 0xF0A9B98A, 0x5EFA4 },
	{ 0xF0A9B98B, 0x7D2B2 },
	{ 0xF0A9B98C, 0x4E5DE },
	{ 0xF0A9B98D, 0x5EFA5 },
	{ 0xF0A9B98E, 0x5EFA3 },
	{ 0xF0A9B98F, 0x4E5E0 },
	{ 0xF0A9B990, 0x7D2B0 },
	{ 0xF0A9B991, 0x5EFAC },
	{ 0xF0A9B992, 0x7D2B4 },
	{ 0xF0A9B996, 0xFE7AB },
	{ 0xF0A9B997, 0xFE7AC },
	{ 0xF0A9B998, 0xFE7AD },
	{ 0xF0A9B999, 0xFE7AF },
	{ 0xF0A9B99A, 0xFE7B0 },
	{ 0xF0A9B99B, 0xFE7B1 },
	{ 0xF0A9B99C, 0xFE7B2 },
	{ 0xF0A9B99E, 0xFE7AE },
	{ 0xF0A9B9A2, 0x5EFAA },
	{ 0xF0A9B9A8, 0xFE7B4 },
	{ 0xF0A9B9B1, 0x5F2CA },
	{ 0xF0A9B9B2, 0x4E8BF },
	{ 0xF0A9B9B3, 0x5F2CF },
	{ 0xF0A9B9B4, 0x5F2D3 },
	{ 0xF0A9B9B5, 0x5F7A3 },
	{ 0xF0A9B9B6, 0x5F2C9 },
	{ 0xF0A9B9B7, 0x5F2D2 },
	{ 0xF0A9B9B8, 0x4E8B8 },
	{ 0xF0A9B9B9, 0x7D6F1 },
	{ 0xF0A9B9BA, 0x5F2CC },
	{ 0xF0A9B9BB, 0x7D6F2 },
	{ 0xF0A9B9BC, 0x5F2D7 },
	{ 0xF0A9B9BD, 0x7D6ED },
	{ 0xF0A9B9BE, 0x5F2D4 },
	{ 0xF0A9B9BF, 0x5F2CD },
	{ 0xF0A9BA80, 0x7D6F3 },
	{ 0xF0A9BA81, 0x7D6F5 },
	{ 0xF0A9BA82, 0x7D6EA },
	{ 0xF0A9BA83, 0x7D6F4 },
	{ 0xF0A9BA84, 0x5F2D6 },
	{ 0xF0A9BA85, 0x7D6EE },
	{ 0xF0A9BA86, 0x7D6EF },
	{ 0xF0A9BA8D, 0xFE9A8 },
	{ 0xF0A9BA8E, 0xFE9A9 },
	{ 0xF0A9BA8F, 0xFE9AB },
	{ 0xF0A9BA90, 0xFE9AC },
	{ 0xF0A9BA91, 0xFE9AD },
	{ 0xF0A9BA92, 0xFE9AE },
	{ 0xF0A9BA93, 0xFE9AF },
	{ 0xF0A9BA94, 0xFE9B0 },
	{ 0xF0A9BA95, 0xFE9B1 },
	{ 0xF0A9BA96, 0xFE9B2 },
	{ 0xF0A9BA99, 0x7D6EB },
	{ 0xF0A9BA9A, 0x7D6EC },
	{ 0xF0A9BA9B, 0x5F2D5 },
	{ 0xF0A9BA9C, 0x7D6F0 },
	{ 0xF0A9BAAB, 0x5F2D0 },
	{ 0xF0A9BAAD, 0x7DAD4 },
	{ 0xF0A9BAAE, 0x7DAD2 },
	{ 0xF0A9BAAF, 0x5F5B2 },
	{ 0xF0A9BAB0, 0x4EAA2 },
	{ 0xF0A9BAB1, 0x5F5AE },
	{ 0xF0A9BAB2, 0x5F5AF },
	{ 0xF0A9BAB3, 0x7DADA },
	{ 0xF0A9BAB4, 0x7DAD7 },
	{ 0xF0A9BAB5, 0x5F5B0 },
	{ 0xF0A9BAB6, 0x7DADC },
	{ 0xF0A9BAB7, 0x7DAD9 },
	{ 0xF0A9BAB8, 0x5F5B4 },
	{ 0xF0A9BAB9, 0x7DAD6 },
	{ 0xF0A9BABA, 0x7DADB },
	{ 0xF0A9BABB, 0x7DAD3 },
	{ 0xF0A9BABC, 0x7DAD5 },
	{ 0xF0A9BABD, 0x7DAD1 },
	{ 0xF0A9BABE, 0x7DADE },
	{ 0xF0A9BB85, 0xFEAC1 },
	{ 0xF0A9BB86, 0xFEAC2 },
	{ 0xF0A9BB87, 0xFEAC3 },
	{ 0xF0A9BB88, 0xFEAC0 },
	{ 0xF0A9BB89, 0x7DADF },
	{ 0xF0A9BB8A, 0x5F5B3 },
	{ 0xF0A9BB8B, 0x7DAD8 },
	{ 0xF0A9BB8D, 0x7DADD },
	{ 0xF0A9BB96, 0x5F5B1 },
	{ 0xF0A9BB98, 0x5F6FE },
	{ 0xF0A9BB99, 0x7DDF8 },
	{ 0xF0A9BB9A, 0x5F7A2 },
	{ 0xF0A9BB9B, 0x4EBBE },
	{ 0xF0A9BB9C, 0x4EBBF },
	{ 0xF0A9BB9D, 0x5F6FC },
	{ 0xF0A9BB9E, 0x7DDF7 },
	{ 0xF0A9BB9F, 0x4E5DC },
	{ 0xF0A9BBA0, 0x7E0C6 },
	{ 0xF0A9BBA1, 0x7DDF5 },
	{ 0xF0A9BBA2, 0x7DEA2 },
	{ 0xF0A9BBA3, 0x7DDF6 },
	{ 0xF0A9BBA4, 0x5F6FD },
	{ 0xF0A9BBA5, 0x7DEA1 },
	{ 0xF0A9BBA6, 0x7DDFC },
	{ 0xF0A9BBA7, 0x5F7A1 },
	{ 0xF0A9BBA8, 0x7DDF9 },
	{ 0xF0A9BBAA, 0xFEBBD },
	{ 0xF0A9BBAB, 0xFEBBF },
	{ 0xF0A9BBB2, 0x7DDFA },
	{ 0xF0A9BBB4, 0x7DDFD },
	{ 0xF0A9BBB5, 0x7DDFE },
	{ 0xF0A9BBB6, 0x7DDFB },
	{ 0xF0A9BBB8, 0xFEBBC },
	{ 0xF0A9BC82, 0x7E0C3 },
	{ 0xF0A9BC83, 0x5F8DC },
	{ 0xF0A9BC84, 0x5F8E0 },
	{ 0xF0A9BC85, 0x5F8DA },
	{ 0xF0A9BC86, 0x7E0C1 },
	{ 0xF0A9BC87, 0x4ECCF },
	{ 0xF0A9BC88, 0x4ECCC },
	{ 0xF0A9BC89, 0x5F8D9 },
	{ 0xF0A9BC8A, 0x5F8E1 },
	{ 0xF0A9BC8B, 0x4ECCB },
	{ 0xF0A9BC8C, 0x5F8DF },
	{ 0xF0A9BC8D, 0x5F8DE },
	{ 0xF0A9BC8E, 0x5F8D7 },
	{ 0xF0A9BC90, 0x7E0CB },
	{ 0xF0A9BC91, 0x7E0C7 },
	{ 0xF0A9BC92, 0x5F8D8 },
	{ 0xF0A9BC96, 0xFEBF5 },
	{ 0xF0A9BC97, 0xFEBF8 },
	{ 0xF0A9BC98, 0x7E0C8 },
	{ 0xF0A9BC9C, 0x7E0C2 },
	{ 0xF0A9BC9D, 0x7E0C4 },
	{ 0xF0A9BC9E, 0x7E0C5 },
	{ 0xF0A9BC9F, 0x5F8DD },
	{ 0xF0A9BCA0, 0x7E0CA },
	{ 0xF0A9BCA1, 0x7E0C9 },
	{ 0xF0A9BCA5, 0x7E1F3 },
	{ 0xF0A9BCA6, 0x5F9E8 },
	{ 0xF0A9BCA7, 0x4EDB8 },
	{ 0xF0A9BCA8, 0x5F9E9 },
	{ 0xF0A9BCA9, 0x7E1EE },
	{ 0xF0A9BCAA, 0x7E0FA },
	{ 0xF0A9BCAB, 0x7E1F1 },
	{ 0xF0A9BCAC, 0x7E1EF },
	{ 0xF0A9BCAD, 0x5F9EB },
	{ 0xF0A9BCAE, 0x7E1F2 },
	{ 0xF0A9BCB1, 0x7E1F0 },
	{ 0xF0A9BCB2, 0xFECC5 },
	{ 0xF0A9BCB3, 0xFECC6 },
	{ 0xF0A9BCB4, 0x5F9EA },
	{ 0xF0A9BCB5, 0x7E1ED },
	{ 0xF0A9BCBB, 0x7E3B5 },
	{ 0xF0A9BCBC, 0x7E3B0 },
	{ 0xF0A9BCBD, 0x7E3B2 },
	{ 0xF0A9BCBE, 0x7E3B3 },
	{ 0xF0A9BCBF, 0x7E3B4 },
	{ 0xF0A9BD80, 0x5FAD1 },
	{ 0xF0A9BD81, 0x5FAD2 },
	{ 0xF0A9BD82, 0xFECDA },
	{ 0xF0A9BD83, 0xFECDB },
	{ 0xF0A9BD84, 0xFECDC },
	{ 0xF0A9BD88, 0xFECDD },
	{ 0xF0A9BD8C, 0x7E3B1 },
	{ 0xF0A9BD8D, 0x5FBA8 },
	{ 0xF0A9BD8E, 0x5FBA7 },
	{ 0xF0A9BD8F, 0x7E4B0 },
	{ 0xF0A9BD90, 0x5FBA9 },
	{ 0xF0A9BD91, 0xFECF4 },
	{ 0xF0A9BD93, 0x7E4B1 },
	{ 0xF0A9BD95, 0x5FBAA },
	{ 0xF0A9BD98, 0x7E4B2 },
	{ 0xF0A9BD9A, 0x7E4FE },
	{ 0xF0A9BD9B, 0x5FBD3 },
	{ 0xF0A9BD9C, 0x5FBD2 },
	{ 0xF0A9BD9D, 0x5FBD5 },
	{ 0xF0A9BD9E, 0x7E4FC },
	{ 0xF0A9BD9F, 0x7E5A1 },
	{ 0xF0A9BDA0, 0x7E4FB },
	{ 0xF0A9BDA1, 0x5FBD4 },
	{ 0xF0A9BDA3, 0x7E4FD },
	{ 0xF0A9BDA6, 0xFECF5 },
	{ 0xF0A9BDA7, 0x5FBF3 },
	{ 0xF0A9BDA8, 0x5FBF2 },
	{ 0xF0A9BDA9, 0x5FBF1 },
	{ 0xF0A9BDAA, 0x5FBF0 },
	{ 0xF0A9BDAB, 0x7E5D0 },
	{ 0xF0A9BDAC, 0x5FCA6 },
	{ 0xF0A9BDAD, 0xFEDAB },
	{ 0xF0A9BDAE, 0xFEDAC },
	{ 0xF0A9BDB0, 0x5FCA7 },
	{ 0xF0A9BDB1, 0x7E5EB },
	{ 0xF0A9BDB3, 0x5FCAE },
	{ 0xF0A9BDB5, 0x5FCB7 },
	{ 0xF0A9BDB6, 0x7E6AF },
	{ 0xF0A9BDB7, 0x5FCB6 },
	{ 0xF0A9BE80, 0xFD3BC },
	{ 0xF0A9BE89, 0xFDDF8 },
	{ 0xF0A9BE8D, 0xFEBBE },
	{ 0xF0A9BE8F, 0x6D0CC },
	{ 0xF0A9BE90, 0xFC0B3 },
	{ 0xF0A9BE91, 0x6D0CD },
	{ 0xF0A9BE92, 0x4C2AB },
	{ 0xF0A9BE93, 0x6DAD7 },
	{ 0xF0A9BE94, 0x5C4D1 },
	{ 0xF0A9BE95, 0x5C4D2 },
	{ 0xF0A9BE96, 0x6DADC },
	{ 0xF0A9BE97, 0x6DAD8 },
	{ 0xF0A9BE98, 0x6DAD9 },
	{ 0xF0A9BE99, 0x5C4D0 },
	{ 0xF0A9BE9B, 0x6DADA },
	{ 0xF0A9BE9C, 0x6DADB },
	{ 0xF0A9BE9D, 0x6E4F0 },
	{ 0xF0A9BE9E, 0x5CBEA },
	{ 0xF0A9BE9F, 0x6E4F1 },
	{ 0xF0A9BEA0, 0x5CBE9 },
	{ 0xF0A9BEA1, 0x4C8EE },
	{ 0xF0A9BEA2, 0x4C8EF },
	{ 0xF0A9BEA3, 0x6E4F2 },
	{ 0xF0A9BEA4, 0x6E4F3 },
	{ 0xF0A9BEA5, 0x6E4F4 },
	{ 0xF0A9BEA6, 0x4C8F0 },
	{ 0xF0A9BEA7, 0x5CBE8 },
	{ 0xF0A9BEA9, 0xFCDCF },
	{ 0xF0A9BEAA, 0xFCDD0 },
	{ 0xF0A9BEAB, 0xFCDD1 },
	{ 0xF0A9BEAC, 0x5CBE7 },
	{ 0xF0A9BEB0, 0x4CFC5 },
	{ 0xF0A9BEB1, 0x7ABF2 },
	{ 0xF0A9BEB2, 0x7ABFD },
	{ 0xF0A9BEB3, 0x7ABEF },
	{ 0xF0A9BEB4, 0x7ABF3 },
	{ 0xF0A9BEB5, 0x7ABF9 },
	{ 0xF0A9BEB6, 0x5D3B7 },
	{ 0xF0A9BEB7, 0x5D3BB },
	{ 0xF0A9BEB8, 0x5D3BD },
	{ 0xF0A9BEB9, 0x5D3B9 },
	{ 0xF0A9BEBA, 0x7ABF6 },
	{ 0xF0A9BEBB, 0x7ABFC },
	{ 0xF0A9BEBC, 0x5D3BF },
	{ 0xF0A9BEBD, 0x5D3B4 },
	{ 0xF0A9BEBE, 0x4CFBD },
	{ 0xF0A9BEBF, 0x5D3C1 },
	{ 0xF0A9BF80, 0x5D3BE },
	{ 0xF0A9BF81, 0x5D3B5 },
	{ 0xF0A9BF82, 0x4CFBE },
	{ 0xF0A9BF83, 0x5D3C2 },
	{ 0xF0A9BF84, 0x7ABFA },
	{ 0xF0A9BF85, 0x4CFBC },
	{ 0xF0A9BF86, 0x7ABF5 },
	{ 0xF0A9BF87, 0x4CFC3 },
	{ 0xF0A9BF88, 0x4CFBA },
	{ 0xF0A9BF89, 0x5D3C3 },
	{ 0xF0A9BF8A, 0x4CFC6 },
	{ 0xF0A9BF8B, 0x7ABF0 },
	{ 0xF0A9BF8C, 0x7ABFB },
	{ 0xF0A9BF8F, 0xFD3C0 },
	{ 0xF0A9BF90, 0x7ABEE },
	{ 0xF0A9BF91, 0x7ABF7 },
	{ 0xF0A9BF92, 0x7ABF8 },
	{ 0xF0A9BF93, 0x5D3B6 },
	{ 0xF0A9BF94, 0x5D3BA },
	{ 0xF0A9BF95, 0x5D3C0 },
	{ 0xF0A9BF96, 0x7ABF1 },
	{ 0xF0A9BF97, 0x7ABF4 },
	{ 0xF0A9BF9B, 0x5D3BC },
	{ 0xF0A9BF9C, 0x7B6CB },
	{ 0xF0A9BF9D, 0x5DAD4 },
	{ 0xF0A9BF9E, 0x5DAD6 },
	{ 0xF0A9BF9F, 0x5DAD1 },
	{ 0xF0A9BFA0, 0x5DACF },
	{ 0xF0A9BFA1, 0x4D5CC },
	{ 0xF0A9BFA2, 0x5DAD3 },
	{ 0xF0A9BFA3, 0x5DAD9 },
	{ 0xF0A9BFA4, 0x5DAD2 },
	{ 0xF0A9BFA5, 0x7B6D7 },
	{ 0xF0A9BFA6, 0x7B6D2 },
	{ 0xF0A9BFA7, 0x5DAD7 },
	{ 0xF0A9BFA8, 0x4D5D6 },
	{ 0xF0A9BFA9, 0x7B6D4 },
	{ 0xF0A9BFAA, 0x5DAD8 },
	{ 0xF0A9BFAB, 0x7B6D0 },
	{ 0xF0A9BFAC, 0x5DAD5 },
	{ 0xF0A9BFAD, 0x7B6D3 },
	{ 0xF0A9BFAE, 0x7B6CC },
	{ 0xF0A9BFB1, 0x7B6C5 },
	{ 0xF0A9BFB2, 0x7B6CE },
	{ 0xF0A9BFB3, 0xFD9BD },
	{ 0xF0A9BFB4, 0xFD9BE },
	{ 0xF0A9BFB5, 0xFD9BF },
	{ 0xF0A9BFB6, 0xFD9C0 },
	{ 0xF0A9BFB7, 0x7B6CD },
	{ 0xF0A9BFB8, 0x7B6CF },
	{ 0xF0A9BFBC, 0x7B6D8 },
	{ 0xF0AA8080, 0x7B6D6 },
	{ 0xF0AA8081, 0x7B6C7 },
	{ 0xF0AA8087, 0x7B6C8 },
	{ 0xF0AA8088, 0x7B6D5 },
	{ 0xF0AA8089, 0x4D5D3 },
	{ 0xF0AA808A, 0x4D5D1 },
	{ 0xF0AA808B, 0x6D0CE },
	{ 0xF0AA808C, 0x7B6C9 },
	{ 0xF0AA808D, 0x5DAD0 },
	{ 0xF0AA808F, 0x7B6C6 },
	{ 0xF0AA8091, 0xFD6B3 },
	{ 0xF0AA8092, 0x7BED1 },
	{ 0xF0AA8093, 0x4DACC },
	{ 0xF0AA8094, 0x5E0DE },
	{ 0xF0AA8095, 0x5E0E9 },
	{ 0xF0AA8096, 0x7BED4 },
	{ 0xF0AA8097, 0x4DAD3 },
	{ 0xF0AA8098, 0x5E0E7 },
	{ 0xF0AA8099, 0x7BED5 },
	{ 0xF0AA809A, 0x5E0DD },
	{ 0xF0AA809B, 0x5E0E1 },
	{ 0xF0AA809D, 0x7BECE },
	{ 0xF0AA809E, 0x5E0E4 },
	{ 0xF0AA809F, 0x5E0EB },
	{ 0xF0AA80A0, 0x5E0E0 },
	{ 0xF0AA80A1, 0x5E0E2 },
	{ 0xF0AA80A2, 0x4DAD4 },
	{ 0xF0AA80A3, 0x7BED7 },
	{ 0xF0AA80A4, 0x5E0DC },
	{ 0xF0AA80A5, 0x5E0E3 },
	{ 0xF0AA80A6, 0x4DAD8 },
	{ 0xF0AA80A7, 0x7BECF },
	{ 0xF0AA80A8, 0x4DADB },
	{ 0xF0AA80A9, 0x5E0EC },
	{ 0xF0AA80AA, 0x7BED8 },
	{ 0xF0AA80AB, 0x7BED3 },
	{ 0xF0AA80AC, 0x5E0E8 },
	{ 0xF0AA80AD, 0x5E0EA },
	{ 0xF0AA80B0, 0xFDDFA },
	{ 0xF0AA80B1, 0xFDDFB },
	{ 0xF0AA80B2, 0xFDDFC },
	{ 0xF0AA80B3, 0xFDDFD },
	{ 0xF0AA80B4, 0xFDEA1 },
	{ 0xF0AA80B5, 0xFDEA2 },
	{ 0xF0AA80B6, 0xFDEA3 },
	{ 0xF0AA80B7, 0xFDEA5 },
	{ 0xF0AA80B8, 0x7BED0 },
	{ 0xF0AA80BA, 0x5E0DF },
	{ 0xF0AA80BC, 0x4DADA },
	{ 0xF0AA80BD, 0x7BED6 },
	{ 0xF0AA80BF, 0x5E0E5 },
	{ 0xF0AA8180, 0x5E0E6 },
	{ 0xF0AA8188, 0x7BED2 },
	{ 0xF0AA8189, 0x4DAD7 },
	{ 0xF0AA818A, 0x7C5DB },
	{ 0xF0AA818B, 0x5E0ED },
	{ 0xF0AA818C, 0x7C5DF },
	{ 0xF0AA818D, 0x5E6FD },
	{ 0xF0AA818E, 0x5E7A5 },
	{ 0xF0AA818F, 0x5E7A7 },
	{ 0xF0AA8190, 0x4DFAE },
	{ 0xF0AA8191, 0x5E7AA },
	{ 0xF0AA8192, 0x5E6FA },
	{ 0xF0AA8193, 0x5E7A1 },
	{ 0xF0AA8194, 0x5E6FE },
	{ 0xF0AA8195, 0x5E6FB },
	{ 0xF0AA8196, 0x7C5DD },
	{ 0xF0AA8197, 0x7C5D8 },
	{ 0xF0AA8198, 0x4DFAD },
	{ 0xF0AA8199, 0x7C5DE },
	{ 0xF0AA819A, 0x5E6FC },
	{ 0xF0AA819B, 0x5E7AB },
	{ 0xF0AA819C, 0x4DFB0 },
	{ 0xF0AA819D, 0x7C5E7 },
	{ 0xF0AA819E, 0x5E7A2 },
	{ 0xF0AA819F, 0x7C5E4 },
	{ 0xF0AA81A0, 0x7C5DC },
	{ 0xF0AA81A1, 0x5E7A8 },
	{ 0xF0AA81A2, 0x7C5E1 },
	{ 0xF0AA81A3, 0x7C5E2 },
	{ 0xF0AA81A4, 0x7C5E6 },
	{ 0xF0AA81A5, 0x5E7A4 },
	{ 0xF0AA81A6, 0x7C5D9 },
	{ 0xF0AA81A7, 0x5E7A3 },
	{ 0xF0AA81A8, 0x7C5E8 },
	{ 0xF0AA81A9, 0x7C5D6 },
	{ 0xF0AA81AA, 0x7C5E0 },
	{ 0xF0AA81AB, 0xFE1F4 },
	{ 0xF0AA81AC, 0xFE1F5 },
	{ 0xF0AA81AD, 0x7C5D7 },
	{ 0xF0AA81AE, 0x5E7A9 },
	{ 0xF0AA81B0, 0x7C5E3 },
	{ 0xF0AA81B2, 0x5EBB9 },
	{ 0xF0AA81B7, 0x7CCDD },
	{ 0xF0AA81B8, 0x5EBBA },
	{ 0xF0AA81B9, 0x7CCE2 },
	{ 0xF0AA81BB, 0x5EBBE },
	{ 0xF0AA81BC, 0x5EBCA },
	{ 0xF0AA81BD, 0x5EBC0 },
	{ 0xF0AA81BE, 0x7CCEA },
	{ 0xF0AA81BF, 0x7CCE4 },
	{ 0xF0AA8280, 0x5EBBB },
	{ 0xF0AA8281, 0x7CCE8 },
	{ 0xF0AA8282, 0x7CCEB },
	{ 0xF0AA8283, 0x7CCE3 },
	{ 0xF0AA8284, 0x5EBCC },
	{ 0xF0AA8285, 0x5EBBD },
	{ 0xF0AA8286, 0x5EBCB },
	{ 0xF0AA8287, 0x4E2EB },
	{ 0xF0AA8288, 0x5EBC2 },
	{ 0xF0AA8289, 0x5EBC5 },
	{ 0xF0AA828A, 0x7CCE0 },
	{ 0xF0AA828B, 0x7CCDE },
	{ 0xF0AA828C, 0x5EBC8 },
	{ 0xF0AA828D, 0x5EBC4 },
	{ 0xF0AA828E, 0x7CCDC },
	{ 0xF0AA828F, 0x7CCE6 },
	{ 0xF0AA8290, 0x7CCEC },
	{ 0xF0AA8291, 0x5EBC1 },
	{ 0xF0AA8293, 0x4E2ED },
	{ 0xF0AA8294, 0x7CCE9 },
	{ 0xF0AA8295, 0x5EBC6 },
	{ 0xF0AA8297, 0xFE4F4 },
	{ 0xF0AA8298, 0xFE4F6 },
	{ 0xF0AA8299, 0xFE4F7 },
	{ 0xF0AA829A, 0x7CCE1 },
	{ 0xF0AA829B, 0x5EBC7 },
	{ 0xF0AA829D, 0x7CCEF },
	{ 0xF0AA829E, 0x5EBC9 },
	{ 0xF0AA829F, 0x7C5E9 },
	{ 0xF0AA82A1, 0x7CCE5 },
	{ 0xF0AA82A3, 0x7CCE7 },
	{ 0xF0AA82A5, 0x7CCED },
	{ 0xF0AA82AA, 0x5EBC3 },
	{ 0xF0AA82AD, 0x7CCEE },
	{ 0xF0AA82B4, 0x7CCDF },
	{ 0xF0AA82B5, 0x4E2E9 },
	{ 0xF0AA82B6, 0x5EFB8 },
	{ 0xF0AA82B7, 0x5EFB0 },
	{ 0xF0AA82B8, 0x7D2BA },
	{ 0xF0AA82B9, 0x4E5E5 },
	{ 0xF0AA82BA, 0x5EFBE },
	{ 0xF0AA82BB, 0x7D2C3 },
	{ 0xF0AA82BC, 0x5EFB2 },
	{ 0xF0AA82BD, 0x5EFC2 },
	{ 0xF0AA82BE, 0x4E2F0 },
	{ 0xF0AA82BF, 0x7D2B6 },
	{ 0xF0AA8380, 0x5EFAF },
	{ 0xF0AA8381, 0x4E5E3 },
	{ 0xF0AA8382, 0x5EFB1 },
	{ 0xF0AA8383, 0x4E5EE },
	{ 0xF0AA8384, 0x4E5E8 },
	{ 0xF0AA8385, 0x5EFB3 },
	{ 0xF0AA8386, 0x5EFAD },
	{ 0xF0AA8387, 0x5EFB7 },
	{ 0xF0AA8388, 0x5EFC4 },
	{ 0xF0AA8389, 0x5EFB9 },
	{ 0xF0AA838A, 0x4E5ED },
	{ 0xF0AA838B, 0x4E5E6 },
	{ 0xF0AA838C, 0x5EFBA },
	{ 0xF0AA838D, 0x5EFBC },
	{ 0xF0AA838E, 0x5EFC0 },
	{ 0xF0AA838F, 0x4E5E7 },
	{ 0xF0AA8390, 0x5EFAE },
	{ 0xF0AA8391, 0x5EFBB },
	{ 0xF0AA8392, 0x5EFB6 },
	{ 0xF0AA8393, 0x5EFBF },
	{ 0xF0AA8394, 0x7D2BF },
	{ 0xF0AA8395, 0x7D2BB },
	{ 0xF0AA8396, 0x7D2C0 },
	{ 0xF0AA8397, 0x7D2B5 },
	{ 0xF0AA8398, 0x7D2B7 },
	{ 0xF0AA839A, 0x5EFBD },
	{ 0xF0AA839B, 0x5EFB5 },
	{ 0xF0AA839C, 0x5EFB4 },
	{ 0xF0AA839D, 0x5EFC3 },
	{ 0xF0AA83A0, 0x7D2B8 },
	{ 0xF0AA83A2, 0xFE7B7 },
	{ 0xF0AA83A4, 0x7D2BE },
	{ 0xF0AA83A6, 0x7D2BD },
	{ 0xF0AA83A7, 0x7D2B9 },
	{ 0xF0AA83A9, 0x7D2C4 },
	{ 0xF0AA83AA, 0x7D2C1 },
	{ 0xF0AA83AF, 0x7D2BC },
	{ 0xF0AA83B3, 0xFE7B8 },
	{ 0xF0AA83B6, 0x5EFC1 },
	{ 0xF0AA83B9, 0x7C5DA },
	{ 0xF0AA83BA, 0x5F2DE },
	{ 0xF0AA83BB, 0x7D6F9 },
	{ 0xF0AA83BC, 0x5F2E6 },
	{ 0xF0AA83BD, 0x7D6FE },
	{ 0xF0AA83BE, 0x5F2DD },
	{ 0xF0AA83BF, 0x5F2E0 },
	{ 0xF0AA8480, 0x5F2DB },
	{ 0xF0AA8481, 0x5F2E5 },
	{ 0xF0AA8482, 0x5F2E4 },
	{ 0xF0AA8483, 0x7D7A1 },
	{ 0xF0AA8484, 0x7D6FD },
	{ 0xF0AA8485, 0x7D6FA },
	{ 0xF0AA8486, 0x5F2E8 },
	{ 0xF0AA8487, 0x7D7A7 },
	{ 0xF0AA8489, 0x7D7A6 },
	{ 0xF0AA848A, 0x7D7A4 },
	{ 0xF0AA848B, 0x5F2DC },
	{ 0xF0AA848C, 0x5F2E1 },
	{ 0xF0AA848D, 0x5EFC5 },
	{ 0xF0AA848E, 0x5F2DA },
	{ 0xF0AA848F, 0x5F2E2 },
	{ 0xF0AA8490, 0x7D7A2 },
	{ 0xF0AA8491, 0x7D6FC },
	{ 0xF0AA8492, 0x5F2E9 },
	{ 0xF0AA8493, 0x5F2EA },
	{ 0xF0AA8494, 0xFE9B4 },
	{ 0xF0AA8497, 0x5F2DF },
	{ 0xF0AA8498, 0x7D7A3 },
	{ 0xF0AA849B, 0x7D6F7 },
	{ 0xF0AA849C, 0x7D7A8 },
	{ 0xF0AA849E, 0x7D6F6 },
	{ 0xF0AA84A0, 0x7D6FB },
	{ 0xF0AA84A3, 0xFE9B3 },
	{ 0xF0AA84A9, 0x5F2D8 },
	{ 0xF0AA84AA, 0x7D6F8 },
	{ 0xF0AA84AB, 0x5F2D9 },
	{ 0xF0AA84AC, 0xFE7B6 },
	{ 0xF0AA84AD, 0x5F5C2 },
	{ 0xF0AA84AE, 0x5F5BD },
	{ 0xF0AA84AF, 0x4EAA4 },
	{ 0xF0AA84B0, 0x4EAAD },
	{ 0xF0AA84B1, 0x5F5BC },
	{ 0xF0AA84B2, 0x4EAA8 },
	{ 0xF0AA84B3, 0x5F5C3 },
	{ 0xF0AA84B4, 0x5F5B9 },
	{ 0xF0AA84B5, 0x5EFC6 },
	{ 0xF0AA84B6, 0x5F5C4 },
	{ 0xF0AA84B7, 0x5F5C0 },
	{ 0xF0AA84B8, 0x5F5BF },
	{ 0xF0AA84B9, 0x4EAAB },
	{ 0xF0AA84BB, 0x7DAE2 },
	{ 0xF0AA84BC, 0x7DAEC },
	{ 0xF0AA84BD, 0x7DAEA },
	{ 0xF0AA84BE, 0x7DAF0 },
	{ 0xF0AA84BF, 0x4EAAA },
	{ 0xF0AA8580, 0x7DAEB },
	{ 0xF0AA8581, 0x7DAEE },
	{ 0xF0AA8582, 0x5F5BB },
	{ 0xF0AA8583, 0x4EAA9 },
	{ 0xF0AA8584, 0x7DAE9 },
	{ 0xF0AA8585, 0x5F5B7 },
	{ 0xF0AA8586, 0x7DAE8 },
	{ 0xF0AA8587, 0x5F5B8 },
	{ 0xF0AA8588, 0x5F5C6 },
	{ 0xF0AA8589, 0x5F2E7 },
	{ 0xF0AA858A, 0x7DAF1 },
	{ 0xF0AA858B, 0x5F5C1 },
	{ 0xF0AA858C, 0x7DAEF },
	{ 0xF0AA858D, 0x7DAE7 },
	{ 0xF0AA858E, 0x7D7A5 },
	{ 0xF0AA8591, 0xFEAC4 },
	{ 0xF0AA8592, 0xFEAC5 },
	{ 0xF0AA8593, 0xFEAC6 },
	{ 0xF0AA8594, 0xFEAC7 },
	{ 0xF0AA8595, 0xFEAC8 },
	{ 0xF0AA8596, 0x5F5BE },
	{ 0xF0AA859A, 0x7DAE6 },
	{ 0xF0AA859C, 0x7DAE4 },
	{ 0xF0AA859F, 0x7DAE1 },
	{ 0xF0AA85A1, 0x7DAE3 },
	{ 0xF0AA85AE, 0x5F5BA },
	{ 0xF0AA85AF, 0x7DEAB },
	{ 0xF0AA85B0, 0x7DEA7 },
	{ 0xF0AA85B1, 0x7DEB1 },
	{ 0xF0AA85B2, 0x5F7B3 },
	{ 0xF0AA85B3, 0x7DEAF },
	{ 0xF0AA85B4, 0x5F7AE },
	{ 0xF0AA85B5, 0x5F7A9 },
	{ 0xF0AA85B6, 0x4EBC3 },
	{ 0xF0AA85B7, 0x7DEB2 },
	{ 0xF0AA85B8, 0x7DEB6 },
	{ 0xF0AA85B9, 0x5F7A5 },
	{ 0xF0AA85BA, 0x5F7B0 },
	{ 0xF0AA85BB, 0x5F7AA },
	{ 0xF0AA85BC, 0x5F7A8 },
	{ 0xF0AA85BD, 0x5F7AF },
	{ 0xF0AA85BE, 0x7DEAC },
	{ 0xF0AA85BF, 0x5F7A7 },
	{ 0xF0AA8680, 0x5F7A6 },
	{ 0xF0AA8681, 0x5F7B8 },
	{ 0xF0AA8682, 0x5F7AB },
	{ 0xF0AA8683, 0x4EBC9 },
	{ 0xF0AA8684, 0x4EBC2 },
	{ 0xF0AA8685, 0x7DEB5 },
	{ 0xF0AA8686, 0x5F7B1 },
	{ 0xF0AA8687, 0x7DEB0 },
	{ 0xF0AA8688, 0x7DEB3 },
	{ 0xF0AA8689, 0x5F7AD },
	{ 0xF0AA868A, 0x7DAE5 },
	{ 0xF0AA868B, 0x5F7B5 },
	{ 0xF0AA868C, 0x7DAED },
	{ 0xF0AA868D, 0x7DEB4 },
	{ 0xF0AA8691, 0x5F7B6 },
	{ 0xF0AA8694, 0x7DEAD },
	{ 0xF0AA8695, 0xFEBC0 },
	{ 0xF0AA8696, 0x7DEA4 },
	{ 0xF0AA8697, 0x7DEA6 },
	{ 0xF0AA869A, 0x7DEAE },
	{ 0xF0AA869D, 0x7DEA9 },
	{ 0xF0AA86A1, 0x7DEA8 },
	{ 0xF0AA86A8, 0x5F7B2 },
	{ 0xF0AA86A9, 0x7DEAA },
	{ 0xF0AA86AA, 0x7DEA5 },
	{ 0xF0AA86AB, 0x4EBC1 },
	{ 0xF0AA86AC, 0xFEBFA },
	{ 0xF0AA86AD, 0x7DEB7 },
	{ 0xF0AA86AE, 0x7E0CD },
	{ 0xF0AA86AF, 0x5F8E7 },
	{ 0xF0AA86B0, 0x5F8E9 },
	{ 0xF0AA86B1, 0x5F8ED },
	{ 0xF0AA86B2, 0x5F8E5 },
	{ 0xF0AA86B3, 0x5F7B7 },
	{ 0xF0AA86B4, 0x5F8E8 },
	{ 0xF0AA86B5, 0x7E0CE },
	{ 0xF0AA86B6, 0x5F8EA },
	{ 0xF0AA86B7, 0x5F8EB },
	{ 0xF0AA86B8, 0x7E0CF },
	{ 0xF0AA86B9, 0x7E0D0 },
	{ 0xF0AA86BA, 0x7E0D4 },
	{ 0xF0AA86BB, 0x5F8EC },
	{ 0xF0AA86BC, 0x7E0D3 },
	{ 0xF0AA86BD, 0x7E0CC },
	{ 0xF0AA86BE, 0x7E0D1 },
	{ 0xF0AA86BF, 0x5F8E3 },
	{ 0xF0AA8781, 0x5F8E6 },
	{ 0xF0AA8782, 0x5F8E2 },
	{ 0xF0AA8783, 0xFEBF9 },
	{ 0xF0AA8784, 0x7E0D2 },
	{ 0xF0AA8786, 0x4ECD5 },
	{ 0xF0AA8789, 0x5F8E4 },
	{ 0xF0AA878A, 0x4ECD3 },
	{ 0xF0AA8791, 0x5F9F1 },
	{ 0xF0AA8792, 0x5F9ED },
	{ 0xF0AA8793, 0x5F9F0 },
	{ 0xF0AA8794, 0x7E1F6 },
	{ 0xF0AA8795, 0x4EDBB },
	{ 0xF0AA8796, 0x5F9EE },
	{ 0xF0AA8797, 0x5F9EC },
	{ 0xF0AA8798, 0x4EDBC },
	{ 0xF0AA879A, 0x7E1F4 },
	{ 0xF0AA879C, 0x5F9EF },
	{ 0xF0AA879D, 0x7E1F8 },
	{ 0xF0AA87A0, 0x7E1F5 },
	{ 0xF0AA87A1, 0x7E1F7 },
	{ 0xF0AA87AC, 0x4EDBE },
	{ 0xF0AA87AD, 0x5FAD8 },
	{ 0xF0AA87AE, 0x7E3B9 },
	{ 0xF0AA87AF, 0x5FAD6 },
	{ 0xF0AA87B0, 0x4EDEB },
	{ 0xF0AA87B1, 0x5FADA },
	{ 0xF0AA87B2, 0x5FAD9 },
	{ 0xF0AA87B3, 0x5FAD5 },
	{ 0xF0AA87B4, 0x5FAD7 },
	{ 0xF0AA87B5, 0x4EDEA },
	{ 0xF0AA87B6, 0x7E3B8 },
	{ 0xF0AA87B7, 0x5FAD4 },
	{ 0xF0AA87B8, 0x7E3BB },
	{ 0xF0AA87B9, 0x5FADB },
	{ 0xF0AA87BA, 0x7E3BD },
	{ 0xF0AA87BB, 0xFECDE },
	{ 0xF0AA87BC, 0x7E3BA },
	{ 0xF0AA87BF, 0x7E3B6 },
	{ 0xF0AA8881, 0x7E3BC },
	{ 0xF0AA8883, 0x5FBAE },
	{ 0xF0AA8884, 0x7E4B4 },
	{ 0xF0AA8885, 0x7E4B6 },
	{ 0xF0AA8886, 0x5FBAF },
	{ 0xF0AA8887, 0x5FBAC },
	{ 0xF0AA8889, 0x5FBAB },
	{ 0xF0AA888A, 0x5FBB1 },
	{ 0xF0AA888B, 0x5FBB0 },
	{ 0xF0AA888C, 0x5FBAD },
	{ 0xF0AA888D, 0x7E4B7 },
	{ 0xF0AA888E, 0xFECF6 },
	{ 0xF0AA8890, 0x4EEAE },
	{ 0xF0AA8892, 0x7E4B3 },
	{ 0xF0AA8893, 0x7E4B5 },
	{ 0xF0AA8898, 0x5FBD6 },
	{ 0xF0AA8899, 0x7E5A2 },
	{ 0xF0AA889A, 0x7E5D3 },
	{ 0xF0AA889B, 0x7E5A4 },
	{ 0xF0AA889C, 0x7E5A6 },
	{ 0xF0AA889D, 0x7E5A3 },
	{ 0xF0AA889E, 0x7E5A7 },
	{ 0xF0AA889F, 0x5FBD7 },
	{ 0xF0AA88A2, 0x7E5A5 },
	{ 0xF0AA88A4, 0x4EEC2 },
	{ 0xF0AA88A5, 0x5FBF4 },
	{ 0xF0AA88A6, 0x7E5D4 },
	{ 0xF0AA88A7, 0x7E5D5 },
	{ 0xF0AA88A8, 0x5FBF5 },
	{ 0xF0AA88A9, 0x7E5D2 },
	{ 0xF0AA88AA, 0x7E5D6 },
	{ 0xF0AA88AB, 0x7E5D1 },
	{ 0xF0AA88AE, 0x7E5ED },
	{ 0xF0AA88AF, 0x7E5EC },
	{ 0xF0AA88B0, 0x5FCA9 },
	{ 0xF0AA88B1, 0x5FCA8 },
	{ 0xF0AA88B2, 0xFEDB2 },
	{ 0xF0AA88B4, 0x5FCAF },
	{ 0xF0AA88B5, 0x7E6A1 },
	{ 0xF0AA88B7, 0x7E5FE },
	{ 0xF0AA88B8, 0x5FCB8 },
	{ 0xF0AA88B9, 0x7E6B0 },
	{ 0xF0AA88BA, 0x5FCB9 },
	{ 0xF0AA88BB, 0x7E6BA },
	{ 0xF0AA88BC, 0x5FCC1 },
	{ 0xF0AA88BD, 0xFEDB7 },
	{ 0xF0AA88BF, 0x5FCC8 },
	{ 0xF0AA8980, 0x7E6C5 },
	{ 0xF0AA8996, 0x4C8F1 },
	{ 0xF0AA8997, 0x4C8F2 },
	{ 0xF0AA8998, 0x5D3C4 },
	{ 0xF0AA8999, 0x7ACA2 },
	{ 0xF0AA899A, 0x7ACA1 },
	{ 0xF0AA899B, 0x7ABFE },
	{ 0xF0AA899C, 0x5DADA },
	{ 0xF0AA899D, 0x5DADC },
	{ 0xF0AA899E, 0x7B6DA },
	{ 0xF0AA899F, 0x7B6DB },
	{ 0xF0AA89A0, 0xFD9C1 },
	{ 0xF0AA89A1, 0x7B6D9 },
	{ 0xF0AA89A3, 0x5E7AC },
	{ 0xF0AA89A4, 0x7BED9 },
	{ 0xF0AA89A6, 0x4E2F1 },
	{ 0xF0AA89A7, 0x7CCF0 },
	{ 0xF0AA89A8, 0x5EBCD },
	{ 0xF0AA89A9, 0x7CCF1 },
	{ 0xF0AA89AD, 0x7D2C6 },
	{ 0xF0AA89AE, 0x5EFC8 },
	{ 0xF0AA89AF, 0x5EFC9 },
	{ 0xF0AA89B0, 0x7D2C7 },
	{ 0xF0AA89B1, 0x5EFC7 },
	{ 0xF0AA89B2, 0x7D2C9 },
	{ 0xF0AA89B3, 0x7D2C8 },
	{ 0xF0AA89B5, 0x4E8C5 },
	{ 0xF0AA89B6, 0x7D7AB },
	{ 0xF0AA89B7, 0x7D7AA },
	{ 0xF0AA89B8, 0x5F2EB },
	{ 0xF0AA89BA, 0x7DAF3 },
	{ 0xF0AA89BC, 0x7DAF2 },
	{ 0xF0AA89BF, 0x4EBCC },
	{ 0xF0AA8A80, 0x7DEB8 },
	{ 0xF0AA8A81, 0x7DEB9 },
	{ 0xF0AA8A82, 0x5F7B9 },
	{ 0xF0AA8A83, 0x7E0D5 },
	{ 0xF0AA8A84, 0x4ECD7 },
	{ 0xF0AA8A86, 0x5F9F2 },
	{ 0xF0AA8A87, 0x4EDBF },
	{ 0xF0AA8A88, 0x7E3BE },
	{ 0xF0AA8A89, 0x5FBB2 },
	{ 0xF0AA8A8B, 0x6DADD },
	{ 0xF0AA8A8C, 0xFC6BD },
	{ 0xF0AA8A8D, 0x5CBEC },
	{ 0xF0AA8A8E, 0xFCDD2 },
	{ 0xF0AA8A8F, 0x7ACA8 },
	{ 0xF0AA8A90, 0x5D3C5 },
	{ 0xF0AA8A91, 0x7ACA7 },
	{ 0xF0AA8A93, 0x7ACA6 },
	{ 0xF0AA8A94, 0x7ACA4 },
	{ 0xF0AA8A95, 0x5D3C6 },
	{ 0xF0AA8A96, 0x7ACA5 },
	{ 0xF0AA8A97, 0x5D3C7 },
	{ 0xF0AA8A98, 0x7ACA9 },
	{ 0xF0AA8A99, 0x7ACA3 },
	{ 0xF0AA8A9B, 0x7B6DD },
	{ 0xF0AA8A9C, 0x5DADD },
	{ 0xF0AA8A9E, 0xFD9C2 },
	{ 0xF0AA8AA0, 0xFD9C3 },
	{ 0xF0AA8AA1, 0xFD9C4 },
	{ 0xF0AA8AA5, 0x5E0EF },
	{ 0xF0AA8AA6, 0x5E0F2 },
	{ 0xF0AA8AA7, 0x5E0F0 },
	{ 0xF0AA8AA8, 0x4DADC },
	{ 0xF0AA8AAA, 0x5E0F3 },
	{ 0xF0AA8AAB, 0x5E0F1 },
	{ 0xF0AA8AAC, 0x7BEDB },
	{ 0xF0AA8AAD, 0x7BEDA },
	{ 0xF0AA8AAF, 0x7BEDE },
	{ 0xF0AA8AB1, 0x7BEDD },
	{ 0xF0AA8AB2, 0xFDEA6 },
	{ 0xF0AA8AB3, 0x5E0EE },
	{ 0xF0AA8AB4, 0x7C5EE },
	{ 0xF0AA8AB5, 0x5E7B1 },
	{ 0xF0AA8AB6, 0x5E7AE },
	{ 0xF0AA8AB7, 0x5E7AD },
	{ 0xF0AA8AB8, 0x7C5EB },
	{ 0xF0AA8AB9, 0x7C5ED },
	{ 0xF0AA8ABA, 0x7C5EA },
	{ 0xF0AA8ABB, 0x5E7B0 },
	{ 0xF0AA8ABC, 0x7C5EC },
	{ 0xF0AA8ABD, 0xFE1F8 },
	{ 0xF0AA8ABE, 0xFE1F9 },
	{ 0xF0AA8ABF, 0xFE1FA },
	{ 0xF0AA8B83, 0x5E7AF },
	{ 0xF0AA8B84, 0x5EBCF },
	{ 0xF0AA8B85, 0x5EBCE },
	{ 0xF0AA8B86, 0x5EBD1 },
	{ 0xF0AA8B87, 0x4E2F3 },
	{ 0xF0AA8B88, 0x7CCF3 },
	{ 0xF0AA8B89, 0x5EBD0 },
	{ 0xF0AA8B8B, 0x7CCF2 },
	{ 0xF0AA8B8D, 0x5E8C0 },
	{ 0xF0AA8B8E, 0x7D2CB },
	{ 0xF0AA8B8F, 0x4E2F4 },
	{ 0xF0AA8B90, 0x4E5EF },
	{ 0xF0AA8B91, 0x7CCF4 },
	{ 0xF0AA8B92, 0xFE7B9 },
	{ 0xF0AA8B94, 0x7D2CA },
	{ 0xF0AA8B95, 0x7D2CC },
	{ 0xF0AA8B96, 0x5EFCA },
	{ 0xF0AA8B97, 0x4E8C7 },
	{ 0xF0AA8B98, 0x7D7AC },
	{ 0xF0AA8B99, 0x7D7AD },
	{ 0xF0AA8B9A, 0x4E8C6 },
	{ 0xF0AA8B9B, 0xFE9B5 },
	{ 0xF0AA8B9C, 0x5F5C7 },
	{ 0xF0AA8B9D, 0x4EAAE },
	{ 0xF0AA8B9E, 0xFEAC9 },
	{ 0xF0AA8BA1, 0x5F7BA },
	{ 0xF0AA8BA2, 0x5F7BC },
	{ 0xF0AA8BA3, 0x5F7BB },
	{ 0xF0AA8BA5, 0x7DEBA },
	{ 0xF0AA8BA7, 0x7DEBB },
	{ 0xF0AA8BAA, 0x7E0D6 },
	{ 0xF0AA8BAB, 0x4ECD8 },
	{ 0xF0AA8BAC, 0x7E0D7 },
	{ 0xF0AA8BAD, 0xFEBFB },
	{ 0xF0AA8BAE, 0x5F9F5 },
	{ 0xF0AA8BAF, 0x5F9F4 },
	{ 0xF0AA8BB0, 0x5F8EE },
	{ 0xF0AA8BB2, 0x4EDC0 },
	{ 0xF0AA8BB3, 0x4EDEC },
	{ 0xF0AA8BB4, 0xFECC7 },
	{ 0xF0AA8BB7, 0x7E5A8 },
	{ 0xF0AA8BB8, 0x7E5D7 },
	{ 0xF0AA8BBA, 0x5FCC6 },
	{ 0xF0AA8BBB, 0x7E6C7 },
	{ 0xF0AA8BBC, 0x6DADF },
	{ 0xF0AA8BBD, 0x6DADE },
	{ 0xF0AA8BBE, 0x5C4D3 },
	{ 0xF0AA8BBF, 0xFC6BF },
	{ 0xF0AA8C81, 0x4C8F5 },
	{ 0xF0AA8C82, 0x6E4F5 },
	{ 0xF0AA8C83, 0xFCDD3 },
	{ 0xF0AA8C85, 0x5D3CB },
	{ 0xF0AA8C86, 0x5D3CA },
	{ 0xF0AA8C87, 0x4CFCF },
	{ 0xF0AA8C88, 0x5D3C9 },
	{ 0xF0AA8C89, 0x5D3C8 },
	{ 0xF0AA8C8A, 0x7ACAB },
	{ 0xF0AA8C8B, 0x7ACAF },
	{ 0xF0AA8C8C, 0x7ACAA },
	{ 0xF0AA8C8D, 0x4CFCE },
	{ 0xF0AA8C8E, 0x7ACAC },
	{ 0xF0AA8C90, 0x5D3CC },
	{ 0xF0AA8C91, 0x7ACAE },
	{ 0xF0AA8C92, 0x7ACAD },
	{ 0xF0AA8C94, 0x7B6E1 },
	{ 0xF0AA8C95, 0x7B6DF },
	{ 0xF0AA8C96, 0x7B6DE },
	{ 0xF0AA8C97, 0x7B6E3 },
	{ 0xF0AA8C98, 0x4D5DB },
	{ 0xF0AA8C9A, 0x7B6E2 },
	{ 0xF0AA8C9B, 0x6C7D3 },
	{ 0xF0AA8C9C, 0xFD9C5 },
	{ 0xF0AA8C9D, 0x5DADE },
	{ 0xF0AA8CA0, 0x7B6E0 },
	{ 0xF0AA8CA2, 0x5E0F4 },
	{ 0xF0AA8CA3, 0x5E0F5 },
	{ 0xF0AA8CA4, 0x7BEE0 },
	{ 0xF0AA8CA5, 0x7BEE1 },
	{ 0xF0AA8CA6, 0xFDEA8 },
	{ 0xF0AA8CA8, 0x7BEE2 },
	{ 0xF0AA8CAC, 0x7BEDF },
	{ 0xF0AA8CAD, 0x7C5F0 },
	{ 0xF0AA8CAE, 0x5E7B2 },
	{ 0xF0AA8CAF, 0x7C5F2 },
	{ 0xF0AA8CB0, 0x5E7B3 },
	{ 0xF0AA8CB1, 0x5E7B5 },
	{ 0xF0AA8CB2, 0x7C5F3 },
	{ 0xF0AA8CB3, 0x5E7B4 },
	{ 0xF0AA8CB4, 0xFE1FB },
	{ 0xF0AA8CB8, 0x7C5F1 },
	{ 0xF0AA8CBB, 0x7C5EF },
	{ 0xF0AA8CBC, 0x4E2FA },
	{ 0xF0AA8CBD, 0x4E2F8 },
	{ 0xF0AA8CBE, 0x7CCF9 },
	{ 0xF0AA8CBF, 0x7CCFB },
	{ 0xF0AA8D80, 0x7CCF5 },
	{ 0xF0AA8D81, 0x5EBD4 },
	{ 0xF0AA8D82, 0x5EBD2 },
	{ 0xF0AA8D83, 0x7CCFA },
	{ 0xF0AA8D84, 0x5EBD5 },
	{ 0xF0AA8D85, 0x5EBD3 },
	{ 0xF0AA8D86, 0x7CCF8 },
	{ 0xF0AA8D87, 0x4E2FB },
	{ 0xF0AA8D89, 0x7CCF7 },
	{ 0xF0AA8D8B, 0x7CCF6 },
	{ 0xF0AA8D8C, 0x5EFCB },
	{ 0xF0AA8D8D, 0x7D2D3 },
	{ 0xF0AA8D8E, 0x7D2D2 },
	{ 0xF0AA8D8F, 0x5EFCC },
	{ 0xF0AA8D90, 0x7D2D0 },
	{ 0xF0AA8D91, 0x4E5F0 },
	{ 0xF0AA8D92, 0x7D2CF },
	{ 0xF0AA8D93, 0x5EFCE },
	{ 0xF0AA8D94, 0x5EFCD },
	{ 0xF0AA8D95, 0x7D2D1 },
	{ 0xF0AA8D96, 0xFE7BA },
	{ 0xF0AA8D98, 0x7D2CE },
	{ 0xF0AA8D9A, 0x7D2CD },
	{ 0xF0AA8D9B, 0x5F2EC },
	{ 0xF0AA8D9C, 0x7D7AF },
	{ 0xF0AA8D9D, 0x5F2EF },
	{ 0xF0AA8D9E, 0x7D7B0 },
	{ 0xF0AA8D9F, 0x5F2EE },
	{ 0xF0AA8DA0, 0x7D7B1 },
	{ 0xF0AA8DA1, 0x7D7AE },
	{ 0xF0AA8DA2, 0x5F2ED },
	{ 0xF0AA8DA3, 0x5F5CB },
	{ 0xF0AA8DA4, 0x5F5CC },
	{ 0xF0AA8DA5, 0x7DAF4 },
	{ 0xF0AA8DA6, 0x5F5C9 },
	{ 0xF0AA8DA7, 0x5F5CE },
	{ 0xF0AA8DA8, 0x7DAFB },
	{ 0xF0AA8DA9, 0x7DAF6 },
	{ 0xF0AA8DAA, 0x7DAF7 },
	{ 0xF0AA8DAB, 0x7DAFC },
	{ 0xF0AA8DAC, 0x7DAF9 },
	{ 0xF0AA8DAD, 0x5F5CA },
	{ 0xF0AA8DAE, 0x7DAF5 },
	{ 0xF0AA8DAF, 0x7DAF8 },
	{ 0xF0AA8DB0, 0x7DAFA },
	{ 0xF0AA8DB2, 0x5F7BF },
	{ 0xF0AA8DB3, 0x4EBCF },
	{ 0xF0AA8DB4, 0x5F7BE },
	{ 0xF0AA8DB5, 0x5F7C0 },
	{ 0xF0AA8DB6, 0x5F7BD },
	{ 0xF0AA8DB8, 0x5F8EF },
	{ 0xF0AA8DB9, 0x5F8F1 },
	{ 0xF0AA8DBA, 0x5F8F0 },
	{ 0xF0AA8DBB, 0x7E0D9 },
	{ 0xF0AA8DBC, 0x7DEBC },
	{ 0xF0AA8DBD, 0x4ECD9 },
	{ 0xF0AA8DBE, 0x7E0D8 },
	{ 0xF0AA8DBF, 0x4EDED },
	{ 0xF0AA8E80, 0x7E3BF },
	{ 0xF0AA8E81, 0x7E4B9 },
	{ 0xF0AA8E82, 0x7E4B8 },
	{ 0xF0AA8E83, 0x5FBD8 },
	{ 0xF0AA8E84, 0x7E5A9 },
	{ 0xF0AA8E86, 0x4EED2 },
	{ 0xF0AA8E87, 0x5FCB0 },
	{ 0xF0AA8E8D, 0xFA9A1 },
	{ 0xF0AA8E8E, 0xFC6BE },
	{ 0xF0AA8E8F, 0xFD3C2 },
	{ 0xF0AA8E90, 0xFDEA7 },
	{ 0xF0AA8E92, 0x5CBF0 },
	{ 0xF0AA8E93, 0x5CBEE },
	{ 0xF0AA8E94, 0x5CBEF },
	{ 0xF0AA8E95, 0x5D3CE },
	{ 0xF0AA8E96, 0x4CFD0 },
	{ 0xF0AA8E97, 0x5D3CD },
	{ 0xF0AA8E9A, 0x7ACB0 },
	{ 0xF0AA8E9B, 0x5DAE1 },
	{ 0xF0AA8E9C, 0x7B6E4 },
	{ 0xF0AA8E9D, 0x5DADF },
	{ 0xF0AA8E9E, 0x5DAE0 },
	{ 0xF0AA8E9F, 0xFD9C6 },
	{ 0xF0AA8EA0, 0x5E0F8 },
	{ 0xF0AA8EA1, 0x5E0F6 },
	{ 0xF0AA8EA2, 0xFDEA9 },
	{ 0xF0AA8EA3, 0x5E0F7 },
	{ 0xF0AA8EA4, 0x5E7B6 },
	{ 0xF0AA8EA5, 0x7CCFC },
	{ 0xF0AA8EA6, 0x5EBD6 },
	{ 0xF0AA8EA7, 0x7CCFD },
	{ 0xF0AA8EA8, 0x4E5F3 },
	{ 0xF0AA8EAA, 0x7D7B2 },
	{ 0xF0AA8EAB, 0x5F2F0 },
	{ 0xF0AA8EAC, 0x7DAFE },
	{ 0xF0AA8EAD, 0x4EBD0 },
	{ 0xF0AA8EAE, 0x7DBD6 },
	{ 0xF0AA8EAF, 0x7DEBD },
	{ 0xF0AA8EB0, 0x4EBD1 },
	{ 0xF0AA8EB2, 0x5FCB1 },
	{ 0xF0AA8EB3, 0xFCDD4 },
	{ 0xF0AA8EB4, 0x7ACB2 },
	{ 0xF0AA8EB5, 0x5DAE2 },
	{ 0xF0AA8EB6, 0x5DAE4 },
	{ 0xF0AA8EB9, 0x5DAE3 },
	{ 0xF0AA8EBA, 0x5E0FA },
	{ 0xF0AA8EBB, 0x5E7B8 },
	{ 0xF0AA8EBD, 0x5E0F9 },
	{ 0xF0AA8EBE, 0x5E7B9 },
	{ 0xF0AA8F81, 0x5E7B7 },
	{ 0xF0AA8F82, 0x5EBD7 },
	{ 0xF0AA8F83, 0x4E3A2 },
	{ 0xF0AA8F84, 0xFE4F9 },
	{ 0xF0AA8F86, 0x4E5F5 },
	{ 0xF0AA8F87, 0x4E5F4 },
	{ 0xF0AA8F88, 0x5EFD0 },
	{ 0xF0AA8F89, 0x5EFCF },
	{ 0xF0AA8F8A, 0x4E5F7 },
	{ 0xF0AA8F8B, 0x7D2D4 },
	{ 0xF0AA8F8C, 0x7D2D5 },
	{ 0xF0AA8F8D, 0x7D2D6 },
	{ 0xF0AA8F8E, 0xFE7BB },
	{ 0xF0AA8F91, 0x7D2D7 },
	{ 0xF0AA8F93, 0x5F2F3 },
	{ 0xF0AA8F94, 0x5F2F2 },
	{ 0xF0AA8F95, 0x5F2F1 },
	{ 0xF0AA8F96, 0x7D7B3 },
	{ 0xF0AA8F98, 0x7D7B4 },
	{ 0xF0AA8F99, 0x5F5CF },
	{ 0xF0AA8F9A, 0x4EAAF },
	{ 0xF0AA8F9B, 0x4EAB0 },
	{ 0xF0AA8F9C, 0x7DBA3 },
	{ 0xF0AA8F9D, 0x7DBA2 },
	{ 0xF0AA8F9E, 0x7DBA1 },
	{ 0xF0AA8FA1, 0x7DEBE },
	{ 0xF0AA8FA4, 0x5F8F2 },
	{ 0xF0AA8FA5, 0x7E0DA },
	{ 0xF0AA8FA6, 0x5F8F3 },
	{ 0xF0AA8FA7, 0x7E1F9 },
	{ 0xF0AA8FA8, 0x5F9F6 },
	{ 0xF0AA8FAC, 0x7E6A7 },
	{ 0xF0AA8FAD, 0x4C8F6 },
	{ 0xF0AA8FAE, 0x5D3CF },
	{ 0xF0AA8FAF, 0x4CFD1 },
	{ 0xF0AA8FB0, 0x7B6E8 },
	{ 0xF0AA8FB1, 0x7B6E6 },
	{ 0xF0AA8FB2, 0x5DAE6 },
	{ 0xF0AA8FB3, 0x5DAE5 },
	{ 0xF0AA8FB4, 0x5DAE7 },
	{ 0xF0AA8FB6, 0x5E0FE },
	{ 0xF0AA8FB7, 0x7BEE4 },
	{ 0xF0AA8FB8, 0x5E0FC },
	{ 0xF0AA8FB9, 0x7BEE3 },
	{ 0xF0AA8FBA, 0x5E0FB },
	{ 0xF0AA8FBB, 0x4DADE },
	{ 0xF0AA8FBC, 0x5E0FD },
	{ 0xF0AA8FBD, 0x7BEE5 },
	{ 0xF0AA8FBE, 0x7BEE6 },
	{ 0xF0AA8FBF, 0x5E7BB },
	{ 0xF0AA9080, 0x5E7BA },
	{ 0xF0AA9082, 0x4E5F8 },
	{ 0xF0AA9083, 0x5EFD1 },
	{ 0xF0AA9084, 0x5EFD3 },
	{ 0xF0AA9087, 0x5F2F4 },
	{ 0xF0AA9088, 0x7D7B6 },
	{ 0xF0AA9089, 0x7D7B5 },
	{ 0xF0AA908A, 0xFE9B6 },
	{ 0xF0AA908B, 0x5F5D0 },
	{ 0xF0AA908C, 0x4EBD4 },
	{ 0xF0AA908D, 0x5F7C2 },
	{ 0xF0AA908E, 0x5F7C1 },
	{ 0xF0AA908F, 0x4EBD3 },
	{ 0xF0AA9091, 0x7E3C0 },
	{ 0xF0AA9092, 0x7E1FA },
	{ 0xF0AA9093, 0x4EDEE },
	{ 0xF0AA9094, 0x5FBDA },
	{ 0xF0AA9095, 0x7E5AA },
	{ 0xF0AA9096, 0x5FBD9 },
	{ 0xF0AA9097, 0x6E4F6 },
	{ 0xF0AA9098, 0x5C4D4 },
	{ 0xF0AA9099, 0x6E4F8 },
	{ 0xF0AA909B, 0x6E4F7 },
	{ 0xF0AA909C, 0x7ACB4 },
	{ 0xF0AA909D, 0x4CFD5 },
	{ 0xF0AA909E, 0x4CFD4 },
	{ 0xF0AA909F, 0x5D3D0 },
	{ 0xF0AA90A0, 0x7ACB5 },
	{ 0xF0AA90A1, 0x7ACB6 },
	{ 0xF0AA90A4, 0x7B6EA },
	{ 0xF0AA90A5, 0x5DAEA },
	{ 0xF0AA90A6, 0x5DAE8 },
	{ 0xF0AA90A7, 0x5DAE9 },
	{ 0xF0AA90A8, 0x7B6E9 },
	{ 0xF0AA90AA, 0x7B6EB },
	{ 0xF0AA90AB, 0x7B6EC },
	{ 0xF0AA90B2, 0x4DAE0 },
	{ 0xF0AA90B3, 0x7BEE8 },
	{ 0xF0AA90B4, 0x5E1A1 },
	{ 0xF0AA90B8, 0xFDEAA },
	{ 0xF0AA90B9, 0x7BEE7 },
	{ 0xF0AA90BF, 0x5E7BE },
	{ 0xF0AA9180, 0x5E7BC },
	{ 0xF0AA9181, 0x7C5F4 },
	{ 0xF0AA9182, 0x5EBD8 },
	{ 0xF0AA9183, 0x5E1A2 },
	{ 0xF0AA9184, 0x5E7BF },
	{ 0xF0AA9188, 0x5EBDA },
	{ 0xF0AA9189, 0x5EBD9 },
	{ 0xF0AA918A, 0x5EBDB },
	{ 0xF0AA918B, 0x5EBDD },
	{ 0xF0AA918C, 0x5EBDC },
	{ 0xF0AA918D, 0x7CDA1 },
	{ 0xF0AA918E, 0x7CCFE },
	{ 0xF0AA9192, 0x5EFD6 },
	{ 0xF0AA9193, 0x5EFD7 },
	{ 0xF0AA9194, 0x7D2DB },
	{ 0xF0AA9195, 0x5EFDB },
	{ 0xF0AA9196, 0x5EFD9 },
	{ 0xF0AA9197, 0x5EFD5 },
	{ 0xF0AA9198, 0x7D2D8 },
	{ 0xF0AA9199, 0x4E5FE },
	{ 0xF0AA919A, 0x4E5FB },
	{ 0xF0AA919B, 0x7D2DC },
	{ 0xF0AA919C, 0x5EFDA },
	{ 0xF0AA919D, 0x4E5FA },
	{ 0xF0AA919E, 0x7D2DA },
	{ 0xF0AA91A1, 0xFE7BC },
	{ 0xF0AA91A3, 0x7D2D9 },
	{ 0xF0AA91A5, 0x7D7B8 },
	{ 0xF0AA91A6, 0x4E8D3 },
	{ 0xF0AA91A7, 0x4E8D1 },
	{ 0xF0AA91A8, 0x5F2F8 },
	{ 0xF0AA91A9, 0x4E8D0 },
	{ 0xF0AA91AA, 0x5F2FB },
	{ 0xF0AA91AB, 0x7D7B7 },
	{ 0xF0AA91AC, 0x5F2F5 },
	{ 0xF0AA91AD, 0x5F2F9 },
	{ 0xF0AA91AE, 0x5F2F7 },
	{ 0xF0AA91AF, 0x4E8D4 },
	{ 0xF0AA91B0, 0x5F2F6 },
	{ 0xF0AA91B1, 0x4E8D5 },
	{ 0xF0AA91B2, 0x4EAB4 },
	{ 0xF0AA91B3, 0x7D7B9 },
	{ 0xF0AA91B4, 0x7D7BA },
	{ 0xF0AA91B7, 0x5F2FA },
	{ 0xF0AA91BE, 0x5F5D1 },
	{ 0xF0AA91BF, 0x4EAB3 },
	{ 0xF0AA9280, 0x4EAB5 },
	{ 0xF0AA9281, 0x7DBAA },
	{ 0xF0AA9282, 0x7DBA7 },
	{ 0xF0AA9283, 0x7DBA6 },
	{ 0xF0AA9284, 0x4EAB2 },
	{ 0xF0AA9285, 0x7DBA9 },
	{ 0xF0AA9288, 0x7DBA8 },
	{ 0xF0AA928B, 0x5F5D2 },
	{ 0xF0AA928C, 0x7DBA5 },
	{ 0xF0AA928F, 0x5F7C7 },
	{ 0xF0AA9290, 0x7DEC1 },
	{ 0xF0AA9291, 0x5F7C6 },
	{ 0xF0AA9292, 0x5F7C4 },
	{ 0xF0AA9293, 0x5F7C5 },
	{ 0xF0AA9294, 0x5F7C3 },
	{ 0xF0AA9295, 0x5F7C8 },
	{ 0xF0AA9296, 0x7DEBF },
	{ 0xF0AA9298, 0x5F8F6 },
	{ 0xF0AA9299, 0x5F8F7 },
	{ 0xF0AA929A, 0x7E0DD },
	{ 0xF0AA929B, 0x4ECDC },
	{ 0xF0AA929C, 0x4ECE0 },
	{ 0xF0AA929D, 0x5F8F5 },
	{ 0xF0AA929E, 0x7E0DC },
	{ 0xF0AA929F, 0x5F8F4 },
	{ 0xF0AA92A0, 0x4ECDF },
	{ 0xF0AA92A1, 0x4ECDE },
	{ 0xF0AA92A2, 0x4ECDD },
	{ 0xF0AA92A3, 0x7DEC0 },
	{ 0xF0AA92A7, 0x7E0DB },
	{ 0xF0AA92A9, 0x5F9F8 },
	{ 0xF0AA92AA, 0x5F9F9 },
	{ 0xF0AA92AB, 0x5F9FA },
	{ 0xF0AA92AC, 0x5F9F7 },
	{ 0xF0AA92AD, 0x4EDC5 },
	{ 0xF0AA92AE, 0x7E1FB },
	{ 0xF0AA92AF, 0x7E1FC },
	{ 0xF0AA92B0, 0x4EDC6 },
	{ 0xF0AA92B4, 0x5FADC },
	{ 0xF0AA92B5, 0x7E4BA },
	{ 0xF0AA92B8, 0x7E5AB },
	{ 0xF0AA92B9, 0x4EEB0 },
	{ 0xF0AA92BA, 0x7E4BB },
	{ 0xF0AA92BB, 0x5FBB3 },
	{ 0xF0AA92BE, 0x4EEAF },
	{ 0xF0AA92BF, 0x5FBDB },
	{ 0xF0AA9380, 0x5FBDC },
	{ 0xF0AA9381, 0x7E5AC },
	{ 0xF0AA9383, 0x4EECA },
	{ 0xF0AA9384, 0x5FBF6 },
	{ 0xF0AA9386, 0x7E5EE },
	{ 0xF0AA9389, 0x5FCCA },
	{ 0xF0AA938A, 0x7E6D2 },
	{ 0xF0AA938B, 0x7C5F5 },
	{ 0xF0AA938C, 0x4E6A2 },
	{ 0xF0AA938E, 0x5F2FC },
	{ 0xF0AA938F, 0x4E8D7 },
	{ 0xF0AA9390, 0x5F7C9 },
	{ 0xF0AA9391, 0x6E4F9 },
	{ 0xF0AA9392, 0x7ACB8 },
	{ 0xF0AA9393, 0x7ACB7 },
	{ 0xF0AA9394, 0x5E1A4 },
	{ 0xF0AA9395, 0x7B6ED },
	{ 0xF0AA9396, 0x4DAE1 },
	{ 0xF0AA9397, 0x7BEE9 },
	{ 0xF0AA9398, 0x7BEEA },
	{ 0xF0AA939A, 0x7C5F8 },
	{ 0xF0AA939B, 0x5E7C2 },
	{ 0xF0AA939C, 0x7C5F9 },
	{ 0xF0AA939D, 0x7C5F7 },
	{ 0xF0AA939E, 0x7C5F6 },
	{ 0xF0AA939F, 0x4DFC1 },
	{ 0xF0AA93A1, 0x7CDA4 },
	{ 0xF0AA93A2, 0x7CDA5 },
	{ 0xF0AA93A4, 0x7BEEB },
	{ 0xF0AA93A5, 0x7CDA3 },
	{ 0xF0AA93A7, 0x7D2DE },
	{ 0xF0AA93A8, 0x7D2DF },
	{ 0xF0AA93A9, 0x7D2DD },
	{ 0xF0AA93AC, 0x5F2FD },
	{ 0xF0AA93AD, 0x7D7BB },
	{ 0xF0AA93AE, 0x4EAB6 },
	{ 0xF0AA93AF, 0x7DBAC },
	{ 0xF0AA93B0, 0x7DBB1 },
	{ 0xF0AA93B1, 0x7DBB2 },
	{ 0xF0AA93B2, 0x7DBAE },
	{ 0xF0AA93B3, 0x7DBB0 },
	{ 0xF0AA93B4, 0x7DBAD },
	{ 0xF0AA93B5, 0x7DBAB },
	{ 0xF0AA93B6, 0x7DBAF },
	{ 0xF0AA93B7, 0x5F7CA },
	{ 0xF0AA93B8, 0x7DEC2 },
	{ 0xF0AA93B9, 0x5F8F8 },
	{ 0xF0AA93BB, 0x5F9FB },
	{ 0xF0AA93BC, 0x5FADD },
	{ 0xF0AA93BD, 0x4EDC7 },
	{ 0xF0AA93BE, 0x7E3C1 },
	{ 0xF0AA93BF, 0x5FBB4 },
	{ 0xF0AA9480, 0x7E3C2 },
	{ 0xF0AA9481, 0x7E5AD },
	{ 0xF0AA9482, 0x6D0CF },
	{ 0xF0AA9484, 0x7B6EE },
	{ 0xF0AA9485, 0x7B6EF },
	{ 0xF0AA9486, 0x5DAEB },
	{ 0xF0AA9488, 0x7C6CF },
	{ 0xF0AA948A, 0x7E5AE },
	{ 0xF0AA948B, 0x5DAEC },
	{ 0xF0AA948D, 0x5E1A5 },
	{ 0xF0AA948E, 0x7BEED },
	{ 0xF0AA948F, 0x5E7C3 },
	{ 0xF0AA9490, 0x7C5FA },
	{ 0xF0AA9491, 0x5E7C4 },
	{ 0xF0AA9492, 0xFE1FD },
	{ 0xF0AA9494, 0x7CDA7 },
	{ 0xF0AA9495, 0x5EBE0 },
	{ 0xF0AA9496, 0x7CDA6 },
	{ 0xF0AA9497, 0x5EBDE },
	{ 0xF0AA9498, 0x5EBDF },
	{ 0xF0AA949B, 0x4E3A5 },
	{ 0xF0AA949C, 0x4E6A3 },
	{ 0xF0AA949D, 0x7D2E0 },
	{ 0xF0AA94A2, 0x4EAB9 },
	{ 0xF0AA94A3, 0x4E8D8 },
	{ 0xF0AA94A4, 0x7D7BC },
	{ 0xF0AA94A5, 0x7D7BD },
	{ 0xF0AA94A6, 0x5F5D3 },
	{ 0xF0AA94A7, 0x7DBB4 },
	{ 0xF0AA94A8, 0x7DBB5 },
	{ 0xF0AA94A9, 0x5F5D5 },
	{ 0xF0AA94AA, 0x4EAB8 },
	{ 0xF0AA94AB, 0x7DBB3 },
	{ 0xF0AA94AC, 0x5F5D4 },
	{ 0xF0AA94AE, 0x7DEC3 },
	{ 0xF0AA94AF, 0x7E0DE },
	{ 0xF0AA94B0, 0x5F8F9 },
	{ 0xF0AA94B1, 0x7E0DF },
	{ 0xF0AA94B3, 0x5F9FC },
	{ 0xF0AA94B5, 0x7E3C3 },
	{ 0xF0AA94B6, 0x5FBB5 },
	{ 0xF0AA94B7, 0x5FBF7 },
	{ 0xF0AA94B8, 0x7ACB9 },
	{ 0xF0AA94BA, 0x5DAED },
	{ 0xF0AA94BB, 0x7BEEE },
	{ 0xF0AA94BC, 0x5DAEE },
	{ 0xF0AA94BD, 0x5E1A8 },
	{ 0xF0AA94BE, 0x5E1AA },
	{ 0xF0AA94BF, 0x5E1AB },
	{ 0xF0AA9580, 0x5E1A9 },
	{ 0xF0AA9581, 0x5E1A7 },
	{ 0xF0AA9582, 0x7BEF0 },
	{ 0xF0AA9583, 0x5E1A6 },
	{ 0xF0AA9584, 0x7BEEF },
	{ 0xF0AA9586, 0x5E1AC },
	{ 0xF0AA9588, 0x4DAE2 },
	{ 0xF0AA9589, 0x7C5FC },
	{ 0xF0AA958A, 0x7CDAC },
	{ 0xF0AA958B, 0x5E7C7 },
	{ 0xF0AA958C, 0x5E7C8 },
	{ 0xF0AA958D, 0x5E7C6 },
	{ 0xF0AA958E, 0x5E7C5 },
	{ 0xF0AA958F, 0x7C5FB },
	{ 0xF0AA9591, 0x7CDAA },
	{ 0xF0AA9592, 0x5EBE1 },
	{ 0xF0AA9593, 0x5EBE3 },
	{ 0xF0AA9594, 0x5EBE2 },
	{ 0xF0AA9597, 0x7CDAD },
	{ 0xF0AA9598, 0x7CDAE },
	{ 0xF0AA9599, 0x7CDA9 },
	{ 0xF0AA959A, 0x7D2E2 },
	{ 0xF0AA959B, 0x7D2E4 },
	{ 0xF0AA959C, 0x7D2E3 },
	{ 0xF0AA959D, 0x5EFDD },
	{ 0xF0AA959E, 0x5EFDE },
	{ 0xF0AA959F, 0x7CDAB },
	{ 0xF0AA95A1, 0x7D2E5 },
	{ 0xF0AA95A4, 0x5EFDC },
	{ 0xF0AA95A7, 0x7D2E1 },
	{ 0xF0AA95A8, 0x5F3A1 },
	{ 0xF0AA95A9, 0x5F2FE },
	{ 0xF0AA95AA, 0x7D7BE },
	{ 0xF0AA95AB, 0x5F5D7 },
	{ 0xF0AA95AC, 0x7DBB6 },
	{ 0xF0AA95AD, 0x5F5D8 },
	{ 0xF0AA95AE, 0x5F5D9 },
	{ 0xF0AA95AF, 0x5F5D6 },
	{ 0xF0AA95B1, 0x4EABA },
	{ 0xF0AA95B5, 0x7DEC4 },
	{ 0xF0AA95B6, 0x5F7CB },
	{ 0xF0AA95B7, 0x4EBD9 },
	{ 0xF0AA95B8, 0x7DEC8 },
	{ 0xF0AA95B9, 0x4EBD7 },
	{ 0xF0AA95BA, 0x4EBDA },
	{ 0xF0AA95BB, 0x7DEC7 },
	{ 0xF0AA95BD, 0x7DEC6 },
	{ 0xF0AA95BE, 0x7DEC5 },
	{ 0xF0AA95BF, 0x5F8FD },
	{ 0xF0AA9680, 0x4ECE3 },
	{ 0xF0AA9681, 0x5F8FB },
	{ 0xF0AA9682, 0x5F8FA },
	{ 0xF0AA9683, 0x7E0E0 },
	{ 0xF0AA9685, 0x7E1FE },
	{ 0xF0AA9686, 0x7E1FD },
	{ 0xF0AA9687, 0x4EDC9 },
	{ 0xF0AA9688, 0x5F9FD },
	{ 0xF0AA968B, 0x5FBB6 },
	{ 0xF0AA968C, 0x5FBF9 },
	{ 0xF0AA968D, 0x5FBF8 },
	{ 0xF0AA968E, 0x7E5EF },
	{ 0xF0AA968F, 0x7E6A2 },
	{ 0xF0AA9690, 0x4CFD7 },
	{ 0xF0AA9691, 0x7B6F0 },
	{ 0xF0AA9692, 0x7B6F1 },
	{ 0xF0AA9693, 0x7BEF2 },
	{ 0xF0AA9694, 0x7BEF1 },
	{ 0xF0AA9695, 0x5E7C9 },
	{ 0xF0AA9696, 0x7C5FE },
	{ 0xF0AA9697, 0x7C6A1 },
	{ 0xF0AA9698, 0x7C5FD },
	{ 0xF0AA969A, 0x5EBE4 },
	{ 0xF0AA969B, 0x5EBE5 },
	{ 0xF0AA96A1, 0x7D2E6 },
	{ 0xF0AA96A2, 0x5EFDF },
	{ 0xF0AA96A3, 0x5EFE0 },
	{ 0xF0AA96A4, 0x7D2E8 },
	{ 0xF0AA96A5, 0x4E8DB },
	{ 0xF0AA96A6, 0x5F3A2 },
	{ 0xF0AA96A7, 0x7D7BF },
	{ 0xF0AA96A8, 0x7D7C0 },
	{ 0xF0AA96A9, 0x5F3A3 },
	{ 0xF0AA96AA, 0x5F3A4 },
	{ 0xF0AA96AE, 0x7DBB7 },
	{ 0xF0AA96AF, 0x5F7CC },
	{ 0xF0AA96B0, 0x7DEC9 },
	{ 0xF0AA96B3, 0x5F8FC },
	{ 0xF0AA96B4, 0xFEBFE },
	{ 0xF0AA96B5, 0x7E0E1 },
	{ 0xF0AA96B6, 0x5F9FE },
	{ 0xF0AA96B7, 0x5FAA1 },
	{ 0xF0AA96BB, 0x7E3C6 },
	{ 0xF0AA96BC, 0x5FADE },
	{ 0xF0AA96BD, 0x7E3C5 },
	{ 0xF0AA96BE, 0x7E4BC },
	{ 0xF0AA9781, 0x4EED3 },
	{ 0xF0AA9782, 0x5FCB2 },
	{ 0xF0AA9784, 0xFC0B4 },
	{ 0xF0AA9785, 0x4D5E4 },
	{ 0xF0AA9786, 0x4DAE5 },
	{ 0xF0AA9787, 0x7C6A2 },
	{ 0xF0AA9789, 0x4E3A8 },
	{ 0xF0AA978A, 0x7CDAF },
	{ 0xF0AA978B, 0x5EDD7 },
	{ 0xF0AA978C, 0x4E6A4 },
	{ 0xF0AA978D, 0x4EABB },
	{ 0xF0AA978E, 0xFE9B7 },
	{ 0xF0AA978F, 0x5FAA3 },
	{ 0xF0AA9790, 0x5FAA2 },
	{ 0xF0AA9791, 0x7E2A1 },
	{ 0xF0AA9792, 0x7E5AF },
	{ 0xF0AA9794, 0x5E1AE },
	{ 0xF0AA9795, 0x7BEF3 },
	{ 0xF0AA9798, 0x7C6A5 },
	{ 0xF0AA9799, 0x4DFC7 },
	{ 0xF0AA979A, 0x7C6A4 },
	{ 0xF0AA979B, 0x7CDB0 },
	{ 0xF0AA979C, 0x5EBE6 },
	{ 0xF0AA979D, 0x4E3AA },
	{ 0xF0AA979E, 0x7CDB1 },
	{ 0xF0AA979F, 0x7CDB4 },
	{ 0xF0AA97A0, 0x7CDB2 },
	{ 0xF0AA97A1, 0x7CDB3 },
	{ 0xF0AA97A2, 0x7CDB5 },
	{ 0xF0AA97A3, 0x7CDB6 },
	{ 0xF0AA97A4, 0x5EBE7 },
	{ 0xF0AA97A5, 0x7D2EB },
	{ 0xF0AA97A6, 0x5EFE3 },
	{ 0xF0AA97A7, 0x5EFE2 },
	{ 0xF0AA97A8, 0x4E6A8 },
	{ 0xF0AA97A9, 0x7D2E9 },
	{ 0xF0AA97AA, 0x4E6AA },
	{ 0xF0AA97AB, 0x7D2ED },
	{ 0xF0AA97AC, 0x4E6A9 },
	{ 0xF0AA97AD, 0x7D2EE },
	{ 0xF0AA97AF, 0x7D2EA },
	{ 0xF0AA97B2, 0x4C8F8 },
	{ 0xF0AA97B5, 0x7D2EC },
	{ 0xF0AA97B6, 0x7D7C6 },
	{ 0xF0AA97B7, 0x5F3AA },
	{ 0xF0AA97B8, 0x5F3A7 },
	{ 0xF0AA97B9, 0x7D7C3 },
	{ 0xF0AA97BA, 0x7D7C2 },
	{ 0xF0AA97BB, 0x4E8DE },
	{ 0xF0AA97BC, 0x5F3A8 },
	{ 0xF0AA97BD, 0x4E8DF },
	{ 0xF0AA97BE, 0x4E8DD },
	{ 0xF0AA97BF, 0x7D7C4 },
	{ 0xF0AA9880, 0x5F3A5 },
	{ 0xF0AA9881, 0x5F3AB },
	{ 0xF0AA9884, 0x7D7C5 },
	{ 0xF0AA9885, 0x7D7C7 },
	{ 0xF0AA988A, 0x5F3A9 },
	{ 0xF0AA988B, 0x7D7C1 },
	{ 0xF0AA988D, 0x5F3A6 },
	{ 0xF0AA988E, 0x7DBB8 },
	{ 0xF0AA988F, 0x4EABE },
	{ 0xF0AA9890, 0x5F5DC },
	{ 0xF0AA9891, 0x5F5DB },
	{ 0xF0AA9892, 0x5F5DE },
	{ 0xF0AA9893, 0x7DBC0 },
	{ 0xF0AA9894, 0x7DBBF },
	{ 0xF0AA9895, 0x5F5DF },
	{ 0xF0AA9896, 0x7DBBA },
	{ 0xF0AA9897, 0x5F5E0 },
	{ 0xF0AA9898, 0x4EABF },
	{ 0xF0AA989B, 0x7DBB9 },
	{ 0xF0AA989C, 0x5F5DA },
	{ 0xF0AA989F, 0x7DBBB },
	{ 0xF0AA98A0, 0x7DBBD },
	{ 0xF0AA98A1, 0x7DBBE },
	{ 0xF0AA98A2, 0x7DBBC },
	{ 0xF0AA98A4, 0x5F5DD },
	{ 0xF0AA98A5, 0x5F7CF },
	{ 0xF0AA98A6, 0x5F7CE },
	{ 0xF0AA98A7, 0x4EBDE },
	{ 0xF0AA98A8, 0x4EBE2 },
	{ 0xF0AA98A9, 0x4EBE3 },
	{ 0xF0AA98AA, 0x4EBDF },
	{ 0xF0AA98AC, 0x4EBE0 },
	{ 0xF0AA98AD, 0x5F7D0 },
	{ 0xF0AA98AE, 0x7DECE },
	{ 0xF0AA98B0, 0x7DECC },
	{ 0xF0AA98B2, 0x4EBDD },
	{ 0xF0AA98B4, 0x7DECA },
	{ 0xF0AA98B6, 0x7DECB },
	{ 0xF0AA98B7, 0x7DECF },
	{ 0xF0AA98B8, 0x4EBE4 },
	{ 0xF0AA98B9, 0x4ECE7 },
	{ 0xF0AA98BA, 0x5F8FE },
	{ 0xF0AA98BB, 0x7E0E7 },
	{ 0xF0AA98BC, 0x4ECE8 },
	{ 0xF0AA98BD, 0x7E0E5 },
	{ 0xF0AA98BE, 0x5F9A1 },
	{ 0xF0AA98BF, 0x7E2A3 },
	{ 0xF0AA9980, 0x4ECE5 },
	{ 0xF0AA9981, 0x7E0E3 },
	{ 0xF0AA9982, 0x7E0E6 },
	{ 0xF0AA9983, 0x7E0E4 },
	{ 0xF0AA9986, 0x7E0E2 },
	{ 0xF0AA9987, 0x7E0E8 },
	{ 0xF0AA9988, 0x5F9A2 },
	{ 0xF0AA9989, 0x4EDCE },
	{ 0xF0AA998A, 0x4EDCA },
	{ 0xF0AA998B, 0x7E2A5 },
	{ 0xF0AA998C, 0x5FAA6 },
	{ 0xF0AA998D, 0x4EDD0 },
	{ 0xF0AA998E, 0x4EDCD },
	{ 0xF0AA998F, 0x5FAA4 },
	{ 0xF0AA9990, 0x7E2A7 },
	{ 0xF0AA9991, 0x4EDCF },
	{ 0xF0AA9992, 0x7E2A4 },
	{ 0xF0AA9993, 0x7E2A6 },
	{ 0xF0AA9996, 0x7E2A8 },
	{ 0xF0AA9997, 0x7E2A9 },
	{ 0xF0AA9998, 0x7E2A2 },
	{ 0xF0AA9999, 0x5FAA5 },
	{ 0xF0AA999A, 0x7E3C8 },
	{ 0xF0AA999B, 0x5FAE0 },
	{ 0xF0AA999C, 0x7E3C7 },
	{ 0xF0AA999D, 0x5FAE2 },
	{ 0xF0AA999E, 0x5FADF },
	{ 0xF0AA999F, 0x5FAE1 },
	{ 0xF0AA99A3, 0x7E4BE },
	{ 0xF0AA99A4, 0x4EEB2 },
	{ 0xF0AA99A5, 0x7E4BD },
	{ 0xF0AA99A6, 0x5FBB7 },
	{ 0xF0AA99A7, 0x5FBB9 },
	{ 0xF0AA99A9, 0x5FBB8 },
	{ 0xF0AA99AA, 0x7E4C0 },
	{ 0xF0AA99AC, 0x7E4C1 },
	{ 0xF0AA99AE, 0x7E4BF },
	{ 0xF0AA99B0, 0x4EEC6 },
	{ 0xF0AA99B2, 0x7E5B2 },
	{ 0xF0AA99B3, 0x5FBDD },
	{ 0xF0AA99B4, 0x7E5B1 },
	{ 0xF0AA99B5, 0x7E5B0 },
	{ 0xF0AA99B6, 0x7E5D9 },
	{ 0xF0AA99B7, 0x7E5F1 },
	{ 0xF0AA99B8, 0x7E5F2 },
	{ 0xF0AA99B9, 0x5FCAA },
	{ 0xF0AA99BB, 0x7E5F0 },
	{ 0xF0AA99BC, 0x7E5F3 },
	{ 0xF0AA99BD, 0x5FCB3 },
	{ 0xF0AA99BF, 0x7E6A4 },
	{ 0xF0AA9A80, 0x7E6A3 },
	{ 0xF0AA9A81, 0x5FCBB },
	{ 0xF0AA9A82, 0x7E6B2 },
	{ 0xF0AA9A83, 0x5FCBA },
	{ 0xF0AA9A84, 0x7E6B1 },
	{ 0xF0AA9A86, 0x7E6BD },
	{ 0xF0AA9A88, 0x7E6BC },
	{ 0xF0AA9A89, 0x5FCC5 },
	{ 0xF0AA9A8B, 0x7E6C1 },
	{ 0xF0AA9A8C, 0x7E6C8 },
	{ 0xF0AA9A8D, 0x5FCCE },
	{ 0xF0AA9A8E, 0x5FCCD },
	{ 0xF0AA9A91, 0x5EBE8 },
	{ 0xF0AA9A92, 0x7CDB7 },
	{ 0xF0AA9A93, 0x4E3AC },
	{ 0xF0AA9A95, 0x7D2F0 },
	{ 0xF0AA9A96, 0x7D2EF },
	{ 0xF0AA9A97, 0x7CEA4 },
	{ 0xF0AA9A98, 0x5EFE4 },
	{ 0xF0AA9A99, 0x7D7C8 },
	{ 0xF0AA9A9B, 0xFE7BD },
	{ 0xF0AA9A9C, 0x7DBC2 },
	{ 0xF0AA9A9D, 0x7DBC1 },
	{ 0xF0AA9A9E, 0x7DBC3 },
	{ 0xF0AA9A9F, 0x7DBC4 },
	{ 0xF0AA9AA0, 0x5F7D1 },
	{ 0xF0AA9AA5, 0x5FCD1 },
	{ 0xF0AA9AA6, 0x7B6F2 },
	{ 0xF0AA9AA7, 0x7BEF4 },
	{ 0xF0AA9AA8, 0x7C6A6 },
	{ 0xF0AA9AAB, 0x7D7C9 },
	{ 0xF0AA9AAC, 0x5EFE5 },
	{ 0xF0AA9AAD, 0x4E6AB },
	{ 0xF0AA9AAE, 0x5EFE7 },
	{ 0xF0AA9AAF, 0x5EFE6 },
	{ 0xF0AA9AB0, 0x4E6AC },
	{ 0xF0AA9AB1, 0x7D2F3 },
	{ 0xF0AA9AB3, 0x7D2F1 },
	{ 0xF0AA9AB4, 0xFE7BE },
	{ 0xF0AA9AB5, 0x7D2F2 },
	{ 0xF0AA9AB6, 0x5F3AC },
	{ 0xF0AA9AB7, 0x5F3AE },
	{ 0xF0AA9AB8, 0x7D7CB },
	{ 0xF0AA9AB9, 0x5F3AF },
	{ 0xF0AA9ABA, 0x5EBEA },
	{ 0xF0AA9ABB, 0x5F3AD },
	{ 0xF0AA9ABC, 0x7D4AA },
	{ 0xF0AA9ABD, 0x7D7CA },
	{ 0xF0AA9ABE, 0x7CDB9 },
	{ 0xF0AA9ABF, 0x7CDB8 },
	{ 0xF0AA9B80, 0x5FBDE },
	{ 0xF0AA9B81, 0x7E1A9 },
	{ 0xF0AA9B82, 0x5FBBA },
	{ 0xF0AA9B83, 0x5F7D2 },
	{ 0xF0AA9B84, 0x7E4C2 },
	{ 0xF0AA9B86, 0xFEDAD },
	{ 0xF0AA9B88, 0x5FCC2 },
	{ 0xF0AA9B89, 0xFA9A6 },
	{ 0xF0AA9B8A, 0x5F3B0 },
	{ 0xF0AA9B8B, 0x7E2AB },
	{ 0xF0AA9B8D, 0x7E2AA },
	{ 0xF0AA9B8E, 0x5FAE4 },
	{ 0xF0AA9B8F, 0x5FAE3 },
	{ 0xF0AA9B90, 0x7E3CA },
	{ 0xF0AA9B91, 0x7E3C9 },
	{ 0xF0AA9B92, 0x5FBBB },
	{ 0xF0AA9B93, 0x4EEC7 },
	{ 0xF0AA9B94, 0x7E6A5 },
	{ 0xF0AA9B95, 0x4EED6 },
	{ 0xF0AA9B96, 0x7E6CC },
	{ 0xF0AFA080, 0x6A9B6 },
	{ 0xF0AFA081, 0x6A1B1 },
	{ 0xF0AFA082, 0x6A1A1 },
	{ 0xF0AFA083, 0x6A5E6 },
	{ 0xF0AFA084, 0x6A5F2 },
	{ 0xF0AFA085, 0x4A5BD },
	{ 0xF0AFA086, 0x6AEE1 },
	{ 0xF0AFA087, 0xFADE8 },
	{ 0xF0AFA088, 0x6BDB5 },
	{ 0xF0AFA089, 0x6D0DB },
	{ 0xF0AFA08A, 0x4BCB0 },
	{ 0xF0AFA08B, 0x6DAF2 },
	{ 0xF0AFA08C, 0xFD9CD },
	{ 0xF0AFA08D, 0x6A3D2 },
	{ 0xF0AFA08E, 0x3A4D2 },
	{ 0xF0AFA08F, 0x3A7D3 },
	{ 0xF0AFA090, 0xFE7C0 },
	{ 0xF0AFA091, 0x3A7D4 },
	{ 0xF0AFA092, 0x6BDBC },
	{ 0xF0AFA093, 0x7CDBE },
	{ 0xF0AFA094, 0x6A1D0 },
	{ 0xF0AFA095, 0x3A2FB },
	{ 0xF0AFA096, 0x6A3D9 },
	{ 0xF0AFA097, 0x3A1CF },
	{ 0xF0AFA098, 0x6B5C4 },
	{ 0xF0AFA099, 0x4A1BF },
	{ 0xF0AFA09A, 0x6A2BC },
	{ 0xF0AFA09B, 0x3A4C1 },
	{ 0xF0AFA09C, 0x7B6FA },
	{ 0xF0AFA09D, 0x5A1A9 },
	{ 0xF0AFA09E, 0x6A1B8 },
	{ 0xF0AFA09F, 0xFA3B7 },
	{ 0xF0AFA0A0, 0x6A9E3 },
	{ 0xF0AFA0A1, 0x6AEF6 },
	{ 0xF0AFA0A2, 0x6C6E7 },
	{ 0xF0AFA0A3, 0x3C0C3 },
	{ 0xF0AFA0A4, 0xFA2A9 },
	{ 0xF0AFA0A5, 0x6AFA5 },
	{ 0xF0AFA0A6, 0x6B5D8 },
	{ 0xF0AFA0A7, 0x4B6CC },
	{ 0xF0AFA0A8, 0x4A1AF },
	{ 0xF0AFA0A9, 0x6A2C6 },
	{ 0xF0AFA0AA, 0x3A2A5 },
	{ 0xF0AFA0AB, 0x6A2C9 },
	{ 0xF0AFA0AC, 0x3A3A9 },
	{ 0xF0AFA0AD, 0x6AFB8 },
	{ 0xF0AFA0AE, 0x6C6F4 },
	{ 0xF0AFA0AF, 0x6AAA3 },
	{ 0xF0AFA0B0, 0x6AFBD },
	{ 0xF0AFA0B1, 0x6BDD9 },
	{ 0xF0AFA0B2, 0x6BDDA },
	{ 0xF0AFA0B3, 0x3BAA6 },
	{ 0xF0AFA0B4, 0xFA1B3 },
	{ 0xF0AFA0B5, 0x3A4A9 },
	{ 0xF0AFA0B6, 0x6A1E1 },
	{ 0xF0AFA0B7, 0x6A6C3 },
	{ 0xF0AFA0B8, 0x5B1B1 },
	{ 0xF0AFA0B9, 0x6A2DB },
	{ 0xF0AFA0BA, 0x5A1E0 },
	{ 0xF0AFA0BB, 0x3A3BC },
	{ 0xF0AFA0BC, 0x4A3DC },
	{ 0xF0AFA0BD, 0x6A6CE },
	{ 0xF0AFA0BE, 0x4A3DB },
	{ 0xF0AFA0BF, 0x6AABC },
	{ 0xF0AFA181, 0x3B0A3 },
	{ 0xF0AFA182, 0x6B5FE },
	{ 0xF0AFA183, 0x4B0F6 },
	{ 0xF0AFA184, 0x6BDFC },
	{ 0xF0AFA185, 0x6C7AA },
	{ 0xF0AFA186, 0x6C7AC },
	{ 0xF0AFA187, 0x6C7B0 },
	{ 0xF0AFA188, 0x6C7B1 },
	{ 0xF0AFA189, 0x6C7B3 },
	{ 0xF0AFA18A, 0x4BCD0 },
	{ 0xF0AFA18B, 0x6DBDB },
	{ 0xF0AFA18C, 0x6D1B6 },
	{ 0xF0AFA18D, 0x6DBD9 },
	{ 0xF0AFA18E, 0x7A1E0 },
	{ 0xF0AFA18F, 0x7ACE5 },
	{ 0xF0AFA190, 0x3A1FC },
	{ 0xF0AFA191, 0x6A4B3 },
	{ 0xF0AFA192, 0x6B6B5 },
	{ 0xF0AFA193, 0x6BEAC },
	{ 0xF0AFA194, 0x6BEAB },
	{ 0xF0AFA195, 0x3B4F0 },
	{ 0xF0AFA196, 0x4B6F6 },
	{ 0xF0AFA197, 0x6D1CA },
	{ 0xF0AFA198, 0x7A1F6 },
	{ 0xF0AFA199, 0x7C6BE },
	{ 0xF0AFA19A, 0xFA3DB },
	{ 0xF0AFA19B, 0x6D1D7 },
	{ 0xF0AFA19C, 0x5A3E2 },
	{ 0xF0AFA19D, 0x6A4BB },
	{ 0xF0AFA19E, 0x6D1DE },
	{ 0xF0AFA19F, 0x6C7D6 },
	{ 0xF0AFA1A0, 0x6A2E7 },
	{ 0xF0AFA1A1, 0xFAAAB },
	{ 0xF0AFA1A2, 0x6B6CC },
	{ 0xF0AFA1A3, 0x6B6CD },
	{ 0xF0AFA1A4, 0xFAEED },
	{ 0xF0AFA1A5, 0x6BED4 },
	{ 0xF0AFA1A6, 0x6BED0 },
	{ 0xF0AFA1A7, 0x6C7E1 },
	{ 0xF0AFA1A8, 0x6D1E9 },
	{ 0xF0AFA1A9, 0xFC7C6 },
	{ 0xF0AFA1AA, 0x3DAB3 },
	{ 0xF0AFA1AB, 0x7C6D1 },
	{ 0xF0AFA1AC, 0x6A4C8 },
	{ 0xF0AFA1AD, 0x4B1B0 },
	{ 0xF0AFA1AE, 0xFC1AB },
	{ 0xF0AFA1AF, 0x6DCA2 },
	{ 0xF0AFA1B0, 0x3DAB6 },
	{ 0xF0AFA1B1, 0x7E0ED },
	{ 0xF0AFA1B2, 0x6A7A1 },
	{ 0xF0AFA1B3, 0x6B6E7 },
	{ 0xF0AFA1B4, 0x6A4CB },
	{ 0xF0AFA1B5, 0x4A1B4 },
	{ 0xF0AFA1B6, 0x5A8F3 },
	{ 0xF0AFA1B7, 0x6C7FB },
	{ 0xF0AFA1B8, 0x4A1B5 },
	{ 0xF0AFA1B9, 0xFA6E2 },
	{ 0xF0AFA1BA, 0x3ACC0 },
	{ 0xF0AFA1BB, 0x6B0CE },
	{ 0xF0AFA1BC, 0x6C8AB },
	{ 0xF0AFA1BD, 0x6C8B5 },
	{ 0xF0AFA1BE, 0x3C0FE },
	{ 0xF0AFA1BF, 0x6D2B3 },
	{ 0xF0AFA280, 0x6DCBD },
	{ 0xF0AFA281, 0x6A7B6 },
	{ 0xF0AFA282, 0x6DCC9 },
	{ 0xF0AFA283, 0xFA1DF },
	{ 0xF0AFA284, 0x6C8B7 },
	{ 0xF0AFA285, 0x6B7AC },
	{ 0xF0AFA286, 0x6C8BC },
	{ 0xF0AFA287, 0x7ADD3 },
	{ 0xF0AFA288, 0x7ADD5 },
	{ 0xF0AFA289, 0x7E0EE },
	{ 0xF0AFA28A, 0x5A9A7 },
	{ 0xF0AFA28B, 0x6BFC6 },
	{ 0xF0AFA28C, 0x6BFC5 },
	{ 0xF0AFA28D, 0x3B5DF },
	{ 0xF0AFA28E, 0x6D2C0 },
	{ 0xF0AFA28F, 0x5C5DD },
	{ 0xF0AFA290, 0x6A1F4 },
	{ 0xF0AFA291, 0x6A7CA },
	{ 0xF0AFA292, 0x6ABAF },
	{ 0xF0AFA293, 0x6B0F4 },
	{ 0xF0AFA295, 0xFAADD },
	{ 0xF0AFA296, 0x6ABB9 },
	{ 0xF0AFA297, 0x7ADE3 },
	{ 0xF0AFA298, 0x5F3C0 },
	{ 0xF0AFA299, 0x3ACD1 },
	{ 0xF0AFA29A, 0x6BFDE },
	{ 0xF0AFA29B, 0x5ADC8 },
	{ 0xF0AFA29C, 0x3B5E5 },
	{ 0xF0AFA29D, 0x6A7DF },
	{ 0xF0AFA29E, 0xFA4B3 },
	{ 0xF0AFA29F, 0x5A4B8 },
	{ 0xF0AFA2A0, 0x6B1B6 },
	{ 0xF0AFA2A1, 0x6B1B0 },
	{ 0xF0AFA2A2, 0xFAAE7 },
	{ 0xF0AFA2A3, 0x4A9CA },
	{ 0xF0AFA2A4, 0x6C8FC },
	{ 0xF0AFA2A5, 0x6C8F8 },
	{ 0xF0AFA2A6, 0x3C6F0 },
	{ 0xF0AFA2A7, 0x6D2EC },
	{ 0xF0AFA2A8, 0x6D2E6 },
	{ 0xF0AFA2A9, 0x6DDA6 },
	{ 0xF0AFA2AA, 0x6DDA4 },
	{ 0xF0AFA2AB, 0x4C3D1 },
	{ 0xF0AFA2AC, 0x7ADE9 },
	{ 0xF0AFA2AD, 0x7ADF9 },
	{ 0xF0AFA2AE, 0x7A2FB },
	{ 0xF0AFA2AF, 0x3D4E0 },
	{ 0xF0AFA2B0, 0x4DBAC },
	{ 0xF0AFA2B1, 0x7C7A8 },
	{ 0xF0AFA2B2, 0x3A6A7 },
	{ 0xF0AFA2B3, 0x6C0A3 },
	{ 0xF0AFA2B4, 0x5A2EE },
	{ 0xF0AFA2B5, 0x6ABE3 },
	{ 0xF0AFA2B6, 0x6ABE0 },
	{ 0xF0AFA2B7, 0x6B1CF },
	{ 0xF0AFA2B8, 0xFABAB },
	{ 0xF0AFA2B9, 0x6B7F1 },
	{ 0xF0AFA2BA, 0x3B6A8 },
	{ 0xF0AFA2BB, 0x6C0B6 },
	{ 0xF0AFA2BC, 0x6C0AB },
	{ 0xF0AFA2BD, 0x6C9CA },
	{ 0xF0AFA2BE, 0x6C9B0 },
	{ 0xF0AFA2BF, 0xFC1DF },
	{ 0xF0AFA380, 0x7A3B0 },
	{ 0xF0AFA381, 0x6DDB8 },
	{ 0xF0AFA382, 0x5C6AC },
	{ 0xF0AFA383, 0x7A3AD },
	{ 0xF0AFA384, 0xFCFA5 },
	{ 0xF0AFA385, 0x4CAA7 },
	{ 0xF0AFA386, 0x7B8B9 },
	{ 0xF0AFA387, 0xFDEF0 },
	{ 0xF0AFA388, 0x4ADC6 },
	{ 0xF0AFA389, 0x6C9D7 },
	{ 0xF0AFA38A, 0xFDAB6 },
	{ 0xF0AFA38B, 0x3B6C0 },
	{ 0xF0AFA38C, 0x6B8B6 },
	{ 0xF0AFA38E, 0xFC1F2 },
	{ 0xF0AFA38F, 0x6D3BC },
	{ 0xF0AFA390, 0x5C6C1 },
	{ 0xF0AFA391, 0xFABB8 },
	{ 0xF0AFA392, 0x6B1ED },
	{ 0xF0AFA393, 0x6C0D7 },
	{ 0xF0AFA394, 0x6C9F8 },
	{ 0xF0AFA395, 0x6DDDB },
	{ 0xF0AFA396, 0x6ACA3 },
	{ 0xF0AFA397, 0x5A6CA },
	{ 0xF0AFA398, 0x4B2BE },
	{ 0xF0AFA399, 0x6C0D8 },
	{ 0xF0AFA39A, 0x5BFE6 },
	{ 0xF0AFA39B, 0x4A4C7 },
	{ 0xF0AFA39C, 0x6A8AE },
	{ 0xF0AFA39D, 0xFA4D1 },
	{ 0xF0AFA39E, 0x4A6E8 },
	{ 0xF0AFA39F, 0x3ADB5 },
	{ 0xF0AFA3A0, 0x6B8CA },
	{ 0xF0AFA3A1, 0x3B1DC },
	{ 0xF0AFA3A2, 0x4ADDC },
	{ 0xF0AFA3A3, 0x6B8D0 },
	{ 0xF0AFA3A4, 0x5B2FE },
	{ 0xF0AFA3A5, 0x3BCBA },
	{ 0xF0AFA3A6, 0x6D3DE },
	{ 0xF0AFA3A7, 0x5BFF1 },
	{ 0xF0AFA3A8, 0x3C1EE },
	{ 0xF0AFA3A9, 0x6DDE8 },
	{ 0xF0AFA3AA, 0x7A3F2 },
	{ 0xF0AFA3AB, 0xFD4F4 },
	{ 0xF0AFA3AC, 0x7AEEA },
	{ 0xF0AFA3AD, 0x4DFF6 },
	{ 0xF0AFA3AE, 0x7D8A3 },
	{ 0xF0AFA3AF, 0x6A5A3 },
	{ 0xF0AFA3B0, 0x6CABF },
	{ 0xF0AFA3B1, 0x7A3F8 },
	{ 0xF0AFA3B2, 0x7DEF2 },
	{ 0xF0AFA3B3, 0xFC8F9 },
	{ 0xF0AFA3B4, 0x6D3F7 },
	{ 0xF0AFA3B5, 0x4ADE5 },
	{ 0xF0AFA3B6, 0xFB5F4 },
	{ 0xF0AFA3B7, 0x6CACD },
	{ 0xF0AFA3B8, 0x6ACC2 },
	{ 0xF0AFA3B9, 0xFC8FB },
	{ 0xF0AFA3BA, 0x6A5AE },
	{ 0xF0AFA3BB, 0xFA4DD },
	{ 0xF0AFA3BC, 0x6ACDB },
	{ 0xF0AFA3BD, 0x6ACD1 },
	{ 0xF0AFA3BE, 0x3ADD2 },
	{ 0xF0AFA3BF, 0x6B2B9 },
	{ 0xF0AFA480, 0x6B2C2 },
	{ 0xF0AFA481, 0x4AAA5 },
	{ 0xF0AFA482, 0x4ADF0 },
	{ 0xF0AFA483, 0x6B9AD },
	{ 0xF0AFA484, 0x6B8F4 },
	{ 0xF0AFA485, 0x6B9A1 },
	{ 0xF0AFA486, 0xFB0DB },
	{ 0xF0AFA487, 0x3B6F5 },
	{ 0xF0AFA488, 0x6CAE5 },
	{ 0xF0AFA489, 0x6CAE3 },
	{ 0xF0AFA48A, 0x4BEB3 },
	{ 0xF0AFA48B, 0x6D4C9 },
	{ 0xF0AFA48C, 0x6D4CF },
	{ 0xF0AFA48D, 0xFC2F4 },
	{ 0xF0AFA48E, 0x6DEBE },
	{ 0xF0AFA48F, 0x7A4CF },
	{ 0xF0AFA490, 0x7A4D8 },
	{ 0xF0AFA491, 0xFCFE9 },
	{ 0xF0AFA492, 0x7AFC2 },
	{ 0xF0AFA493, 0xFD5D6 },
	{ 0xF0AFA494, 0x4D6DD },
	{ 0xF0AFA495, 0x7CEA8 },
	{ 0xF0AFA496, 0x7D3E0 },
	{ 0xF0AFA497, 0x7D3D8 },
	{ 0xF0AFA498, 0x6ACE0 },
	{ 0xF0AFA499, 0x6ACDD },
	{ 0xF0AFA49A, 0x6B2C8 },
	{ 0xF0AFA49B, 0x4B8E8 },
	{ 0xF0AFA49C, 0xFC3AF },
	{ 0xF0AFA49D, 0x6D4D9 },
	{ 0xF0AFA49E, 0xFD0BD },
	{ 0xF0AFA49F, 0xFD5D8 },
	{ 0xF0AFA4A0, 0x5FBFB },
	{ 0xF0AFA4A1, 0x3D5C5 },
	{ 0xF0AFA4A2, 0x6C1E1 },
	{ 0xF0AFA4A3, 0x6C1E3 },
	{ 0xF0AFA4A4, 0x6C1EA },
	{ 0xF0AFA4A5, 0x6DEDE },
	{ 0xF0AFA4A6, 0x6B2E2 },
	{ 0xF0AFA4A7, 0x6CBC2 },
	{ 0xF0AFA4A8, 0x7C7F5 },
	{ 0xF0AFA4A9, 0x6A2A6 },
	{ 0xF0AFA4AA, 0xFA4F8 },
	{ 0xF0AFA4AB, 0x6ADA4 },
	{ 0xF0AFA4AC, 0xFACB9 },
	{ 0xF0AFA4AD, 0xFB1A8 },
	{ 0xF0AFA4AE, 0x6CBC7 },
	{ 0xF0AFA4AF, 0xFC3E4 },
	{ 0xF0AFA4B0, 0x4C4EE },
	{ 0xF0AFA4B1, 0x7C0E3 },
	{ 0xF0AFA4B2, 0xFE3A4 },
	{ 0xF0AFA4B3, 0x6C2A1 },
	{ 0xF0AFA4B4, 0x3BDBF },
	{ 0xF0AFA4B5, 0x6B2F9 },
	{ 0xF0AFA4B6, 0x4AAC4 },
	{ 0xF0AFA4B7, 0x5B3E5 },
	{ 0xF0AFA4B8, 0x6CBD6 },
	{ 0xF0AFA4B9, 0x4BEEC },
	{ 0xF0AFA4BA, 0x6C2B2 },
	{ 0xF0AFA4BB, 0xFCAAF },
	{ 0xF0AFA4BC, 0x7D3FB },
	{ 0xF0AFA4BD, 0x6ADBA },
	{ 0xF0AFA4BE, 0x5B3F1 },
	{ 0xF0AFA4BF, 0xFD6BC },
	{ 0xF0AFA580, 0x6ADC5 },
	{ 0xF0AFA581, 0x6ADBD },
	{ 0xF0AFA582, 0x6B3BD },
	{ 0xF0AFA583, 0x6B3B1 },
	{ 0xF0AFA584, 0x5AFA6 },
	{ 0xF0AFA585, 0xFACD7 },
	{ 0xF0AFA586, 0x6BAAD },
	{ 0xF0AFA587, 0x6BAAE },
	{ 0xF0AFA588, 0x6C2C8 },
	{ 0xF0AFA589, 0x6CBFA },
	{ 0xF0AFA58A, 0xFD0DF },
	{ 0xF0AFA58B, 0x7B0CA },
	{ 0xF0AFA58C, 0x6A5BF },
	{ 0xF0AFA58D, 0x6ADC6 },
	{ 0xF0AFA58E, 0x3C3B3 },
	{ 0xF0AFA58F, 0x6D5EB },
	{ 0xF0AFA590, 0x7A5FB },
	{ 0xF0AFA591, 0x7B9ED },
	{ 0xF0AFA592, 0xFA8BC },
	{ 0xF0AFA593, 0x6B3CA },
	{ 0xF0AFA594, 0xFBDE0 },
	{ 0xF0AFA595, 0x4CBE0 },
	{ 0xF0AFA596, 0x7A6A7 },
	{ 0xF0AFA597, 0x6BAC3 },
	{ 0xF0AFA599, 0x4C5DF },
	{ 0xF0AFA59A, 0x4D2A1 },
	{ 0xF0AFA59B, 0x7B0E6 },
	{ 0xF0AFA59C, 0x6DFF5 },
	{ 0xF0AFA59D, 0x7A6BE },
	{ 0xF0AFA59E, 0x7A6BC },
	{ 0xF0AFA59F, 0x7B0F3 },
	{ 0xF0AFA5A0, 0xFCAFB },
	{ 0xF0AFA5A1, 0x6E0A3 },
	{ 0xF0AFA5A2, 0xFD1A3 },
	{ 0xF0AFA5A3, 0x7A6CD },
	{ 0xF0AFA5A4, 0x7C1BC },
	{ 0xF0AFA5A5, 0x5ECFD },
	{ 0xF0AFA5A6, 0x7B1AD },
	{ 0xF0AFA5A7, 0x7BAB3 },
	{ 0xF0AFA5A8, 0x4DCD9 },
	{ 0xF0AFA5A9, 0x7C1C4 },
	{ 0xF0AFA5AA, 0x3AED6 },
	{ 0xF0AFA5AB, 0x6B3E6 },
	{ 0xF0AFA5AC, 0x3C8EA },
	{ 0xF0AFA5AD, 0xFD1B7 },
	{ 0xF0AFA5AE, 0x7A6EA },
	{ 0xF0AFA5AF, 0x7A6E9 },
	{ 0xF0AFA5B0, 0x4E4A6 },
	{ 0xF0AFA5B1, 0x7E2CD },
	{ 0xF0AFA5B2, 0x6CCF2 },
	{ 0xF0AFA5B3, 0x7BAC6 },
	{ 0xF0AFA5B4, 0xFBEB2 },
	{ 0xF0AFA5B5, 0x7BAC9 },
	{ 0xF0AFA5B6, 0x7C8ED },
	{ 0xF0AFA5B7, 0x7DFBC },
	{ 0xF0AFA5B8, 0x6CDA3 },
	{ 0xF0AFA5B9, 0xFD7A7 },
	{ 0xF0AFA5BA, 0x4ABA6 },
	{ 0xF0AFA5BB, 0x7A7A8 },
	{ 0xF0AFA5BC, 0xFD7A8 },
	{ 0xF0AFA5BD, 0x6E0DD },
	{ 0xF0AFA5BE, 0x5C8F4 },
	{ 0xF0AFA5BF, 0xFDCAD },
	{ 0xF0AFA680, 0x6A8FB },
	{ 0xF0AFA681, 0x4A7E8 },
	{ 0xF0AFA682, 0x6ADE9 },
	{ 0xF0AFA683, 0x3B3D0 },
	{ 0xF0AFA684, 0x5BBD0 },
	{ 0xF0AFA685, 0x6CDC8 },
	{ 0xF0AFA686, 0xFC4E8 },
	{ 0xF0AFA687, 0xFCBD7 },
	{ 0xF0AFA688, 0xFCBD6 },
	{ 0xF0AFA689, 0x4CCD6 },
	{ 0xF0AFA68A, 0x4D8AD },
	{ 0xF0AFA68B, 0x4B4D7 },
	{ 0xF0AFA68C, 0x6CDDE },
	{ 0xF0AFA68D, 0x3C4A5 },
	{ 0xF0AFA68E, 0x6E1A5 },
	{ 0xF0AFA68F, 0x3A7AA },
	{ 0xF0AFA690, 0x6A5D2 },
	{ 0xF0AFA691, 0x6A9A7 },
	{ 0xF0AFA692, 0xFA8DC },
	{ 0xF0AFA693, 0x6A9A8 },
	{ 0xF0AFA695, 0x6AEA2 },
	{ 0xF0AFA696, 0x6AEA3 },
	{ 0xF0AFA697, 0x6B4C4 },
	{ 0xF0AFA698, 0x6AEA4 },
	{ 0xF0AFA699, 0x6BBD2 },
	{ 0xF0AFA69A, 0xFB2BA },
	{ 0xF0AFA69B, 0x4B4F3 },
	{ 0xF0AFA69C, 0x6C4AB },
	{ 0xF0AFA69D, 0x4B4F4 },
	{ 0xF0AFA69E, 0x6C3F6 },
	{ 0xF0AFA69F, 0x6C4BB },
	{ 0xF0AFA6A0, 0x4BAE6 },
	{ 0xF0AFA6A1, 0x6C4BE },
	{ 0xF0AFA6A2, 0x6C4BC },
	{ 0xF0AFA6A3, 0x6C4BD },
	{ 0xF0AFA6A4, 0x6CEBB },
	{ 0xF0AFA6A5, 0x6E1BE },
	{ 0xF0AFA6A6, 0x6E1CF },
	{ 0xF0AFA6A7, 0xFD1E4 },
	{ 0xF0AFA6A8, 0x4CCF9 },
	{ 0xF0AFA6A9, 0x7A7E1 },
	{ 0xF0AFA6AA, 0x7A7ED },
	{ 0xF0AFA6AB, 0x7B2C4 },
	{ 0xF0AFA6AC, 0xFD7C7 },
	{ 0xF0AFA6AD, 0x7BAEF },
	{ 0xF0AFA6AE, 0xFE0DD },
	{ 0xF0AFA6AF, 0x7C2BC },
	{ 0xF0AFA6B0, 0x7D4DE },
	{ 0xF0AFA6B1, 0x4E7AB },
	{ 0xF0AFA6B3, 0x6B4C7 },
	{ 0xF0AFA6B4, 0x4C0CF },
	{ 0xF0AFA6B5, 0x7BBB8 },
	{ 0xF0AFA6B6, 0x3DBA6 },
	{ 0xF0AFA6B7, 0x6BBF1 },
	{ 0xF0AFA6B8, 0x4BAF5 },
	{ 0xF0AFA6B9, 0x6CEC6 },
	{ 0xF0AFA6BA, 0x4C6FC },
	{ 0xF0AFA6BB, 0x4CDB3 },
	{ 0xF0AFA6BC, 0xFD2A4 },
	{ 0xF0AFA6BD, 0x7A8AE },
	{ 0xF0AFA6BE, 0xFD1FD },
	{ 0xF0AFA6BF, 0x7C2E0 },
	{ 0xF0AFA780, 0x7C2DF },
	{ 0xF0AFA781, 0x3DBAD },
	{ 0xF0AFA782, 0x4E4BF },
	{ 0xF0AFA783, 0x4D3CC },
	{ 0xF0AFA784, 0x6A5D3 },
	{ 0xF0AFA785, 0x5B0BE },
	{ 0xF0AFA786, 0x6D8AE },
	{ 0xF0AFA787, 0x6D8AC },
	{ 0xF0AFA788, 0xFC5BD },
	{ 0xF0AFA789, 0x7BBE1 },
	{ 0xF0AFA78A, 0xFB8CA },
	{ 0xF0AFA78B, 0x5FAB8 },
	{ 0xF0AFA78C, 0x6BCAD },
	{ 0xF0AFA78D, 0x4B5C5 },
	{ 0xF0AFA78E, 0xFBFBB },
	{ 0xF0AFA78F, 0x6E2C7 },
	{ 0xF0AFA790, 0x7B3CF },
	{ 0xF0AFA791, 0x7D9C1 },
	{ 0xF0AFA792, 0x6A9AA },
	{ 0xF0AFA793, 0x6D8D0 },
	{ 0xF0AFA795, 0x6D8DC },
	{ 0xF0AFA796, 0x3E0FC },
	{ 0xF0AFA797, 0x6BCBB },
	{ 0xF0AFA798, 0x7B3F9 },
	{ 0xF0AFA799, 0x7B3F3 },
	{ 0xF0AFA79A, 0xFBFD3 },
	{ 0xF0AFA79B, 0x3C4ED },
	{ 0xF0AFA79C, 0x7A9C4 },
	{ 0xF0AFA79D, 0x6B4DD },
	{ 0xF0AFA79E, 0x4B0AC },
	{ 0xF0AFA79F, 0x7B4B1 },
	{ 0xF0AFA7A0, 0x4D4B7 },
	{ 0xF0AFA7A1, 0x7BCE1 },
	{ 0xF0AFA7A2, 0x6A5DB },
	{ 0xF0AFA7A3, 0x4B5F2 },
	{ 0xF0AFA7A4, 0x6D9C7 },
	{ 0xF0AFA7A5, 0x6D9CA },
	{ 0xF0AFA7A6, 0x7BCEB },
	{ 0xF0AFA7A7, 0xFC5F3 },
	{ 0xF0AFA7A8, 0x6E3D3 },
	{ 0xF0AFA7A9, 0x6E3CF },
	{ 0xF0AFA7AA, 0x4D4CA },
	{ 0xF0AFA7AB, 0xFE6DE },
	{ 0xF0AFA7AC, 0x7D0EB },
	{ 0xF0AFA7AD, 0xFECBF },
	{ 0xF0AFA7AE, 0x6E3D8 },
	{ 0xF0AFA7AF, 0x7B4FA },
	{ 0xF0AFA7B0, 0x7B4F1 },
	{ 0xF0AFA7B1, 0xFE1CA },
	{ 0xF0AFA7B2, 0x6D0A2 },
	{ 0xF0AFA7B3, 0x6E3EE },
	{ 0xF0AFA7B4, 0x7B5B5 },
	{ 0xF0AFA7B5, 0x3D6F8 },
	{ 0xF0AFA7B6, 0x5DFDE },
	{ 0xF0AFA7B7, 0x7BDD0 },
	{ 0xF0AFA7B8, 0xFD8F8 },
	{ 0xF0AFA7B9, 0x7CBDF },
	{ 0xF0AFA7BA, 0x4E5AA },
	{ 0xF0AFA7BB, 0x7CBEB },
	{ 0xF0AFA7BC, 0x5BDC7 },
	{ 0xF0AFA7BD, 0x5C4B5 },
	{ 0xF0AFA7BE, 0x6DAB3 },
	{ 0xF0AFA7BF, 0x6E4B0 },
	{ 0xF0AFA880, 0x4D9F6 },
	{ 0xF0AFA881, 0x6E4BA },
	{ 0xF0AFA882, 0x6BCF7 },
	{ 0xF0AFA883, 0x6DABD },
	{ 0xF0AFA884, 0x4D5A3 },
	{ 0xF0AFA885, 0x4DEE0 },
	{ 0xF0AFA886, 0x6E4D0 },
	{ 0xF0AFA887, 0x7BEA9 },
	{ 0xF0AFA888, 0x7ABD5 },
	{ 0xF0AFA889, 0xFD9B2 },
	{ 0xF0AFA88A, 0x7D1FA },
	{ 0xF0AFA88B, 0x7DAE0 },
	{ 0xF0AFA88C, 0x4DAD9 },
	{ 0xF0AFA88D, 0x7C5E5 },
	{ 0xF0AFA88E, 0x4DFB7 },
	{ 0xF0AFA88F, 0x4E2EE },
	{ 0xF0AFA890, 0x7D2C5 },
	{ 0xF0AFA891, 0x5F5B6 },
	{ 0xF0AFA892, 0x5F5B5 },
	{ 0xF0AFA893, 0xFECF7 },
	{ 0xF0AFA894, 0x7BEDC },
	{ 0xF0AFA895, 0x6C6BE },
	{ 0xF0AFA896, 0x4E8CF },
	{ 0xF0AFA897, 0x6DAE0 },
	{ 0xF0AFA898, 0x4A8B4 },
	{ 0xF0AFA899, 0x3DCAF },
	{ 0xF0AFA89A, 0x5D3D1 },
	{ 0xF0AFA89B, 0x7CDA8 },
	{ 0xF0AFA89C, 0x4C8F7 },
	{ 0xF0AFA89D, 0x7DECD }
};

#endif	/* _KERNEL */

#ifdef __cplusplus
}
#endif

#endif	/* _SYS_KICONV_UTF8_EUCTW_H */
